<?php
/*
	Plugin Name: WPJobster Affiliate
	Plugin URL: http://wpjobster.com/
	Description: WPJobster Affiliate System.
	Version: 2.0.2
	Author: WPJobster
	Author URI: http://wpjobster.com/
*/

define( 'WPJOBSTER_AFFILIATE_PLUGIN_VERSION', '2.0.2' );
define( 'WPJOBSTER_AFFILIATE_PLUGIN_FILE', __FILE__ );

// INCLUDE CLASS FOR CREATING LICENSE TAB
function wpjobster_referral_include_updater_class(){
	if( !class_exists( 'WPJ_Plugin_License' ) ) {
		include( plugin_dir_path( __FILE__ ) . 'updater/plugin-updater.php' );
	}
	$wpj_invoices_license = new WPJ_Plugin_License(
		array(
			'file'       => __FILE__,
			'item_name'  => 'Affiliate',
			'version'    => '2.0.2',
			'author'     => 'WPJobster',
			'api_url'    => 'http://wpjobster.com',
			'short_slug' => 'affiliate',
			'full_slug'  => 'wpjobster_affiliate',
			'textdomain' => 'wpjobster-affiliate'
		)
	);
}
add_action( 'init','wpjobster_referral_include_updater_class' );

/* INCLUDE STYLES AND SCRIPTS */
add_action('admin_enqueue_scripts', 'wpjobster_referral_user_load_scripts');
add_action('wp_enqueue_scripts', 'wpjobster_referral_user_load_scripts');
function wpjobster_referral_user_load_scripts() {
	wp_enqueue_script( 'main-scripts', plugins_url( 'assets/js/scripts.js', __FILE__ ), array() );
	wp_enqueue_style( 'main-styles', plugins_url( 'assets/css/style.css', __FILE__ ), array() );
}

/* GET PLUGIN SLUG */
function get_referral_plugin_slug() {
	return 'wpjobster_affiliate';
}

/* GET MENU URL */
function get_referral_menu_url() {
	return menu_page_url( get_referral_plugin_slug(), false );
}

/* GET PLUGIN ADDRESS */
function get_plugin_address(){
	return plugin_dir_url( __FILE__ );
}

/* LOAD TRANSLATIONS */
add_action( 'plugins_loaded', 'wpjobster_load_affiliate_plugin_textdomain' );
function wpjobster_load_affiliate_plugin_textdomain() {
	load_plugin_textdomain( 'wpjobster-affiliate', false, plugin_dir_url(__FILE__) . '/languages' );
}

/* ADD SETTINGS LINK */
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'wpjobster_referral_user_action_links' );
function wpjobster_referral_user_action_links ( $links ) {
	$mylinks = array(
		'<a href="' . get_referral_menu_url( get_referral_plugin_slug(), false ) . '">' . __('Settings', 'wpjobster-affiliate') . '</a>',
	);
return array_merge( $links, $mylinks );
}

/* INCLUDE PLUGIN PAGE IN JOBSTER MENU */
add_action('admin_menu', 'wpjobster_referral_user_create_menu', 12);
function wpjobster_referral_user_create_menu() {
	add_submenu_page( 'PT1_admin_mnu', __('WPJobster Affiliate','wpjobster-affiliate'), '<img style="width: 20px; height: 20px;" src="' . get_plugin_address() . 'assets/images/ref.png"> ' . __('Affiliate','wpjosbter'), 'manage_options', get_referral_plugin_slug(), 'wpjobster_affiliate_plugin_settings_page');
}

add_action('admin_bar_menu', 'wpjobster_referral_user_in_admin_bar', 999);
function wpjobster_referral_user_in_admin_bar( $wp_admin_bar ) {
	$wp_admin_bar->add_node( array(
		'id'     => 'wpjobster_affiliate',
		'parent' => 'PT1_admin_mnu',
		'title' => __( 'Affiliate', 'wpjobster-affiliate' ),
		'href'  => get_admin_url() . 'admin.php?page=wpjobster_affiliate',
		'meta'  => array(
			'title' => __( 'WPJobster Affiliate', 'wpjobster-affiliate' )
		),
	));
}

/* GET USER IP */
function wpjobster_get_user_ip(){
	$ip = "";
	if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}
	return $ip;
}

/* CONTENT OF PLUGIN PAGE FROM TOOLS MENU */
include('front-admin-page.php');

/* GENERATE AFFILIATE KEY */
function wpj_generate_affiliate_key( $uid, $name = false, $email = false ) {
	if ( ! $name === false || $email === false ) {
		$user = get_userdata( $uid );
		$name = $user->user_login;
		$email = $user->user_email;
	}
	$key = md5( $id . $name . $email );
	return $key;
}

function wpj_get_affiliate_key( $uid ) {
	$key = get_user_meta( $uid, 'wpjobster_affiliate_key', true );
	if ( ! $key ) {
		$key = wpj_generate_affiliate_key( $uid );
		update_user_meta( $uid, 'wpjobster_affiliate_key', $key );
	}
	return $key;
}

function wpj_get_affiliate_id_by_key( $key_value ) {
	$users = get_users( array(
		'meta_key' => 'wpjobster_affiliate_key',
		'meta_value' => array( $key_value )
	) );

	if ( isset( $users[0] ) ) {
		return $users[0]->ID;
	} else {
		return false;
	}
}

/* EXPIRE TIME FOR COOKIES */
function cookie_expire_time(){
	$cookie_life_day     = get_option('cookie_life_day');

	$seconds_in_seconds = 1;
	$minute_in_seconds  = 60;
	$hour_in_seconds    = 60 * 60;
	$day_in_seconds     = 60 * 60 * 24;
	$week_in_seconds    = 60 * 60 * 24 * 7;
	$month_in_seconds   = 60 * 60 * 24 * 30;
	$year_in_seconds    = 60 * 60 * 24 * 365;

	$time = time();

	if(!empty($cookie_life_day))
		$time += (intval($cookie_life_day) * intval($day_in_seconds));
	else
		$time += (30 * intval($day_in_seconds));

	return $time;
}

/* CREATE SHORTCODE - DISPLAY USER REFERRAL LINK */
// add_shortcode('user_referral_link', 'display_referral_link');
function display_referral_link() {
	if ( is_user_logged_in() ) {
		$current_user      = wp_get_current_user();
		$user_id           = $current_user->ID;
		$user_referral_link = wpj_get_affiliate_key( $user_id );

		$output = "";
		$output .= '<div class="referral-link-box">';
			$output .= '<h4 class="referral-link-title referral-link-icon"><p class="lighter">'. __("My referral link: ","wpjobster-affiliate") . '<b>' . get_site_URL().'/?ref='.$user_referral_link.'</b></p></h4>';
			$output .= '<div class="share-via">';
				$output .= '<a target="_blank" href="http://www.facebook.com/sharer.php?u='.get_site_URL()."/?ref=".$user_referral_link.'"><img src="'.get_plugin_address().'assets/images/viaFacebook.png" /></a>';
				$output .= '<a href="http://twitter.com/share?text=My%20referral%20link&url='.get_site_URL()."/?ref=".$user_referral_link.'"><img src="'.get_plugin_address().'assets/images/viaTwitter.png" /></a>';
				$output .= '<a href="mailto:?subject=I wanted you to see this site&amp;body=Check out this site '.get_site_URL()."/?ref=".$user_referral_link.'"
				title="Share via Email"><img src="'.get_plugin_address().'assets/images/viEmail.png" /></a>';
			$output .= '</div>';
		$output .= '</div>';
		return $output;
	}else{
		return;
	}
}


add_shortcode( 'referral_url', 'wpj_af_referral_url' );
function wpj_af_referral_url() {
	if ( is_user_logged_in() ) {
		$current_user = wp_get_current_user();
		$user_id      = $current_user->ID;
		$referral_key = wpj_get_affiliate_key( $user_id );
		$output       = get_site_URL() . '/?ref=' . $referral_key;

		return $output;
	} else {
		return get_site_URL();
	}
}



/* CREATE SHORTCODE - REFERRAL URL GENERATOR */
add_shortcode('referral_url_generator', 'display_referral_url_generator');
function display_referral_url_generator() {
	if ( is_user_logged_in() ) {
		$current_user = wp_get_current_user();
		$user_id      = $current_user->ID;
		$referral_key = wpj_get_affiliate_key( $user_id );
		$output       = "";

		$output .= '<div class="ui form">';
			$output .= '<form method="POST">';
				$output .= '<br />';
				$output .= '<p class="lighter">'.__('Your affiliate ID is','wpjobster-affiliate').': <b>' . $referral_key . '</b></p>';
				$output .= '<p class="lighter">'.__('Your referral URL is','wpjobster-affiliate').': <b>' . get_site_URL().'/?ref='.$referral_key . '</b></p>';
				$output .= '<br />';
				$output .= '<p class="lighter">'.__('Enter any URL from this website in the form below to generate a referral link!','wpjobster-affiliate').'</p>';
				$output .= '<br />';
				$output .= '<label><b>'.__('Landing page link','wpjobster-affiliate').':</b></label>';
				$output .= '<div class="field">';
					$output .= '<input type="text" class="page_url" name="page_url" id="page_url" />';
				$output .= '</div>';
				$output .= '<div class="field">';
					$output .= '<input class="ui primary button btn btn-front page_url_submit" name="generate" type="submit" value="'.__("Generate URL",'wpjobster-affiliate').'" />';
				$output .= '</div>';

			$output .= '</form>';

			if(isset($_POST['generate'])){
				if(isset($_POST['page_url']) && $_POST['page_url'] != ""){
					$page_url = $_POST['page_url'];
				}else{
					$page_url = get_site_URL();
				}
				$newaddrress = add_query_arg( 'ref', $referral_key, $page_url );
				$output .= '<br />';
				$output .= "<label><b>".__('Your new referral link','wpjobster-affiliate').":</b></label>" . '<input type="text" class="result_url" name="result_url" id="result_url" value="' . $newaddrress . '" />';
			}
		$output .= '</div>';

		return $output;
	}
}

/* CREATE SHORTCODE - ONLY REFERRAL URL */
add_shortcode('referral_url', 'display_referral_url');
function display_referral_url() {
	if ( is_user_logged_in() ) {
		$current_user = wp_get_current_user();
		$user_id      = $current_user->ID;
		$referral_key = wpj_get_affiliate_key( $user_id );

		$output = get_site_URL().'/?ref='.$referral_key;
		return $output;
	}
}

/* REGISTER FROM GENERATED URL */
add_action( 'init', 'register_by_generated_url' );
function register_by_generated_url(){
	if(isset($_GET['ref'])){
		$referral_key            = $_GET['ref'];
		$expire_time            = cookie_expire_time();

		if (isset($_COOKIE['referral_key'])) {
			unset($_COOKIE['referral_key']);
			setcookie("referral_key", $referral_key, $expire_time, "/");
		} else {
			setcookie("referral_key", $referral_key, $expire_time, "/");
		}
	}

	if ( is_user_logged_in() ) {
		$current_user = wp_get_current_user();
		$user_id      = $current_user->ID;
		if (isset($_COOKIE['referral_key']) && get_user_meta_transient($user_id, 'referral_key_cookie') != $_COOKIE['referral_key']) {
			set_user_meta_transient($user_id, 'referral_key_cookie', $_COOKIE['referral_key'], cookie_expire_time());
		}
	}

	if(isset($_GET['ref'])){
		$base_url     = ( is_ssl() ? 'https' : 'http' ) . '://' .  $_SERVER['HTTP_HOST'];
		$full_url     = $base_url . $_SERVER["REQUEST_URI"];
		$url_no_param = remove_query_arg( 'ref', $full_url );

		if ( is_user_logged_in() ) {
			$current_user = wp_get_current_user();
			$user_id      = $current_user->ID;
			set_user_meta_transient($user_id, 'referral_key_cookie', $referral_key, $expire_time);
		}

		/* GET USER IP */
		$ip      = wpjobster_get_user_ip();
		$user_ip = array($ip);

		$cash_referral_ip_select = get_option('cash_referral_ip_select');
		$cash_referral_ip_input  = get_option('cash_referral_ip_input');

		$user_id = wpj_get_affiliate_id_by_key( $referral_key );

		if ( $user_id ) {

			/* CHECK IF IP EXIST */
			$ip_lists    = get_user_meta ($user_id, 'wpjobster_referral_user_ip', true );
			$count_click = get_user_meta ($user_id, 'wpjobster_referral_user_clicks', true );

			if(is_array($ip_lists)){
				if (!in_array($ip, $ip_lists)){
					array_push($ip_lists, $ip);
					update_user_meta( $user_id, 'wpjobster_referral_user_ip', $ip_lists );
					update_user_meta( $user_id, 'wpjobster_referral_user_clicks', $count_click + 1 );
					if($cash_referral_ip_select == "yes"){
						$cr        = wpjobster_get_credits($user_id);
						wpjobster_update_credits($user_id, $cr + $cash_referral_ip_input);
						$reason    = __('Payment received from Affiliate System', 'wpjobster-affiliate');
						wpjobster_add_history_log('1', $reason, $cash_referral_ip_input ,$user_id, '', '', 15, '');
						$reason_id = 1;
						$reason    = wpjobster_text_reason($reason_id);
						wpjobster_add_affiliate_log($user_id, '', $reason_id, $reason, $cash_referral_ip_input);
					}
				}
			}else{
				update_user_meta( $user_id, 'wpjobster_referral_user_ip', $user_ip );
				update_user_meta( $user_id, 'wpjobster_referral_user_clicks', $count_click + 1 );
				if($cash_referral_ip_select == "yes"){
					$cr        = wpjobster_get_credits($user_id);
					wpjobster_update_credits($user_id, $cr + $cash_referral_ip_input);
					$reason    = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $cash_referral_ip_input ,$user_id, '', '', 15, '');
					$reason_id = 1;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($user_id, '', $reason_id, $reason, $cash_referral_ip_input);
				}
			}
		}
		wp_redirect( $url_no_param );
		exit;
	}
}

/* CREATE DATABASE TABLE */
register_activation_hook( __FILE__, 'create_affiliate_table' );
function create_affiliate_table () {
	global $wpdb;
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

	global $charset_collate;
	$charset_collate = $wpdb->get_charset_collate();

	$create_job_affiliate_transactions = "
		CREATE TABLE {$wpdb->prefix}job_affiliate_transactions (
		  id int(11) NOT NULL AUTO_INCREMENT,
		  user_id int(11) NOT NULL,
		  referral_id int(11) NOT NULL,
		  reason text NOT NULL,
		  reason_id int(11) NOT NULL,
		  amount float NOT NULL,
		  payedamount varchar(50) NOT NULL,
		  date int(11) NOT NULL,
		  PRIMARY KEY  (id)
		) $charset_collate;
	";
	dbDelta( $create_job_affiliate_transactions );
}

/* REGISTER BY REFERRAL */
add_action('register_form', 'wpjobster_register_by_referral');
add_action('zm_ajax_login_register_below_email_field', 'wpjobster_register_by_referral' );
if(get_option('wsl_settings_bouncer_profile_completion_hook_extra_fields') != 1){
	add_action('add_new_fields', 'wpjobster_user_type_add_custom_registration_form' );
}
function wpjobster_register_by_referral(){
	$cash_referral_register_select = get_option('cash_referral_register_select');
	$cash_referral_register_input  = get_option('cash_referral_register_input');
	if(isset($_COOKIE['referral_key'])){
		echo '<input type="hidden" name="ref_id_val" value="'.$_COOKIE['referral_key'].'" />';
	}
}

/* ALLOW OR NOT ALLOW MANY ACCOUNTS */
function many_ips_account_or_not($user_id){
	$cash_referral_register_input = get_option('cash_referral_register_input');

	$referral_key      = $_POST['ref_id_val'];
	$based_user_id     = wpj_get_affiliate_id_by_key( $referral_key );
	$referral_list     = array( $user_id );
	$referral_all_list = get_user_meta( $based_user_id, 'wpjobster_referral_user_list', true );

	$cash_referral_register_select = get_option('cash_referral_register_select');

	if ( $based_user_id ) {
		if(is_array($referral_all_list)){
			if (!in_array($user_id, $referral_all_list)){
				array_push($referral_all_list, $user_id);
				update_user_meta($based_user_id, 'wpjobster_referral_user_list', $referral_all_list);
				update_user_meta($user_id, 'wpjobster_my_referral_user_id', $based_user_id);
				$cr        = wpjobster_get_credits($based_user_id);
				if(isset($cash_referral_register_select) && $cash_referral_register_select == "yes"){
					wpjobster_update_credits($based_user_id, $cr + $cash_referral_register_input);
					$reason    = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $cash_referral_register_input ,$based_user_id, '', '', 15, '');
					$reason_id = 2;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($based_user_id, $user_id, $reason_id, $reason, $cash_referral_register_input);
				}
			}
		}else{
			update_user_meta($based_user_id, 'wpjobster_referral_user_list', $referral_list);
			update_user_meta($user_id, 'wpjobster_my_referral_user_id', $based_user_id);
			$cr        = wpjobster_get_credits($based_user_id);
			if(isset($cash_referral_register_select) && $cash_referral_register_select == "yes"){
				wpjobster_update_credits($based_user_id, $cr + $cash_referral_register_input);
				$reason    = __('Payment received from Affiliate System', 'wpjobster-affiliate');
				wpjobster_add_history_log('1', $reason, $cash_referral_register_input ,$based_user_id, '', '', 15, '');
				$reason_id = 2;
				$reason    = wpjobster_text_reason($reason_id);
				wpjobster_add_affiliate_log($based_user_id, $user_id, $reason_id, $reason, $cash_referral_register_input);
			}
		}
	}
}

/* SAVE REGISTER BY REFERRAL */
add_action('user_register', 'wpjobster_save_register_by_referral', 10, 1 );
add_action('zm_ajax_login_after_successfull_registration', 'wpjobster_save_register_by_referral');
function wpjobster_save_register_by_referral( $user_id ){
	$many_ips_account              = get_option('many_ips_account');

	$cash_referral_register_select = get_option('cash_referral_register_select');

	if(isset($_POST['ref_id_val'])){

		$referral_key  = $_POST['ref_id_val'];
		$based_user_id = wpj_get_affiliate_id_by_key( $referral_key );

		if ( $based_user_id ) {
			$ip            = wpjobster_get_user_ip();
			$user_ip       = array($ip);
			$ip_lists      = get_user_meta ($based_user_id, 'wpjobster_referral_user_up_registered', true );
			if(!is_array($ip_lists)){
				update_user_meta( $based_user_id, 'wpjobster_referral_user_up_registered', array() );
				$ip_lists = get_user_meta ($based_user_id, 'wpjobster_referral_user_up_registered', true );
			}

			array_push($ip_lists, $ip);
			update_user_meta( $based_user_id, 'wpjobster_referral_user_up_registered', $ip_lists );

			if(isset($many_ips_account) && $many_ips_account == "yes"){
				many_ips_account_or_not($user_id);
			}else{
				if (!in_array($ip, $ip_lists)){
					many_ips_account_or_not($user_id);
				}
			}
		}
	}
}

/* REFERRAL FIRST JOB */
add_action('wpjobster_new_job_completed','wpjobster_affiliate_first_job', 10, 2);
function wpjobster_affiliate_first_job($uid, $pid){
	$cash_referral_first_job_select = get_option('cash_referral_first_job_select');
	$cash_referral_first_job_input  = get_option('cash_referral_first_job_input');
	if(isset($cash_referral_first_job_select) && $cash_referral_first_job_select == "yes"){
		$my_referral           = get_user_meta ($uid, 'wpjobster_my_referral_user_id', true );
		$referral_user_nr_jobs = get_user_meta ($uid, 'referral_user_nr_jobs', true );

		if($my_referral && $my_referral != ''){
			if($referral_user_nr_jobs != '1'){
				$cr        = wpjobster_get_credits($my_referral);
				wpjobster_update_credits($my_referral, $cr + $cash_referral_first_job_input);
				update_user_meta($uid, 'referral_user_nr_jobs', '1');
				$reason    = __('Payment received from Affiliate System', 'wpjobster-affiliate');
				wpjobster_add_history_log('1', $reason, $cash_referral_first_job_input ,$my_referral, '', '', 15, '');
				$reason_id = 3;
				$reason    = wpjobster_text_reason($reason_id);
				wpjobster_add_affiliate_log($my_referral, $uid, $reason_id, $reason, $cash_referral_first_job_input);
			}
		}
	}
}

/* REFERRAL BUYING A JOB */
add_action('wpjobster_job_payment_completed','wpjobster_affiliate_job_purchase', 10, 1);
function wpjobster_affiliate_job_purchase( $orderid ) {

	// order info
	$order     = wpjobster_get_order( $orderid );
	$job_price = $order->mc_gross;
	$buyer_id  = wpj_get_buyer_id( $orderid );
	$seller_id = wpj_get_seller_id( $orderid );

	// affiliate id from registration
	$affiliate_id = get_user_meta( $buyer_id, 'wpjobster_my_referral_user_id', true );

	// affiliate id from cookie
	$referral_key_cookie = get_user_meta_transient( $buyer_id, 'referral_key_cookie' );

	if ( $referral_key_cookie ) {
		$affiliate_id_cookie = wpj_get_affiliate_id_by_key( $referral_key_cookie );
	} else {
		$affiliate_id_cookie = false;
	}

	// registered referral (only if no affiliate cookie)
	$cash_referral_job_purchase_select      = get_option('cash_referral_job_purchase_select');
	$type_cash_referral_job_purchase_select = get_option('type_cash_referral_job_purchase_select');

	if ( $cash_referral_job_purchase_select == "yes"
		&& $affiliate_id
		&& $affiliate_id != $buyer_id
		&& $affiliate_id != $seller_id
		&& ( ! $affiliate_id_cookie || $affiliate_id == $affiliate_id_cookie ) ) {

		$referral_user_nr_sales = get_user_meta( $buyer_id, 'wpjobster_referral_user_job_nr_sales', true );
		if ( ! $referral_user_nr_sales ) {
			$referral_user_nr_sales = 0;
		}

		if ( $type_cash_referral_job_purchase_select == "amount" ) {
			$cash_referral_job_amount_purchase = get_option( 'cash_referral_job_amount_purchase' );
			$cash_referral_job_amount_sales    = get_option( 'cash_referral_job_amount_sales' );

			if ( ! $cash_referral_job_amount_sales
				|| $referral_user_nr_sales < $cash_referral_job_amount_sales ) {

				$cr = wpjobster_get_credits( $affiliate_id );
				wpjobster_update_credits( $affiliate_id, $cr + $cash_referral_job_amount_purchase );

				wpjobster_add_history_log( '1', wpjobster_text_reason( 0 ), $cash_referral_job_amount_purchase, $affiliate_id, '', '', 15, '');

				wpjobster_add_affiliate_log( $affiliate_id, $buyer_id, 4, wpjobster_text_reason( 4 ), $cash_referral_job_amount_purchase );

				update_user_meta( $buyer_id, 'wpjobster_referral_user_job_nr_sales', $referral_user_nr_sales + 1 );
			}

		} elseif ( $type_cash_referral_job_purchase_select == "percent" ) {
			$cash_referral_job_percent_purchase = get_option('cash_referral_job_percent_purchase');
			$cash_referral_job_sales            = get_option('cash_referral_job_sales');
			$cash_referral_job_max_of           = get_option('cash_referral_job_max_of');

			if ( ! $cash_referral_job_sales
				|| $referral_user_nr_sales < $cash_referral_job_sales ) {

				$cr    = wpjobster_get_credits( $affiliate_id );
				$total = ( $job_price * $cash_referral_job_percent_purchase ) / 100;
				if ( is_numeric( $cash_referral_job_max_of ) ) {
					if ( $total > $cash_referral_job_max_of ) {
						$total = $cash_referral_job_max_of;
					}
				}
				wpjobster_update_credits( $affiliate_id, $cr + $total );

				wpjobster_add_history_log( '1', wpjobster_text_reason( 0 ), $total, $affiliate_id, '', '', 15, '' );

				wpjobster_add_affiliate_log( $affiliate_id, $buyer_id, 4, wpjobster_text_reason(4), $total );

				update_user_meta( $buyer_id, 'wpjobster_referral_user_job_nr_sales', $referral_user_nr_sales + 1 );
			}
		}
	}


	// regular referral (prioritized)
	$cash_referral_user_registered_job_purchase_select      = get_option('cash_referral_user_registered_job_purchase_select');
	$type_cash_referral_user_registered_job_purchase_select = get_option('type_cash_referral_user_registered_job_purchase_select');

	if ( $cash_referral_user_registered_job_purchase_select == "yes"
		&& $affiliate_id_cookie
		&& $affiliate_id_cookie != $affiliate_id
		&& $affiliate_id_cookie != $buyer_id
		&& $affiliate_id_cookie != $seller_id ) {

		if ( $type_cash_referral_user_registered_job_purchase_select == "amount" ) {
			$cash_referral_user_registered_job_amount_purchase = get_option( 'cash_referral_user_registered_job_amount_purchase' );

			$cr = wpjobster_get_credits( $affiliate_id_cookie );
			wpjobster_update_credits( $affiliate_id_cookie, $cr + $cash_referral_user_registered_job_amount_purchase );

			wpjobster_add_history_log( '1', wpjobster_text_reason( 0 ), $cash_referral_user_registered_job_amount_purchase, $affiliate_id_cookie, '', '', 15, '' );

			wpjobster_add_affiliate_log( $affiliate_id_cookie, $buyer_id, 8, wpjobster_text_reason( 8 ), $cash_referral_user_registered_job_amount_purchase );

		} elseif ( $type_cash_referral_user_registered_job_purchase_select == "percent" ) {
			$cash_referral_user_registered_job_percent_purchase = get_option( 'cash_referral_user_registered_job_percent_purchase' );
			$cash_referral_user_registered_job_max_of = get_option( 'cash_referral_user_registered_job_max_of' );

			$cr    = wpjobster_get_credits( $affiliate_id_cookie );
			$total = ( $job_price * $cash_referral_user_registered_job_percent_purchase ) / 100;
			if ( is_numeric( $cash_referral_user_registered_job_max_of ) ) {
				if ( $total > $cash_referral_user_registered_job_max_of ) {
					$total = $cash_referral_user_registered_job_max_of;
				}
			}
			wpjobster_update_credits( $affiliate_id_cookie, $cr + $total );

			wpjobster_add_history_log( '1', wpjobster_text_reason( 0 ), $total, $affiliate_id_cookie, '', '', 15, '' );

			wpjobster_add_affiliate_log( $affiliate_id_cookie, $buyer_id, 8, wpjobster_text_reason( 8 ), $total );
		}
	}
}

/* REFERRAL JOB SALES */
add_action('wpjobster_job_payment_completed','wpjobster_affiliate_job_sale', 10, 1);
function wpjobster_affiliate_job_sale($orderid){
	global $wpdb;

	$cash_referral_purchase_select = get_option('cash_referral_purchase_select');
	$type_cash_referral_purchase_select = get_option('type_cash_referral_purchase_select');

	if(isset($cash_referral_purchase_select) && $cash_referral_purchase_select == "yes"){

		$bQuery = "SELECT * FROM {$wpdb->prefix}job_orders WHERE id='".$orderid."'";
		$b = $wpdb->get_results($bQuery);
		$buyer_id = $b[0]->uid;

		$sQuery = "SELECT * FROM {$wpdb->prefix}job_payment_transactions WHERE oid = '".$orderid."' AND uid != '".$buyer_id."'";
		$s = $wpdb->get_results($sQuery);
		$seller_id = $s[0]->uid;
		$my_referral = get_user_meta ($seller_id, 'wpjobster_my_referral_user_id', true );
		$job_price = $b[0]->mc_gross;

		$referral_user_nr_sales = get_user_meta ($seller_id, 'wpjobster_referral_user_nr_sales', true );

		if($my_referral && $my_referral != ""){
			if($type_cash_referral_purchase_select == "amount"){
				$cash_referral_amount_purchase = get_option('cash_referral_amount_purchase');
				$cash_referral_amount_sales = get_option('cash_referral_amount_sales');

				if(!$cash_referral_amount_sales || $referral_user_nr_sales < $cash_referral_amount_sales){
					$cr = wpjobster_get_credits($my_referral);
					wpjobster_update_credits($my_referral, $cr + $cash_referral_amount_purchase);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $cash_referral_amount_purchase ,$my_referral, '', '', 15, '');
					$reason_id = 5;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $seller_id, $reason_id, $reason, $cash_referral_amount_purchase);
				}

				if($referral_user_nr_sales){
					update_user_meta($my_referral, 'wpjobster_referral_user_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($my_referral, 'wpjobster_referral_user_nr_sales', 1);
				}
			}
			if($type_cash_referral_purchase_select == "percent"){
				$cash_referral_percent_purchase = get_option('cash_referral_percent_purchase');
				$cash_referral_sales = get_option('cash_referral_sales');
				$cash_referral_max_of = get_option('cash_referral_max_of');

				if(!$cash_referral_sales || $referral_user_nr_sales < $cash_referral_sales){
					$cr = wpjobster_get_credits($my_referral);
					$total = ($job_price * $cash_referral_percent_purchase)/100;
					if(is_numeric($cash_referral_max_of)){
						if($total > $cash_referral_max_of){
							$total = $cash_referral_max_of;
						}
					}
					wpjobster_update_credits($my_referral, $cr + $total);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $total ,$my_referral, '', '', 15, '');

					$reason_id = 5;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $seller_id, $reason_id, $reason, $total);
				}

				if($referral_user_nr_sales){
					update_user_meta($my_referral, 'wpjobster_referral_user_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($my_referral, 'wpjobster_referral_user_nr_sales', 1);
				}
			}
		}
	}
}

/* REFERRAL FEATURED SALES */
add_action('wpjobster_featured_payment_completed','wpjobster_affiliate_featured_sales', 10, 1);
function wpjobster_affiliate_featured_sales($order_id){
	global $wpdb;

	$cash_referral_featured_purchase_select = get_option('cash_referral_featured_purchase_select');
	$type_cash_referral_featured_purchase_select = get_option('type_cash_referral_featured_purchase_select');

	if(isset($cash_referral_featured_purchase_select) && $cash_referral_featured_purchase_select == "yes"){

		$fQuery = "SELECT * FROM {$wpdb->prefix}job_featured_orders WHERE id='".$order_id."'";
		$f = $wpdb->get_results($fQuery);
		$buyer_id = $f[0]->user_id;

		$my_referral = get_user_meta ($buyer_id, 'wpjobster_my_referral_user_id', true );
		$job_price = $f[0]->payable_amount;

		$referral_user_nr_sales = get_user_meta ($buyer_id, 'wpjobster_referral_user_featured_nr_sales', true );

		if($my_referral && $my_referral != ""){
			if($type_cash_referral_featured_purchase_select == "amount"){
				$cash_referral_featured_amount_purchase = get_option('cash_referral_featured_amount_purchase');
				$cash_referral_featured_amount_sales = get_option('cash_referral_featured_amount_sales');

				if(!$cash_referral_featured_amount_sales || $referral_user_nr_sales < $cash_referral_featured_amount_sales){
					$cr = wpjobster_get_credits($my_referral);
					wpjobster_update_credits($my_referral, $cr + $cash_referral_featured_amount_purchase);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $cash_referral_featured_amount_purchase ,$my_referral, '', '', 15, '');
					$reason_id = 6;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $buyer_id, $reason_id, $reason, $cash_referral_featured_amount_purchase);
				}

				if($referral_user_nr_sales){
					update_user_meta($buyer_id, 'wpjobster_referral_user_featured_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($buyer_id, 'wpjobster_referral_user_featured_nr_sales', 1);
				}
			}
			if($type_cash_referral_featured_purchase_select == "percent"){
				$cash_referral_featured_percent_purchase = get_option('cash_referral_featured_percent_purchase');
				$cash_referral_featured_sales = get_option('cash_referral_featured_sales');
				$cash_referral_featured_max_of = get_option('cash_referral_featured_max_of');

				if(!$cash_referral_featured_sales || $referral_user_nr_sales < $cash_referral_featured_sales){
					$cr = wpjobster_get_credits($my_referral);
					$total = ($job_price * $cash_referral_featured_percent_purchase)/100;
					if(is_numeric($cash_referral_featured_max_of)){
						if($total > $cash_referral_featured_max_of){
							$total = $cash_referral_featured_max_of;
						}
					}
					wpjobster_update_credits($my_referral, $cr + $total);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $total ,$my_referral, '', '', 15, '');
					$reason_id = 6;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $buyer_id, $reason_id, $reason, $total);
				}

				if($referral_user_nr_sales){
					update_user_meta($buyer_id, 'wpjobster_referral_user_featured_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($buyer_id, 'wpjobster_referral_user_featured_nr_sales', 1);
				}
			}
		}
	}
}

/* REFERRAL TOP UP SALES */
add_action('wpjobster_top_up_payment_completed','wpjobster_affiliate_top_up_sales', 10, 1);
function wpjobster_affiliate_top_up_sales($order_id){
	global $wpdb;

	$cash_referral_top_up_purchase_select = get_option('cash_referral_top_up_purchase_select');
	$type_cash_referral_top_up_purchase_select = get_option('type_cash_referral_top_up_purchase_select');

	if(isset($cash_referral_top_up_purchase_select) && $cash_referral_top_up_purchase_select == "yes"){

		$tQuery = "SELECT * FROM {$wpdb->prefix}job_topup_orders WHERE id='".$order_id."'";
		$t = $wpdb->get_results($tQuery);
		$buyer_id = $t[0]->user_id;

		$my_referral = get_user_meta ($buyer_id, 'wpjobster_my_referral_user_id', true );
		$job_price = $t[0]->package_amount;

		$referral_user_nr_sales = get_user_meta ($buyer_id, 'wpjobster_referral_user_top_up_nr_sales', true );

		if($my_referral && $my_referral != ""){
			if($type_cash_referral_top_up_purchase_select == "amount"){
				$cash_referral_top_up_amount_purchase = get_option('cash_referral_top_up_amount_purchase');
				$cash_referral_top_up_amount_sales = get_option('cash_referral_top_up_amount_sales');

				if(!$cash_referral_top_up_amount_sales || $referral_user_nr_sales < $cash_referral_top_up_amount_sales){
					$cr = wpjobster_get_credits($my_referral);
					wpjobster_update_credits($my_referral, $cr + $cash_referral_top_up_amount_purchase);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $cash_referral_top_up_amount_purchase ,$my_referral, '', '', 15, '');
					$reason_id = 7;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $buyer_id, $reason_id, $reason, $cash_referral_top_up_amount_purchase);
				}

				if($referral_user_nr_sales){
					update_user_meta($my_referral, 'wpjobster_referral_user_top_up_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($my_referral, 'wpjobster_referral_user_top_up_nr_sales', 1);
				}
			}
			if($type_cash_referral_top_up_purchase_select == "percent"){
				$cash_referral_top_up_percent_purchase = get_option('cash_referral_top_up_percent_purchase');
				$cash_referral_top_up_sales = get_option('cash_referral_top_up_sales');
				$cash_referral_top_up_max_of = get_option('cash_referral_top_up_max_of');

				if(!$cash_referral_top_up_sales || $referral_user_nr_sales < $cash_referral_top_up_sales){
					$cr = wpjobster_get_credits($my_referral);
					$total = ($job_price * $cash_referral_top_up_percent_purchase)/100;
					if(is_numeric($cash_referral_top_up_max_of)){
						if($total > $cash_referral_top_up_max_of){
							$total = $cash_referral_top_up_max_of;
						}
					}
					wpjobster_update_credits($my_referral, $cr + $total);
					$reason = __('Payment received from Affiliate System', 'wpjobster-affiliate');
					wpjobster_add_history_log('1', $reason, $total ,$my_referral, '', '', 15, '');
					$reason_id = 7;
					$reason    = wpjobster_text_reason($reason_id);
					wpjobster_add_affiliate_log($my_referral, $buyer_id, $reason_id, $reason, $total);
				}

				if($referral_user_nr_sales){
					update_user_meta($my_referral, 'wpjobster_referral_user_top_up_nr_sales', $referral_user_nr_sales + 1);
				}else{
					update_user_meta($my_referral, 'wpjobster_referral_user_top_up_nr_sales', 1);
				}
			}
		}
	}
}

/* TRANSACTIONS */
/*****************************************************************
**INSTRUCTIONS
* $uid - current user id
* $referral_key - id of referral from current user id
* $reason_id
	* $reason_id == 1    => Someone accessed my referral link
	* $reason_id == 2    => Someone registered from my referral link
	* $reason_id == 3    => Referral post his first job
	* $reason_id == 4    => Referral buy a job
	* $reason_id == 5    => Referral sell a job
	* $reason_id == 6    => Referral buy a featured job
	* $reason_id == 7    => Referral topup his account
	* $reason_id == 8    => Someone bought a job from my referral link
* $reason - a text which will appear in database
* $amount - total of money
*****************************************************************/
function wpjobster_add_affiliate_log($uid, $referral_key, $reason_id, $reason, $amount) {
	$tm = current_time('timestamp', 1);
	global $wpdb;
	global $wpjobster_currencies_array;

	if (isset($_POST['mc_currency'])) {
		$currency = $_POST['mc_currency'];
	} elseif (isset($_GET['site_currency'])) {
		$selected = $_GET['site_currency'];
		$selected = strtoupper($selected);
		$currency = $selected;
	} elseif (isset($_COOKIE["site_currency"])) {
		$selected = $_COOKIE["site_currency"];
		$selected = strtoupper($selected);
		$currency = $selected;
	} else {
		$currency = $wpjobster_currencies_array[0];
	}

	$payedamount = $currency . '|' . wpjobster_formats_special($amount, 2);

	$reason = esc_sql($reason);

	$s = "
		insert into " . $wpdb->prefix . "job_affiliate_transactions
		values('','$uid','$referral_key','$reason','$reason_id','$amount','$payedamount','$tm')
	";
	$wpdb->query($s);
}

/* ADD TRANSACTIONS TO PAYMENT PAGE */
add_action('after_payment_type_list','wpj_aff_add_new_payment_type');
function wpj_aff_add_new_payment_type(){
	$using_perm = wpjobster_using_permalinks();
	if($using_perm) $pay_pg_lnk = get_permalink(get_option('wpjobster_my_account_payments_page_id'));
	else $pay_pg_lnk = get_bloginfo('url'). "?page_id=". get_option('wpjobster_my_account_payments_page_id'). "&";

	global $wp_query;
	$pg = isset( $wp_query->query_vars['pg']) ? urldecode($wp_query->query_vars['pg']) : 'home'; ?>

	<a class="ui white button <?php if ($pg == 'affiliate' ) { echo 'active'; } ?>" href="<?php echo $pay_pg_lnk; ?>affiliate"><?php _e('Affiliate Reports','wpjobster-affiliate'); ?></a>
	<?php
}

/* Display affiliate transactions to payment tab */
if ( ! function_exists( 'wpjobster_show_affiliate_transaction_row' ) ) {
	function wpjobster_show_affiliate_transaction_row($row="") {
		//User Timezone Function
		wpjobster_timezone_change();

		$uid = get_user_by( 'id', $row->user_id );
		$rid = get_user_by( 'id', $row->referral_id );
		$uid_user_login = isset( $uid->user_login ) ? $uid->user_login : '-';
		$rid_user_login = isset( $rid->user_login ) ? $rid->user_login : '-';
		$date = date_i18n( get_option( 'date_format' ) . ' - ' . get_option( 'time_format' ), $row->date );

		$find = array( '/Referral/', '/Someone/' );
		$replace = array( $rid_user_login, $rid_user_login );
		$reason = wpjobster_text_reason( $row->reason_id, $row->referral_id );
		if ( $rid ) { $reason = preg_replace( $find, $replace, $reason ); }

		$sign = '+'; ?>

		<div class="bs-table-row post_results_item flex-middle cf">
			<div class="bs-col-container cf">
				<div class="bs-col2">
					<div class="small-single-line">
						<span class="responsive_titles"> <?php _e( 'Reason', 'wpjobster-affiliate' ); ?></span><?php echo $reason; ?>
					</div>
				</div>
				<div class="bs-col3">
					<div class="small-single-line">
						<span class="responsive_titles"> <?php _e( 'Date', 'wpjobster-affiliate' ); ?></span>
						<?php echo $date; ?>
					</div>
				</div>
				<div class="bs-col6 greengreen text-right">
					<div class="small-single-line">
						<span class="responsive_titles"> <?php _e( 'Amount', 'wpjobster-affiliate' ); ?></span>
						<?php echo $sign . wpjobster_get_show_price( ( $row->amount ) , 2 ); ?>
					</div>
				</div>
			</div>
		</div>
	<?php }
}

add_action('new_payment_type_content','wpj_aff_new_payment_type_content');
function wpj_aff_new_payment_type_content(){
	$using_perm = wpjobster_using_permalinks();
	if($using_perm) $pay_pg_lnk = get_permalink(get_option('wpjobster_my_account_payments_page_id'));
	else $pay_pg_lnk = get_bloginfo('url'). "?page_id=". get_option('wpjobster_my_account_payments_page_id'). "&";

	global $wp_query;
	$pg = isset( $wp_query->query_vars['pg']) ? urldecode($wp_query->query_vars['pg']) : 'home';

	if ($pg == 'affiliate'){
		include('templates/user-transactions.php');
	}
}

/* TEXT FOR REASONS */
function wpjobster_text_reason( $reason_id, $referral_key = 0 ) {
	if ( $reason_id == 0 ) {
		$reason = __( 'Payment received for Affiliate Referrals', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 1 ) {
		$reason = __( 'Someone accessed my referral link', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 2 ) {
		$reason = __( 'Referral registered through my referral link', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 3 ) {
		$reason = __( 'Referral posted his first job', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 4 ) {
		$reason = __( 'Referral bought a job', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 5 ) {
		$reason = __( 'Referral sold a job', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 6 ) {
		$reason = __( 'Referral featured a job', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 7 ) {
		$reason = __( 'Referral topped up his balance', 'wpjobster-affiliate' );
	} elseif ( $reason_id == 8 ) {
		$reason = __( 'Someone bought a job through my referral link', 'wpjobster-affiliate' );
	} else{
		$reason = "";
	}
	return $reason;
}

/* FIRST RUN */
add_action( 'admin_init', 'wpj_aff_first_run' );
function wpj_aff_first_run(){
	if ( ! function_exists( 'wpj_get_wpjobster_plugins_list' ) && ! defined( 'wpjobster_VERSION' ) ) {
		if ( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
			deactivate_plugins( plugin_basename( __FILE__ ) ); ?>

			<div data-dismissible="notice-affiliate-plugin-compatibility-forever" class="notice notice-error is-dismissible">
				<p>
					<?php echo __( 'The current theme is not compatible with the plugin WPJobster Affiliate. Activate the WPJobster theme before installing this plugin.', 'wpjobster-affiliate' ); ?>
				</p>
			</div>

			<?php if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
		}
	}

	if ( get_option( 'wpj_aff_url_generator' ) != 'done' ) {
		update_option( 'wpj_aff_url_generator', 'done' );

		wpjobster_insert_pages( 'wpjobster_referral_url_generator_page_id',
			'Referral URL Generator',
			'[referral_url_generator]',
			0,
			'page-full-width.php'
		);
	}
}

if (!function_exists('wpjobster_aff_page_list_filter')) {
	function wpjobster_aff_page_list_filter( $aff_page_assignment ) {
		$aff_page_assignment[ __( 'Referral URL Generator','wpjobster' ) ] = 'wpjobster_referral_url_generator_page_id';

		return $aff_page_assignment;
	}
}
add_filter("wpjobster_page_assignments_list", "wpjobster_aff_page_list_filter", 10, 1);
