<?php
if ( ! class_exists( 'DSAdminDiscounts' ) ) {
	$classes = array( 'GeneralSettings', 'DiscountsSettings' );
	foreach ( $classes as $class_name ) {
		include_once plugin_dir_path( __FILE__ ) . $class_name . '.php';
	}

	class DSAdminDiscounts {
		/**
		 * __CONSTRUCT
		 */
		public function __construct() {
			$this->GeneralSettings = new DSGeneralSettings();
			$this->DiscountsSettings = new DSDiscountsSettings();
		}

		/**
		 * Enqueue the scripts
		 */
		public function load_scripts_and_styles() {
			wp_enqueue_style( 'discount-admin-style', $this->GeneralSettings->getDirectoryUrl() . 'css/admin-style.css', array(), wpjobster_VERSION );
		}

		/**
		 * Show the item in the left menu
		 */
		public function adminLeftMenu() {
			add_submenu_page(
				'PT1_admin_mnu', // parent slug
				__( 'Discounts', 'wpjobster-discounts' ), // page title
				'<img style="width: 20px; height: 20px;" src="' . $this->GeneralSettings->getDirectoryUrl() . 'icon.png"> ' . __( 'Discounts', 'wpjobster-discounts' ), // menu title
				'manage_options', // capability
				$this->GeneralSettings->getSlug(), // menu slug
				array( $this, 'adminShowSettings' ) // callable
			);
		}

		/**
		 * Show the item in the top menu
		 * @param array $wp_admin_bar
		 */
		public function adminTopMenu( $wp_admin_bar ) {
			$wp_admin_bar->add_node( array(
				'id'     => $this->GeneralSettings->getSlug(),
				'parent' => 'PT1_admin_mnu',
				'title'  => __( 'Discounts', 'wpjobster-discounts' ),
				'href'   => get_admin_url() . 'admin.php?page=wpjobster_discounts',
				'meta'   => array(
					'title' => __( 'Discounts', 'wpjobster-discounts' )
				),
			));
		}

		/**
		 * Save general settings
		 */
		public function adminSaveGeneralSettings() {
			if ( isset( $_POST['wpjobster_save_general_settings_post'] ) ) {
				if ( defined( 'wpjobster_VERSION' ) && wpjobster_VERSION >= '5.4.0' ) {
					update_option( 'wpjobster_discounts_enable'                         , $_POST['wpjobster_discounts_enable'] );
					update_option( 'wpjobster_purchase_this_discounts_enable'           , $_POST['wpjobster_purchase_this_discounts_enable'] );
					update_option( 'wpjobster_admin_discounts_to_seller_earnings_enable', $_POST['wpjobster_admin_discounts_to_seller_earnings_enable'] );
				} else {
					update_option( 'wpjobster_discounts_enable', 'no' );

					if ( $_POST['wpjobster_discounts_enable'] == 'yes' ) {
						echo '<div class="error fade"><p>' . __( 'You can\'t enable discount plugin because is incompatible with this version of theme.', 'wpjobster-discounts' ) . '</p></div>';
					}
				}
			}
		}

		public function checkPluginCompatibilityWithCurrentTheme() {
			if ( class_exists( 'PAnD' ) && ! PAnD::is_admin_notice_active( 'notice-discount-plugin-compatibility-forever' ) ) {
				return;
			}

			if ( defined( 'wpjobster_VERSION' ) && wpjobster_VERSION < '5.4.0' ) {
				update_option( 'wpjobster_discounts_enable', 'no' ); ?>

				<div data-dismissible="notice-discount-plugin-compatibility-forever" class="notice notice-warning is-dismissible">
					<p>
						<?php echo __( 'Your current version of theme is not compatible with discount plugin. Please update the theme to version 5.4.0 or higher.', 'wpjobster-discounts' ); ?>
					</p>
				</div>
			<?php }

			if ( ! function_exists( 'wpj_get_wpjobster_plugins_list' ) && ! defined( 'wpjobster_VERSION' ) ) {

				if ( is_plugin_active( plugin_basename( MYPLUGIN_FILE ) ) ) {
					deactivate_plugins( plugin_basename( MYPLUGIN_FILE ) ); ?>

					<div data-dismissible="notice-discounts-plugin-compatibility-forever" class="notice notice-error is-dismissible">
						<p>
							<?php echo __( 'The current theme is not compatible with the plugin WPJobster Discounts. Activate the WPJobster theme before installing this plugin.', 'wpjobster' ); ?>
						</p>
					</div>

					<?php if ( isset( $_GET['activate'] ) ) {
						unset( $_GET['activate'] );
					}
				}

			}
		}

		/**
		 * Form for general settings
		 */
		public function generalSettings() {
			$arr = array(
				'yes' => __( 'Yes', 'wpjobster-discounts' ),
				'no' => __( 'No', 'wpjobster-discounts' )
			); ?>

			<form method="post" action="<?php echo $this->GeneralSettings->getMenuUrl(); ?>">
				<table width="100%" class="sitemile-table">
					<tr>
						<td></td>
						<td><h2><?php echo __( 'General Settings', 'wpjobster-discounts' ); ?></h2></td>
						<td></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td><?php echo __( 'Enable:', 'wpjobster-discounts' ); ?></td>
						<td><?php echo wpjobster_get_option_drop_down( $arr, 'wpjobster_discounts_enable' ); ?></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td><?php echo __( 'Enable discounts on payment page:', 'wpjobster-discounts' ); ?></td>
						<td><?php echo wpjobster_get_option_drop_down( $arr, 'wpjobster_purchase_this_discounts_enable' ); ?></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td><?php echo __( 'Apply the administrator\'s coupons to the seller\'s earnings:', 'wpjobster-discounts' ); ?></td>
						<td><?php echo wpjobster_get_option_drop_down( $arr, 'wpjobster_admin_discounts_to_seller_earnings_enable', 'yes' ); ?></td>
					</tr>
					<tr>
						<td valign=top width="22"></td>
						<td width="25%"></td>
						<td><input type="submit" class="button-secondary" name="wpjobster_save_general_settings_post" value="<?php echo __( 'Save', 'wpjobster-discounts' ); ?>"/></td>
					</tr>
				</table>
			</form>
		<?php }

		/**
		 * Delete a coupon
		 */
		public function adminDeleteCoupon() {
			$action   = WPJ_FORM::get( 'action' , '' );
			$discount = WPJ_FORM::get( 'discount' , '' );

			if ( $action && $action == 'delete' && $discount ) {
				global $wpdb;
				$uid = get_current_user_id();

				$query   = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND deleted = 0 LIMIT 1";
				$results = $wpdb->get_results( $query );

				if ( $results ) {
					$coupon_id = $wpdb->update(
						$wpdb->prefix . 'job_discount_codes',
						array(
							'deleted' => 1,
						),
						array( 'id' => $results[0]->id ),
						array(
							'%d'
						),
						array( '%d' )
					);

					if ( FALSE === $coupon_id ) {
						echo '<div class="error fade"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
					} else {
						echo '<div class="updated fade"><p>' . __( 'Coupon deleted successfully', 'wpjobster-discounts' ) . '!</p></div>';
						wp_safe_redirect( $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs3' ); exit;
					}
				} else {
					echo '<div class="error fade"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
				}
			}
		}

		/**
		 * Save new coupon
		 */
		public function adminSaveNewCoupon() {
			if ( isset( $_POST['wpjobster_save_new_coupon_post'] ) ) {
				global $wpdb;

				$is_ok = true;

				$name         = WPJ_FORM::post( 'discount_name', '' );
				$type         = WPJ_FORM::post( 'discount_type', '' );
				$price        = WPJ_FORM::post( 'discount_price', '' );
				$start_date   = WPJ_FORM::post( 'discount_start_date', '' );
				$end_date     = WPJ_FORM::post( 'discount_end_date', '' );
				$uses         = WPJ_FORM::post( 'discount_number_of_uses', '' );
				$min_amount   = WPJ_FORM::post( 'discount_minimum_amount', '' );
				$limit_once   = WPJ_FORM::post( 'discount_limit_once', 0 );
				$featured_job = WPJ_FORM::post( 'discount_featured_job', 0 );
				$job_category = isset( $_POST['discount_job_category'] ) ? $_POST['discount_job_category'] : array();
				$limit_user   = isset( $_POST['discount_limit_user'] ) ? $_POST['discount_limit_user'] : array();

				if ( empty( $name ) ) {
					echo '<div class="error fade"><p>' . __( 'Fill discount name.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				if ( strlen( $name ) > 500 ) {
					echo '<div class="error fade"><p>' . __( 'Discount name is too long.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				if ( empty( $price ) ) {
					if ( $type == 'percent' ) {
						echo '<div class="error fade"><p>' . __( 'Fill discount percent.', 'wpjobster-discounts' ) . '</p></div>';
					} else {
						echo '<div class="error fade"><p>' . __( 'Fill discount price.', 'wpjobster-discounts' ) . '</p></div>';
					}
					$is_ok = false;
				}

				if ( $type == "percent" && ( $price <= 0 || $price > 100 ) ) {
					echo '<div class="error fade"><p>' . __( 'Percentage number is incorrect.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				if ( $type == "fixed" && $min_amount < $price ) {
					echo '<div class="error fade"><p>' . __( 'Minimum amount must be greater than discount value.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				if ( $start_date && strtotime( $start_date ) <= strtotime( "-1 day", time() ) ) {
					echo '<div class="error fade"><p>' . __( 'Incorrect start date.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				if ( $end_date && strtotime( $end_date ) <= time() ) {
					echo '<div class="error fade"><p>' . __( 'Incorrect end date.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				$date_ok = true;
				if ( $start_date && $end_date && strtotime( $start_date ) >= strtotime( $end_date ) ) {
					$date_ok = false;
				} elseif ( ! $start_date && $end_date && strtotime( $end_date ) <= time() ) {
					$date_ok = false;
				}

				if ( ! $date_ok ) {
					echo '<div class="error fade"><p>' . __( 'End date must be greater than start date.', 'wpjobster-discounts' ) . '</p></div>';
					$is_ok = false;
				}

				$action   = WPJ_FORM::get( 'action' , '' );
				$discount = WPJ_FORM::get( 'discount' , '' );

				if ( $is_ok == true ) {
					if ( $action && $action == 'edit' && $discount  ) {
						global $wpdb;
						$uid = get_current_user_id();

						$query   = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND deleted = 0 LIMIT 1";
						$results = $wpdb->get_results( $query );

						if ( $results ) {
							$coupon_id = $wpdb->update(
								$wpdb->prefix . 'job_discount_codes',
								array(
									'name'           => $name,
									'type'           => $type,
									'price'          => $price,
									'start_date'     => $start_date ? strtotime( $start_date ) : time(),
									'end_date'       => strtotime( $end_date ),
									'uses_number'    => $uses,
									'minimum_amount' => $min_amount,
									'limit_once'     => $limit_once,
									'limit_featured' => $featured_job,
									'limit_category' => implode( ',', $job_category ),
									'limit_user'     => implode( ',', $limit_user )
								),
								array( 'id' => $results[0]->id ),
								array(
									'%s',
									'%s',
									'%f',
									'%d',
									'%d',
									'%d',
									'%f',
									'%d',
									'%d',
									'%s',
									'%s'
								),
								array( '%d' )
							);
						}
					} else {
						$coupon_id = $wpdb->insert(
							$wpdb->prefix . 'job_discount_codes',
							array(
								'code'           => $this->DiscountsSettings->generateCouponCode( 10 ),
								'name'           => $name,
								'type'           => $type,
								'price'          => $price,
								'start_date'     => $start_date ? strtotime( $start_date ) : time(),
								'end_date'       => strtotime( $end_date ),
								'uses_number'    => $uses,
								'minimum_amount' => $min_amount,
								'limit_once'     => $limit_once,
								'limit_featured' => $featured_job,
								'limit_category' => implode( ',', $job_category ),
								'limit_user'     => implode( ',', $limit_user ),
								'seller_id'      => get_current_user_id(),
								'creator'        => 0,
								'deleted'        => 0
							),
							array(
								'%s',
								'%s',
								'%s',
								'%f',
								'%d',
								'%d',
								'%d',
								'%f',
								'%d',
								'%d',
								'%s',
								'%s',
								'%d',
								'%d',
								'%d'
							)
						);
					}
				}

				if ( isset( $coupon_id ) ) {
					if ( FALSE === $coupon_id ) {
						echo '<div class="error fade"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
					} else {
						echo '<div class="updated fade"><p>' . __( 'New coupon added successfully', 'wpjobster-discounts' ) . '!</p></div>';
						if ( isset( $results[0] ) && $results[0]->creator == 1 ) {
							wp_safe_redirect( $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs8&user=' . $results[0]->seller_id ); exit;
						} else {
							wp_safe_redirect( $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs3' ); exit;
						}
					}
				}
			}
		}

		/**
		 * Form for new coupon
		 */
		public function adminFormNewCoupon() {
			$edit = false;

			$action   = WPJ_FORM::get( 'action' , '' );
			$discount = WPJ_FORM::get( 'discount' , '' );

			if ( $action && $action == 'edit' && $discount  ) {
				global $wpdb;
				$uid = get_current_user_id();

				$query   = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND deleted = 0 LIMIT 1";
				$results = $wpdb->get_results( $query );

				$edit = $results ? true : false;
			}

			$action_url = $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs2';
			$action_url = $edit ? $action_url . '&action=' . $action . '&discount=' . $discount : $action_url; ?>

			<form method="post" action="<?php echo $action_url; ?>">
				<table width="100%" class="sitemile-table discount-new-wrapper">
					<tr>
						<td></td>
						<td><h2><?php echo $edit ? __( 'Edit coupon details', 'wpjobster-discounts' ) : __( 'Create new coupon', 'wpjobster-discounts' ); ?></h2></td>
						<td></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Discount name', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="text" value="<?php echo WPJ_FORM::post( 'discount_name', $edit ? $results[0]->name : '' ); ?>" name="discount_name" /></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Discount type', 'wpjobster-discounts' ) . ':'; ?></td>
						<td>
							<select name="discount_type">
								<option <?php echo WPJ_FORM::post( 'discount_type', $edit ? $results[0]->type : '' ) == 'percent' ? 'selected=selected' : ''; ?> value="percent"><?php echo __( 'Percent', 'wpjobster-discounts' ); ?></option>
								<option <?php echo WPJ_FORM::post( 'discount_type', $edit ? $results[0]->type : '' ) == 'fixed' ? 'selected=selected' : ''; ?> value="fixed"><?php echo __( 'Fixed', 'wpjobster-discounts' ); ?></option>
							</select>
							<input type="number" step="0.01" value="<?php echo WPJ_FORM::post( 'discount_price', $edit ? $results[0]->price : '' ); ?>" class="discount-price" name="discount_price" /><?php echo '% ' . __( 'or', 'wpjobster-discounts' ) . ' ' . wpjobster_get_currency_classic(); ?></td>
						</td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Start date (if left blank starts immediately)', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="date" value="<?php echo WPJ_FORM::post( 'discount_start_date', $edit ? date_i18n( 'Y-m-d', $results[0]->start_date ) : '' ); ?>" name="discount_start_date" /></td>
					</tr>
					<tr>
						<?php
						$end_date_value_post = WPJ_FORM::post( 'discount_end_date', '' );
						$end_date_value_db = $edit && $results[0]->end_date && $results[0]->end_date != 0 ? date_i18n( 'Y-m-d', $results[0]->end_date ) : '';
						$end_date = $end_date_value_post ? $end_date_value_post : $end_date_value_db;
						?>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'End date (if left blank it continues forever)', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="date" value="<?php echo $end_date; ?>" name="discount_end_date" /></td>
					</tr>
					<tr>
						<?php $total_uses_val = WPJ_FORM::post( 'discount_number_of_uses', $edit ? $results[0]->uses_number : '' ); ?>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Total number of uses (if left blank it continues forever)', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="number" value="<?php echo $total_uses_val != 0 ? $total_uses_val : ''; ?>" name="discount_number_of_uses" /></td>
					</tr>
					<tr>
						<?php $minimum_amount_val = WPJ_FORM::post( 'discount_minimum_amount', $edit ? $results[0]->minimum_amount : '' ); ?>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Minimum amount', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="number" step="0.01" value="<?php echo $minimum_amount_val != 0 ? $minimum_amount_val : ''; ?>" name="discount_minimum_amount" /><?php echo ' ' . wpjobster_get_currency_classic(); ?></td>
					</tr>
					<tr>
						<?php $checked = WPJ_FORM::post( 'discount_limit_once', $edit ? $results[0]->limit_once : 0 ) == 1 ? 'checked=checked' : ''; ?>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Limit once per customer', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="checkbox" <?php echo $checked; ?> name="discount_limit_once" value="1" /></td>
					</tr>
					<tr>
						<?php $checked = WPJ_FORM::post( 'discount_featured_job', $edit ? $results[0]->limit_featured : 0 ) == 1 ? 'checked=checked' : ''; ?>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td width="20%"><?php echo __( 'Only for featured jobs', 'wpjobster-discounts' ) . ':'; ?></td>
						<td><input type="checkbox" <?php echo $checked; ?> name="discount_featured_job" value="1" /></td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td valign=top width="20%">
							<?php
							echo __( 'Only for jobs in selected categories:', 'wpjobster-discounts' ) . ':';
							echo '<br><span class="note">' . __( 'If you want to select multiple categories,<br>hold down CTRL key!', 'wpjobster-discounts' ) . '!</span>';
							?>
						</td>
						<td>
							<?php
							$current_categories = isset( $_POST['discount_job_category'] ) ? $_POST['discount_job_category'] : array();
							$current_categories = ! $current_categories && $edit ? explode( ',', $results[0]->limit_category ) : array();

							$args = "orderby=name&order=ASC&hide_empty=0&parent=0";
							$taxo = 'job_cat';
							$terms = get_terms( $taxo, $args );

							$ret = '<select name="discount_job_category[]" class="discount-job-category" multiple="multiple">';
								$ret .= '<option value="">' . __( 'None', 'wpjobster-discounts' ) . '</option>';
								foreach ( $terms as $term ) {
									$ide = $term->term_id;
									$selected_ide = in_array( $ide, $current_categories ) ? " selected " : "";
									$ret .= '<option ' . $selected_ide . ' value="' . $ide . '">' . $term->name . '</option>';

									$args = "orderby=name&order=ASC&hide_empty=0&parent=" . $ide;
									$sub_terms = get_terms( $taxo, $args );
									foreach ( $sub_terms as $sub_term ) {
										$sub_id = $sub_term->term_id;
										$selected_sub_id = in_array( $sub_id, $current_categories ) ? " selected " : "";
										$ret .= '<option ' . $selected_sub_id . ' value="' . $sub_id . '">&nbsp;&nbsp;|&nbsp;' . $sub_term->name . '</option>';

										$args2 = "orderby=name&order=ASC&hide_empty=0&parent=" . $sub_id;
										$sub_terms2 = get_terms( $taxo, $args2 );
										foreach ( $sub_terms2 as $sub_term2 ) {
											$sub_id2 = $sub_term2->term_id;
											$selected_sub_id2 = in_array( $sub_id2, $current_categories ) ? " selected " : "";
											$ret .= '<option ' . $selected_sub_id2 . ' value="' . $sub_id2 . '">&nbsp;&nbsp;&nbsp;&nbsp;|&nbsp;' . $sub_term2->name . '</option>';

										}
									}
								}
							$ret .= '</select>';

							echo $ret; ?>
						</td>
					</tr>
					<tr>
						<td valign=top width="22"><?php wpjobster_theme_bullet( __( '', 'wpjobster-discounts' ) ); ?></td>
						<td valign=top width="20%">
							<?php
							echo __( 'Only for selected users:', 'wpjobster-discounts' ) . ':';
							echo '<br><span class="note">' . __( 'If you want to select multiple users,<br>hold down CTRL key!', 'wpjobster-discounts' ) . '!</span>';
							?>
						</td>
						<td>
							<?php
							$users = get_users( array( 'fields' => array( 'user_nicename', 'display_name', 'ID' ) ) );
							$users_arr = array();

							$current_users = isset( $_POST['discount_limit_user'] ) ? $_POST['discount_limit_user'] : array();
							$current_users = !$current_users && $edit ? explode( ',', $results[0]->limit_user ) : array(); ?>

							<select name="discount_limit_user[]" multiple="multiple" class="discount-limit-user">
								<option value=""><?php echo __( 'All', 'wpjobster-discounts' ); ?></option>
								<?php foreach ( $users as $user ) {
									$selected = in_array( $user->ID, $current_users ) ? " selected " : "";
									echo '<option ' . $selected . ' value="' . $user->ID . '">' . $user->user_nicename . '</option>';
								} ?>
							</select>
						</td>
					</tr>
					<tr>
						<td valign=top width="22"></td>
						<td width="20%"></td>
						<td>
							<input type="submit" class="button-secondary" name="wpjobster_save_new_coupon_post" value="<?php echo __( 'Save', 'wpjobster-discounts' ); ?>"/>
							<?php if ( $action && $action == 'edit' && $discount  ) { ?>
								<a href="<?php echo $this->GeneralSettings->getMenuUrl(); ?>/&active_tab=tabs2" class="button-secondary"><?php echo __( 'Cancel', 'wpjobster-discounts' ); ?></a>
							<?php } ?>
						</td>
					</tr>
				</table>
			</form>
		<?php }

		/**
		 * Form for coupons view
		 *
		 * @param string $view_type
		 * @param int $uid
		 */
		public function adminFormCouponsView( $view_type = 'all', $uid = '' ) {

			global $wpdb;

			$query = '';
			if ( $view_type == 'active' ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 0 AND ( start_date = 0 || start_date <= UNIX_TIMESTAMP() ) AND ( end_date = 0 || end_date >= UNIX_TIMESTAMP() ) AND ( used_number < uses_number OR uses_number = 0 ) AND deleted = 0 ORDER by id DESC";
			} elseif ( $view_type == 'pending' ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 0 AND start_date > UNIX_TIMESTAMP() AND start_date != 0 AND deleted = 0 ORDER by id DESC";
			} elseif ( $view_type == 'completed' ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 0 AND used_number >= uses_number AND uses_number != 0 AND deleted = 0 ORDER by id DESC";
			} elseif ( $view_type == 'expired' ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 0 AND end_date < UNIX_TIMESTAMP() AND end_date != 0 AND deleted = 0 ORDER by id DESC";
			} elseif ( $view_type == 'all' ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 0 AND deleted = 0 ORDER by id DESC";
			} elseif ( $view_type == 'seller' && $uid ) {
				$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND seller_id = {$uid} AND deleted = 0 ORDER by id DESC";
			}
			$results = $wpdb->get_results( $query ); ?>

			<form method="post" action="<?php echo $this->GeneralSettings->getMenuUrl(); ?>/&active_tab=tabs2">
				<table width="100%" class="sitemile-table">
					<tr>
						<td>
							<h2>
								<?php $user = get_user_by( 'id', $uid );
								echo __( 'Coupons', 'wpjobster-discounts' );
								if ( $view_type == 'seller' && $uid ) { echo ' - ' . $user->user_login; } ?>
							</h2>
						</td>
					</tr>

					<?php if ( ! $results ) { ?>
						<tr>
							<td><?php echo __( 'You don\'t have any coupon', 'wpjobster-discounts' ) . '!'; ?></td>
						</tr>
					<?php } ?>
				</table>

				<?php if ( $results ) { ?>

					<table class="widefat post fixed" cellspacing="0">
						<thead>
							<tr>
								<th width="3%"><?php echo __( 'No.', 'wpjobster-discounts' ); ?></th>
								<th width="8%"><?php echo __( 'Discount Code', 'wpjobster-discounts' ); ?></th>
								<th width="14%"><?php echo __( 'Name', 'wpjobster-discounts' ); ?></th>
								<th width="5%"><?php echo __( 'Price Type', 'wpjobster-discounts' ); ?></th>
								<th width="6%"><?php echo __( 'Discount', 'wpjobster-discounts' ); ?></th>
								<th width="10%"><?php echo __( 'Start date', 'wpjobster-discounts' ); ?></th>
								<th width="10%"><?php echo __( 'End date', 'wpjobster-discounts' ); ?></th>
								<th width="7%"><?php echo __( 'Total number of uses', 'wpjobster-discounts' ); ?></th>
								<th width="5%"><?php echo __( 'Minimum amount', 'wpjobster-discounts' ); ?></th>
								<th width="5%"><?php echo __( 'Limit once per customer', 'wpjobster-discounts' ); ?></th>
								<th width="5%"><?php echo __( 'Only for featured jobs', 'wpjobster-discounts' ); ?></th>
								<th width="6%"><?php echo __( 'Only for jobs with specific category', 'wpjobster-discounts' ); ?></th>
								<th width="6%"><?php echo __( 'Only for user(s)', 'wpjobster-discounts' ); ?></th>
								<th width="10%"><?php echo __( 'Actions', 'wpjobster-discounts' ); ?></th>
							</tr>
						</thead>

						<tbody>
							<?php
							$count = 0;
							foreach ( $results as $row ) { $count++;

								$price = $row->type == 'fixed' ? wpjobster_get_show_price_classic( $row->price ) : $row->price . '%';
								$uses = $row->uses_number ? $row->uses_number : __( 'unlimited', 'wpjobster-discounts' );
								$limit_once = $row->limit_once == 1 ? __( 'Yes', 'wpjobster-discounts' ) : __( 'No', 'wpjobster-discounts' );
								$limit_featured = $row->limit_featured == 1 ? __( 'Yes', 'wpjobster-discounts' ) : __( 'No', 'wpjobster-discounts' );

								$cat_arr = array();
								$limit_category = explode( ',', $row->limit_category );
								if ( $limit_category ) {
									foreach ( $limit_category as $category_id ) {
										$category = get_term_by( 'id', $category_id, 'job_cat' );
										if ( $category ) {
											$cat_arr[] = $category->name;
										}
									}
								}
								$limit_category = $cat_arr ? implode( ', ', $cat_arr ) : __( 'No', 'wpjobster-discounts' );

								$user_arr = array();
								$limit_user = explode( ',', $row->limit_user );
								if ( $limit_user ) {
									foreach ( $limit_user as $user_id ) {
										$user = get_user_by( 'id', $user_id );
										if ( $user ) {
											$user_arr[] = $user->user_login;
										}
									}
								}
								$limit_user = $user_arr ? implode( ', ', $user_arr ) : __( 'No', 'wpjobster-discounts' );

								$end_date = $row->end_date && $row->end_date != 0 ? date_i18n( 'd-M-Y', $row->end_date ) : '-';

								$td_columns = array( $count, $row->code, $row->name, $row->type, $price, date_i18n( 'd-M-Y', $row->start_date ), $end_date, $row->used_number . '/' . $uses, wpjobster_get_show_price_classic( $row->minimum_amount ), $limit_once, $limit_featured, $limit_category, $limit_user );

								echo '<tr>';
									foreach ( $td_columns as $column ) {
										echo '<td class="valign-middle">' . $column . '</td>';
									}
									echo '
										<td>
											<a href="' . $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs2&action=edit&discount=' . $row->code . '" class="button-secondary">' . __( 'Edit', 'wpjobster-discounts' ) . '</a>
											<a href="' . $this->GeneralSettings->getMenuUrl() . '/&active_tab=tabs2&action=delete&discount=' . $row->code . '" class="button-secondary">' . __( 'Delete', 'wpjobster-discounts' ) . '</a>
										</td>
									';
								echo '</tr>';
							} ?>
						</tbody>
					</table>

				<?php } ?>
			</form>
		<?php }

		/**
		 * List the discounts
		 */
		public function adminGetCouponUsersList() {
			global $wpdb;

			$query = "SELECT DISTINCT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND deleted = 0 GROUP BY seller_id";
			$results = $wpdb->get_results( $query ); ?>

			<table width="100%" class="sitemile-table">
				<tr>
					<td>
						<h2>
							<?php echo __( 'Seller Coupons', 'wpjobster-discounts' ); ?>
						</h2>
					</td>
				</tr>

				<?php if ( ! $results ) { ?>
					<tr>
						<td><?php echo __( 'No coupons yet', 'wpjobster-discounts' ) . '!'; ?></td>
					</tr>
				<?php } ?>
			</table>

			<?php if ( $results ) { ?>
				<table class="widefat post fixed" cellspacing="0">
					<thead>
						<tr>
							<th><?php echo __( 'Username', 'wpjobster-discounts' ); ?></th>
						</tr>
					</thead>
					<tbody>
						<?php
						foreach ( $results as $key => $row ) {
							$user = get_user_by( 'id', $row->seller_id );

							if ( $user ) {
								echo '<tr>';
									echo '<th><a href="' . $this->GeneralSettings->getMenuUrl() . '&active_tab=tabs8&user=' . $user->ID . '">' . $user->user_login .'</a></th>';
								echo '</tr>';
							}
						} ?>
					</tbody>
				</table>
			<?php }
		}

		/**
		 * Admin item CONTENT - HTML
		 * Show the discount settings to admin
		 */
		public function adminShowSettings() { ?>
			<div class="wrap">

				<h2 class="my_title_class_sitemile"><?php echo __( 'Jobster - Discounts', 'wpjobster-discounts' ); ?></h2>

				<?php
				$action   = WPJ_FORM::get( 'action' , '' );
				$discount = WPJ_FORM::get( 'discount' , '' );

				$coupon_tab_name = $action && $action == 'edit' && $discount ? __( 'Edit coupon', 'wpjobster-discounts' ) : __( 'New coupon', 'wpjobster-discounts' );
				?>

				<div id="usual2" class="usual">
					<ul>
						<li><a href="#tabs1"><?php echo __( 'General Settings',       'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs2"><?php echo $coupon_tab_name; ?></a></li>
						<li><a href="#tabs3"><?php echo __( 'View active coupons',    'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs4"><?php echo __( 'View pending coupons',   'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs5"><?php echo __( 'View completed coupons', 'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs6"><?php echo __( 'View expired coupons',   'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs7"><?php echo __( 'View all coupons',       'wpjobster-discounts' ); ?></a></li>
						<li><a href="#tabs8"><?php echo __( 'Seller\'s coupons',      'wpjobster-discounts' ); ?></a></li>
						<?php do_action( 'wpj_discounts_add_tab_name' ); ?>
					</ul>

					<div id="tabs1"><?php $this->adminSaveGeneralSettings(); $this->generalSettings(); ?></div>
					<div id="tabs2"><?php $this->adminSaveNewCoupon(); $this->adminFormNewCoupon(); $this->adminDeleteCoupon(); ?></div>
					<div id="tabs3"><?php $this->adminFormCouponsView( 'active' ); ?></div>
					<div id="tabs4"><?php $this->adminFormCouponsView( 'pending' ); ?></div>
					<div id="tabs5"><?php $this->adminFormCouponsView( 'completed' ); ?></div>
					<div id="tabs6"><?php $this->adminFormCouponsView( 'expired' ); ?></div>
					<div id="tabs7"><?php $this->adminFormCouponsView( 'all' ); ?></div>
					<div id="tabs8">
						<?php
						if ( isset( $_GET['user'] ) && $_GET['user'] ) {
							// User discounts list
							echo '<a href="' . $this->GeneralSettings->getMenuUrl() . '&active_tab=tabs8">' . __( 'Back to sellers list', 'wpjobster-discounts' ) . '</a>';

							$this->adminFormCouponsView( 'seller', $_GET['user'] );
						} else {
							// Users list
							$this->adminGetCouponUsersList();
						} ?>
					</div>
					<?php do_action('wpj_discounts_add_tab_content');  ?>

				</div>

			</div>
		<?php }

		public function adminShowDiscountOrderList( $discount_total = 0, $row = array(), $amount = '' ) {
			if ( $row ) {
				$price_for_discount = $this->DiscountsSettings->calculateOrderPrice( $row->id );

				global $wpdb;
				$result_discount_order = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_discounts WHERE order_id = '{$row->id}'" );

				if ( $result_discount_order ) {
					foreach ( $result_discount_order as $key => $value ) {
						$discount = $this->DiscountsSettings->calculateJobDiscount( $price_for_discount['job_price'], $value->discount_id );
						$discount_total += $discount['discount'];
					}
				}

				if ( $discount_total && $amount ) {
					$currency = explode( '|', $amount );
					if ( $currency[0] != 'USD' ) {
						$discount_total = wpjobster_get_show_price_precise( get_exchange_value( $discount_total, get_option( 'wpjobster_currency_1' ), $currency[0] ), 2, $currency[0] );
					} else {
						$discount_total = wpjobster_get_show_price_classic( $discount_total );
					}

					$discount_total = $discount_total ? ' (-' . $discount_total . ')' : '';

					return $discount_total;
				}
			}

			return false;
		}

		public function adminShowDiscountDetailsOrder( $price_arr = array(), $order_id = '' ) {
			if ( $order_id ) {
				$price_for_discount = $this->DiscountsSettings->calculateOrderPrice( $order_id );

				global $wpdb;

				$discount_order_query  = "SELECT * FROM {$wpdb->prefix}job_discounts WHERE order_id = '{$order_id}'";
				$result_discount_order = $wpdb->get_results( $discount_order_query );

				if ( $result_discount_order ) {

					foreach ( $result_discount_order as $key => $value ) {
						$discount = $this->DiscountsSettings->calculateJobDiscount( $price_for_discount['job_price'], $value->discount_id );
						$discount_total = $discount['discount'];

						$query  = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE id = '{$value->discount_id}' LIMIT 1";
						$result = $wpdb->get_results( $query );

						if ( isset( $result[0] ) ) {
							$price_arr[] = array(
								'discount_nr'    => array(
									'label' => sprintf( __( 'Discount #%d', 'wpjobster-discounts' ), $key+1 ),
									'value' => '',
								),
								'discount_name'  => array(
									'label' => __( 'Discount name', 'wpjobster-discounts' ),
									'value' => $result[0]->name,
								),
								'discount_type'  => array(
									'label' => __( 'Discount type', 'wpjobster-discounts' ),
									'value' => $result[0]->type,
								),
								'discount_value' => array(
									'label' => __( 'Discount value', 'wpjobster-discounts' ),
									'value' => $result[0]->price . ( $result[0]->type == 'percent' ? '%' : wpjobster_get_currency_symbol( wpjobster_get_currency_classic() ) ),
								),
								'discount_price' => array(
									'label' => __( 'Discount order price', 'wpjobster-discounts' ),
									'value' => wpjobster_get_show_price_classic( $discount_total ),
								)
							);
						}
					}
				}
			}

			return $price_arr;
		}
	}
}
$DSAdminDiscounts = new DSAdminDiscounts();
