<?php
if ( ! class_exists( 'DSGeneralSettings' ) ) {
	class DSGeneralSettings {
		/**
		 * Updater
		 */
		public function include_updater_class() {
			if ( ! class_exists( 'WPJ_Plugin_License' ) ) {
				include( $this->getDirectoryPath() . 'updater/plugin-updater.php' );
			}
			$wpj_discount_license = new WPJ_Plugin_License(
				array(
					'file'       => MYPLUGIN_FILE,
					'item_name'  => 'Discounts',
					'version'    => '1.0.6',
					'author'     => 'WPJobster',
					'api_url'    => 'http://wpjobster.com',
					'short_slug' => 'discounts',
					'full_slug'  => 'wpjobster_discounts',
					'textdomain' => 'wpjobster-discounts'
				)
			);
		}

		/**
		 * Get plugin slug
		 * @return string
		 */
		public function getSlug() {
			return 'wpjobster_discounts';
		}

		/**
		 * Enqueue the scripts
		 */
		public function load_scripts_and_styles() {
			// Current user
			$current_user = wp_get_current_user();

			// Currency array
			global $wpjobster_currencies_array;

			// Subscription
			wpj_get_subscription_info_path();
			$wpjobster_subscription_info = get_wpjobster_subscription_info( $current_user->ID );
			extract( $wpjobster_subscription_info );

			// Scripts and styles
			wp_enqueue_style( 'discount-style', $this->getDirectoryUrl() . 'css/front-style.css', array(), wpjobster_VERSION );
			wp_enqueue_script( 'discount-script', $this->getDirectoryUrl() . 'js/front-script.js', array(), wpjobster_VERSION, true );
			wp_localize_script( 'discount-script', 'discount_vars', array(
				'ajax_url'                               => admin_url( 'admin-ajax.php' ),
				'lbl_coupon'                             => __( 'Coupon', 'wpjobster-discounts' ),
				'lbl_coupon_already_applied'             => __( 'Coupon code already applied', 'wpjobster-discounts' ),
				'lbl_total_discount_greater_than_amount' => __( 'You can\'t apply this coupon because the value of discount if greater than order price', 'wpjobster-discounts' ),
				'user_balance'                           => wpjobster_formats_special_exchange( wpjobster_get_credits( $current_user->ID ) ),
				'adm_dsc_opt'                            => get_option( 'wpjobster_admin_discounts_to_seller_earnings_enable' ),
				'uid'                                    => $current_user->ID,
				'wpjobster_subscription_enabled'         => $wpjobster_subscription_enabled,
				'wpjobster_fees_for_subscriber_enabled'  => isset( $wpjobster_fees_for_subscriber_enabled ) ? $wpjobster_fees_for_subscriber_enabled : '',
				'wpjobster_subscription_fees'            => $wpjobster_subscription_fees,
				'wpjobster_enable_site_fee'              => get_option( 'wpjobster_enable_site_fee' ),
				'percent_taken'                          => get_option( 'wpjobster_percent_fee_taken' ),
				'solid_fee_taken'                        => get_option( 'wpjobster_solid_fee_taken' ),
			));
		}

		/**
		 * Get plugin menu url
		 * @return link
		 */
		public function getMenuUrl() {
			return menu_page_url( $this->getSlug(), false );
		}

		/**
		 * Get plugin directory url
		 * @return link
		 */
		public function getDirectoryUrl() {
			return plugin_dir_url( dirname( __FILE__ ) );
		}

		/**
		 * Get plugin path url
		 * @return link
		 */
		public function getDirectoryPath() {
			return plugin_dir_path( dirname( __FILE__ ) );
		}

		/**
		 * Add settings link
		 * @param string $links
		 * @return array
		 */
		public function actionLinks ( $links ) {
			$mylinks = array(
				'<a href="' . $this->getMenuUrl() . '">' . __( 'Settings', 'wpjobster-discounts' ) . '</a>',
			);
			return array_merge( $links, $mylinks );
		}

		/**
		 * On plugin activation
		 */
		public function onPluginActivation() {
			// Enable the plugin
			if ( defined( 'wpjobster_VERSION' ) && wpjobster_VERSION >= '5.4.0' ) {
				update_option( 'wpjobster_discounts_enable', 'yes' );
				update_option( 'wpjobster_purchase_this_discounts_enable', 'yes' );
			} else {
				update_option( 'wpjobster_discounts_enable', 'no' );
				update_option( 'wpjobster_purchase_this_discounts_enable', 'no' );
			}

			// Create discount tables
			global $wpdb;
			global $charset_collate;
			$charset_collate = $wpdb->get_charset_collate();

			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

			$sql = "
				CREATE TABLE {$wpdb->prefix}job_discount_codes (
					id int(11) NOT NULL AUTO_INCREMENT,
					code varchar(500) NOT NULL DEFAULT '0',
					name varchar(500) NOT NULL DEFAULT '0',
					type varchar(500) NOT NULL DEFAULT '0',
					price float NOT NULL DEFAULT '0',
					start_date int(11) NOT NULL DEFAULT '0',
					end_date int(11) NOT NULL DEFAULT '0',
					uses_number int(11) NOT NULL DEFAULT '0',
					used_number int(11) NOT NULL DEFAULT '0',
					minimum_amount float NOT NULL DEFAULT '0',
					limit_once int(11) NOT NULL DEFAULT '0',
					limit_featured int(11) NOT NULL DEFAULT '0',
					limit_category varchar(500) NOT NULL DEFAULT '0',
					limit_user varchar(500) NOT NULL DEFAULT '0',
					seller_id int(11) NOT NULL DEFAULT '0',
					creator int(11) NOT NULL DEFAULT '0',
					deleted int(11) NOT NULL DEFAULT '0',
					PRIMARY KEY (id)
				) $charset_collate;

				CREATE TABLE {$wpdb->prefix}job_discounts (
					id int(11) NOT NULL AUTO_INCREMENT,
					discount_id int(11) NOT NULL DEFAULT '0',
					user_id int(11) NOT NULL DEFAULT '0',
					job_id int(11) NOT NULL DEFAULT '0',
					order_id int(11) DEFAULT NULL,
					PRIMARY KEY (id)
				) $charset_collate;
			";

			dbDelta( $sql );

			// First run
			$this->onFirstRun();
		}

		/**
		 * On plugin deactivation
		 */
		public function onPluginDeactivation() {
			// Delete discount page
			wp_delete_post( get_option( 'wpjobster_discounts_page_id' ), true );
			update_option( 'wpjobster_discounts_page_id', '' );

			// Disable the plugin
			update_option( 'wpjobster_discounts_enable', 'no' );
			update_option( 'wpjobster_purchase_this_discounts_enable', 'no' );

			// Reset first-run
			update_option( 'wpj_discount_update_101', '' );
			update_option( 'wpj_discount_update_seller_page', '' );
		}

		/**
		 * On first run
		 */
		public function onFirstRun() {
			ob_start();
			if ( get_option( 'wpj_discount_update_seller_page' ) != 'done' ) {
				$d_page = get_page_by_title( 'Discounts' );
				if ( ! get_option( 'wpjobster_discounts_page_id' ) ) {
					if ( ! $d_page ) {
						wpjobster_insert_pages( 'wpjobster_discounts_page_id', 'Discounts', '[wpjobster_theme_my_discount_codes]' );
					} else {
						update_option( 'wpjobster_discounts_page_id', $d_page->ID );
					}
					update_option( 'wpj_discount_update_seller_page', 'done' );
				}
			}

			if ( get_option( 'wpj_discount_update_101' ) != 'done' ) {

				if ( get_option( 'wpjobster_discounts_page_id' ) ) {
					$menu_obj = wp_get_nav_menu_object( 'Header User Account Menu' );

					wp_update_nav_menu_item( $menu_obj->term_id, 0, array(
						'menu-item-object-id' => get_option( 'wpjobster_discounts_page_id', false ),
						'menu-item-position'  => 4,
						'menu-item-type'      => 'post_type',
						'menu-item-object'    => 'page',
						'menu-item-title'     => get_the_title( get_option( 'wpjobster_discounts_page_id', false ) ),
						'menu-item-status'    => 'publish'
					) );

					update_option( 'wpj_discount_update_101', 'done' );
				}
			}
			ob_end_clean();
		}

	}
}
$DSGeneralSettings = new DSGeneralSettings();
