<?php
if ( ! class_exists( 'DSSellerDiscounts' ) ) {
	$classes = array( 'GeneralSettings', 'DiscountsSettings' );
	foreach ( $classes as $class_name ) {
		include_once plugin_dir_path( __FILE__ ) . $class_name . '.php';
	}

	class DSSellerDiscounts {
		/**
		 * __CONSTRUCT
		 */
		public function __construct() {
			$this->GeneralSettings   = new DSGeneralSettings();
			$this->DiscountsSettings = new DSDiscountsSettings();
		}

		/**
		 * Return true if the user is seller
		 * @param int $user_id
		 * @return bool
		 */
		public function isSeller( $user_id = '' ) {
			$user_id = $user_id ? $user_id : get_current_user_id();
			if ( function_exists( 'wpjobster_user_type' ) ) {
				if ( wpjobster_user_type( $user_id ) == 'buyer' ) {
					return false;
				} else {
					return true;
				}
			} else {
				return true;
			}
		}

		/**
		 * Show 'Discounts' link in user dropdown menu
		 * @param array $drop_down_user_menu
		 * @return array
		 */
		public function includeInDropdownMenu( $drop_down_user_menu ) {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && $this->isSeller() ) {
				$discount_menu = array(
					'label' => __( 'Discounts', 'wpjobster-discounts' ),
					'url' => get_option( 'wpjobster_discounts_page_id' ),
					'childs' => array(),
					'order' => '4',
				);

				$drop_down_user_menu['discounts'] = $discount_menu;
			}

			return $drop_down_user_menu;
		}

		/**
		 * Show 'Discounts' link in page assignments tab
		 * @param array $page_assignment
		 * @return array
		 */
		public function includeInPageAssignments( $page_assignment ) {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() ) {
				$page_assignment[ __( 'Discount', 'wpjobster-discounts' ) ] = 'wpjobster_discounts_page_id';
			}
			return $page_assignment;
		}

		/**
		 * Delete a coupon
		 */
		public function sellerDeleteCoupon() {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() && $this->isSeller() ) {
				$action   = WPJ_FORM::get( 'action', '' );
				$discount = WPJ_FORM::get( 'discount', '' );
				$tab      = WPJ_FORM::get( 'tab', 'coupons' );

				if ( $action && $action == 'delete' && $discount ) {
					global $wpdb;
					$uid = get_current_user_id();

					$query   = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND seller_id = {$uid} AND creator = 1 AND deleted = 0 LIMIT 1";
					$results = $wpdb->get_results( $query );

					if ( $results ) {
						$coupon_id = $wpdb->update(
							$wpdb->prefix . 'job_discount_codes',
							array(
								'deleted' => 1,
							),
							array( 'id' => $results[0]->id ),
							array(
								'%d'
							),
							array( '%d' )
						);

						if ( FALSE === $coupon_id ) {
							echo '<div class="ui negative message"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
						} else {
							echo '<div class="ui positive message"><p>' . __( 'Coupon deleted successfully', 'wpjobster-discounts' ) . '!</p></div>';
							wp_safe_redirect( get_permalink( get_option( 'wpjobster_discounts_page_id' ) ) . '/' . $tab ); exit;
						}
					} else {
						echo '<div class="ui negative message"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
					}
				}
			} else {
				wp_safe_redirect( get_bloginfo( 'url' ) ); exit;
			}
		}

		/**
		 * Save new coupon
		 */
		public function sellerSaveNewCoupon() {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() && $this->isSeller() ) {
				if ( isset( $_POST['save_new_coupon_post'] ) ) {
					global $wpdb;

					$is_ok = true;

					$name         = WPJ_FORM::post( 'discount_name', '' );
					$type         = WPJ_FORM::post( 'discount_type', '' );
					$price        = WPJ_FORM::post( 'discount_value', '' );
					$start_date   = WPJ_FORM::post( 'discount_start_date', '' );
					$end_date     = WPJ_FORM::post( 'discount_end_date', '' );
					$uses         = WPJ_FORM::post( 'discount_number_of_uses', '' );
					$min_amount   = WPJ_FORM::post( 'discount_minimum_amount', '' );
					$limit_once   = WPJ_FORM::post( 'discount_limit_once', 0 );
					$limit_user   = isset( $_POST['discount_limit_user'] ) ? $_POST['discount_limit_user'] : array();

					if ( empty( $name ) ) {
						echo '<div class="ui negative message"><p>' . __( 'Fill discount name.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					if ( strlen( $name ) > 500 ) {
						echo '<div class="ui negative message"><p>' . __( 'Discount name is too long.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					if ( empty( $price ) ) {
						if ( $type == 'percent' ) {
							echo '<div class="ui negative message"><p>' . __( 'Fill discount percent.', 'wpjobster-discounts' ) . '</p></div>';
						} else {
							echo '<div class="ui negative message"><p>' . __( 'Fill discount price.', 'wpjobster-discounts' ) . '</p></div>';
						}
						$is_ok = false;
					}

					if ( $type == "percent" && ( $price <= 0 || $price > 100 ) ) {
						echo '<div class="ui negative message"><p>' . __( 'Percentage number is incorrect.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					if ( $type == "fixed" && $min_amount < $price ) {
						echo '<div class="ui negative message"><p>' . __( 'Minimum amount must be greater than discount value.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					if ( $start_date && $start_date < strtotime( "midnight", time() ) ) {
						echo '<div class="ui negative message"><p>' . __( 'Incorrect start date.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					if ( $end_date && $end_date <= time() ) {
						echo '<div class="ui negative message"><p>' . __( 'Incorrect end date.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					$date_ok = true;
					if ( $start_date && $end_date && $start_date >= $end_date ) {
						$date_ok = false;
					} elseif ( ! $start_date && $end_date && $end_date <= time() ) {
						$date_ok = false;
					}

					if ( ! $date_ok ) {
						echo '<div class="ui negative message"><p>' . __( 'End date must be greater than start date.', 'wpjobster-discounts' ) . '</p></div>';
						$is_ok = false;
					}

					$action   = WPJ_FORM::get( 'action' , '' );
					$discount = WPJ_FORM::get( 'discount' , '' );
					$tab      = WPJ_FORM::get( 'tab', 'coupons' );

					if ( $is_ok == true ) {
						if ( $action && $action == 'edit' && $discount  ) {
							global $wpdb;
							$uid = get_current_user_id();

							$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND seller_id = {$uid} AND creator = 1 AND deleted = 0 LIMIT 1";
							$results = $wpdb->get_results( $query );

							if ( $results ) {
								$coupon_id = $wpdb->update(
									$wpdb->prefix . 'job_discount_codes',
									array(
										'name'           => $name,
										'type'           => $type,
										'price'          => $price,
										'start_date'     => $start_date ? $start_date : time(),
										'end_date'       => $end_date,
										'uses_number'    => $uses,
										'minimum_amount' => $min_amount,
										'limit_once'     => $limit_once,
										'limit_user'     => implode( ',', $limit_user ),
									),
									array( 'id' => $results[0]->id ),
									array(
										'%s',
										'%s',
										'%f',
										'%d',
										'%d',
										'%d',
										'%f',
										'%d',
										'%s',
									),
									array( '%d' )
								);
							}
						} else {
							$coupon_id = $wpdb->insert(
								$wpdb->prefix . 'job_discount_codes',
								array(
									'code'           => $this->DiscountsSettings->generateCouponCode( 10 ),
									'name'           => $name,
									'type'           => $type,
									'price'          => $price,
									'start_date'     => $start_date ? $start_date : time(),
									'end_date'       => $end_date,
									'uses_number'    => $uses,
									'minimum_amount' => $min_amount,
									'limit_once'     => $limit_once,
									'limit_featured' => 0,
									'limit_category' => 0,
									'limit_user'     => implode( ',', $limit_user ),
									'seller_id'      => get_current_user_id(),
									'creator'        => 1,
									'deleted'        => 0
								),
								array(
									'%s',
									'%s',
									'%s',
									'%f',
									'%d',
									'%d',
									'%d',
									'%f',
									'%d',
									'%d',
									'%s',
									'%s',
									'%d',
									'%d',
									'%d'
								)
							);
						}
					}

					if ( isset( $coupon_id ) ) {
						if ( FALSE === $coupon_id ) {
							echo '<div class="ui negative message"><p>' . __( 'Something went wrong. Please try again.', 'wpjobster-discounts' ) . '</p></div>';
						} else {
							echo '<div class="ui positive message"><p>' . __( 'New coupon added successfully', 'wpjobster-discounts' ) . '!</p></div>';
							wp_safe_redirect( get_permalink( get_option( 'wpjobster_discounts_page_id' ) ) . '/' . $tab ); exit;
						}
					}
				}
			} else {
				wp_safe_redirect( get_bloginfo( 'url' ) ); exit;
			}
		}

		/**
		 * Form for new coupon
		 */
		public function sellerFormNewCoupon() {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() && $this->isSeller() ) {
				$edit = false;

				$action = WPJ_FORM::get( 'action' , '' );
				$discount = WPJ_FORM::get( 'discount' , '' );

				if ( $action && $action == 'edit' && $discount  ) {
					global $wpdb;
					$uid = get_current_user_id();

					$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE code = '{$discount}' AND seller_id = {$uid} AND creator = 1 AND deleted = 0 LIMIT 1";
					$results = $wpdb->get_results( $query );

					$edit = $results ? true : false;
				} ?>

				<form class="ui form" method="post" name="new-discount">
					<h4 class="ui dividing header"><?php echo $edit ? __( 'Edit coupon details', 'wpjobster-discounts' ) : __( 'Create new coupon', 'wpjobster-discounts' ); ?></h4>

					<div class="two fields">
						<div class="field">
							<label><?php echo __( 'Discount name', 'wpjobster-discounts' ); ?></label>
							<div class="ui input"><input value="<?php echo WPJ_FORM::post( 'discount_name', $edit ? $results[0]->name : '' ); ?>" type="text" name="discount_name" /></div>
						</div>

						<div class="field">
							<?php
							$users = get_users( array( 'fields' => array( 'user_nicename', 'display_name', 'ID' ) ) );
							$users_arr = array();

							$current_users = isset( $_POST['discount_limit_user'] ) ? $_POST['discount_limit_user'] : array();
							$current_users = !$current_users && $edit ? explode( ',', $results[0]->limit_user ) : array(); ?>

							<label><?php echo __( 'Only for user(s)', 'wpjobster-discounts' ); ?></label>
							<select name="discount_limit_user[]" multiple="" class="ui fluid search dropdown">
								<option value=""><?php echo __( 'All', 'wpjobster-discounts' ); ?></option>
								<?php foreach ( $users as $user ) {
									$selected = in_array( $user->ID, $current_users ) ? " selected " : "";
									echo '<option ' . $selected . ' value="' . $user->ID . '">' . $user->user_nicename . '</option>';
								} ?>
							</select>
						</div>
					</div>

					<div class="two fields">
						<div class="field">
							<label><?php echo __( 'Discount type', 'wpjobster-discounts' ); ?></label>
							<select class="ui dropdown js-discount-type" name="discount_type">
								<option <?php echo WPJ_FORM::post( 'discount_type', $edit ? $results[0]->type : '' ) == 'percent' ? 'selected=selected' : ''; ?> value="percent"><?php echo __( 'Percent', 'wpjobster-discounts' ); ?></option>
								<option <?php echo WPJ_FORM::post( 'discount_type', $edit ? $results[0]->type : '' ) == 'fixed' ? 'selected=selected' : ''; ?> value="fixed"><?php echo __( 'Fixed', 'wpjobster-discounts' ); ?></option>
							</select>
						</div>

						<div class="field">
							<label><?php echo __( 'Discount value', 'wpjobster-discounts' ); ?></label>
							<div class="ui labeled input">
								<div class="ui label js-percent"><?php echo '%'; ?></div>
								<div class="ui label js-fixed"><?php echo wpjobster_get_currency_symbol( wpjobster_get_currency_classic() ); ?></div>
								<input value="<?php echo WPJ_FORM::post( 'discount_value', $edit ? $results[0]->price : '' ); ?>" type="number" step="0.01" name="discount_value" />
							</div>
						</div>
					</div>

					<div class="two fields">
						<?php $start_date_val = WPJ_FORM::post( 'discount_start_date', $edit ? $results[0]->start_date : '' ); ?>
						<div class="field">
							<label><?php echo __( 'Start date (if left blank starts immediately)', 'wpjobster-discounts' ); ?></label>
							<div class="ui calendar" id="start_date_input_ui">
								<div class="ui input left icon">
									<i class="calendar icon"></i>
									<input value="<?php echo $start_date_val ? $start_date_val : ''; ?>" id="discount_start_date_input" type="text" name="discount_start_date">
								</div>
							</div>
						</div>

						<?php $end_date_val = WPJ_FORM::post( 'discount_end_date', $edit ? $results[0]->end_date : '' ); ?>
						<div class="field">
							<label><?php echo __( 'End date (if left blank it continues forever)', 'wpjobster-discounts' ); ?></label>
							<div class="ui calendar" id="end_date_input_ui">
								<div class="ui input left icon">
									<i class="calendar icon"></i>
									<input value="<?php echo $end_date_val ? $end_date_val : ''; ?>" id="indiscount_end_date_input" type="text" name="discount_end_date">
								</div>
							</div>
						</div>
					</div>

					<div class="two fields">
						<?php $total_uses_val = WPJ_FORM::post( 'discount_number_of_uses', $edit ? $results[0]->uses_number : '' ); ?>
						<div class="field">
							<label><?php echo __( 'Total number of uses (if left blank it continues forever)', 'wpjobster-discounts' ); ?></label>
							<div class="ui input"><input value="<?php echo $total_uses_val != 0 ? $total_uses_val : ''; ?>" type="number" name="discount_number_of_uses" /></div>
						</div>

						<?php $minimum_amount_val = WPJ_FORM::post( 'discount_minimum_amount', $edit ? $results[0]->minimum_amount : '' ); ?>
						<div class="field">
							<label><?php echo __( 'Minimum amount', 'wpjobster-discounts' ); ?></label>
							<div class="ui input"><input value="<?php echo $minimum_amount_val != 0 ? $minimum_amount_val : ''; ?>" type="number" step="0.01" name="discount_minimum_amount" /></div>
						</div>
					</div>

					<div class="field">
						<?php $checked = WPJ_FORM::post( 'discount_limit_once', $edit ? $results[0]->limit_once : 0 ) == 1 ? 'checked=checked' : ''; ?>
						<div class="ui checkbox">
							<input type="checkbox" <?php echo $checked; ?> name="discount_limit_once" value="1" />
							<label><?php echo __( 'Limit once per customer', 'wpjobster-discounts' ); ?></label>
						</div>
					</div>

					<input class="ui primary button" name="save_new_coupon_post" type="submit" value="<?php echo __( 'Save', 'wpjobster-discounts' ); ?>" />
				</form>
			<?php } else {
				wp_safe_redirect( get_bloginfo( 'url' ) ); exit;
			}
		}

		/**
		 * List the discounts
		 *
		 * @param string $view_type
		 */
		public function sellerCouponsView( $view_type = 'active' ) {
			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() && $this->isSeller() ) { ?>
				<div class="ui two column stackable grid">
					<div class="sixteen wide column">
						<h2><?php _e( "Coupons", 'wpjobster-discounts' ); ?></h2>
					</div>

					<div class="ui fitted divider"></div>

					<?php global $wpdb;

					$uid = get_current_user_id();

					if ( $view_type == 'active' ) {
						$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND ( start_date = 0 || start_date <= UNIX_TIMESTAMP() ) AND ( end_date = 0 || end_date >= UNIX_TIMESTAMP() ) AND ( used_number < uses_number OR uses_number = 0 ) AND seller_id = {$uid} AND creator = 1 AND deleted = 0 ORDER by id DESC";
					} elseif ( $view_type == 'pending' ) {
						$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND start_date > UNIX_TIMESTAMP() AND start_date != 0 AND seller_id = {$uid} AND creator = 1 AND deleted = 0 ORDER by id DESC";
					} elseif ( $view_type == 'completed' ) {
						$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND used_number >= uses_number AND uses_number != 0 AND seller_id = {$uid} AND creator = 1 AND deleted = 0 ORDER by id DESC";
					} elseif ( $view_type == 'expired' ) {
						$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND end_date < UNIX_TIMESTAMP() AND end_date != 0 AND seller_id = {$uid} AND creator = 1 AND deleted = 0 ORDER by id DESC";
					} elseif ( $view_type == 'all' ) {
						$query = "SELECT * FROM {$wpdb->prefix}job_discount_codes WHERE creator = 1 AND seller_id = {$uid} AND creator = 1 AND deleted = 0 ORDER by id DESC";
					} else {
						$query = "";
					}
					$results = $wpdb->get_results( $query );

					if ( $results ) { ?>

						<div class="three wide column discount-title-table column-vertical-center"><?php echo __( 'Discount Code', 'wpjobster-discounts' ); ?></div>
						<div class="two wide column discount-title-table column-vertical-center"><?php echo __( 'Name', 'wpjobster-discounts' ); ?></div>
						<div class="two wide column discount-title-table column-vertical-center"><?php echo __( 'Price Type', 'wpjobster-discounts' ); ?></div>
						<div class="one wide column discount-title-table column-vertical-center"><?php echo __( 'Discount', 'wpjobster-discounts' ); ?></div>
						<div class="two wide column discount-title-table column-vertical-center"><?php echo __( 'Start date', 'wpjobster-discounts' ); ?></div>
						<div class="two wide column discount-title-table column-vertical-center"><?php echo __( 'End date', 'wpjobster-discounts' ); ?></div>
						<div class="one wide column discount-title-table column-vertical-center"><?php echo __( 'Total number of uses', 'wpjobster-discounts' ); ?></div>
						<div class="one wide column discount-title-table column-vertical-center"><?php echo __( 'Min amount', 'wpjobster-discounts' ); ?></div>
						<div class="one wide column discount-title-table column-vertical-center"><?php echo __( 'Limit once per customer', 'wpjobster-discounts' ); ?></div>
						<div class="one wide column discount-title-table column-vertical-center"><?php echo __( 'Limit user(s)', 'wpjobster-discounts' ); ?></div>

						<?php
						if ( function_exists( 'wpjobster_timezone_change' ) ) { wpjobster_timezone_change(); }

						foreach ( $results as $key => $row ) {
							$price = $row->type == 'fixed' ? wpjobster_get_show_price_classic( $row->price ) : $row->price . '%';
							$uses = $row->uses_number ? $row->uses_number : '&infin;';
							$limit_once = $row->limit_once == 1 ? __( 'Yes', 'wpjobster-discounts' ) : __( 'No', 'wpjobster-discounts' );
							$start_date = $row->start_date && $row->start_date != 0 ? date_i18n( 'd-M-Y', $row->start_date ) : '-';
							$end_date = $row->end_date && $row->end_date != 0 ? date_i18n( 'd-M-Y', $row->end_date ) : '-';

							$user_arr = array();
							$limit_user = explode( ',', $row->limit_user );
							if ( $limit_user ) {
								foreach ( $limit_user as $user_id ) {
									$user = get_user_by( 'id', $user_id );
									if ( $user ) {
										$user_arr[] = $user->user_login;
									}
								}
							}
							$limit_user = $user_arr ? implode( ', ', $user_arr ) : __( 'No', 'wpjobster-discounts' ); ?>

							<div class="row special wpj-load-more-target cf discount-row">
								<div class="ui stackable grid discount-list-border">

									<div class="three wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Code", 'wpjobster-discounts' ); ?></span>
										<?php echo $row->code;

										global $wp_query;
										$tab = isset( $wp_query->query_vars['pg'] ) ? urldecode( $wp_query->query_vars['pg'] ) : 'coupons'; ?>

										<!-- Actions -->
										<ul class="list-style-none list-inline p5t">
											<li>
												<a class="ui primary button btn important lighter smallest p5r" href="<?php echo get_permalink( get_option( 'wpjobster_discounts_page_id' ) ) ?>/?action=edit&discount=<?php echo $row->code; ?>&tab=<?php echo $tab; ?>">
													<?php echo __( 'Edit', 'wpjobster-discounts' ); ?>
												</a>
											</li>
											<li>
												<a class="ui secondary button btn lighter smallest p5r request-open-modal" href="<?php echo get_permalink( get_option( 'wpjobster_discounts_page_id' ) ) ?>/?action=delete&discount=<?php echo $row->code; ?>&tab=<?php echo $tab; ?>">
													<?php echo __( 'Delete', 'wpjobster-discounts' ); ?>
												</a>
											</li>
										</ul>
										<!-- END Actions -->

									</div>
									<div class="two wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Name", 'wpjobster-discounts' ); ?></span>
										<?php echo $row->name; ?>
									</div>
									<div class="two wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Price Type", 'wpjobster-discounts' ); ?></span>
										<?php echo $row->type; ?>
									</div>
									<div class="one wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Discount", 'wpjobster-discounts' ); ?></span>
										<?php echo $price; ?>
									</div>
									<div class="two wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Start date", 'wpjobster-discounts' ); ?></span>
										<?php echo $start_date; ?>
									</div>
									<div class="two wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "End date", 'wpjobster-discounts' ); ?></span>
										<?php echo $end_date; ?>
									</div>
									<div class="one wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Total number of uses", 'wpjobster-discounts' ); ?></span>
										<?php echo $row->used_number . '/' . $uses; ?>
									</div>
									<div class="one wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Minimum amount", 'wpjobster-discounts' ); ?></span>
										<?php echo wpjobster_get_show_price_classic( $row->minimum_amount ); ?>
									</div>
									<div class="one wide column column-vertical-center">
										<span class="responsive_titles transfer"><?php echo __( "Limit once per customer", 'wpjobster-discounts' ); ?></span>
										<?php echo $limit_once; ?>
									</div>
									<div class="one wide column column-vertical-center limit-user">
										<span class="responsive_titles transfer"><?php echo __( "Limit user(s)", 'wpjobster-discounts' ); ?></span>
										<?php echo $limit_user; ?>
									</div>

								</div>
							</div>
						<?php }
					} else {
						echo '<div class="sixteen wide column">' . __( 'You don\'t have any coupon!', 'wpjobster-discounts' ) . '</div>';
					} ?>

				</div>
			<?php } else {
				wp_safe_redirect( get_bloginfo( 'url' ) ); exit;
			}
		}

		/**
		 * Seller CONTENT - HTML
		 * Show the content for discount page
		 */
		public function sellerDiscountPageContent() {
			$ret = '';

			if ( get_option( 'wpjobster_discounts_enable' ) == 'yes' && is_user_logged_in() && $this->isSeller() ) { ob_start(); ?>

				<div id="content-full-ov">

					<div class="ui basic notpadded segment">
						<div class="ui one column stackable grid">
							<div class="sixteen wide column">
								<h1 class="ui header wpj-title-icon">
									<i class="money bill alternate icon"></i>
									<?php echo __( 'Discounts', 'wpjobster-discounts' ); ?>
								</h1>
							</div>
						</div>
					</div>

					<?php $using_perm = wpjobster_using_permalinks();
					if ( $using_perm ) $acc_pg_lnk = get_permalink( get_option( 'wpjobster_discounts_page_id' ) );
					else $acc_pg_lnk = get_bloginfo( 'url' ) . "/?page_id=" . get_option( 'wpjobster_discounts_page_id' ) . "&";

					global $wp_query;
					$pg = isset( $wp_query->query_vars['pg'] ) ? urldecode( $wp_query->query_vars['pg'] ) : 'new-coupon';
					$pages = array( 'new-coupon', 'coupons', 'pending-coupons', 'completed-coupons', 'expired-coupons', 'all-coupons' );
					if ( ! in_array( $pg, $pages ) ) { $pg = 'new-coupon'; } ?>

					<div class="stackable-buttons js-buttons-to-dropdown">
						<a class="ui white button <?php if ( $pg == 'new-coupon' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>"><?php _e( 'New coupon', 'wpjobster-discounts' ); ?></a>
						<a class="ui white button <?php if ( $pg == 'coupons' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>coupons"><?php _e( 'Active coupons', 'wpjobster-discounts' ); ?></a>
						<a class="ui white button <?php if ( $pg == 'pending-coupons' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>pending-coupons"><?php _e( 'Pending coupons', 'wpjobster-discounts' ); ?></a>
						<a class="ui white button <?php if ( $pg == 'completed-coupons' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>completed-coupons"><?php _e( 'Completed coupons', 'wpjobster-discounts' ); ?></a>
						<a class="ui white button <?php if ( $pg == 'expired-coupons' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>expired-coupons"><?php _e( 'Expired coupons', 'wpjobster-discounts' ); ?></a>
						<a class="ui white button <?php if ( $pg == 'all-coupons' ) { echo 'active'; } ?>" href="<?php echo $acc_pg_lnk; ?>all-coupons"><?php _e( 'All coupons', 'wpjobster-discounts' ); ?></a>
					</div>

					<div class="ui segment">
						<?php $this->sellerDeleteCoupon();
						if ( $pg == 'new-coupon' ) {
							$this->sellerSaveNewCoupon(); $this->sellerFormNewCoupon();
						} elseif ( $pg == 'coupons' ) {
							$this->sellerCouponsView( 'active' );
						} elseif ( $pg == 'pending-coupons' ) {
							$this->sellerCouponsView( 'pending' );
						} elseif ( $pg == 'completed-coupons' ) {
							$this->sellerCouponsView( 'completed' );
						} elseif ( $pg == 'expired-coupons' ) {
							$this->sellerCouponsView( 'expired' );
						} elseif ( $pg == 'all-coupons' ) {
							$this->sellerCouponsView( 'all' );
						} ?>
					</div>
				</div>

				<div class="ui hidden divider"></div>

				<?php $ret .= ob_get_contents(); ob_end_clean();

			}

			return $ret;
		}

		public function sellerHistoryLog( $oid, $uid ) {
			global $wpdb;

			$order_url = get_bloginfo( 'url' ) . '/?jb_action=chat_box&oid=' . $oid;
			$order_info = wpjobster_get_order_details_by_orderid( $oid );

			$price_for_discount = $this->DiscountsSettings->calculateOrderPrice( $oid );

			$reason = __( 'Discount for', 'wpjobster-discounts' ) . ': <a href="' . $order_url . '">' . $order_info->job_title . '</a>';

			$discount_order_query  = "SELECT * FROM {$wpdb->prefix}job_discounts WHERE order_id = '{$oid}'";
			$result_discount_order = $wpdb->get_results( $discount_order_query );

			if ( $result_discount_order ) {
				foreach ( $result_discount_order as $key => $value ) {
					$discount = $this->DiscountsSettings->calculateJobDiscount( $price_for_discount['job_price'], $value->discount_id );

					$result = $this->DiscountsSettings->getDiscountById( $value->discount_id );
					if ( get_option( 'wpjobster_admin_discounts_to_seller_earnings_enable' ) == 'no' && $result->creator != 1 ) {
						return false;
					}

					wpjobster_add_history_log( '0', $reason, $discount['discount'], $uid, '', $oid, 21, '' );
				}
			}
		}
	}
}
$DSSellerDiscounts = new DSSellerDiscounts();
