<?php
/*
	Plugin Name: WPJobster Discounts
	Plugin URL: http://wpjobster.com/
	Description: WPJobster Discounts System.
	Version: 1.0.6
	Author: WPJobster
	Author URI: http://wpjobster.com/
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WPJobsterDiscounts' ) ) {

	define( 'MYPLUGIN_FILE', __FILE__ );
	$classes = array( 'GeneralSettings', 'DiscountsSettings', 'AdminDiscounts', 'SellerDiscounts' );
	foreach ( $classes as $class_name ) {
		include_once( plugin_dir_path( __FILE__ ) . 'classes/' . $class_name . '.php' );
	}

	class WPJobsterDiscounts {
		/**
		 * Constructor
		 */
		public function __construct() {
			$this->GeneralSettings  = new DSGeneralSettings();
			$this->DiscountSettings = new DSDiscountsSettings();
			$this->AdminDiscounts   = new DSAdminDiscounts();
			$this->SellerDiscounts  = new DSSellerDiscounts();

			// Plugin Activation / Deactivation
			register_activation_hook( MYPLUGIN_FILE, array( $this->GeneralSettings, 'onPluginActivation' ) );
			register_deactivation_hook( MYPLUGIN_FILE, array( $this->GeneralSettings, 'onPluginDeactivation' ) );

			// Filters
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this->GeneralSettings, 'actionLinks' ), 10, 2 );

			add_filter( 'wpjobster_dropdown_menu_list'              , array( $this->SellerDiscounts, 'includeInDropdownMenu' ), 10, 1 );
			add_filter( 'wpjobster_page_assignments_list'           , array( $this->SellerDiscounts, 'includeInPageAssignments' ), 10, 1 );

			add_filter( 'wpj_price_filter'                          , array( $this->DiscountSettings, 'chatboxTotalPrice' ), 10, 3 );
			add_filter( 'wpj_refund_price_filter'                   , array( $this->DiscountSettings, 'updatePriceAfterDiscount' ), 10, 2 );
			add_filter( 'wpj_shopping_update_filter'                , array( $this->DiscountSettings, 'updatePriceAfterDiscount' ), 10, 2 );
			add_filter( 'wpj_sales_update_filter'                   , array( $this->DiscountSettings, 'updatePriceAfterDiscount' ), 10, 2 );
			add_filter( 'wpj_pending_clearance_buyer_update_filter' , array( $this->DiscountSettings, 'updatePriceAfterDiscount' ), 10, 2 );

			add_filter( 'wpj_pending_clearance_seller_update_filter', array( $this->DiscountSettings, 'updatePriceForClearing' ), 10, 2 );
			add_filter( 'wpj_raw_amount_update_filter'              , array( $this->DiscountSettings, 'updatePriceForClearing' ), 10, 2 );
			add_filter( 'wpj_pending_payment_amount_update_filter'  , array( $this->DiscountSettings, 'updatePriceForClearing' ), 10, 2 );

			add_filter( 'wpj_order_list_discount_filter'            , array( $this->AdminDiscounts, 'adminShowDiscountOrderList' ), 10, 3 );
			add_filter( 'wpj_order_details_price_info_filter'       , array( $this->AdminDiscounts, 'adminShowDiscountDetailsOrder' ), 10, 2 );

			// Actions
			add_action( 'init'                      , array( $this->GeneralSettings, 'include_updater_class' ) ); // create license fields

			add_action( 'wpj_after_job_cleared'     , array( $this->SellerDiscounts, 'sellerHistoryLog' ), 10, 2 ); // history log for seller

			add_action( 'admin_menu'                , array( $this->AdminDiscounts, 'adminLeftMenu' ), 12 ); // item in Jobster left menu
			add_action( 'admin_bar_menu'            , array( $this->AdminDiscounts, 'adminTopMenu' ), 999 ); // item in Jobster top menu

			add_action( 'admin_notices'             , array( $this->AdminDiscounts, 'checkPluginCompatibilityWithCurrentTheme' ), 10 ); // plugin compatibility

			add_action( 'list_before_shipping_price', array( $this->DiscountSettings, 'showDiscountPost' ), 10, 2 ); // checkout page
			add_action( 'list_after_tax_price'      , array( $this->DiscountSettings, 'showDicountForm' ), 10, 2 ); // checkout page

			add_action( 'after_new_job_order'       , array( $this->DiscountSettings, 'insertDiscountOrder' ), 10, 2 ); // after order creation

			add_action( 'wp_ajax_apply_discount_code'       , array( $this->DiscountSettings, 'validateDiscountCode' ) ); // ajax discount code validation
			add_action( 'wp_ajax_nopriv_apply_discount_code', array( $this->DiscountSettings, 'validateDiscountCode' ) ); // ajax discount code validation

			add_action( 'wp_ajax_calculate_site_fee'        , array( $this->DiscountSettings, 'calculateSiteFee' ) ); // ajax calculate site fee
			add_action( 'wp_ajax_nopriv_calculate_site_fee' , array( $this->DiscountSettings, 'calculateSiteFee' ) ); // ajax calculate site fee

			// Enqueue
			add_action( 'wp_enqueue_scripts'   , array( $this->GeneralSettings, 'load_scripts_and_styles' ), 11 ); // front scripts&styles
			add_action( 'admin_enqueue_scripts', array( $this->AdminDiscounts, 'load_scripts_and_styles' ) ); // admin scripts&styles

			// Shortcode
			add_shortcode( 'wpjobster_theme_my_discount_codes', array( $this->SellerDiscounts, 'sellerDiscountPageContent' ) );
		}
	}
}

$WPJobsterDiscounts = new WPJobsterDiscounts();