<?php
/*
Plugin Name: WPJobster Invoices
Plugin URI: http://wpjobster.com/
Description: Automatically generates invoices for your orders, downloadable from Jobster > Orders for admins or from the transaction pages for the buyers.
Version: 2.0.7
Author: WPJobster
Author URI: http://wpjobster.com/
*/

// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// INCLUDE CLASS FOR CREATING LICENSE TAB
function wpjobster_invoices_include_updater_class(){
	if( !class_exists( 'WPJ_Plugin_License' ) ) {
		include( plugin_dir_path( __FILE__ ) . 'updater/plugin-updater.php' );
	}
	$wpj_invoices_license = new WPJ_Plugin_License(
		array(
			'file'       => __FILE__,
			'item_name'  => 'Invoices',
			'version'    => '2.0.7',
			'author'     => 'WPJobster',
			'api_url'    => 'http://wpjobster.com',
			'short_slug' => 'invoices',
			'full_slug'  => 'wpjobster_invoices',
			'textdomain' => 'wpjobster-invoices'
		)
	);
}
add_action( 'init','wpjobster_invoices_include_updater_class' );

/* FIRST RUN */
add_action( 'admin_init', 'wpj_invoice_first_run' );
function wpj_invoice_first_run(){

	if ( ! function_exists( 'wpj_get_wpjobster_plugins_list' ) && ! defined( 'wpjobster_VERSION' ) ) {
		if ( is_plugin_active( plugin_basename( __FILE__ ) ) ) {
			deactivate_plugins( plugin_basename( __FILE__ ) ); ?>

			<div data-dismissible="notice-invoice-plugin-compatibility-forever" class="notice notice-error is-dismissible">
				<p>
					<?php echo __( 'The current theme is not compatible with the plugin WPJobster Invoices. Activate the WPJobster theme before installing this plugin.', 'wpjobster-invoices' ); ?>
				</p>
			</div>

			<?php if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
		}
	}

}

// EXIT IF ACCESSED DIRECTLY
if( !defined( 'ABSPATH' ) ) exit;

// DEFINE PLUGIN PATH
defined( 'WPJ_INVOICE_ABS_PATH' ) || define( 'WPJ_INVOICE_ABS_PATH', plugin_dir_path( __FILE__ ) );

// INCLUDE CLASS FOR CREATING PDF INVOICE
require_once( WPJ_INVOICE_ABS_PATH . 'fpdf/tfpdf.php');
require_once( WPJ_INVOICE_ABS_PATH . 'fpdf/PDF_Functions.php');
require_once( WPJ_INVOICE_ABS_PATH . 'invoice_hooks.php');

// WPJ INVOICE ADMIN INTERFACES
if( is_admin() && ( !defined( 'DOING_AJAX' ) || !DOING_AJAX ) ) {
	require_once( WPJ_INVOICE_ABS_PATH . 'lib/wpj_database.php'); // The entry point to WPJ Invoice interfaces
	require_once( WPJ_INVOICE_ABS_PATH . 'lib/wpj_invoice_admin_ui.php'); // The entry point to WPJ Invoice interfaces
}

// GET PLUGIN SLUG
function get_invoices_plugin_slug() {
	return 'wpjobster_invoices';
}

// GET MENU URL
function get_invoices_menu_url() {
	return menu_page_url( get_invoices_plugin_slug(), false );
}

// GET PLUGIN URL
function get_invoices_plugin_address(){
	return plugin_dir_url( __FILE__ );
}

/* LOAD TRANSLATIONS */
add_action( 'plugins_loaded', 'wpjobster_load_invoices_plugin_textdomain' );
function wpjobster_load_invoices_plugin_textdomain() {
	load_plugin_textdomain( 'wpjobster-invoices', false, plugin_dir_url(__FILE__) . '/languages' );
}


function custom_redirect_from_plugin($vars) {
	$vars[] = 'invoice_page';
	$vars[] = 'payment_type';
	return $vars;
}
add_filter( 'query_vars', 'custom_redirect_from_plugin' );

function redirect_page_by_plugin(){
	global $wp_query;

	$page_q = isset($wp_query->query_vars['invoice_page'])?$wp_query->query_vars['invoice_page']:"";
	$payment_type = isset($wp_query->query_vars['payment_type'])?$wp_query->query_vars['payment_type']:"";

	if ( $page_q == "invoice" && $payment_type == "chat_box" ) {
		include 'invoice-jobs.php';
		die;
	}elseif ( $page_q == "invoice" && $payment_type == "feature_job" ) {
		include 'invoice-featured.php';
		die;
	}elseif ( $page_q == "invoice" && $payment_type == "show_bank_details" ) {
		include 'invoice-topup.php';
		die;
	}elseif ( $page_q == "invoice" && $payment_type == "subscription" ) {
		include 'invoice-subscription.php';
		die;
	}elseif ( $page_q == "invoice" && $payment_type == "custom_extra" ) {
		include 'invoice-custom-extra.php';
		die;
	}elseif ( $page_q == "invoice" && $payment_type == "tips" ) {
		include 'invoice-tips.php';
		die;
	}
}
add_filter('template_redirect', 'redirect_page_by_plugin');


/**
* ATTEMPT TO INSTALL/MIGRATE/REPAIR WPJ UPON ACTIVATION
*
* CREATE WPJ TABLES
* MIGRATE OLD VERSIONS
* REGISTER DEFAULT COMPONENTS
**/
function wpj_install() {
	wpj_database_install();
//  wsl_update_compatibilities();
//  wsl_register_components();
}
register_activation_hook( __FILE__, 'wpj_install' );

function wpj_uninstall() {
	wpj_database_uninstall();
}
register_deactivation_hook( __FILE__, 'wpj_uninstall' );

//INCLUDE PLUGIN PAGE IN JOBSTER MENU
add_action('admin_menu', 'wpjobster_invoices_create_menu', 11);
function wpjobster_invoices_create_menu() {
	add_submenu_page( 'PT1_admin_mnu', __('WPJobster Invoices','wpjobster-invoices'), '<img style="width: 20px; height: 20px;" src="' . get_invoices_plugin_address() . 'images/invoices_icon.png">' . __('Invoices','wpjosbter'), 'manage_options', get_invoices_plugin_slug(), 'wpjobster_invoices_plugin_settings_page');
}

add_action('admin_bar_menu', 'wpjobster_invoices_in_admin_bar', 999);
function wpjobster_invoices_in_admin_bar( $wp_admin_bar ) {
	$wp_admin_bar->add_node( array(
		'id'     => 'wpjobster_invoices',
		'parent' => 'PT1_admin_mnu',
		'title' => __( 'Invoices', 'wpjobster-invoices' ),
		'href'  => get_admin_url () . 'admin.php?page=wpjobster_invoices',
		'meta'  => array(
			'title' => __( 'WPJobster Invoices', 'wpjobster-invoices' )
		),
	));
}

// ADD A SETTINGS TO PLUGIN_ACTION_LINKS
function wpj_invoice_add_plugin_action_links( $links, $file ) {
	static $this_plugin;
	if( ! $this_plugin ){
		$this_plugin = plugin_basename( __FILE__ );
	}

	if( $file == $this_plugin ){
		$wjp_invoice_links = '<a href="' . get_admin_url() . 'admin.php?page=wpjobster_invoices">' . __( "Settings" ) . '</a>';
		array_unshift( $links, $wjp_invoice_links );
	}
	return $links;
}
add_filter( 'plugin_action_links', 'wpj_invoice_add_plugin_action_links', 10, 2 );

// GET USER INFO
function wpj_invoice_get_user_info( $user_id ) {
	global $wpdb;

	$b_name = ""; $b_info = ""; $b_logo = plugin_dir_url( __FILE__ ) . "images/logo.png";

	$buyer  = get_userdata( $user_id );

	$buyer_f_name  = get_user_meta( $user_id, 'first_name'   , TRUE );
	$buyer_l_name  = get_user_meta( $user_id, 'last_name'    , TRUE );
	$buyer_company = get_user_meta( $user_id, 'user_company' , TRUE );
	$buyer_tax_id  = get_user_meta( $user_id, 'tax_id'       , TRUE );
	$buyer_address = get_user_meta( $user_id, 'address'      , TRUE );
	$buyer_street  = get_user_meta( $user_id, 'str_nr'       , TRUE );
	$buyer_city    = get_user_meta( $user_id, 'city'         , TRUE );
	$buyer_zip     = get_user_meta( $user_id, 'zip'          , TRUE );

	$c = user( $user_id, 'country_code' );
	if( $c != '' ) {
		$country = get_country_name( $c );
	} else {
		$country = "";
	}

	$buyer_info = "";

	if ( $buyer_company != '' ) {
		$buyer_info .= __( "Company:", "wpjobster-invoices" ) . " " . $buyer_company ."\n" ;
	} elseif ( $buyer_f_name != '' && $buyer_l_name != '' ) {
		$buyer_info .= __( "Name:", "wpjobster-invoices" ) . " " . $buyer_f_name . " " . $buyer_l_name ."\n" ;
	}else{
		$buyer_info .= __( "Username:", "wpjobster-invoices" ) . " " . $buyer->user_login ."\n" ;
	}

	if ( $buyer_tax_id != '' ) {
		$buyer_info .= __( "Tax/VAT ID:", "wpjobster-invoices" ) . " " . $buyer_tax_id . "\n\n";
	} else {
		$buyer_info .= "\n";
	}

	if ( $buyer_address != '' || $buyer_street != '') {
		$buyer_info .= __( "Address:", "wpjobster-invoices" ) . " " . $buyer_address . " " . $buyer_street . "\n";
	}

	if ( $buyer_city != '' ) {
		$buyer_info .= __( "City:", "wpjobster-invoices" ) . " " . $buyer_city . "\n";
	}

	if ( $country != '' ) {
		$buyer_info .= __( "Country:", "wpjobster-invoices" ) . " " . $country . "\n";
	}

	if ( $buyer_zip != '' ) {
		$buyer_info .= __( "Postal Code:", "wpjobster-invoices" ) . " " . $buyer_zip;
	}

	$q = "select * from " . $wpdb->prefix . "job_invoice_business_info";
	$r = $wpdb->get_results( $q );

	if ( count( $r ) > 0 ) {
		$b_name = $r[0]->business_name;
		$b_info = $r[0]->business_information;
		$b_logo = $r[0]->image_url;

		if ( $b_logo == '' ) {
			$b_logo = plugin_dir_url( __FILE__ ) . "/images/logo.png";
		}
	}

	return array( 'buyer_info' => $buyer_info, 'b_name' => $b_name, 'b_info' => $b_info, 'b_logo' => $b_logo );
}

add_action( 'init', 'wpj_invoice_alter_characterset' );
function wpj_invoice_alter_characterset() {
	if ( get_option( 'wpj_invoice_alter_characterset' ) != 'done' ) {
		global $wpdb;

		$wpdb->query( "ALTER TABLE {$wpdb->prefix}job_invoice_business_info CHANGE business_name business_name VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;" );

		$wpdb->query( "ALTER TABLE {$wpdb->prefix}job_invoice_business_info CHANGE business_information business_information VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;" );

		update_option( 'wpj_invoice_alter_characterset', 'done' );
	}
}
