//----------------------------------------
// Initialize calendar fields
//----------------------------------------
( function ( $ ) {
	$.fn.wpjcalendar = function( page, date_type, time_format ) {
		var today = new Date();

		if ( ! date_type ) { date_type = 'date'; }
		if ( ! time_format ) { time_format = 'false'; }

		var inp_val_ts    = $( this ).find( "input" ).val();
		var inp_val_ts_js = inp_val_ts * 1000;

		var new_date = getSafeDateFormat( inp_val_ts_js, date_type );
		if ( inp_val_ts ) {
			$( this ).find( "input" ).val( new_date );
		}

		var inp_name = $( this ).find( "input" ).attr( 'name' );
		$( this ).find( "input" ).attr( 'name', inp_name + '-old' );

		var new_input = $( '<input type="hidden" name="' + inp_name + '" value="' + inp_val_ts + '" />' );
		new_input.insertAfter( $( this ) );

		var min_date = page == 'vacation' ? new Date( today.getFullYear(), today.getMonth(), today.getDate() ) : null;

		$( this ).calendar({
			type           : date_type,
			ampm           : time_format == 'true' ? true : false,
			firstDayOfWeek : parseInt( wpj_vars.starting_day ),
			minDate        : min_date,
			popupOptions   : {
				position   : 'top left',
				lastResort : 'bottom left'
			},
			text           : {
				days       : [
					wpj_vars.days.sun,
					wpj_vars.days.mon,
					wpj_vars.days.tue,
					wpj_vars.days.wed,
					wpj_vars.days.thu,
					wpj_vars.days.fri,
					wpj_vars.days.sat
				],
				months     : [
					wpj_vars.months.jan,
					wpj_vars.months.feb,
					wpj_vars.months.mar,
					wpj_vars.months.apr,
					wpj_vars.months.may,
					wpj_vars.months.jun,
					wpj_vars.months.jul,
					wpj_vars.months.aug,
					wpj_vars.months.sep,
					wpj_vars.months.oct,
					wpj_vars.months.nov,
					wpj_vars.months.dec
				],
				monthsShort: [
					wpj_vars.monthsShort.jan,
					wpj_vars.monthsShort.feb,
					wpj_vars.monthsShort.mar,
					wpj_vars.monthsShort.apr,
					wpj_vars.monthsShort.may,
					wpj_vars.monthsShort.jun,
					wpj_vars.monthsShort.jul,
					wpj_vars.monthsShort.aug,
					wpj_vars.monthsShort.sep,
					wpj_vars.monthsShort.oct,
					wpj_vars.monthsShort.nov,
					wpj_vars.monthsShort.dec
				],
				today      : wpj_vars.today,
				now        : wpj_vars.now,
				am         : wpj_vars.am,
				pm         : wpj_vars.pm
			},
			monthFirst: false,
			onChange: function( date, text, mode ) {
				var timestamp = '';

				if ( date ) {
					timestamp = Math.floor( date.getTime() / 1000 );
				}
				$( this ).find( 'input' ).attr( 'data-timestamp', timestamp );

				$( this ).next( 'input[type=hidden]' ).attr( 'data-timestamp', timestamp );
				$( this ).next( 'input[type=hidden]' ).val( timestamp );
			}
		});

		new_input.attr( 'data-timestamp', inp_val_ts );

		if ( inp_val_ts ) {
			new_input.val( inp_val_ts );
		}

		return this;
	}

	$.fn.wpjCalendarInit = function() {
		if ( $( '.js-calendar' ).length ) {
			jQuery( '.js-calendar' ).each( function() {
				var datetype_attr   = $( this ).attr( 'data-datetype' );
				var datepage_attr   = $( this ).attr( 'data-page' );
				var timeformat_attr = $( this ).attr( 'data-timeformat' );

				if ( typeof datetype_attr !== typeof undefined && datetype_attr !== false ) {
					$( this ).wpjcalendar( datepage_attr, datetype_attr, timeformat_attr );
				} else {
					$( this ).wpjcalendar();
				}
			});
		}
	}

	$.fn.wpjCalendarInit();
} ( jQuery ) );

//----------------------------------------
// Initialize tag fields
//----------------------------------------
( function ( $ ) {
	$.fn.wpjTagsInit = function() {
		if ( $( '.js-tags' ).length ) {
			jQuery( '.js-tags' ).each( function() {
				$( this ).tagsInput({
					'defaultText':'',
					'height': 'auto',
					'width' : '100%'
				});
			});
		}
	}

	$.fn.wpjTagsInit();
} ( jQuery ) );

//----------------------------------------
// Initialize location autocomplete fields
//----------------------------------------
( function ( $ ) {
	// Google Places API
	$.fn.wpjMapsInit = function() {
		if ( typeof google !== 'undefined' ) {
			if ( jQuery( '.js-location-autocomplete' ).length ) {
				jQuery( '.js-location-autocomplete' ).each( function() {
					var location_input = jQuery( this );
					if ( ! location_input.is( 'input' ) ) {
						location_input = location_input.find( 'input' );
					}

					var maps_return = wpj_vars.locations_types[0] ? wpj_vars.locations_types[0] : '(cities)';

					var options = {
						componentRestrictions: {country: wpj_vars.locations_country},
						types: [maps_return],
						language: [wpj_vars.language_attr]
					}

					if ( wpj_vars.location_fields ) {
						options['fields'] = JSON.parse( wpj_vars.location_fields );
					}

					var autocomplete = new google.maps.places.Autocomplete( location_input[0], options );

					google.maps.event.addListener( autocomplete, 'place_changed', function() {
						var place = autocomplete.getPlace();
						if ( place.geometry ) {
							location_input.next( 'input' ).val( place.geometry.location.lat() );
							location_input.next( 'input' ).next( 'input' ).val( place.geometry.location.lng() );
						}
					});
				});
			}
		}
	}

	// TomTom Search API
	$.fn.wpjTomTomInit = function() {
		if ( jQuery( '.js-location-autocomplete' ).length ) {
			jQuery( '.js-location-autocomplete' ).each( function() {
				var this_ui_input = jQuery( this );
				this_ui_input.search({
					apiSettings: {
						onResponse: function(tomtomResponse) {
							var response = { results: [] };
							// translate TomTom API response to work with search
							$.each(tomtomResponse.results, function(index, item) {
								response.results.push({
									title : item.address.freeformAddress,
									lat   : item.position.lat,
									lng   : item.position.lon
								})
							});
							return response;
						},
						url: 'https://api.tomtom.com/search/2/search/{query}.json?countrySet=' + encodeURI( wpj_vars.locations_country.join() ) + '&key=' + wpj_vars.tomtom_api_key
					},
					fields: {
						results : 'results',
						title   : 'title',
						description: false,
						url     : false
					},
					minCharacters : 2,
					showNoResults: false,
					onSelect: function(result, response) {
						jQuery( this_ui_input.find( 'input' )[1] ).val( result.lat );
						jQuery( this_ui_input.find( 'input' )[2] ).val( result.lng );
					}
				});
			});
		}
	}

	// Init
	if ( wpj_vars.locations_api === '' || wpj_vars.locations_api === 'google'
		&& typeof google !== 'undefined' ) {
		google.maps.event.addDomListener( window, 'load', $.fn.wpjMapsInit );
	} else if ( wpj_vars.locations_api === 'tomtom' ) {
		jQuery( document ).ready( function() { $.fn.wpjTomTomInit(); } );
	}
} ( jQuery ) );

//----------------------------------------
// Initialize reCAPTCHA Responsive
//----------------------------------------
( function ( $ ) {
	$.fn.wpjResizeReCaptcha = function() {
		if ( $( '.g-recaptcha-class' ).length ) {
			var width;
			$( '.g-recaptcha-class' ).each( function() {
				if ( ! width ) {
					width = $( this ).parent().width();
				}
				if ( width ) {
					var scale = width / 302;
					$( this ).css( 'transform', 'scale(' + scale + ')' );
					$( this ).css( '-webkit-transform', 'scale(' + scale + ')' );
					$( this ).css( 'transform-origin', '0 0' );
					$( this ).css( '-webkit-transform-origin', '0 0' );
				}
			});
		}
	}

	$( window ).on( 'load resize', function() {
		$.fn.wpjResizeReCaptcha();
	});
} ( jQuery ) );

//----------------------------------------
// Initialize tooltip fields
//----------------------------------------
( function( $ ) {
	$.fn.wpjTooltip = function() {
		$( this ).each( function() {
			var handler_id     = $( this ).attr( 'data-handler-id' );
			var this_handler   = $( this );
			var other_handlers = $( '.js-tooltip-handler:not([data-handler-id="' + handler_id + '"])' );

			var ui_popup       = $( '[data-tooltip-id="' + handler_id + '"]' );

			if ( ui_popup.text().length > 0 ) {
				this_handler.popup({
					target      : this_handler,
					on          : 'manual',
					popup       : ui_popup,
					position    : "right center",
					lastResort  : "right center",
					transition  : 'fade down',
					distanceAway: 0,
					offset      : 0,
					hoverable   : false, // creates issues
					exclusive   : false, // creates issues
					inline      : true,
					preserve    : true,
				});

				this_handler.hover( function() {
					other_handlers.popup( 'hide' );
					this_handler.popup( 'show' );
				});
			} else {
				this_handler.removeClass( 'js-tooltip-handler' );
				ui_popup.removeClass( 'ui popup' );
				ui_popup.hide();
			}
		});
	}

	$( '.js-tooltip-handler' ).wpjTooltip();
} ( jQuery ) );

//----------------------------------------
// Initialize Semantic UI fields
//----------------------------------------
( function( $ ) {
	$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	$( '.ui.dropdown.full-text-search' ).dropdown( { fullTextSearch: true, message: { noResults: wpj_vars.nothing_found } } );
	$( '.ui.menu .item' ).tab();
	$( '.ui.accordion' ).accordion();
	$( '.ui.checkbox' ).checkbox();
} ( jQuery ) );

jQuery( document ).ready( function( $ ) {

	//----------------------------------------
	// Initialize Semantic UI dropdown upward
	//----------------------------------------
	window.onload = function() {
		$( '.ui.dropdown.upward' ).each( function() {
			$( this ).dropdown({ direction: 'upward', fullTextSearch: true, message: { noResults: wpj_vars.nothing_found } });
		});
	}

	//----------------------------------------
	// Initialize Semantic UI clearable input
	//----------------------------------------
	$( '.ui.input.clearable' ).each( function() {
		var $clearable = $( this );
		$clearable.append( '<i class="icon clear link hidden"></i>' );

		var $input = $clearable.find( 'input' );
		var $icon = $clearable.find( 'i.clear.icon' );

		if ( $input.val() ) {
			$icon.removeClass( 'hidden' );
			$clearable.addClass( 'icon' );
		} else {
			$icon.addClass( 'hidden' );
			$clearable.removeClass( 'icon' );
		}

		$input.on( 'change paste keyup', function() {
			if ( $input.val() ) {
				$icon.removeClass( 'hidden' );
				$clearable.addClass( 'icon' );
			} else {
				$icon.addClass( 'hidden' );
				$clearable.removeClass( 'icon' );
			}
		});

		$icon.click( function( e ) {
			$input.val( '' );
			$icon.addClass( 'hidden' );
			$clearable.removeClass( 'icon' );
			e.stopPropagation();
		});
	});

	//------------------------------------------
	// Initialize Semantic UI clearable dropdown
	//------------------------------------------
	$( '.ui.dropdown.clearable' ).each( function() {
		if ( $( this ).dropdown( 'get value' ) ) {
			$( this ).find( '.dropdown.icon' ).removeClass( 'dropdown' ).addClass( 'x' ).addClass( 'clear-dropdown' );
		} else {
			$( this ).removeClass( 'clear-dropdown' ).removeClass( 'x' ).addClass( 'dropdown' );
		}

		$( this ).on( 'change', function() {
			$( this ).find( '.dropdown.icon' ).removeClass( 'dropdown' ).addClass( 'x' ).addClass( 'clear-dropdown' );
		});

		$( document ).on( 'click', '.clear-dropdown', function() {
			$( this ).parents( '.clearable' ).dropdown( 'clear' );
			$( this ).removeClass( 'clear-dropdown' ).removeClass( 'x' ).addClass( 'dropdown' );
		});
	});
});

//----------------------------------------
// Initialize autohide keyboard iOS
//----------------------------------------
( function( $ ) {
	jQuery( '.autohide-keyboard' ).form({
		on: 'blur',
		keyboardShortcuts: false
	});
} ( jQuery ) );

//----------------------------------------
// Initialize button to dropdown on mobile
//----------------------------------------
( function( $ ) {
	$( ".js-buttons-to-dropdown" ).each( function() {
		var $cnt = $( this );

		var selected_val = false;

		$( "<select />" ).appendTo( $cnt );
		$cnt.find( "a" ).each( function() {
			var $el = $( this );

			if ( $el.hasClass( 'active' ) == true ) {
				selected_val = $el.index();
			}

			$( "<option />", {
				"value": $el.attr( "href" ),
				"text" : $el.text()
			}).appendTo( $cnt.find( "select" ) );
		});

		if ( selected_val ) {
			$cnt.find( "select" ).find( "option" ).eq( selected_val - 1 ).prop( 'selected', true );
		}

		$cnt.find( "select" ).change( function() {
			window.parent.postMessage( {data: {
				isExternal    : false,
				isTargetBlank : false,
				currentUrl    : window.location.href,
				nextUrl       : $( this ).find( "option:selected" ).val()
			}}, "*" );
			window.location = $( this ).find( "option:selected" ).val();
		});

		$cnt.find( "select" ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	});
} ( jQuery ) );

//----------------------------------------
// Initialize tab to dropdown on mobile
//----------------------------------------
( function( $ ) {
	$( ".js-tab-to-dropdown" ).each( function() {
		var $cnt = $( this );

		var selected_val = false;

		$( "<select />" ).appendTo( $cnt );
		$cnt.find( "div.item.force-white-btn" ).each( function() {
			var $el = $( this );

			if ( $el.hasClass( 'active' ) == true ) {
				selected_val = $el.index();
			}

			$( "<option />", {
				"value"   : $el.attr( "data-tab" ),
				"text"    : $el.text(),
			}).appendTo( $cnt.find( "select" ) );
		});

		if ( selected_val ) {
			$cnt.find( "select" ).find( "option" ).eq( selected_val - 1 ).prop( 'selected', true );
		}

		$cnt.find( "select" ).change( function() {
			var active_tab = $( '.item.force-white-btn.active' ).attr( 'data-tab' );
			$( 'div[data-tab="' + active_tab + '"]' ).removeClass( 'active' );
			$( 'div[data-tab="' + $( this ).find( "option:selected" ).val() + '"]' ).addClass( 'active' );
		});

		$cnt.find( "select" ).addClass( 'fluid' );
		$cnt.find( "select" ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	});
} ( jQuery ) );

//----------------------------------------
// Initialize toggle arrow
//----------------------------------------
( function( $ ) {
	$( ".js-toggle-arrow" ).each( function() {
		var $cnt = $( this );

		// iOS workaround for on click event
		$cnt.css( 'cursor', 'pointer' );

		// Add ui grid on parent element
		$cnt.addClass( 'ui grid js-toggle-wrapper' );

		// Move existing title inside a 'column' div
		$cnt.find( ':header' ).wrap('<div class="fourteen wide column dynamically dynamically-title"></div>');

		// Append a new column for icon
		$cnt.append( '<div class="two wide column dynamically dynamically-icon"><i class="js-toggle-angle-icon toggle-angle-icon toggle-angle-icon-up icon"></i></div>' );

	});

	// Click on arrow
	$( document ).on( 'click', '.js-toggle-arrow', function() {
		if ( $( this ).find( '.dynamically-icon' ).is( ':visible' ) ) {
			var $cnt = $( this ).find( '.js-toggle-angle-icon' );

			if ( $( this ).find( '.js-toggle-angle-icon' ).hasClass( 'toggle-angle-icon-up' ) ) {
				$cnt.removeClass( 'toggle-angle-icon-up' ).addClass( 'toggle-angle-icon-down' );
				$cnt.parents( '.ui.grid.js-toggle-wrapper' ).nextAll().slideUp( "slow" );
			} else {
				$cnt.removeClass( 'toggle-angle-icon-down' ).addClass( 'toggle-angle-icon-up' );
				$cnt.parents( '.ui.grid.js-toggle-wrapper' ).nextAll().slideDown( "slow" );
			}
		}
	});

	// Hide content on ready
	if ( isMobile() ) {
		$( ".js-toggle-arrow" ).each( function() {
			$( this ).trigger( 'click' );
		});
	}
} ( jQuery ) );

//----------------------------------------
// Initialize number format
//----------------------------------------
jQuery( window ).ready( function( $ ) {
	Number.prototype.formatMoney = function( c, d, t ) {
		var n = Math.round( this * 100 ) / 100,
		c = isNaN( c = Math.abs( c ) ) ? 2 : c,
		d = d == undefined ? "." : d,
		t = t == undefined ? "," : t,
		s = n < 0 ? "-" : "",
		i = parseInt( n = Math.abs( +n || 0 ).toFixed( c ) ) + "",
		j = ( j = i.length ) > 3 ? j % 3 : 0;
		return s + ( j ? i.substr( 0, j ) + t : "" ) + i.substr( j ).replace( /(\d{3})(?=\d)/g, "$1" + t ) + ( c ? d + Math.abs( n - i ).toFixed( c ).slice( 2 ) : "" );
	};
});

//----------------------------------------
// Initialize args for wysiwyg textarea
//----------------------------------------
function wpj_js_description_args_allowed( max_chr_description, post_status, rejected_description, pck_index, identifier_id ) {
	if ( ! identifier_id ) { var identifier_id = 'job_description'; }

	var wysihtml5ParserRules = {
		classes: "any",
		classes_blacklist: {
			"Apple-interchange-newline": 1,
			"MsoNormal": 1,
			"MsoPlainText": 1
		},
		tags: {
			strong : { rename_tag: "b" },
			b      : {},
			i      : {},
			em     : { rename_tag: "i" },
			u      : {},
			br     : {},
			p      : {},
			span   : 1,
			div    : 1,
			ul     : {},
			ol     : {},
			li     : {},
			comment: { remove: 1 },
			style  : { remove: 1 },
		}
	};

	if ( typeof pck_index !== 'undefined' && pck_index ) {
		var input_id = 'package_description_' + pck_index;
		var input_id_toolbar = 'package_description_' + pck_index + '_toolbar';
	} else {
		var input_id = identifier_id;
		var input_id_toolbar = identifier_id + '_toolbar';
	}

	if ( jQuery( 'body' ).hasClass( "rtl" ) ) {
		var stylesheets = [wpj_vars.theme_path + '/assets/css/front-rtl/wysiwyg-rtl.css'];
	} else {
		var stylesheets = [wpj_vars.theme_path + '/assets/css/vendor/front/wysiwyg.css'];
	}

	var editor = new wysihtml5.Editor( input_id, {
		toolbar    : input_id_toolbar,
		autoLink   : false,
		parserRules: wysihtml5ParserRules,
		stylesheets: stylesheets
	});

	editor.on( "load", function() {

		if ( typeof pck_index === 'undefined' || ! pck_index  ) {
			var $iframe = jQuery( this.composer.iframe );
			var $body   = jQuery( this.composer.element );
			var $html   = $body.parent();

			$body.css( { 'min-height': '100px', 'overflow': 'hidden', 'height': 'auto' } );
			$html.css( { 'height': 'auto', } );

			jQuery( '<link rel="stylesheet" href="' + wpj_vars.blog_url + '?action=kirki-styles">' ).appendTo( $html.children( 'head' ) );

			var scrollHeightInit = $body[0].scrollHeight;
			var bodyHeightInit   = $body.height();
			var heightInit       = Math.min( scrollHeightInit, bodyHeightInit );
			$iframe.height( heightInit );

			$body.bind( 'keypress keyup keydown paste change focus blur', function( e ) {
				var scrollHeight = $body[0].scrollHeight;
				var bodyHeight   = $body.height();
				var height       = Math.min( scrollHeight, bodyHeight );
				$iframe.height( height );
			});
		}

		add_input_length_listener( editor, jQuery( "#" + input_id ).siblings( ".char-count" ), max_chr_description, "html" );

		jQuery( '#' + identifier_id ).parents( '#job_description_field' ).removeClass( 'error' );
		if ( post_status == 'pending' && typeof rejected_description !== 'undefined' && rejected_description == 1 ) {
			jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).addClass( "visible" );
		}

		if ( jQuery( 'body' ).hasClass( 'wpj-is-ios' ) ) {
			if ( jQuery( '#' + input_id + '_iosblurfix' ).length == 0 ) {
				// create fake input to help with blur
				jQuery( '#' + input_id ).after( '<input id="' + input_id + '_iosblurfix" type="text" disabled="disabled" style="width: 0; height: 0; padding: 1px; border: 0; position: absolute; opacity: 0;">' );
			}

			jQuery( document ).mouseup( function( e ) {
				// if the target of the click isn't the container nor a descendant of the container
				if ( ! jQuery( '#' + input_id ).is( e.target )
					&& jQuery( '#' + input_id ).has( e.target ).length === 0
					&& ( e.target.tagName.toUpperCase() !== 'INPUT' )
					&& ( e.target.tagName.toUpperCase() !== 'TEXTAREA' )
				) {
					jQuery( '#' + input_id + '_iosblurfix' ).removeAttr( "disabled" ).focus().blur().attr( "disabled", "disabled" );
				}
			});
		}
	})
	.on( "focus", function() {
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).addClass( "visible" );
		jQuery( '#' + identifier_id ).parents( ".post-new-job-wrapper-x" ).eq( 0 ).addClass( 'has-focus' );
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( 'iframe' ).addClass( 'focus' );
		jQuery( '#' + identifier_id ).parents( "#job_description_field" ).removeClass( 'error' );
	})
	.on( "blur", function() {
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).removeClass( "visible" );
		jQuery( '#' + identifier_id ).parents( ".post-new-job-wrapper-x" ).eq( 0 ).removeClass( 'has-focus' );
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( 'iframe' ).removeClass( 'focus' );
	})

	editor.observe( "load", function() {

	});
}

jQuery( document ).ready( function( $ ) {

	//-----------------------------------
	// Initialize modal open
	//-----------------------------------
	$( '.button-modal-open' ).click( function( e ) {
		e.preventDefault();

		var modal_class = $( this ).next( '.ui.modal' ).attr( 'class' );
		if ( modal_class ) {
			var classes = modal_class.split( ' ' );

			var class_list = "";
			for ( var i = 0; i < classes.length; i++ ) {
				if ( classes[i].length > 0 ) {
					class_list += "." + classes[i];
				}
			}

			localStorage.setItem( 'modal_name', class_list );
		} else {
			class_list = localStorage.getItem( 'modal_name' );
		}

		$( class_list )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	//-----------------------------------
	// Initialize form submit
	//-----------------------------------
	$( "[data-submit]" ).click( function() {
		var ob = $( this ).parents( "form" );

		if ( $( this ).data( "submit" ) ) { ob = $( $( this ).data( "submit" ) ); }

		ob.submit();

		return false;
	});

	//-----------------------------------
	// Initialize range slider
	//-----------------------------------
	var slider_default = $( "#slider-range-min" ).data( "value" );

	if ( 'undefined' == typeof slider_default ) slider_default = wpj_vars.max_default_days;

	$( "#slider-range-min" ).slider({
		range: "min",
		value: slider_default,
		min  : 1,
		max  : wpj_vars.max_default_days,
		slide: function( event, ui ) {
			$( "#amount" ).val( ui.value );

			jQuery.ajax({
				type    : 'POST',
				url     : wpj_vars.ajaxurl,
				data    : {
					action : 'day_translation',
					value  : ui.value
				},
				success : function( data ) {
					$( "#amount-label" ).html( data );
				}
			});
		}
	});

	$( "#amount" ).val( $( "#slider-range-min" ).slider( "value" ) );

});

function wpj_audio_js_player_init( id, url, filename ) {
	jQuery( "#jquery_jplayer_" + id ).jPlayer({
		ready: function() {
			jQuery( this ).jPlayer( "setMedia", {
				title:filename,
				mp3: url,
				wav: url
			});
		},
		play: function() { // to avoid multiple jPlayers playing together.
			jQuery( this ).jPlayer( "pauseOthers" );
		},
		swfPath            : "../../js",
		supplied           : "mp3, wav",
		cssSelectorAncestor: "#jp_container_" + id,
		wmode              : "window",
		globalVolume       : true,
		useStateClassSkin  : true,
		autoBlur           : false,
		smoothPlayBar      : true,
		keyEnabled         : true
	});
}
