jQuery( document ).ready( function( $ ) {

	// initialize top search
	if ( typeof wpj_big_search_top == 'function' ) { wpj_big_search_top(); }

	// modernizr library
	if ( typeof Modernizr !== 'undefined' ) {
		if ( Modernizr.touch ){
			$( 'body' ).addClass( 'touch' );
		} else {
			$( 'body' ).addClass( 'no-touch' );
		}
	}

	// disable mousewheel on a input number field when not in focus
	// (to prevent Cromium browsers change the value when scrolling)
	$( 'form' ).on( 'blur', 'input[type=number]', function ( e ) {
		$( this ).off( 'mousewheel.disableScroll' );
	});

	// iOS devices
	var ver = getIOSversion();
	if ( ver[0] >= 11 ) {
		$( "body" ).addClass( "ios11" );
	}

	// mobile iframe
	if ( inIframe() ) {
		jQuery( 'body' ).addClass( 'wpj-is-iframe' );
		jQuery( 'body' ).removeClass( 'wpj-maybe-iframe' );
		$.cookie( 'wpj_is_iframe', 'true', { expires: 7, path: '/' });
	} else {
		jQuery( 'body' ).removeClass( 'wpj-is-iframe' );
		jQuery( 'body' ).removeClass( 'wpj-maybe-iframe' );
		$.cookie( 'wpj_is_iframe', 'false', { expires: 7, path: '/' });
	}

	// get the real viewport height on mobile when the address bar or other bars are on
	// https://css-tricks.com/the-trick-to-viewport-units-on-mobile/
	let vh = window.innerHeight * 0.01;
	document.documentElement.style.setProperty('--vh', `${vh}px`);
	jQuery( window ).on( 'load resize', _.debounce( function() {
		let vh = window.innerHeight * 0.01;
		document.documentElement.style.setProperty('--vh', `${vh}px`);
	}, 200 ) );

	// brizy: stop login/register popup when editing
	if ( wpj_vars.is_user_logged_in && ( getUrlParameter( 'brizy-edit' ) || getUrlParameter( 'brizy-edit-iframe' ) ) ) {
		$( document ).off( 'click', '.login-link' );
		$( document ).off( 'click', '.register-link' );
	}

	// apply lazy loading to all site images
	if ( wpj_vars.lazy_loading_enabled == 1 && typeof wpj_enable_lazy_loading == 'function' ) {

		$( 'img' ).each( function() {

			if (
				! $( this ).hasClass( "brz-img" )
				&& ! $( this ).hasClass( "portfolio-image" )
				&& ! $( this ).hasClass( "rs-pzimg" )
				&& ! $( this ).hasClass( "rev-slidebg" )
				&& ! $( this ).parents( '.message-box-logo-container' )[0]
			) { // exclude brizy, featherlight (portofolio), revslider images

				$( this ).attr( 'data-echo', $( this ).attr( 'src' ) );
				$( this ).addClass( 'echo-lazy-load' );
				$( this ).attr( 'src', wpj_vars.theme_path + "/assets/images/blank.gif" );

			}

		});

		wpj_enable_lazy_loading();

	}

	// clear localstorage on logout
	$( document ).on( 'click', '.log-out', function() {
		localStorage.clear();
	});

	// accepts only numbers in numeric inputs
	$( 'input[type="number"]' ).on( 'keypress', function( e ) {

		var allowed_key_codes_arr = [/*backspace*/8,/*tab*/9,/*arrows*/37,39,/*numbers*/48,49,50,51,52,53,54,55,56,57,/*dot*/46,110,190]; // allowed keys

		// if event key is not in array and its not Ctrl+V (paste) return false
		if ( $.inArray( e.keyCode, allowed_key_codes_arr ) === -1 && ( e.keyCode != 17 && e.keyCode != 86 ) ) {
			e.preventDefault();

		// if float decimal exists and key is not backspace return false
		} else if ( $.trim( $( this ).val() ).indexOf( '.' ) > -1 && $.inArray( e.keyCode, [110, 190] ) != -1 ) {
			e.preventDefault();

		// return true
		} else {
			return true;

		}

	}).on( 'paste', function( e ) {

		// get event text and filter out letter characters
		var pasted_text = e.originalEvent.clipboardData.getData( 'Text' ).replace( /[^0-9.]/g, '' );

		if ( $.isNumeric( pasted_text ) ) {
			e.originalEvent.target.value = pasted_text;
			e.preventDefault();

		} else {
			e.preventDefault();

		};

	});

});