function wpj_get_val( identificator ) {
	return wpj_validate_input_content( jQuery( identificator ).val() );
}

function wpj_item_has_value( item_name ) {
	var value = false;
	if ( item_name == "languages" ) {
		if ( wpj_get_val( ".up_language" ) && wpj_get_val( ".up_proficiency" ) ) { value = true; }
	} else if ( item_name == "skills" ) {
		if ( wpj_get_val( ".up_skills" ) ) { value = true; }
	}

	return value;
}

function wpj_get_html_for_inputs( $this, item_name, item_value ) {
	var content = "";

	if ( item_name == "languages" ) {
		content = '\
			<div class="new_item">\
				<div class="ui mini input new-item-content">\
					<input placeholder="' + wpj_vars.language_lbl + '" class="di up_language" type="text" name="language" />\
					&nbsp;\
					<input placeholder="' + wpj_vars.proficiency_lbl + '" class="di up_proficiency" type="text" name="proficiency" />\
				</div>\
			</div>\
		';
	} else if ( item_name == "skills" ) {
		content = '\
			<div class="new_item">\
				<input placeholder="' + wpj_vars.skill_lbl + '" class="up_skills" type="text" name="skill" />\
			</div>\
		';
	} else if ( item_name == "tagline" ) {
		content = "\
			<div class='tagline-temp'>\
				<div class='ui input'><input type='text' id='tmp_tagline' class='tmp_tagline' value='" + item_value + "' /></div>\
				<a data-type='tagline' class='save-info'>" + wpj_vars.save_lbl + "</a>\
			</div>\
		";
	} else if ( item_name == "description" ) {
		if ( item_value == null || item_value === false ) { item_value = ''; }
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			content = '<textarea class="tmp_description" id="tmp_description">' + item_value + '</textarea>\
				\
				<div id="tmp_description_toolbar" class="tmp_description-wysiwyg-toolbar">\
					<a data-wysihtml5-command="bold"><i class="bordered bold icon"></i></a>\
					<a data-wysihtml5-command="italic"><i class="bordered italic icon"></i></a>\
					<a data-wysihtml5-command="underline"><i class="bordered underline icon"></i></a>\
					<a data-wysihtml5-command="insertUnorderedList"><i class="bordered unordered list icon"></i></a>\
					<a data-wysihtml5-command="insertOrderedList"><i class="bordered ordered list icon"></i></a>\
				</div>\
			';
		} else {
			content = "<textarea id='tmp_description'>" + item_value + "</textarea>";
		}
	}

	jQuery( $this ).parents( '.user-' + item_name + '-wrapper' ).find( '.' + item_name + '-content' ).append( content );

};

function wpj_get_html_to_show( $this, item_name ) {

	var $ = jQuery.noConflict();

	var content = "";

	if ( item_name == "languages" ) {
		content = '\
			<span class="' + wpj_get_val( ".up_language" ) + '">\
				<input readonly type="text" class="inp_language not_editable di" value="' + wpj_get_val( ".up_language" ) + '" />\
				<input readonly type="text" class="inp_proficiency not_editable di" value="' + wpj_get_val( ".up_proficiency" ) + '" />\
				\
				<div class="right di">\
					<div class="di" data-inverted="" data-tooltip="' + wpj_vars.edit_lbl + '" data-position="top center">\
						<i data-type="' + item_name + '" class="user-edit-language edit icon" class="di"></i>\
					</div>\
					\
					<div class="di" data-inverted="" data-tooltip="' + wpj_vars.delete_lbl + '" data-position="top center">\
						<i data-type="' + item_name + '" class="user-remove-item red remove icon" class="di"></i>\
					</div>\
				</div>\
			</span>\
		';
	} else if ( item_name == "skills" ) {
		content = '\
			<span class="' + wpj_sanitize_title( wpj_get_val( ".up_skills" ) ) + '">' + $.trim( wpj_get_val( ".up_skills" ) ) + '\
				<div class="actions di">\
					<i data-type="' + item_name + '" class="user-remove-item red remove icon" class="di"></i>\
				</div>\
			</span>\
		';
	}

	jQuery( '.' + item_name + '-content' ).append( content );
}

function wpj_initialize_and_remove_textarea( action ) {

	var $ = jQuery.noConflict();

	if ( action == "initialize" ) {
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			wpj_js_description_args_allowed( parseInt( wpj_vars.user_chr_limit ), '', '', '', 'tmp_description' );
		} else {
			$( "#tmp_description" ).height( $( "#tmp_description" )[0].scrollHeight );
			$( "#tmp_description" ).focus();
		}
	} else if ( action == "remove" ) {
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			$( '#tmp_description' ).remove();
			$( '.wysihtml5-sandbox' ).remove();
			$( '#tmp_description_toolbar' ).remove();
		} else {
			$( '#tmp_description' ).remove();
		}
	} else {
		return false;
	}
}

function wpj_get_ajax_action( item_name ) {
	if ( item_name == "languages_new" ) {
		return "save_user_language_content";
	} else if ( item_name == "languages_remove" ) {
		return "remove_user_language_content";
	} else if ( item_name == "skills_new" ) {
		return "save_user_skill_content";
	} else if ( item_name == "skills_remove" ) {
		return "remove_user_skill_content";
	} else if ( item_name == "description_edit" ) {
		return "save_user_description_content";
	} else if ( item_name == "tagline_edit" ) {
		return "save_user_tagline_content";
	} else if ( item_name == "education_remove" ) {
		return "remove_user_education_content";
	} else if ( item_name == "certification_remove" ) {
		return "remove_user_certification_content";
	} else {
		return false;
	}
}

function wpj_get_ajax_data( item_name, item_value ) {
	var data = {};
	if ( item_name == "languages_new" ) {
		data = {
			action      : wpj_get_ajax_action( item_name ),
			language    : wpj_get_val( ".up_language" ),
			proficiency : wpj_get_val( ".up_proficiency" ),
			uid         : jQuery( '#user_id' ).text()
		};
	} else {
		data = {
			action : wpj_get_ajax_action( item_name ),
			item   : item_value,
			uid    : jQuery( '#user_id' ).text()
		};
	}

	return data;
}

function wpj_send_via_ajax( data ) {
	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: data,
		success: function( data ) {}
	});
}

function wpj_up_open_modal( item_name, action_type, $this ) {

	var $ = jQuery.noConflict();

	if ( ! action_type ) { action_type = 'new'; }

	var $indx = $this.parents( '#' + item_name + '-item' ).attr( 'class' );

	$( '.up-' + item_name + '-modal-wrapper' )
		.modal({
			onApprove: function() { return false; },
			onDeny: function() { return false; }
		})
		.modal('setting', 'transition', 'fly down')
		.modal('show')
		.modal('refresh');

	jQuery.ajax({
		type: 'POST',
		url: wpj_vars.ajaxurl,
		data: {
			action: 'show_user_' + item_name + '_content',
			uid: $( '#user_id' ).text(),
			action_type: action_type,
			indx: $indx,
		},
		success: function( data ) {
			var item_action = action_type == 'new' ? wpj_vars.add_lbl : wpj_vars.edit_lbl;
			$( '.add-or-edit-title' ).html( item_action );

			$( '.up-' + item_name + '-modal-main-content' ).html( data );

			$( '.up-' + item_name + '-modal-wrapper' ).modal( 'refresh' );

			if ( action_type == 'new' ) {
				$( '.save-item' ).addClass( 'disabled' );
			}

			if ( $( ".user_from_year" ).val() ) {
				$( ".user_to_year" ).find( 'option' ).each( function() {
					if ( parseInt( $( ".user_from_year" ).val() ) && parseInt( $( this ).val() ) >= parseInt( $( ".user_from_year" ).val() ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});
			}

			if ( $( ".user_to_year" ).val() ) {
				$( ".user_from_year" ).find( 'option' ).each( function() {
					if ( parseInt( $( ".user_to_year" ).val() ) && parseInt( $( this ).val() ) <= parseInt( $( ".user_to_year" ).val() ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});
			}
		}
	});

	return false;
}

function strip_tags( val ) {
	if ( val ) {
		return val.replace( /<(.|\n)*?>/g, '' );
	} else {
		return val;
	}
}

jQuery( document ).ready( function( $ ) {

	// Switch between mobile and pc view
	$( window ).on( 'load resize', function() {
		var win = $( this );
		if ( win.width() > 767 ) {

			// User account table info
			$( '.ui.divided.list.user-account-list' ).addClass( 'relaxed' ).addClass( 'horizontal' );

		} else {

			// User account table info
			$( '.ui.divided.list.user-account-list' ).removeClass( 'relaxed' ).removeClass( 'horizontal' );

		}
	});

	// count info popup
	$( '.content-wrapper' ).popup({ on: 'hover' });

//--> START New Item
	var toggle_new_item = false;
	$( document ).on( "click", ".user-new-item", function( e ) {
		e.preventDefault();

		var $this = $( this );
		var item_name = $( this ).data( 'type' );

		if ( item_name == 'education' || item_name == 'certification' ) {
			wpj_up_open_modal( item_name, 'new', $this );
		} else {

			/* EDIT */ if ( ! toggle_new_item ) { toggle_new_item = true;

				// Change the label to "Save";
				$( this ).text( wpj_vars.save_lbl );

				// Append inputs to complete the content
				wpj_get_html_for_inputs( $this, item_name );

			/* SAVE */ } else { toggle_new_item = false;

				// Get values
				var val = wpj_item_has_value( item_name );

				if ( val && ! $( 'span' ).hasClass( wpj_sanitize_title( wpj_get_val( ".up_" + item_name ) ) ) ) {

					// Show the new content in fron-end
					wpj_get_html_to_show( $this, item_name );

					// Save the data to user_meta
					wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_new", wpj_get_val( ".up_" + item_name ) ) );

					// Remove "no item" paragraph
					$( '.' + item_name + '-content' ).children( '.no_item' ).remove();

				}

				// Change the label to "Add New";
				$( this ).text( wpj_vars.add_new_lbl );

				// Remove editable content
				$( ".new_item" ).remove();
			}

		}
	});
//--> END New Item

//--> START Edit Item
	var toggle_edit_item = false;
	var click_count = 0;
	$( document ).on( "click", ".user-edit-item", function( event, item_name ) { click_count++;
		event.preventDefault();

		var $this = $( this );

		if ( event.originalEvent !== undefined ) { // is clicked
			item_name = $( this ).data( 'type' );
		} else { // is triggered
			toggle_edit_item = true;
		}

		if ( item_name == 'education' || item_name == 'certification' ) {
			wpj_up_open_modal( item_name, 'edit', $this );
		} else {

			/* EDIT */ if ( ! toggle_edit_item ) { if ( item_name != "tagline" ) { toggle_edit_item = true; }
				// Change the label to "Save Description";
				if ( item_name == "description" ) { $( this ).text( wpj_vars.save_lbl ); }

				// Hide paragraph description until edit is done
				if ( item_name == "tagline" ) {
					$( this ).hide();
				} else {
					$( this ).siblings( '.' + item_name + '-content' ).find( '.' + item_name ).hide();
				}

				// Append inputs to complete the content
				if ( item_name == "description" ) {
					var value = wpj_vars.desc_content;
					if ( click_count > 1 ) {
						var value = wpj_vars.wysiwyg_enabled == 'yes' ? $( '.description-content' ).html() : $( '.description-content' ).text();
						if ( value.includes( "no_item" ) ) {
							value = '';
						}
					}
				} else if ( item_name == "tagline" ) {
					var value = $( this ).attr( 'class' ).includes( "no_item" ) ? '' : $( this ).text();
				}

				// Show editable content
				wpj_get_html_for_inputs( $this, item_name, value );

				// Set Focus
				$( '#tmp_' + item_name ).focus();

				// Initialize Textarea
				if ( item_name == "description" ) { wpj_initialize_and_remove_textarea( "initialize" ); }

			/* SAVE */ } else { toggle_edit_item = false;

				// Change the label to "Edit Description";
				if ( item_name == "description" ) { $( this ).text( wpj_vars.edit_desc_lbl ); }

				// Show paragraph
				if ( item_name == "description" ) {
					if ( strip_tags( $( '.tmp_' + item_name ).val() ) == '' ) {
						$( '.user-description-wrapper' ).find( '.description-content' ).find( '.' + item_name ).html( '<p class="no_item">' + wpj_vars.no_description + '</p>' ).show();
					} else {
						$( '.user-description-wrapper' ).find( '.description-content' ).find( '.' + item_name ).html( $( '.tmp_' + item_name ).val() ).show();
					}
				} else {
					$( '.' + item_name ).html( wpj_validate_input_content( $( '.tmp_' + item_name ).val() ) ).show();
				}

				// Lost Focus
				$( '#tmp_' + item_name ).blur();

				// Save the data to user_meta
				wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_edit", $( '#tmp_' + item_name ).val() ) );

				// Remove editable content
				if ( item_name == "description" ) {
					wpj_initialize_and_remove_textarea( "remove" );
				}
			}
		}
	});
//--> END Edit Item

//--> START Remove Item
	$( document ).on( "click", ".user-remove-item", function( e ) {
			e.preventDefault();

			var item_name = $( this ).data( 'type' );

			// Remove in front-end
			$( this ).parents( 'span' ).remove();

			// Insert no item text if items list is empty
			if ( $( '.' + item_name + '-content > span' ).length == 0 ) {
				var message = '';
				if ( item_name == "languages" ) {
					message = wpj_vars.no_languages;
				} else if ( item_name == "skills" ) {
					message = wpj_vars.no_skills;
				} else if ( item_name == "education" ) {
					message = wpj_vars.no_educations;
				} else if ( item_name == "certification" ) {
					message = wpj_vars.no_certifications;
				}
				$( '.' + item_name + '-content' ).append( '<p class="no_item">' + message + '</p>' );
			}

			// Save the data to user_meta
			var item_to_be_removed = item_name == "skills" ? $( this ).parents( "span" ).text() : $( this ).parents( "span" ).attr( "class" );
			wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_remove", wpj_validate_input_content( item_to_be_removed ) ) );

		});
//--> END Remove Item

//--> START Edit User Languages
	var toggle_edit_language = false;
	$( document ).on( "click", ".user-edit-language", function( e ) {
		e.preventDefault();

		var item_name = $( this ).data( 'type' );

		/* EDIT */ if ( !toggle_edit_language ) { toggle_edit_language = true;

			// Current SPAN
			var this_span = $( this ).parents( "span" );

			// Reset divs to store the value before edit
			$( '.old_language, .old_proficiency' ).remove();

			// Make the content editable
			this_span.find( ".inp_language, .inp_proficiency" ).removeClass( "not_editable" );
			this_span.find( ".inp_language, .inp_proficiency" ).attr( "readonly", false );

			// Remove "edit" class and add "save" class
			this_span.find( ".user-edit-language" ).removeClass( "edit" ).addClass( "save" );
			this_span.find( ".user-edit-language" ).parent().attr( "data-tooltip", wpj_vars.save_lbl );

			// Store the value before edit
			var old_content = '\
				<div class="old_language" style="display:none">' + this_span.find( ".inp_language" ).val() + '</div>\
				<div class="old_proficiency" style="display:none">' + this_span.find( ".inp_proficiency" ).val() + '</div>\
			';
			$( old_content ).insertAfter( this_span.find( ".inp_proficiency" ) );

		/* SAVE */ } else { toggle_edit_language = false;

			// Current SPAN
			var this_span = $( this ).parents( "span" );

			// Transform the content to paragraph
			this_span.find( ".inp_language, .inp_proficiency" ).addClass( "not_editable" );
			this_span.find( ".inp_language, .inp_proficiency" ).attr( "readonly", true );

			// Remove "save" class and add "edit" class
			this_span.find( ".user-edit-language" ).removeClass( 'save' ).addClass( 'edit' );
			this_span.find( ".user-edit-language" ).parent().attr( "data-tooltip", wpj_vars.edit_lbl );

			// Save the content
			var data = {
				action          : 'change_user_language_content',
				old_language    : this_span.find( ".old_language" ).html(),
				language        : wpj_validate_input_content( this_span.find( ".inp_language" ).val() ),
				old_proficiency : this_span.find( ".old_proficiency" ).html(),
				proficiency     : wpj_validate_input_content( this_span.find( ".inp_proficiency" ).val() ),
				uid             : $( '#user_id' ).text(),
			};
			wpj_send_via_ajax( data );

		}
	});
//--> END Edit User Languages

//--> START User Tagline
	$( document ).on( "click", ".save-info", function( e ) {
		e.preventDefault();

		var tagline_value = wpj_validate_input_content( $( ".tmp_tagline" ).val() );
		if ( ! tagline_value ) {
			tagline_value = wpj_vars.no_tagline;
			$( this ).parents( '.user-tagline-wrapper' ).find( '.tagline' ).addClass( 'no_item' );
		} else {
			$( this ).parents( '.user-tagline-wrapper' ).find( '.tagline' ).removeClass( 'no_item' );
		}

		$( ".tagline" ).html( tagline_value ).show();

		wpj_send_via_ajax( wpj_get_ajax_data( "tagline_edit", wpj_validate_input_content( $( "#tmp_tagline" ).val() ) ) );

		$( ".tagline-temp" ).remove();
	});
//--> END User Tagline

//--> START User Education & Certification
	var classes = [ "user_from_year", "user_to_year" ];

	classes.forEach( function( class_name ) {
		$( document ).on( 'change', '.' + class_name, function() {
			var this_val = wpj_validate_input_content( $( this ).val() );

			if ( class_name.includes( "to" ) ) {

				$( ".user_from_year" ).find( 'option' ).each( function() {
					if ( parseInt( this_val ) && parseInt( $( this ).val() ) <= parseInt( this_val ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});

			} else {

				$( ".user_to_year" ).find( 'option' ).each( function() {
					if ( parseInt( this_val ) && parseInt( $( this ).val() ) >= parseInt( this_val ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});

			}
		});
	});

	$( document ).on( 'submit', '.modal_form', function( event ) {
		event.preventDefault();

		var item_name = $( this ).data( 'type' );

		$( '.modal_form .actions .button' ).addClass( 'loading' );

		jQuery.ajax({
			type : "POST",
			url  : wpj_vars.ajaxurl,
			data : "action=save_user_" + item_name + "_content&" + $( this ).serialize(),
			success: function( msg ) {
				$( '.ui.modal.up-' + item_name + '-modal-wrapper' ).modal( 'hide' );
				location.reload();
			}
		});

	});

	$( document ).on( 'change', 'input[name="user_school"], input[name="user_certification_name"]', function( event ) {
		if ( $( this ).val().length !== 0 ) {
			$( '.save-item' ).removeClass( 'disabled' );
		} else {
			$( '.save-item' ).addClass( 'disabled' );
		}
	});

	$( document ).on( 'change', '.certification-not-expire, .user_to_year, .user_to_month', function( event ) {
		if ( $( this ).attr( 'class' ) == 'certification-not-expire' ) {
			$( '.user_to_year' ).val( '' );
			$( '.user_to_month' ).val( '' );
		} else {
			$( '.certification-not-expire' ).prop( 'checked', false );
		}
	});

//--> END User Education & Certification

//--> START User Portfolio
	$( document ).on( "click", ".js-toggle-portfolio-handler", function( e ) {
		e.preventDefault();

		$(this).parent().children(".js-profile-portfolio-carousel").hide();
		$(this).hide();

		$(this).parent().children(".js-profile-portfolio-uploader").show();
		$(this).parent().children(".js-refresh-portfolio-handler").show();
	});

	$( document ).on( "click", ".js-refresh-portfolio-handler", function( e ) {
		e.preventDefault();
		location.reload();
	});
//--> END User Portfolio

//--> START User Search
	$( '#searchInp, #locationInp, #radiusInp' ).on( 'keyup keydown keypress blur change', function() {
		var strName        = '';
		var strLocation    = '';
		var strLocationRad = '';
		var strLong        = '';
		var strLat         = '';
		var params         = '';

		if ( $( '#searchInp' ).length !== 0 ) {
			strName = wpj_validate_input_content( $( '#searchInp' ).val() );
			strName = strName.replace( /\s+/g, '-' ).toLowerCase();
			params  = params + '&user=' + strName;
		}

		if ( $( '#locationInp' ).length !== 0 ) {
			strLocation = wpj_validate_input_content( $( '#locationInp' ).val() );
			strLocation = strLocation.replace( /\s+/g, '-' ).toLowerCase();
			params      = params + '&location=' + strLocation;

			strLong     = wpj_validate_input_content( $( '#user_long' ).val() );
			params      = params + '&long=' + strLong;

			strLat      = wpj_validate_input_content( $( '#user_lat' ).val() );
			params      = params + '&lat=' + strLat;
		}

		if ( $( '#radiusInp' ).length !==0 ) {
			strLocationRad = wpj_validate_input_content( $( '#radiusInp' ).val() );
			strLocationRad = strLocationRad.replace( /\s+/g, '-' ).toLowerCase();
			params         = params + '&location_rad=' + strLocationRad;
		}

		if ( params != '' ) {
			params = '?' + params.substring( 1 );
		}

		$( '.searchUsername' ).addClass( 'loading' );

		history.pushState( null, "page 2", wpj_vars.page_url + params );
	});

	if ( $( '#searchInp' ).length > 0 ) {

		var user            = wpj_validate_input_content( $( "#searchInp" ).val() );
		var limitInp        = wpj_vars.posts_per_page;
		var initialLimitInp = wpj_vars.posts_per_page;

		doneTyping();

		var typingTimer;
		var doneTypingInterval = 500;
		var $input = $( '#searchInp, #locationInp, #radiusInp' );

		$input.on( 'keyup keydown keypress blur change', function () {
			clearTimeout( typingTimer );
			typingTimer = setTimeout( doneTyping, doneTypingInterval );
		});

		$input.on( 'keydown', function () {
			clearTimeout( typingTimer );
			$( '.wpj-search-user-load-more' ).show();
			$( '.wpj-search-user-load-more' ).parent().parent().addClass( 'mb150' );
			$( '.wpj-search-user-load-more' ).parent().addClass( 'pr' );

			limitInp = wpj_vars.posts_per_page;
		});

		$( ".wpj-search-user-load-more" ).click( function() {
			$( this ).addClass( 'loading' );
			initialLimitInp = Number( initialLimitInp ) + Number( wpj_vars.posts_per_page );
			limitInp = initialLimitInp;
			doneTyping();
		});
	}

	function doneTyping () {
		var searchInp   = wpj_validate_input_content( $( '#searchInp' ).val() );
		var locationInp = wpj_validate_input_content( $( '#locationInp' ).val() );
		var radiusInp   = wpj_validate_input_content( $( '#radiusInp' ).val() );
		var longInp     = wpj_validate_input_content( $( '#user_long' ).val() );
		var latInp      = wpj_validate_input_content( $( '#user_lat' ).val() );

		$.post( wpj_vars.ajaxurl, {
			action     : 'search_users_ajax',
			searchInp  : searchInp,
			limitInp   : limitInp,
			locationInp: locationInp,
			radiusInp  : radiusInp,
			longInp    : longInp,
			latInp     : latInp,
		},
		function( data ) {
			obj = JSON.parse( data );

			$( ".wpj-search-user-load-more" ).removeClass( 'loading' );

			if ( typeof( obj['usersInfo'][0] ) != "undefined" && obj['usersInfo'][0] !== null ) {
				if ( obj['usersInfo'][0].queryresults < obj['usersInfo'][0].limit ) {
					$( '.wpj-search-user-load-more' ).hide();
					$( '.wpj-search-user-load-more' ).parent().parent().removeClass( 'mb150' );
					$( '.wpj-search-user-load-more' ).parent().removeClass( 'pr' );
				} else {
					$( '.wpj-search-user-load-more' ).show();
					$( '.wpj-search-user-load-more' ).parent().parent().addClass( 'mb150' );
					$( '.wpj-search-user-load-more' ).parent().addClass( 'pr' );
				}
			} else {
				$( '.wpj-search-user-load-more' ).hide();
				$( '.wpj-search-user-load-more' ).parent().parent().removeClass( 'mb150' );
				$( '.wpj-search-user-load-more' ).parent().removeClass( 'pr' );
			}

			$( '.searchUsername' ).removeClass( 'loading' );

			$( '#userInformations' ).empty();

			if ( obj['usersInfo'].length ) {
				$.each( obj['usersInfo'] , function( index, obj ) {
					if( obj.description ) {
						var desc = '<div class="userDescription">' + obj.description + '</div>';
					} else {
						var desc = '';
					}

					if ( obj.current_user ) {
						var login_class = '';
					} else {
						var login_class = 'login-link';
					}

					if ( obj.contact_url ) {
						var contact_button = '<a onclick="return wpj_chat_open_box( ' + obj.id + ' );" class="ui fluid button ' + login_class + '" href="' + obj.contact_url + '">' + wpj_vars.contact + '</a>';
					} else {
						var contact_button = '<span class="ui fluid button disabled" href="#">' + wpj_vars.contact + '</span>';
					}

					if ( obj.company ) {
						var company = ' <span class="user-company">(' + obj.company + ')</span>';
					} else {
						var company = '';
					}

					$( '#userInformations' ).append(
						'<div class="ui segment">\
							<div class="ui three column middle aligned stackable grid">\
								<div class="two wide column">\
									<div class="userImage">\
										<img width="100" height="100" border="0" class="user_img round-avatar" src="' + obj.avatar + '" />' + obj.level_icon + '\
									</div>\
								</div>\
								<div class="eleven wide column">\
									<div class="userDetails">\
										<h2 class="userName di"><a href="' + obj.addr + '">' + obj.username + company + '</a></h2>\
										' + obj.user_icons + desc + '\
										<div class="userExtraDetails">\
											<span class="userRating"><span class="labelDesc">' + wpj_vars.rating + '</span> ' + obj.rating + '</span>\
											<span class="userCompletedOrders"><span class="labelDesc">' + wpj_vars.completed_jobs + '</span> ' + obj.com_jb + '</span>\
											<span class="userCompany"><span class="labelDesc">' + wpj_vars.registered + '</span>  ' + obj.joined + '</span>\
										</div>\
									</div>\
								</div>\
								<div class="three wide column">\
									<div class="userContact">' + Hooks.apply_filters( 'wpj_user_search_action_buttons_filter', contact_button, { uid : obj.id, username : obj.username } ) + '</div>\
								</div>\
							</div>\
						</div>'
					);
				});
			} else {
				$( '#userInformations' ).append( '<div class="no-results">' + wpj_vars.nothing_found + '</div>' );
			}

		});
	}
//--> END User Search

//--> START User Settings Validation
	var fields_arr = {
		current_password: {
			identifier  : 'current_password',
			rules: [{
				type   : 'empty',
				prompt: wpj_vars.old_wrong_password,
			}]
		},
		new_password: {
			identifier  : 'password',
			rules: [{
				type   : 'empty',
				prompt : wpj_vars.blank_password,
			}]
		},
		repeat_password: {
			identifier  : 'repeat_password',
			rules: [{
				type   : 'empty',
				prompt: wpj_vars.repeat_password,
			}]
		},
		new_password_match: {
			identifier  : 'repeat_password',
			rules: [{
				type   : 'match[password]',
				prompt: wpj_vars.password_not_match,
			}]
		},
	};

	fields_arr = Hooks.apply_filters( 'wpj_fields_validation_filter', fields_arr, 'user-profile' );

	jQuery( '.ui.form.edit-profile' ).form({
		on: 'blur',
		keyboardShortcuts: false,
		fields: fields_arr
	});
//--> END User Settings Validation

	var lmt = new Date();
	last_move_time = lmt.getTime();

	jQuery( document ).mousemove( function(){
		var cmt = new Date();
		current_move_time = cmt.getTime();

		if ( ( current_move_time - last_move_time ) > 60000 ) {
			$.ajax({
				method : "POST",
				url    : wpj_vars.light_ajax_url,
				data   : { 'action': 'update_user_meta_for_user_online_status_action' },
				success: function ( data ) {}
			});
			last_move_time = cmt.getTime();
		}
	});

}); //<!-- END jQuery document ready
