/* Global
 * Installing gulp: sudo npm install gulp -g
 */

/* Project
 * npm init
 * npm install gulp --save-dev
 */

/* Dependencies
 * npm install --save-dev gulp-if
 * npm install --save-dev gulp-autoprefixer
 * npm install --save-dev gulp-csso
 * npm install --save-dev gulp-concat-css
 * npm install --save-dev gulp-concat
 * npm install --save-dev gulp-minify
 * npm install --save-dev gulp4-run-sequence
 * npm install --save-dev del
 * npm install --save-dev gulp-rtlcss
 * npm install --save-dev gulp-wp-pot
 * npm install --save-dev gulp-rename
 * npm install --save-dev gulp-replace-name
 * npm install --save-dev vinyl-ftp
 * npm install --save-dev gulp-sftp
 */

/*
 * Vars
 */
var gulp         = require( 'gulp' );
var gulpif       = require( 'gulp-if' );
var autoprefixer = require( 'gulp-autoprefixer' );
var minify_css   = require( 'gulp-csso' );
var concat_css   = require( 'gulp-concat-css' );
var concat_js    = require( 'gulp-concat' );
var minify_js    = require( 'gulp-minify' );
var runSequence  = require( 'gulp4-run-sequence' );
var del          = require( 'del' );
var rtlcss       = require( 'gulp-rtlcss' );
var wpPot        = require( 'gulp-wp-pot' );
var rename       = require( 'gulp-rename' );
var replaceName  = require( 'gulp-replace-name' );
var ftp          = require( 'vinyl-ftp' );
var sftp         = require( 'gulp-sftp' );

/*
 * Configuration
 */
const AUTOPREFIXER_BROWSERS = [
	'ie      >= 10',
	'ie_mob  >= 10',
	'ff      >= 30',
	'chrome  >= 34',
	'safari  >= 7',
	'opera   >= 23',
	'ios     >= 7',
	'android >= 4.4',
	'bb      >= 10'
];

function get_connection() {

	const config = require( './sftp-config.json' );

	if ( config.type == 'ftp' ) {
		var conn = ftp.create({
			host    : config.host,
			user    : config.user,
			password: config.password,
			parallel: 10,
			reload  :   true,
		});

		return conn;
	} else if ( config.type == 'sftp' ) {
		var conn = sftp({
			host: config.host,
			user: config.user,
			pass: config.password,
		});

		return conn;
	}

	return false;
}

var enable_upload = 'yes';
var upload_path = './wpjobster/';

function upload_file( upload_dest ) {
	// if config file doesn't exist, return gulp and set upload path to current path

	var fs = require('fs');
	if ( fs.existsSync('./sftp-config.json') ) {
		return get_connection();
	} else {
		// fallback: if you forgot enable_upload == 'yes' and don't have a config file
		// files will stay on the same location
		upload_path = '';

		// prevent get_connection(...).dest is not a function error when no config file
		// reason: gulpif still evaluates the function even if condition not passed
		return gulp;
	}
}

/*
 * Styles
 */
gulp.task( 'admin-wpj-styles', function () {
	return gulp.src( ['./assets/css/admin/*.css', './plugins/wpjobster-reports/assets/css/admin-styles.css'] )
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "admin.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( './assets/min/css' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'admin-vendor-styles', function () {
	return gulp.src( './assets/css/vendor/admin/*.css' )
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "admin.vendor.min.css" ) )
		.pipe( minify_css() )
		.pipe(gulp.dest( './assets/min/css' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'front-wpj-styles', function () {
	return gulp.src([
			'./assets/css/front/reset.css',
			'./assets/css/front/semantic-custom.css',
			'./assets/css/front/style.css',
			'./assets/css/front/!(responsive)*.css',
			'./assets/css/front/*.css',
			'./assets/css/front/responsive.css',
			'./plugins/wpjobster-reports/assets/css/styles.css',
			'./plugins/wpjobster-seller-order-rejection/assets/css/public_style.css'
		])
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "front.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( './assets/min/css' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'front-vendor-styles', function () {
	return gulp.src( './assets/css/vendor/front/*.css' )
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "front.vendor.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( './assets/min/css' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'common-styles', function () {
	return gulp.src( './assets/css/vendor/common/*.css' )
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "common.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( './assets/min/css' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'build-front-styles', function( callback ) {
	runSequence(
		'front-wpj-styles',
		'front-vendor-styles',
		'common-styles',
		callback
	);
});
gulp.task( 'build-admin-styles', function( callback ) {
	runSequence(
		'admin-wpj-styles',
		'admin-vendor-styles',
		'common-styles',
		callback
	);
});
gulp.task( 'build-styles', function( callback ) {
	runSequence(
		'admin-wpj-styles',
		'admin-vendor-styles',
		'front-wpj-styles',
		'front-vendor-styles',
		'common-styles',
		callback
	);
});

/*
 * Scripts
 */
gulp.task( 'admin-wpj-scripts', function() {
	return gulp.src( './assets/js/admin/*.js' )
		.pipe( concat_js( 'admin.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'admin-vendor-scripts', function() {
	return gulp.src([
			'./assets/js/vendor/admin/daterangepicker.js',
			'./assets/js/vendor/admin/*.js'
		])
		.pipe( concat_js( 'admin.vendor.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'front-wpj-scripts', function() {
	return gulp.src([
			'./assets/js/front/initializations.js',
			'./assets/js/front/*.js',
			'./plugins/wpjobster-reports/assets/js/scripts.js',
			'./plugins/wpjobster-seller-order-rejection/assets/js/public_script.js'
		])
		.pipe( concat_js( 'front.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'front-vendor-scripts', function() {
	return gulp.src([
			'./assets/js/vendor/front/modernizr.touch.js',
			'./assets/js/vendor/front/*.js'
		])
		.pipe( concat_js( 'front.vendor.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'common-scripts', function() {
	return gulp.src([
			'./assets/js/common/hooks.js',
			'./assets/js/common/helpers.js',
			'./assets/js/common/moment.js',
			'./assets/js/common/*.js'
		])
		.pipe( concat_js( 'common.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'no-defer-scripts', function() {
	return gulp.src( './assets/js/no-defer/*.js' )
		.pipe( concat_js( 'no-defer.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './assets/min/js' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/js' ) ) )
});
gulp.task( 'build-front-scripts', function( callback ) {
	runSequence(
		'front-wpj-scripts',
		'front-vendor-scripts',
		'common-scripts',
		'no-defer-scripts',
		callback
	);
});
gulp.task( 'build-admin-scripts', function( callback ) {
	runSequence(
		'admin-wpj-scripts',
		'admin-vendor-scripts',
		'common-scripts',
		'no-defer-scripts',
		callback
	);
});
gulp.task( 'build-scripts', function( callback ) {
	runSequence(
		'admin-wpj-scripts',
		'admin-vendor-scripts',
		'front-wpj-scripts',
		'front-vendor-scripts',
		'common-scripts',
		'no-defer-scripts',
		callback
	);
});

/*
 * ZM-Ajax-Login-Register
 */
gulp.task( 'zm-ajax-styles', function () {
	return gulp.src( './plugins/zm-ajax-login-register/assets/*.css' )
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "styles.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( './plugins/zm-ajax-login-register/dist' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'plugins/zm-ajax-login-register/dist' ) ) )
});
gulp.task( 'zm-ajax-scripts', function() {
	return gulp.src( './plugins/zm-ajax-login-register/assets/*.js' )
		.pipe( concat_js( 'scripts.js' ) )
		.pipe( minify_js() )
		.pipe( replaceName( /\-min/g, '.min' ) )
		.pipe( gulp.dest( './plugins/zm-ajax-login-register/dist' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'plugins/zm-ajax-login-register/dist' ) ) )
});
gulp.task( 'build-zm-ajax', function( callback ) {
	runSequence(
		'zm-ajax-styles',
		'zm-ajax-scripts',
		callback
	);
});

/*
 * RTL
 */
gulp.task( 'front-style-rtl', function() {
	return gulp.src( './assets/css/front/style.css' )
		.pipe( rtlcss() )
		.pipe( rename( { basename: 'style-autogenerated' } ) )
		.pipe( gulp.dest( 'assets/css/front-rtl/' ) )
});
gulp.task( 'front-responsive-rtl', function() {
	return gulp.src( './assets/css/front/responsive.css' )
		.pipe( rtlcss() )
		.pipe( rename( { basename: 'responsive-autogenerated' } ) )
		.pipe( gulp.dest( 'assets/css/front-rtl/' ) )
});
gulp.task( 'front-other-rtl', function() {
	return gulp.src([
			'./assets/css/front/*.css',
			'./assets/css/front/!(style)*.css',
			'./assets/css/front/!(responsive)*.css',
			'./assets/css/front/!(reset)*.css',
			'./plugins/wpjobster-reports/assets/css/styles.css',
			'./plugins/wpjobster-seller-order-rejection/assets/css/public_style.css'
		])
		.pipe( rtlcss() )
		.pipe( concat_css( "other-autogenerated.css" ) )
		.pipe( gulp.dest( 'assets/css/front-rtl/' ) )
});
gulp.task( 'front-rtl-styles-minify', function() {
	return gulp.src([
			'./assets/css/front/reset.css',
			'./assets/css/front-rtl/style-autogenerated.css',
			'./assets/css/front-rtl/other-autogenerated.css',
			'./assets/css/front-rtl/style-extra.css',
			'./assets/css/front-rtl/responsive-autogenerated.css',
			'./assets/css/front-rtl/responsive.css',
			'./assets/css/front-rtl/*.css'
		])
		.pipe( autoprefixer( { overrideBrowserlist: AUTOPREFIXER_BROWSERS } ) )
		.pipe( concat_css( "front.rtl.min.css" ) )
		.pipe( minify_css() )
		.pipe( gulp.dest( 'assets/min/css/' ) )
		.pipe( gulpif( enable_upload == 'yes', upload_file().dest( upload_path + 'assets/min/css' ) ) )
});
gulp.task( 'build-rtl', function( callback ) {
	runSequence(
		[
			'front-style-rtl',
			'front-responsive-rtl',
			'front-other-rtl'
		],
		'front-rtl-styles-minify',
		callback
	);
});

/*
 * POT
 */
gulp.task( 'build-pot', function() {
	return gulp.src( './**/*.php' )
		.pipe( wpPot( {
			domain: 'wpjobster',
			package: 'wpjobster'
		} ) )
		.pipe( gulp.dest( 'languages/wpjobster.pot' ) )
});

/*
 * Build ALL
 */
gulp.task( 'build', function( callback ) {
	runSequence(
		'build-styles',
		'build-rtl',
		'build-scripts',
		'build-zm-ajax',
		'build-pot',
		callback
	);
});

/*
 * Watch ALL
 */
gulp.task( 'watch', function () {
	/* Styles */
	gulp.watch( './assets/css/front/*.css', gulp.series ( 'front-wpj-styles', 'build-rtl' ) );
	gulp.watch( './plugins/wpjobster-reports/assets/css/styles.css', gulp.series ( 'front-wpj-styles', 'build-rtl' ) );
	gulp.watch( './plugins/wpjobster-seller-order-rejection/assets/css/public_style.css', gulp.series ( 'front-wpj-styles', 'build-rtl' ) );
	gulp.watch( './assets/css/vendor/front/*.css', gulp.series ( 'front-vendor-styles' ) );
	gulp.watch( './assets/css/admin/*.css', gulp.series ( 'admin-wpj-styles' ) );
	gulp.watch( './plugins/wpjobster-reports/assets/css/admin-styles.css', gulp.series ( 'admin-wpj-styles' ) );
	gulp.watch( './assets/css/vendor/admin/*.css', gulp.series ( 'admin-vendor-styles' ) );
	gulp.watch( './assets/css/vendor/common/*.css', gulp.series ( 'common-styles' ) );
	/* RTL */
	gulp.watch( './assets/css/front-rtl/style-extra.css', gulp.series ( 'front-rtl-styles-minify' ) );
	gulp.watch( './assets/css/front-rtl/responsive.css', gulp.series ( 'front-rtl-styles-minify' ) );
	gulp.watch( './assets/css/front-rtl/wysiwyg-rtl.css', gulp.series ( 'front-rtl-styles-minify' ) );
	/* Scripts */
	gulp.watch( './assets/js/front/*.js', gulp.series ( 'front-wpj-scripts' ) );
	gulp.watch( './plugins/wpjobster-reports/assets/js/scripts.js', gulp.series ( 'front-wpj-scripts' ) );
	gulp.watch( './plugins/wpjobster-seller-order-rejection/assets/js/public_script.js', gulp.series ( 'front-wpj-scripts' ) );
	gulp.watch( './assets/js/vendor/front/*.js', gulp.series ( 'front-vendor-scripts' ) );
	gulp.watch( './assets/js/admin/*.js', gulp.series ( 'admin-wpj-scripts' ) );
	gulp.watch( './assets/js/vendor/admin/*.js', gulp.series ( 'admin-vendor-scripts' ) );
	gulp.watch( './assets/js/common/*.js', gulp.series ( 'common-scripts' ) );
	gulp.watch( './assets/js/no-defer/*.js', gulp.series ( 'no-defer-scripts' ) );
	/* ZM Ajax */
	gulp.watch( './plugins/zm-ajax-login-register/assets/*', gulp.series ( 'build-zm-ajax' ) );
	/* POT */
	gulp.watch( './**/*.php', gulp.series ( 'build-pot' ) );
});
