<?php
/**
 * Validation status responses
 */
function custom_offers_status( $key = null, $extra = false ) {

	if ( $extra ) {
		$current_user = wp_get_current_user();
		$user_level   = wpjobster_get_user_level( $current_user->ID );

		if ( wpj_get_user_feature_status( 'wpjobster_enable_min_custom_extras', 'wpjobster_subscription_custom_extras_enabled' ) != 'no' ) {
			$price_min = wpj_get_user_feature_value( 'min_customextrasamount', 'min_customextrasamount' );
		} else {
			$price_min = 0;
		}

		if ( wpj_get_user_feature_status( 'wpjobster_enable_max_custom_extras', 'wpjobster_subscription_custom_extras_enabled' ) != 'no' ) {
			$price_max = wpj_get_user_feature_value( 'customextrasamount', 'max_customextrasamount' );
		} else {
			$price_max = '';
		}
	} else {
		$price_min = get_option( 'wpjobster_offer_price_min' );
		$price_max = get_option( 'wpjobster_offer_price_max' );

		if ( ! is_numeric( $price_min ) || ! is_numeric( $price_max ) || $price_min > $price_max ) {
			$price_min = 5;
			$price_max = 5000;
		}
	}

	$status = array(
		'ok' => array(
			'description' =>  __( 'All good', 'wpjobster' ),
			'cssClass'    => 'noon',
			'code'        => 'success'
		),
		'message_sent' => array(
			'description' => __( 'Your message was successfully sent.', 'wpjobster' ),
			'cssClass'    => 'success-container',
			'code'        => 'success'
		),
		'request_sent' => array(
			'description' => __( 'Your request was successfully sent.', 'wpjobster' ),
			'cssClass'    => 'success-container',
			'code'        => 'success'
		),
		'offer_sent' => array(
			'description' => __( 'Your offer was successfully sent.', 'wpjobster' ),
			'cssClass'    => 'success-container',
			'code'        => 'success'
		),
		'message_already_sent' => array(
			'description' => __( 'Your message was already sent.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'request_already_sent' => array(
			'description' => __( 'Your request was already sent.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'offer_already_sent' => array(
			'description' => __( 'Your offer was already sent.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'something_wrong' => array(
			'description' => __( 'Something went wrong... Please try again.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'empty_message' => array(
			'description' => __( 'The message cannot be empty.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'empty_request' => array(
			'description' => __( 'The request cannot be empty.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'empty_offer' => array(
			'description' => __( 'The offer cannot be empty.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'request_yourself' => array(
			'description' => __( 'You cannot send a request to yourself.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'offer_yourself' => array(
			'description' => __( 'You cannot send a offer to yourself.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'wrong_price' => array(
			'description' => __( 'The price must be in the following range:', 'wpjobster' ) . ' ' . $price_min . ' - ' . $price_max . ' ' . wpjobster_get_currency_classic(),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'wrong_delivery' => array(
			'description' => sprintf( __( 'The delivery time must be between 1 and %s days.', 'wpjobster' ), get_option( 'wpjobster_request_max_delivery_days' ) ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'not_eligible' => array(
			'description' => __( 'You need to have at least one active job in order to send custom offers.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'custom_extras_not_enabled' => array(
			'description' => __( 'Custom extras are not enabled.', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'request_logged_in' => array(
			'description' => __( 'You must be logged in to request custom offer. If you want to login, click <a href="/wp-login.php" class="login-link">here</a>', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'loggged_in_error'
		),
		'csrf_empty' => array(
			'description' => __( 'The verification token is empty', 'wpjobster' ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		),
		'csrf_not_match' => array(
			'description' => __( "The verification token doesn't match", "wpjobster" ),
			'cssClass'    => 'error-container',
			'code'        => 'error'
		)
	);

	if ( $extra ) {
		$status['offer_sent']['description']         = __( 'Your extra was successfully sent.', 'wpjobster' );
		$status['offer_already_sent']['description'] = __( 'Your extra was already sent.', 'wpjobster' );
		$status['empty_offer']['description']        = __( 'The extra cannot be empty.', 'wpjobster' );
		$status['offer_yourself']['description']     = __( 'You cannot send an extra to yourself.', 'wpjobster' );
		$status['not_eligible']['description']       = __( 'You need to have at least one active job in order to send custom extras.', 'wpjobster' );
	}

	$status = apply_filters( 'wpj_custom_offer_status_filter', $status );

	if ( ! empty( $key ) ) {
		return $status[$key];
	} else {
		return $status['something_wrong'];
	}
}
