<?php
function wpj_get_payment_types( $exclude = array() ) {
	$payment_type_enable_arr = array(
		"job_purchase"     => array(
			"enable_label" => __( "Enable for job purchase:", "wpjobster" ),
			"hint_label"   => __( "Allow your users to purchase jobs through this payment gateway.", "wpjobster" ),
		),
		"topup"            => array(
			"enable_label" => __( "Enable for top up:", "wpjobster" ),
			"hint_label"   => __( "Allow your users to top up their balance through this payment gateway.", "wpjobster" ),
		),
		"featured"         => array(
			"enable_label" => __( "Enable for featured job:", "wpjobster"),
			"hint_label"   => __( "Allow your users to pay for featured jobs through this payment gateway.", "wpjobster" ),
		),
		"withdraw"       => array(
			"enable_label" => __( "Enable for withdraw:", "wpjobster"),
			"hint_label"   => __( "Allow your users to withdraw their balance through this payment gateway.", "wpjobster" ),
		),
		"custom_extra"     => array(
			"enable_label" => __( "Enable for custom extra:", "wpjobster"),
			"hint_label"   => __( "Allow your users to pay for custom extras through this payment gateway.", "wpjobster" ),
		),
		"tips"             => array(
			"enable_label" => __( "Enable for tips:", "wpjobster"),
			"hint_label"   => __( "Allow your users to pay for tips through this payment gateway.", "wpjobster" ),
		),
		"subscription"     => array(
			"enable_label" => __( "Enable for subscription:", "wpjobster"),
			"hint_label"   => __( "Allow your users to pay for subscription through this payment gateway.", "wpjobster" ),
		)
	);

	if ( $exclude ) {
		foreach ( $exclude as $key => $value ) {
			if ( isset( $payment_type_enable_arr[$value] ) ) {
				unset( $payment_type_enable_arr[$value] );
			}
		}
	}

	return $payment_type_enable_arr;
}

if ( ! function_exists( 'get_wpjobster_payment_gateways' ) ) {
	function get_wpjobster_payment_gateways(){
		$wpjobster_payment_gateways = array(
			"800" => array(
				"label"             => __( "COD", "wpjobster" ),
				"show_settigs_form" => "show_cod_form",
				"action"            => "show_cod_form",
				"response_action"   => "cod_response",
				"unique_id"         => "cod"
			),
			"811" => array(
				"label"             => __( "Bank Transfer", "wpjobster" ),
				"show_settigs_form" => "show_banktransfer_form",
				"action"            => "show_banktransfer_form",
				"response_action"   => "banktransfer_response",
				"unique_id"         => "banktransfer"
			)
		);

		$wpjobster_payment_gateways = apply_filters( "wpjobster_payment_gateways", $wpjobster_payment_gateways );

		ksort( $wpjobster_payment_gateways );

		return $wpjobster_payment_gateways;
	}
}

function wpj_display_credits_payment_button( $pid = '', $payment_type = '' ) {

	if ( ! wpj_is_payment_free( $payment_type ) ) { // Account Balance

		$is_enough_credit = wpjobster_get_credits( get_current_user_id() ) >= wpj_get_payment_info_by_url( 'total_order_price' ) ? true : false;

		if ( $payment_type && $payment_type != 'job_purchase' && $payment_type != 'tips' && $payment_type != 'custom_extra' ) { $is_enough_credit = true; }
		if ( wpj_get_payment_info_by_url( 'custom_amount_enabled' ) == 1 ) { $is_enough_credit = true; }

		do_action( 'wpjobster_before_credits_link', $pid );

		if ( get_option( 'wpjobster_credits_enable' ) != 'no' && $is_enough_credit ) { ?>

			<div class="float-left">
				<div onclick='take_to_gateway( "credits", "", "<?php echo $payment_type; ?>" );' class="ui white button" id="credits"><?php _e( 'Account Balance', 'wpjobster' ); ?></div>
			</div>

		<?php } elseif ( get_option( 'wpjobster_credits_enable' ) != 'no' && ! $is_enough_credit ) { ?>

			<div class="float-left" data-inverted="" data-tooltip="<?php _e( 'Not enough credits', 'wpjobster' ); ?>" data-position="top left">
				<div class="ui white disabled button" id="credits"><?php _e( 'Account Balance', 'wpjobster' ); ?></div>
			</div>

		<?php }

		do_action( 'wpjobster_after_credits_link', $pid );

	} else { // Free ?>

		<div class="float-left">
			<div onclick='take_to_gateway( "credits", "", "<?php echo $payment_type; ?>" );' class="ui white button" id="credits"><?php _e( 'Get for free', 'wpjobster' ); ?></div>
		</div>

	<?php }

}

function wpj_display_gateway_payment_button( $payment_type = 'job_purchase', $pid = '', $include_credits = true ) {

	if ( ! $pid ) { $pid = WPJ_Form::get( 'jobid' ); }

	// Account Balance / Free
	if ( $include_credits ) { wpj_display_credits_payment_button( $pid, $payment_type ); }

	// Gateways
	if ( get_wpjobster_payment_gateways() ) {

		foreach ( get_wpjobster_payment_gateways() as $priority => $gateway ) {

			if ( wpj_is_payment_type_enabled( $gateway['unique_id'], $payment_type ) && empty( $gateway['no_pay_button'] ) ) { $gateway_enabled = true;

				if ( $gateway['unique_id'] == 'cod' && ! wpj_is_COD_payment_allowed( $pid, $payment_type ) ) { $gateway_enabled = false; continue; } // if COD allowed

				do_action( 'wpjobster_before_' . $gateway['unique_id'] . '_' . $payment_type . '_link', $pid ); ?>

				<a
					href="javascript:void(0);"
					onclick='take_to_gateway( "<?php echo $gateway['unique_id']; ?>", "<?php echo get_option( 'wpjobster_' . $gateway['unique_id'] . '_enablepopup' ); ?>", "<?php echo $payment_type; ?>" );'
					class="ui white button <?php echo $payment_type; ?>"
					id="<?php echo $gateway['unique_id']; ?>"
					<?php if ( wpj_is_payment_free( $payment_type ) ) { echo ' style="display: none;"'; } ?>
				>

					<?php echo get_option( 'wpjobster_' . $gateway['unique_id'] . '_button_caption' ) ? get_option( 'wpjobster_' . $gateway['unique_id'] . '_button_caption' ) : $gateway['unique_id']; ?>

				</a>

				<?php do_action( 'wpjobster_after_' . $gateway['unique_id'] . '_' . $payment_type . '_link', $pid );

			}
		}
	}

	if ( $include_credits && get_option( 'wpjobster_credits_enable' ) != 'no' ) { $gateway_enabled = true; }

	// No gateways
	if ( ! isset( $gateway_enabled ) ) { ?>

		<div class="ui payment-method-error label">
			<p><?php _e( 'Payment methods are not available at this time. Please contact the administrator of this site for help.', 'wpjobster' ); ?></p>
		</div>

	<?php }

}

// take_to_gateway popup
add_action( 'wp_ajax_wpjobster_check_payment_gateway_popup', 'wpjobster_take_to_payment_gateway_popup' );
function wpjobster_take_to_payment_gateway_popup() {

	$payment_type = isset( $_POST['payment_type'] ) ? $_POST['payment_type'] : 'job_purchase';
	$gateway      = $_POST['gateway'];

	if ( $payment_type == 'topup' ) {
		$package_id       = $_POST['package_id'];
	} elseif ( $payment_type == 'feature' ) {
		$pid_feature      = $_REQUEST['jobid'];
		$h_start_date     = $_REQUEST['h_date_start'];
		$c_start_date     = $_REQUEST['c_date_start'];
		$s_start_date     = $_REQUEST['s_date_start'];
		$feature_pages    = $_REQUEST['feature_pages'];
	} elseif ( $payment_type == 'subscription' ){
		$sub_amount       = $_REQUEST['sub_amount'];
		$sub_type         = $_REQUEST['sub_type'];
		$sub_level        = $_REQUEST['sub_level'];
		$user_id          = $_REQUEST['user_id'];
	} elseif ( $payment_type =='custom_extra' ) {
		$oid_custom_extra = $_REQUEST['oid'];
		$amount           = $_REQUEST['amount'];
		$custom_extra     = $_REQUEST['custom_extra'];
	} elseif ( $payment_type == 'tips' ) {
		$oid_tips         = $_REQUEST['oid'];
		$amount           = $_REQUEST['amount'];
		$tips             = $_REQUEST['tips'];
	} else {
		$pid              = $_POST['jobid'];
		$main_amount      = $_POST['amount'];
		$extrs2           = $_POST['extras'];
		$extrs_amounts2   = $_POST['extras_amounts'];
	}

	$extra_params = array();
	if ( $_POST ) {
		foreach ( $_POST as $key => $value ) {
			$extra_params[$key] = $value;
		}
	}

	$gateway_developed_in_theme = get_option( "wpjobster_{$gateway}_developed_in_theme" );

	if ( $gateway_developed_in_theme == "yes" ) {
		include get_template_directory() . "/lib/gateways/wpjobster_{$gateway}.php";
	} else {
		$plugin_path = WP_PLUGIN_DIR;
		include $plugin_path . "/wpjobster-{$gateway}/wpjobster-{$gateway}.php";
	}
	exit;
}

// If required, call in payment gateway plugins e.g. Midtrans
add_action( 'wpjobster_include_all_common_payment_type_files', 'wpjobster_all_common_payment_type_classes', 10,2 );
if ( ! function_exists( 'wpjobster_all_common_payment_type_classes' ) ) {

	function wpjobster_all_common_payment_type_classes( $payment_type, $payment_gateway_unique_slug, $return = false ) {

		if ( $payment_type == 'job_purchase' ) {
			if ( ! class_exists( 'WPJ_Common_Job_Purchase' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_job_purchase.php";
				$wcommon = $wcjp = new WPJ_Common_Job_Purchase( $payment_gateway_unique_slug );
			}
		} elseif ( $payment_type == 'feature' ) {
			if ( ! class_exists( 'WPJ_Common_Featured' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_featured.php";
				$wcommon = $wcf = new WPJ_Common_Featured( $payment_gateway_unique_slug );
			}
		} elseif ( $payment_type == 'topup' ) {
			if ( ! class_exists( 'WPJ_Common_Topup' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_topup.php";
				$wcommon = $wct = new WPJ_Common_Topup( $payment_gateway_unique_slug );
			}
		} elseif ( $payment_type == 'custom_extra' ) {
			if ( ! class_exists( 'WPJ_Common_Custom_Extra' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_custom_extra.php";
				$wcommon = $wcce = new WPJ_Common_Custom_Extra( $payment_gateway_unique_slug );
			}
		} elseif ( $payment_type == 'tips' ) {
			if ( ! class_exists( 'WPJ_Common_Tips' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_tips.php";
				$wcommon = $wctp = new WPJ_Common_Tips( $payment_gateway_unique_slug );
			}
		} elseif ( $payment_type == 'subscription' ) {
			if ( ! class_exists( 'WPJ_Common_Subscription' ) ) {
				include_once get_template_directory() . "/lib/gateways/wpjobster_common_subscription.php";
				$wcommon = $ws = new WPJ_Common_Subscription( $payment_gateway_unique_slug );
			}
		} else {
			if ( $return ) {
				$wcommon = '';

				if ( ! class_exists( 'WPJ_Common_Featured' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_featured.php";
					$wcommon = $wcf = new WPJ_Common_Featured( $payment_gateway_unique_slug );
				}
				if ( ! class_exists( 'WPJ_Common_Custom_Extra' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_custom_extra.php";
					$wcommon = $wcce = new WPJ_Common_Custom_Extra( $payment_gateway_unique_slug );
				}
				if ( ! class_exists( 'WPJ_Common_Tips' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_tips.php";
					$wcommon = $wctp = new WPJ_Common_Tips( $payment_gateway_unique_slug );
				}
				if ( ! class_exists( 'WPJ_Common_Topup' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_topup.php";
					$wcommon = $wct = new WPJ_Common_Topup( $payment_gateway_unique_slug );
				}
				if ( ! class_exists( 'WPJ_Common_Job_Purchase' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_job_purchase.php";
					$wcommon = $wcjp = new WPJ_Common_Job_Purchase( $payment_gateway_unique_slug );
				}
				if ( ! class_exists( 'WPJ_Common_Subscription' ) ) {
					include_once get_template_directory() . "/lib/gateways/wpjobster_common_subscription.php";
					$wcommon = $wcs = new WPJ_Common_Subscription( $payment_gateway_unique_slug );
				}

				if ( ! class_exists( 'wpjobster_' . $payment_gateway_unique_slug ) && file_exists( get_template_directory() . "/lib/gateways/wpjobster_" . $payment_gateway_unique_slug . ".php" ) ) {
					if ( $payment_gateway_unique_slug == 'paypal' ) {

						if ( class_exists( 'WPJobster_PayPal_Loader' ) ) {
							$paypalClass = new WPJobster_PayPal_Loader();
						}

					} else {

						if ( get_option( "wpjobster_{$payment_gateway_unique_slug}_developed_in_theme" ) == "yes" ) {
							include get_template_directory() . "/lib/gateways/wpjobster_{$payment_gateway_unique_slug}.php";
						} else {
							$plugin_path = WP_PLUGIN_DIR;
							include $plugin_path . "/wpjobster-{$payment_gateway_unique_slug}/wpjobster-{$payment_gateway_unique_slug}.php";
						}

					}
				}

				return $wcommon;
			} else {
				echo __( "Something went wrong. No payment type defined", "wpjobster" ); die();
			}
		}

	}

}

add_action( 'admin_notices', 'wpj_plugins_enabled_error' );
function wpj_plugins_enabled_error() {

	if ( ! PAnD::is_admin_notice_active( 'disable-gateway-done-notice-forever' ) ) {
		return;
	}

	$gateways = array( 'Stripe', '2Checkout', 'Payza', 'Braintree', 'Authorize' );

	$is_gateway_ok = 0;
	$message_gat = '';
	foreach ( $gateways as $gateway ) {
		$$gateway = get_option( 'wpjobster_' . strtolower( $gateway ) . '_enable' );

		if ( $$gateway == 'yes' ) {
			if ( ! class_exists( "WPJobster_" . $gateway . "_Loader" ) ) {
				$message_gat .= '- ' . $gateway . ' Gateway' . '<br>';

				$is_gateway_ok = 1;
			}
		}
	}

	$plugins = array( 'wpjobster-account-segregation', 'wpjobster-seller-notifications', 'wpjobster-affiliate', 'wpjobster-invoices' );

	$is_plugin_ok = 0; $message_plg = '';

	foreach ( $plugins as $plugin ) {
		if ( is_plugin_active( $plugin . '/' . $plugin . '.php' ) ) {
			$plugin_underscore = str_replace('-', '_', $plugin);
			$$plugin_underscore = get_plugin_data( WP_PLUGIN_DIR . '/' . $plugin . '/' . $plugin . '.php' );

			if( ${$plugin_underscore}['Version'] ){
				if( ${$plugin_underscore}['Version'] < '2.0.0' ) {
					$message_plg .= '- ' . ucwords( str_replace('-', ' ', $plugin) ) . '<br>';

					$is_plugin_ok = 1;
				}
			}
		}
	}

	if ( $is_gateway_ok == 1 || $is_plugin_ok == 1 ) { ?>

		<div data-dismissible="disable-gateway-done-notice-forever" class="is-dismissible notice notice-warning padd10">

			<?php if ( $is_gateway_ok == 1 ) {
				echo '<h2>' . __( 'Gateways', 'wpjobster' ) . '</h2>';

				$lbl_gat = __( 'Some of the gateways you used before need to be installed as plugins if you want to keep using them.', 'wpjobster' );
				$lbl_gat .= '<br>';
				$lbl_gat .= __( "Don't worry, you don't have to pay extra. If your license included them before, you will receive them for free. Please head to our support center for instructions.", 'wpjobster' );
				$lbl_gat .= '<br>';

				echo $lbl_gat;
				echo $message_gat;
			}

			if ( $is_plugin_ok == 1 ) {
				echo '<h2>' . __( 'Other Plugin Updates', 'wpjobster' ) . '</h2>';

				$lbl_plg = __( 'The following plugins need to be updated to the latest version in order to be compatible with Jobster v5.0.0+' );
				$lbl_plg .= '<br>';

				echo $lbl_plg;
				echo $message_plg;
			} ?>

			<br>

			<a class="button action" href="<?php echo admin_url( 'plugins.php' ); ?>"><?php _e( 'Plugins', 'wpjobster' ); ?></a>

		</div>

	<?php }
}

function wpjobster_maintain_log( $orderid, $post_title, $mc_gross, $uid, $pid, $post_author, $buyer_processing_fees = 0, $wpjobster_tax_amount = 0 ) {

	$order_url = get_bloginfo( 'url' ) . '/?jb_action=chat_box&oid=' . $orderid;
	$reason    = __( 'Payment made for', 'wpjobster' ) . ': <a href="' . $order_url . '">' . $post_title . '</a>';
	wpjobster_add_history_log( '0', $reason, $mc_gross,$uid, '', $orderid, 3, '' );

	if ( $buyer_processing_fees > 0 ) {
		$reason = __( 'Processing fee for', 'wpjobster' ) . ': <a href="' . $order_url . '">' . $post_title . '</a>';
		wpjobster_add_history_log( '0', $reason, $buyer_processing_fees, $uid, '', $orderid, 13, '' );
	}

	if ( $wpjobster_tax_amount > 0 ) {
		$reason = __( 'Tax for', 'wpjobster' ) . ': <a href="' . $order_url . '">' . $post_title . '</a>';
		wpjobster_add_history_log( '0', $reason, $wpjobster_tax_amount, $uid, '', $orderid, 14, '' );
	}

	$reason = __( 'Payment collected for', 'wpjobster' ) . ': <a href="' . $order_url . '">' . $post_title . '</a>';
	wpjobster_add_history_log( '2', $reason, $mc_gross, $post_author, '', $orderid, 4, '' );

	$current_order = wpjobster_get_order( $orderid );
	$post = get_post( $pid );

	$instant = get_post_meta( $pid, 'instant', true );
	$allow_auto_delivered = apply_filters( 'wpj_allow_order_auto_delivered_filter', true );

	if ( $instant == "1" && $current_order->payment_gateway != 'cod' && $allow_auto_delivered ) {

		global $wpdb;

		$tm = current_time( 'timestamp', 1 );

		$wpdb->query( "UPDATE {$wpdb->prefix}job_orders SET done_seller = '1', date_finished = '{$tm}' WHERE id = '{$orderid}'" );

		$ccc = __( 'Delivered', 'wpjobster' );
		$wpdb->query( "INSERT INTO {$wpdb->prefix}job_chatbox (datemade, uid, oid, content) VALUES('{$tm}', '-1', '{$orderid}', '{$ccc}')" );

		$this_notification = $wpdb->insert_id;
		wpj_update_user_notifications( $uid, 'notifications', +1, $this_notification );

		if ( wpj_is_custom_offer( $pid ) ) {
			wpj_custom_offer_delivered( $pid, $orderid, $uid );
		} else {
			$user_data = get_userdata( get_current_user_id() );

			wpj_notify_user_translated( 'order_delivered', $uid, array(
				'##sender_username##'       => wpj_get_user_display_type( $user_data->ID ),
				'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $current_order->date_made ),
				'##transaction_page_link##' => wpj_get_order_link( $orderid ),
				'##job_name##'              => $post->post_title,
				'##job_link##'              => urldecode( get_permalink( $pid ) )
			) );
		}

	}

	$user_data = get_userdata( $uid );

	wpj_notify_user_translated( 'job_admin_purchased', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##job_name##' => $post_title, '##job_link##' => get_post_permalink( $pid ) ) );

}

if ( ! function_exists( 'get_wpjobster_sms_gateways' ) ) {
	function get_wpjobster_sms_gateways() {
		$wpjobster_sms_gateways = array( /* "100" => array( 'label' => __( 'Twilio 1', 'wpjobster' ), 'show_settigs_form' => 'show_twilio_form', 'unique_id' => 'twilio1' ) */ );
		$wpjobster_sms_gateways = apply_filters( 'wpjobster_sms_gateways', $wpjobster_sms_gateways );

		ksort( $wpjobster_sms_gateways );

		return $wpjobster_sms_gateways;
	}
}