<?php
function wpjobster_calculate_fee( $raw_amount, $order_id = '', $uid = '' ) {

	$amount_fee = 0;

	// keep consistent if already calculated for job
	if ( $order_id ) {
		$order = wpjobster_get_order( $order_id );
		if ( $order && $order->mc_gross == $raw_amount ) {
			return $order->site_fees;
		}
	}

	if ( ! $uid && isset( $order->pid ) ) {
		$post = get_post( $order->pid );
		$uid  = $post->post_author;
	}

	// subscriptions
	get_wpjobster_subscription_info();
	$wpjobster_subscription_info = get_wpjobster_subscription_info($uid);
	extract( $wpjobster_subscription_info );

	if ( $wpjobster_subscription_enabled == 'yes' && $wpjobster_fees_for_subscriber_enabled == 'yes' ) {

		if ( $wpjobster_subscription_fees && is_numeric( $wpjobster_subscription_fees ) ) {
			$percent_taken = $wpjobster_subscription_fees;
		} else {
			$percent_taken = 0;
		}

		$amount_fee = ( floatval( $percent_taken ) * floatval( $raw_amount ) ) / 100;

	} else {

		$wpjobster_enable_site_fee = get_option( 'wpjobster_enable_site_fee' );

		if ( $wpjobster_enable_site_fee == 'percent' ) { // percent

			$percent_taken = get_option( 'wpjobster_percent_fee_taken' );
			if ( ! is_numeric( $percent_taken ) ) {
				$percent_taken = 0;
			}

			$amount_fee = ( floatval( $percent_taken ) * floatval( $raw_amount ) ) / 100;

		} elseif ( $wpjobster_enable_site_fee == 'fixed' ) { // fixed

			$solid_fee_taken = get_option( 'wpjobster_solid_fee_taken' );
			if ( is_numeric( $solid_fee_taken ) ) {
				$amount_fee = $solid_fee_taken;
			} else {
				$amount_fee = 0;
			}

		} elseif ( $wpjobster_enable_site_fee == 'flexible' ) { // flexible

			if ( $uid != 0 ) {
				$user_level = wpjobster_get_user_level( $uid );
				$raw_amount_default = $raw_amount;

				$wpjobster_percent_fee_taken_range1_base = get_option( 'wpjobster_percent_fee_taken_range1_base' );
				$wpjobster_percent_fee_taken_range2_base = get_option( 'wpjobster_percent_fee_taken_range2_base' );
				$wpjobster_percent_fee_taken_range3_base = get_option( 'wpjobster_percent_fee_taken_range3_base' );


				if ( ! is_numeric( $wpjobster_percent_fee_taken_range1_base ) ) {
					$wpjobster_percent_fee_taken_range1_base = 0;
				}

				if( ! is_numeric( $wpjobster_percent_fee_taken_range2_base ) ) {
					$wpjobster_percent_fee_taken_range2_base = 0;
				}

				if( ! is_numeric( $wpjobster_percent_fee_taken_range3_base ) ) {
					$wpjobster_percent_fee_taken_range3_base = 0;
				}


				if ( $wpjobster_percent_fee_taken_range3_base
					&& $raw_amount_default > $wpjobster_percent_fee_taken_range3_base ) {
					$amount_range = 3;
				} elseif ( $wpjobster_percent_fee_taken_range2_base
					&& $raw_amount_default > $wpjobster_percent_fee_taken_range2_base ) {
					$amount_range = 2;
				} elseif ( $wpjobster_percent_fee_taken_range1_base
					&& $raw_amount_default > $wpjobster_percent_fee_taken_range1_base ) {
					$amount_range = 1;
				} else {
					$amount_range = 0;
				}

				$percent_taken = get_option( "wpjobster_percent_fee_taken_range{$amount_range}_level{$user_level}" );
				if ( ! is_numeric( $percent_taken ) ) {
					$percent_taken = get_option( "wpjobster_percent_fee_taken_range{$amount_range}_level0" );
					if ( ! is_numeric( $percent_taken ) ) {
						$percent_taken = 0;
					}
				}

			} else {
				$percent_taken = 0;
			}

			$amount_fee = ( $percent_taken * $raw_amount ) / 100;
		}
	}

	return round( $amount_fee, 2 );
}

function wpjobster_get_tax( $country_code ) {
	$wpjobster_country_taxes_percentage = get_option( 'wpjobster_country_taxes_percentage' );

	if ( isset( $wpjobster_country_taxes_percentage[$country_code] ) ) {
		$wpjobster_tax_percent = $wpjobster_country_taxes_percentage[$country_code];
	} else {
		$wpjobster_tax_percent = get_option( 'wpjobster_tax_percent' );
	}

	$wpjobster_tax_percent = apply_filters( 'wpj_apply_fees_by_category', $wpjobster_tax_percent );

	return $wpjobster_tax_percent;
}

if ( ! function_exists( 'wpjobster_get_site_tax' ) ) {
	function wpjobster_get_site_tax( $price, $extr_ttl=0, $shipping=0, $buyer_processing_fees=0 ) {

		if ( wpj_bool_option( 'wpjobster_enable_site_tax' ) ) {
			$cur_uid               = get_current_user_id();
			$country_code          = get_user_meta( $cur_uid, 'country_code', true );
			$wpjobster_tax_percent = wpjobster_get_tax( $country_code );

			if ( wpj_bool_option( 'wpjobster_enable_processingfee_tax' ) && $buyer_processing_fees > 0 ) {
				$total_taxable_amount = floatval( $price ) + floatval( $extr_ttl ) + floatval( $shipping ) + floatval( $buyer_processing_fees );
			} else {
				$total_taxable_amount = floatval( $price ) + floatval( $extr_ttl ) + floatval( $shipping );
			}

			$tax_amount = $total_taxable_amount * $wpjobster_tax_percent / 100;
		} else {
			$tax_amount = 0;
		}

		return wpjobster_formats_special( $tax_amount );
	}
}

if ( ! function_exists( 'wpjobster_get_site_processing_fee' ) ) {
	function wpjobster_get_site_processing_fee( $price, $extr_ttl, $shipping ) {

		// initialize in order to return when disabled
		$buyer_processing_fees_percent_amount = 0;

		$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );

		if ( $buyer_processing_fees_enabled == 'percent' ) {
			$buyer_processing_fees_percent = get_option( 'wpjobster_buyer_processing_fees_percent' );
			if ( $buyer_processing_fees_percent > 0 ) {
				$total_processing_amount = floatval( $price ) + floatval( $extr_ttl ) + floatval( $shipping );
				if ( $total_processing_amount > 0 ) {
					$buyer_processing_fees_percent_amount = $total_processing_amount * $buyer_processing_fees_percent / 100;
				} else {
					$buyer_processing_fees_percent_amount = 0;
				}
			} else {
				$buyer_processing_fees_percent_amount = 0;
			}
		}

		if ( $buyer_processing_fees_enabled == 'fixed' ) {
			$buyer_processing_fees_percent_amount = get_option( 'wpjobster_buyer_processing_fees' );
		}

		return wpjobster_formats_special( $buyer_processing_fees_percent_amount );
	}
}
