<?php
function wpj_is_COD_only_payment() {

	$wpjobster_payment_gateways = get_wpjobster_payment_gateways();

	if ( $wpjobster_payment_gateways ) {

		$payment_methods = array();
		foreach ( $wpjobster_payment_gateways as $key => $method ) {
			if ( wpj_is_payment_type_enabled( $method['unique_id'], 'job_purchase' ) ) {
				array_push( $payment_methods, $method['unique_id'] );
			}
		}
	}

	if ( count( $payment_methods ) == 1 && $payment_methods[0] == 'cod' ) {
		return true;
	}

	return false;
}

function wpj_is_COD_payment_allowed( $pid = '', $payment_type = '' ) {
	$post = get_post( $pid );

	$is_allowed = false;

	if ( wpj_is_payment_type_enabled( 'cod', $payment_type ) ) {
		if ( number_format( wpjobster_get_credits( $post->post_author ), 2 ) >= wpjobster_calculate_fee( get_post_meta( $pid, 'price', true ), '', $post->post_author ) ) {
			$is_allowed = true;
		}
	}

	return apply_filters( 'wpj_is_cod_payment_allowed_filter', $is_allowed, $pid, $payment_type );
}

function wpj_get_withdrawals_gateways( $only_for_withdrawal = false ) {
	$gateways = array( 'paypal', 'payoneer', 'banktransfer' ); sort( $gateways );

	if ( $only_for_withdrawal ) {
		$gateways = array( 'payoneer' ); sort( $gateways );
		return apply_filters( 'wpj_only_withdrawals_gateways_filter', $gateways );
	}

	return apply_filters( 'wpj_withdrawals_gateways_filter', $gateways );
}

function wpj_withdrawal_gateway_enabled_exist( $ret_gateways = false ) {

	$gateways_arr = array();

	$gateways = wpj_get_withdrawals_gateways();

	if ( $gateways ) {

		foreach ( $gateways as $key => $gateway ) {

			$no_parent = in_array( $gateway, wpj_get_withdrawals_gateways( true ) ) ? true : false;

			if ( wpj_is_payment_type_enabled( $gateway, 'withdraw', $no_parent ) ) {
				$gateways_arr[] = $gateway;
				if ( ! $ret_gateways ) { return true; }
			}
		}
	}

	if ( $ret_gateways ) { return $gateways_arr; }

	return false;
}

function wpj_is_payment_type_enabled( $payment_gateway = '', $payment_type = '', $no_parent = false ) {

	if ( $payment_gateway == '' || $payment_type == '' ) {
		return false; // exit if no parameters
	}

	if ( strpos( $payment_gateway, '_automatic' ) !== false ) {
		$parent = str_replace( '_automatic', '', $payment_gateway );
	} else {
		$parent = $payment_gateway;
	}

	if ( get_option( 'wpjobster_' . $parent . '_enable' ) != 'yes' && $no_parent != true ) {
		return false; // exit if gateway disabled or option intentionally missing
	}

	if ( get_option( 'wpjobster_' . $payment_gateway . '_enable_' . $payment_type ) == 'yes' ) {
		return true; // true if option explicitely set to yes
	}

	if ( $payment_type == 'job_purchase' && get_option( 'wpjobster_' . $payment_gateway . '_enable_' . $payment_type ) == '' ) {
		return true; // true if option not set for job purchase, for backwards compatibility
	}

	return false;
}

function wpj_payment_type_has_gateway_enabled( $payment_type = '' ) {

	$wpjobster_payment_gateways = get_wpjobster_payment_gateways();

	if ( $wpjobster_payment_gateways ) {

		foreach ( $wpjobster_payment_gateways as $priority => $button_arr ) {

			if ( wpj_is_payment_type_enabled( $button_arr['unique_id'], $payment_type ) ) {
				return true;
			}

		}

	}

	$credits = wpjobster_get_credits( get_current_user_id() );

	if ( $credits > 0 ) { return true; }

	return false;
}

function wpj_save_webhook( $args = array() ) {

	global $wpdb;

	$defaults = array(
		'webhook_id'      => false,
		'payment_id'      => false,
		'status'          => false,
		'type'            => false,
		'description'     => false,
		'amount'          => false,
		'amount_currency' => false,
		'fees'            => false,
		'fees_currency'   => false,
		'create_time'     => false,
		'response'        => false,
		'payment_type'    => false,
		'order_id'        => false
	);

	$args = wp_parse_args( $args, $defaults );

	$webhook_id      = $args['webhook_id'];
	$payment_id      = $args['payment_id'];
	$status          = $args['status'];
	$type            = $args['type'];
	$description     = $args['description'];
	$amount          = $args['amount'];
	$amount_currency = $args['amount_currency'];
	$fees            = $args['fees'];
	$fees_currency   = $args['fees_currency'];
	$create_time     = $args['create_time'];
	$response        = $args['response'];
	$payment_type    = $args['payment_type'];
	$order_id        = $args['order_id'];

	$wpdb->query( "INSERT INTO {$wpdb->prefix}job_webhooks VALUES (NULL, '{$webhook_id}', '{$payment_id}', '{$status}', '{$type}', '{$description}', '{$amount}', '{$amount_currency}', '{$fees}', '{$fees_currency}', '{$create_time}', '{$response}', '{$payment_type}', '{$order_id}')" );

}

function wpj_is_payment_free( $payment_type ) {

	$oid = WPJ_Form::get( 'oid' );

	if ( $payment_type == 'job_purchase' ) {
		return get_post_meta( WPJ_Form::get( 'jobid' ), 'price', true ) > 0 ? false : true;

	} elseif ( $payment_type == 'custom_extra' && $oid ) {
		$order         = wpjobster_get_order( $oid );
		$custom_extras = json_decode( $order->custom_extras );
		$custom_extra  = $custom_extras[WPJ_Form::get( 'custom_extra' )];

		return $custom_extra->price > 0 ? false : true;

	} elseif ( $payment_type == 'tips' && $oid ) {
		$order = wpjobster_get_order( $oid );
		$tips  = json_decode( $order->tips );
		$tip   = $tips[WPJ_Form::get( 'tips' )];

		return $tip->amount > 0 ? false : true;

	} elseif ( $payment_type == 'featured' ) {
		return floatval( get_option( 'wpjobster_featured_price_homepage' ) ) > 0 &&
			floatval( get_option( 'wpjobster_featured_price_category' ) ) > 0 &&
			floatval( get_option( 'wpjobster_featured_price_subcategory' ) ) > 0 ? false : true;

	}

	return false;
}