<?php
/**
 * General php and wp helper functions, not necessarily jobster specific functionality
 */

if ( ! function_exists( 'is_ajax' ) ) {
	function is_ajax() {
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			return true;
		}
		return false;
	}
}

if ( ! function_exists( 'get_light_ajax_url' ) ) {
	function get_light_ajax_url() {
		$url = get_template_directory_uri() . '/ajax-functions/light-ajax.php';
		return $url;
	}
}

if ( ! function_exists( 'wpj_show_code_errors' ) ) {
	add_action( 'init', 'wpj_show_code_errors' );
	function wpj_show_code_errors() {
		// add the following to wp-config.php to enable debug:
		// define('WPJ_DEBUG', true);

		if ( ( defined( 'WP_JOBSTER_DEBUG' ) && WP_JOBSTER_DEBUG == true ) || ( defined( 'WPJ_DEBUG' ) && WPJ_DEBUG == true ) ) {
			ini_set( 'display_errors',1 );
			ini_set( 'display_startup_errors',1 );
			error_reporting( -1 );
		} else {
			ini_set( 'display_errors',0 );
			ini_set( 'display_startup_errors',0 );
			error_reporting( 0 );
		}
	}
}

if ( ! function_exists( 'wpj_disable_updates' ) ) {
	add_filter( 'pre_site_transient_update_themes', 'wpj_disable_updates', 10, 1 );
	function wpj_disable_updates( $array ) {
		// add the following to wp-config.php to disable theme updates:
		// define('WPJ_DISABLE_UPDATES', true);

		if ( defined( 'WPJ_DISABLE_UPDATES' ) && WPJ_DISABLE_UPDATES == true ) {
			global $wp_version;
			return(object) array('last_checked'=> time(),'version_checked'=> $wp_version,);
		} else {
			return $array;
		}
	}
}

function list_options($a,$sel="",$def=""){
	if(!$sel && $def){$sel=$def;}
	if(is_assoc($a)){$assoc=1;}
	foreach($a as $k=>$v){
		if(!$assoc){} ?>
			<option value="<?php echo $k ?>" <?php if($sel==$k){echo "selected='selected'";} ?>><?php echo $v ?></option>
	<?php }
}

function is_assoc($arr){
	return array_keys($arr) !== range(0, count($arr) - 1);
}

//-----------------------------------------
// Better print_r & var_dump for debugging
//-----------------------------------------

if ( ! function_exists( 'pre_print_r' ) ) {
	function pre_print_r( $var ) {
		echo '<pre style="text-align: left; white-space: pre-wrap;">';
			print_r( $var );
		echo '</pre>';
	}
}

if ( ! function_exists( 'pre_var_dump' ) ) {
	function pre_var_dump( $var ) {
		echo '<pre style="text-align: left; white-space: pre-wrap;">';
			var_dump( $var );
		echo '</pre>';
	}
}

function wpjobster_debug_add_action() {
	$debug_tags = array();
	add_action( 'all', function ( $tag ) {
		global $debug_tags;
		if ( in_array( $tag, $debug_tags ) ) {
			return;
		}
		echo "<pre style='margin-left: 210px;';>" . $tag . "</pre>";
		$debug_tags[] = $tag;
	} );
}

function wpjobster_debug_add_filter() {
	$debug_tags = array();
	add_filter( 'all', function ( $tag ) {
		global $debug_tags;
		if ( in_array( $tag, $debug_tags ) ) {
			return;
		}
		echo "<pre style='margin-left: 210px;';>" . $tag . "</pre>";
		$debug_tags[] = $tag;
	} );
}

function wpjobster_debug_list_all_filters() {

	$search = '';

	global $wp_filter;
	$all_filters = array ();
	$h1  = '<h1>Current Filters: ' . $search . '</h1>';
	$out = '';
	$toc = '<ul>';
	foreach ( $wp_filter as $key => $val ) {
		if ( ! $search || ( $search && FALSE !== strpos( $key, $search ) ) ) {
			$all_filters[$key][] = var_export( $val, TRUE );
		}
	}
	foreach ( $all_filters as $name => $arr_vals ) {
		$out .= "<h2 id=$name>$name</h2><pre>" . implode( "\n\n", $arr_vals ) . '</pre>';
		$toc .= "<li><a href='#$name'>$name</a></li>";
	}
	print "$h1$toc</ul>$out";
}

//--------------------------------------
// Get Host
//--------------------------------------

function get_host() {
	$possibleHostSources = array('HTTP_X_FORWARDED_HOST', 'HTTP_HOST', 'SERVER_NAME', 'SERVER_ADDR');
	$sourceTransformations = array(
		"HTTP_X_FORWARDED_HOST" => function($value) {
			$elements = explode(',', $value);
			return trim(end($elements));
		}
	);
	$host = '';
	foreach ($possibleHostSources as $source)
	{
		if (!empty($host)) break;
		if (empty($_SERVER[$source])) continue;
		$host = $_SERVER[$source];
		if (array_key_exists($source, $sourceTransformations))
		{
			$host = $sourceTransformations[$source]($host);
		}
	}

	// Remove port number from host
	$host = preg_replace('/:\d+$/', '', $host);

	return trim($host);
}


//--------------------------------------
// Get Host Without "www."
//--------------------------------------

function get_host_no_www() {
	$host = get_host();
	if (substr($host, 0, 4) == 'www.') {
		$domain = substr($host, 4);
	} else {
		$domain = $host;
	}

	return trim($domain);
}

function wpj_get_current_url() {
	return ( is_ssl() ? 'https' : 'http' ) . '://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
}

function wpj_scan_folders( $path = '', $return = array() ) {
	$path = $path == '' ? dirname( __FILE__ ) : $path;
	$lists = @scandir( $path );

	if ( ! empty( $lists ) ) {
		foreach ( $lists as $f ) {
			if ( is_dir( $path . DIRECTORY_SEPARATOR . $f ) && $f != "." && $f != ".." ) {
				if ( ! in_array( $path . DIRECTORY_SEPARATOR . $f, $return ) )
					$return[] = trailingslashit( $path . DIRECTORY_SEPARATOR . $f );

				wpj_scan_folders( $path . DIRECTORY_SEPARATOR . $f, $return);
			}
		}
	}

	return $return;
}

function wpj_get_folder_files( $dir = '', $ret = [] ) {
	$dir = $dir == '' ? dirname( __FILE__ ) : $dir;
	$files = @scandir( $dir );

	if ( ! empty( $files ) ) {
		foreach ( $files as $key => $filename ) {
			$path = realpath( $dir . DIRECTORY_SEPARATOR . $filename );
			if ( ! is_dir( $path ) ) {
				$ret[] = $path;
			} else if ( $filename != "." && $filename != ".." ) {
				prl_scan_folders( $path, $ret );
			}
		}
	}

	return $ret;
}

function wpj_bool_option( $option, $default = false ) {
	// returns true and false for options set as "yes" and "no"
	// returns true and false for options set as "true" and "false", case insensitive
	// returns false for empty() which includes:
	// str "", FALSE, array(), NULL, str "0", int 0, float 0.0, empty $var

	$get_option = get_option( $option, $default );
	if ( strtolower( $get_option ) === 'no'
		|| strtolower( $get_option ) === 'false'
		|| empty( $get_option )
	) {
		return false;
	}

	return true;
}

function wpj_encode_emoji( $string ) {

	if ( function_exists( 'wp_encode_emoji' ) && function_exists( 'mb_convert_encoding' ) ) {
		$string = wp_encode_emoji( $string );
	}

	return $string;
}

function get_midnight_date_timestamp($timestamp) {
	return strtotime(date("d-m-Y 00:00:00", $timestamp));
}

if ( ! function_exists( 'get_current_page_url' ) ) {
	function get_current_page_url() {
		global $wp;
		return add_query_arg( $_SERVER['QUERY_STRING'], '', home_url( $wp->request ) );
	}
}

function assign_rand_value($num) {
	// accepts 1 - 36
	switch($num) {
		case "1"  : $rand_value = "a"; break;
		case "2"  : $rand_value = "b"; break;
		case "3"  : $rand_value = "c"; break;
		case "4"  : $rand_value = "d"; break;
		case "5"  : $rand_value = "e"; break;
		case "6"  : $rand_value = "f"; break;
		case "7"  : $rand_value = "g"; break;
		case "8"  : $rand_value = "h"; break;
		case "9"  : $rand_value = "i"; break;
		case "10" : $rand_value = "j"; break;
		case "11" : $rand_value = "k"; break;
		case "12" : $rand_value = "l"; break;
		case "13" : $rand_value = "m"; break;
		case "14" : $rand_value = "n"; break;
		case "15" : $rand_value = "o"; break;
		case "16" : $rand_value = "p"; break;
		case "17" : $rand_value = "q"; break;
		case "18" : $rand_value = "r"; break;
		case "19" : $rand_value = "s"; break;
		case "20" : $rand_value = "t"; break;
		case "21" : $rand_value = "u"; break;
		case "22" : $rand_value = "v"; break;
		case "23" : $rand_value = "w"; break;
		case "24" : $rand_value = "x"; break;
		case "25" : $rand_value = "y"; break;
		case "26" : $rand_value = "z"; break;
		case "27" : $rand_value = "0"; break;
		case "28" : $rand_value = "1"; break;
		case "29" : $rand_value = "2"; break;
		case "30" : $rand_value = "3"; break;
		case "31" : $rand_value = "4"; break;
		case "32" : $rand_value = "5"; break;
		case "33" : $rand_value = "6"; break;
		case "34" : $rand_value = "7"; break;
		case "35" : $rand_value = "8"; break;
		case "36" : $rand_value = "9"; break;
	}
	return $rand_value;
}

function get_rand_alphanumeric($length) {
	if ($length>0) {
		$rand_id="";
		for ($i=1; $i<=$length; $i++) {
			mt_srand((double)microtime() * 1000000);
			$num = mt_rand(1,36);
			$rand_id .= assign_rand_value($num);
		}
	}
	return $rand_id;
}

function get_rand_numbers($length) {
	if ($length>0) {
		$rand_id="";
		for($i=1; $i<=$length; $i++) {
			mt_srand((double)microtime() * 1000000);
			$num = mt_rand(27,36);
			$rand_id .= assign_rand_value($num);
		}
	}
	return $rand_id;
}

function get_rand_letters($length) {
	if ($length>0) {
		$rand_id="";
		for($i=1; $i<=$length; $i++) {
			mt_srand((double)microtime() * 1000000);
			$num = mt_rand(1,26);
			$rand_id .= assign_rand_value($num);
		}
	}
	return $rand_id;
}

function wpjobster_better_trim($text, $len = 150, $more = '...') {
	// wp_trim_words sucks because it counts the words
	// mb_strimwidth counts the characters but cuts words
	// wpjobster_better_trim counts the characters and doesn't cut words
	// when the text contains one word only, the word is cut if needed

	$parts = explode(' ', $text);
	$ic = count($parts);
	$tx = '';
	$txt = '';

	for ($i = 0; $i < $ic; $i++) {
		$tx = $txt;
		$txt .= $parts[$i].' ';
		if (mb_strlen($txt) >= $len) {
			break;
		}
	}

	$tx = trim($tx);
	$txt = trim($txt);

	if (mb_strlen($text) > $len) {
		if ($i == 0) {
			$txt = mb_strimwidth($txt, 0, $len, $more);
		} else {

			$txt = $tx . $more;
		}
	}

	return $txt;
}

if (!function_exists('wpjobster_prepare_seconds_to_words')) {

	function wpjobster_prepare_seconds_to_words($seconds)    {
		$res = wpjobster_seconds_to_words_new($seconds);

		if ($res == "Expired")            return __('Expired', 'wpjobster');

		if ($res[0] == 0)            return sprintf(__("%s hours, %s min, %s sec", 'wpjobster'), $res[1], $res[2], $res[3]);

		if ($res[0] == 1) {
			$plural = $res[1] > 1 ? __('days', 'wpjobster') :
			__('day', 'wpjobster');
			return sprintf(__("%s %s, %s hours, %s min", 'wpjobster'), $res[1], $plural, $res[2], $res[3]);
		}

	}

}

function wpjobster_seconds_to_words_new($seconds){

	if ($seconds < 0)        return 'Expired';
	/*** number of days ***/
	$days = (int) ($seconds / 86400);
	/*** if more than one day ***/
	$plural = $days > 1 ? 'days' :
	'day';
	/*** number of hours ***/
	$hours = (int) (($seconds - ($days * 86400)) / 3600);
	/*** number of mins ***/
	$mins = (int) (($seconds - $days * 86400 - $hours * 3600) / 60);
	/*** number of seconds ***/
	$secs = (int) ($seconds - ($days * 86400) - ($hours * 3600) - ($mins * 60));
	/*** return the string ***/

	if ($days == 0 || $days < 0) {
		$arr[0] = 0;
		$arr[1] = $hours;
		$arr[2] = $mins;
		$arr[3] = $secs;
		return $arr;
	} else {
		$arr[0] = 1;
		$arr[1] = $days;
		$arr[2] = $hours;
		$arr[3] = $mins;
		return $arr;
	}

}

function wpjobster_seconds_to_words_joined($seconds){

	if ($seconds < 0) return;

	$years = (int) ($seconds / (365 * 24 * 60 * 60));
	$months = (int) ($seconds / (30 * 24 * 60 * 60));
	$days = (int) ($seconds / (24 * 60 * 60));

	$years_word = _n("year", "years", $years, "wpjobster");
	$months_word = _n("month", "months", $months, "wpjobster");
	$days_word = _n("day", "days", $days, "wpjobster");

	if ($days <= 0) {
		return __("today", "wpjobster");
	}

	if ($months <= 0) {
		return $days . ' ' . $days_word;
	}

	if ($years <= 0) {
		return $months . ' ' . $months_word;
	}

	if (($months % 12) <= 0) {
		return $years . ' ' . $years_word;
	}

	return $years . ' ' . $years_word . ', ' . ($months % 12) . ' ' . $months_word;
}

// GET DATA WITH cURL
function wpjobster_get_cURL_data($url)
{
	$ch = curl_init();
	$timeout = 5;
	curl_setopt($ch,CURLOPT_URL,$url);
	curl_setopt($ch,CURLOPT_RETURNTRANSFER,1);
	curl_setopt($ch,CURLOPT_CONNECTTIMEOUT,$timeout);
	$data = curl_exec($ch);
	curl_close($ch);
	return $data;
}

add_action( 'wp_ajax_get_wpjobster_graph', 'wpjobster_get_graph_ajax' );
if(!function_exists('wpjobster_get_unix_timestamp')){
	function wpjobster_get_unix_timestamp($date){
		$date = new DateTime($date);
		return  $date->getTimestamp();
	}
}

function count_newline_as_one_char($str) {
	$str = stripslashes($str);
	$str = str_replace(array("<br>","<br />","<br/>"),'', $str);
	$str = str_replace(array("\r\n","\n","\r"),' ', $str);
	$str = html_entity_decode($str, ENT_QUOTES, "UTF-8");
	return $str;
}

function get_video_type( $url ) {
	$url = parse_url($url);

	if ( $url['host'] == 'youtube.com'
		|| $url['host'] == 'www.youtube.com'
		|| $url['host'] == 'youtu.be'
		|| $url['host'] == 'www.youtu.be' ) {
		return 'youtube';

	} elseif ( $url['host'] == 'vimeo.com' ) {
		return 'vimeo';

	} else {
		return 'unknown';
	}
}

add_filter('oembed_result', 'iweb_modest_youtube_player', 10, 3);
function iweb_modest_youtube_player($html, $url, $args) {
	return str_replace('?feature=oembed', '?feature=oembed&modestbranding=0&showinfo=0&rel=0&iv_load_policy=3', $html);
}

function wpjobster_insert_widget_in_sidebar( $widget_id, $widget_data, $sidebar ) {
	// Retrieve sidebars, widgets and their instances
	$sidebars_widgets = get_option( 'sidebars_widgets', array() );
	$widget_instances = get_option( 'widget_' . $widget_id, array() );

	// Retrieve the key of the next widget instance
	$numeric_keys = array_filter( array_keys( $widget_instances ), 'is_int' );
	$next_key = $numeric_keys ? max( $numeric_keys ) + 1 : 2;

	// Add this widget to the sidebar
	if ( ! isset( $sidebars_widgets[ $sidebar ] ) ) {
		$sidebars_widgets[ $sidebar ] = array();
	}
	$sidebars_widgets[ $sidebar ][] = $widget_id . '-' . $next_key;

	// Add the new widget instance
	$widget_instances[ $next_key ] = $widget_data;

	// Store updated sidebars, widgets and their instances
	update_option( 'sidebars_widgets', $sidebars_widgets );
	update_option( 'widget_' . $widget_id, $widget_instances );
}

function wpjobster_parameter_exist( $parameter, $has_value='yes' ){
	if( $has_value && $has_value != '' && $has_value != 'no' ){
		if( isset( $_GET[$parameter] ) && $_GET[$parameter] && $_GET[$parameter] != '' ){
			return 1;
		}else{
			return 0;
		}
	}else{
		if( isset( $_GET[$parameter] ) ){
			return 1;
		}else{
			return 0;
		}
	}
}

function wpj_array_in_URI( $arr = array() ) {
	if ( $arr ) {
		foreach ( $arr as $key => $value ) {
			if ( isset( $_REQUEST[$value] ) ) {
				return true;
			}
		}
	}

	return false;
}

function wpjobster_is_json($string) {
	json_decode($string);
	return (json_last_error() == JSON_ERROR_NONE);
}

function wpj_make_links_clickable( $text, $class='', $target='_blank' ){
	return preg_replace( '/\b(?<!=")(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[A-Z0-9+&@#\/%=~_|](?!.*".*>)(?!.*<\/a>)/i', '<a href="\0" rel="nofollow" target="' . $target . '" class="' . $class . '">\0</a>', $text );
}

function wpjobster_crypto_rand_secure( $min, $max ) {
	$range = $max - $min;
	if ($range < 0) return $min; // not so random...
	$log = log($range, 2);
	$bytes = (int) ($log / 8) + 1; // length in bytes
	$bits = (int) $log + 1; // length in bits
	$filter = (int) (1 << $bits) - 1; // set all lower bits to 1
	do {
		$rnd = hexdec(bin2hex(openssl_random_pseudo_bytes($bytes)));
		$rnd = $rnd & $filter; // discard irrelevant bits
	} while ($rnd >= $range);

	return $min + $rnd;
}

function wpjobster_get_token( $length=32 ){
	$token = "";
	$codeAlphabet  = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
	$codeAlphabet .= "abcdefghijklmnopqrstuvwxyz";
	$codeAlphabet .= "0123456789";

	for($i=0;$i<$length;$i++){
		$token .= $codeAlphabet[wpjobster_crypto_rand_secure(0,strlen($codeAlphabet))];
	}

	return '&auth_token=' . $token;
}

function wpjobster_copy_directory( $src, $dst ) {
	$dir = opendir($src);

	@mkdir($dst);
	while(false !== ( $file = readdir($dir)) ) {
		if (( $file != '.' ) && ( $file != '..' )) {
			if ( is_dir($src . '/' . $file) ) {
				wpjobster_copy_directory($src . '/' . $file,$dst . '/' . $file);
			}
			else {
				copy($src . '/' . $file,$dst . '/' . $file);
			}
		}
	}

	closedir($dir);
}

function wpjobster_url_exist( $url = '' ) {
	$exists = true;

	$curl = curl_init( $url );
	curl_setopt( $curl, CURLOPT_NOBODY, true );
	$result = curl_exec( $curl);
	if ( $result !== false ) {
		$statusCode = curl_getinfo( $curl, CURLINFO_HTTP_CODE );
		if ( $statusCode == 404 ) {
			$exists = false;
		} else {
			$exists = true;
		}
	} else {
		$exists = false;
	}

	return $exists;
}

function wpj_url_is_image( $url = '' ) {
	if ( $url ) {
		if ( ini_get( 'allow_url_fopen' ) && is_array( getimagesize( $url ) ) ) {

			return true;

		} else {

			$curl = curl_init();

			curl_setopt_array( $curl, array(
				CURLOPT_URL            => $url,
				CURLOPT_CUSTOMREQUEST  => 'GET',
				CURLOPT_RETURNTRANSFER => false,
				CURLOPT_NOBODY         => true
			) );

			curl_exec( $curl );

			if ( ! curl_errno( $curl ) ) {
				$header = curl_getinfo( $curl, CURLINFO_CONTENT_TYPE );
			} else {
				return false;
			}

			curl_close( $curl );

			if ( strpos( $header, 'image/' ) !== false ) {
				return true;
			}

		}
	}

	return false;
}

function wpj_seconds_to_words( $seconds, $short = false, $one_interval = false ) {
	$ret = '';

	/*** get the years ***/
	$years = intval( intval( $seconds ) / ( 3600 * 24 * 30 * 12 ) );
	if ( $years > 0 ) {
		$ret .= sprintf( _n( '%d year ', '%d years ', $years, 'wpjobster' ), $years );

		if ( $short ) return sprintf( __( '%dy ', 'wpjobster' ), $years );
		if ( $one_interval ) return sprintf( _n( '%d year ago ', '%d years ago ', $years, 'wpjobster' ), $years );
	}

	/*** get the months ***/
	$months = intval( intval( $seconds ) / ( 3600 * 24 * 30 ) );
	if ( $months > 0 ) {
		$ret .= sprintf( _n( '%d month ', '%d months ', $months, 'wpjobster' ), $months );

		if ( $short ) return sprintf( __( '%dmo ', 'wpjobster' ), $months );
		if ( $one_interval ) return sprintf( _n( '%d month ago ', '%d months ago ', $months, 'wpjobster' ), $months );
	}

	/*** get the weeks ***/
	$weeks = intval( intval( $seconds ) / ( 3600 * 24 * 7 ) );
	if ( $weeks > 0 ) {
		$ret .= sprintf( _n( '%d week ', '%d weeks ', $weeks, 'wpjobster' ), $weeks );

		if ( $short ) return sprintf( __( '%dw ', 'wpjobster' ), $weeks );
		if ( $one_interval ) return sprintf( _n( '%d week ago ', '%d weeks ago ', $weeks, 'wpjobster' ), $weeks );
	}

	/*** get the days ***/
	$days = intval( intval( $seconds ) / ( 3600 * 24 ) );
	if ( $days > 0 ) {
		$ret .= sprintf( _n( '%d day ', '%d days ', $days, 'wpjobster' ), $days );

		if ( $short ) return sprintf( __( '%dd ', 'wpjobster' ), $days );
		if ( $one_interval ) return sprintf( _n( '%d day ago ', '%d days ago ', $days, 'wpjobster' ), $days );
	}

	/*** get the hours ***/
	$hours = ( intval( $seconds ) / 3600 ) % 24;
	if ( $hours > 0 ) {
		$ret .= sprintf( _n( '%d hour ', '%d hours ', $hours, 'wpjobster' ), $hours );

		if ( $short ) return sprintf( __( '%dh ', 'wpjobster' ), $hours );
		if ( $one_interval ) return sprintf( _n( '%d hour ago ', '%d hours ago ', $hours, 'wpjobster' ), $hours );
	}

	/*** get the minutes ***/
	$minutes = ( intval( $seconds ) / 60 ) % 60;
	if ( $minutes > 0 ) {
		$ret .= sprintf( _n( '%d minute ', '%d minutes ', $minutes, 'wpjobster' ), $minutes );

		if ( $short ) return sprintf( __( '%dm ', 'wpjobster' ), $minutes );
		if ( $one_interval ) return sprintf( _n( '%d minute ago ', '%d minutes ago ', $minutes, 'wpjobster' ), $minutes );
	}

	/*** get the seconds ***/
	$seconds = intval( $seconds ) % 60;
	if ( $seconds > 0 && $minutes <= 0 ) {
		$ret .= sprintf( _n( '%d second', '%d seconds', $seconds, 'wpjobster' ), $seconds );

		if ( $short ) return sprintf( __( '%ds ', 'wpjobster' ), $seconds );
		if ( $one_interval ) return sprintf( _n( '%d second ago', '%d seconds ago', $seconds, 'wpjobster' ), $seconds );
	}

	return $ret;
}

function wpj_get_selected_value( $val1, $val2 ) {
	return $val1 == $val2 ? 'selected=selected' : '';
}

function wpj_date_number_to_string( $number ) {
	if ( $number == 1 ) { return __( 'Jan', 'wpjobster' ); }
	elseif ( $number == 2 ) { return __( 'Feb', 'wpjobster' ); }
	elseif ( $number == 3 ) { return __( 'Mar', 'wpjobster' ); }
	elseif ( $number == 4 ) { return __( 'Apr', 'wpjobster' ); }
	elseif ( $number == 5 ) { return __( 'May', 'wpjobster' ); }
	elseif ( $number == 6 ) { return __( 'Jun', 'wpjobster' ); }
	elseif ( $number == 7 ) { return __( 'Jul', 'wpjobster' ); }
	elseif ( $number == 8 ) { return __( 'Aug', 'wpjobster' ); }
	elseif ( $number == 9 ) { return __( 'Sep', 'wpjobster' ); }
	elseif ( $number == 10 ) { return __( 'Oct', 'wpjobster' ); }
	elseif ( $number == 11 ) { return __( 'Nov', 'wpjobster' ); }
	elseif ( $number == 12 ) { return __( 'Dec', 'wpjobster' ); }
}

/**
 * Convert number to string
 *
 * @param int $n (0-10)
 * @return string
 */
function wpj_number_to_string( $n ) {
	$strings = array( 'zero', 'one', 'two', 'three', 'four', 'five', 'six', 'seven', 'eight', 'nine', 'ten' );

	if ( 0 <= $n && $n <= 10 ) {
		return $strings[$n];
	}

	return $n;
}

function wpj_truncate_text( $text = '', $max_length = 250 ) {
	$tags   = array();
	$result = "";

	$is_open          = false;
	$grab_open        = false;
	$is_close         = false;
	$in_double_quotes = false;
	$in_single_quotes = false;
	$tag              = "";

	$i        = 0;
	$stripped = 0;

	$stripped_text = strip_tags($text);

	while ( $i < strlen( $text ) && $stripped < strlen( $stripped_text ) && $stripped < $max_length ) {
		$symbol  = $text[$i];
		$result .= $symbol;

		switch ( $symbol ) {
			case '<':
				$is_open   = true;
				$grab_open = true;
				break;
			case '"':
				if ( $in_double_quotes )
					$in_double_quotes = false;
				else
					$in_double_quotes = true;

			break;

			case "'":
				if ($in_single_quotes)
					$in_single_quotes = false;
				else
					$in_single_quotes = true;

			break;

			case '/':
				if ( $is_open && ! $in_double_quotes && ! $in_single_quotes ) {
					$is_close  = true;
					$is_open   = false;
					$grab_open = false;
				}

				break;

			case ' ':
				if ( $is_open )
					$grab_open = false;
				else
					$stripped++;

				break;

			case '>':
				if ( $is_open ) {
					$is_open   = false;
					$grab_open = false;
					array_push( $tags, $tag );
					$tag = "";
				} elseif ( $is_close ) {
					$is_close = false;
					array_pop( $tags );
					$tag = "";
				}

				break;

			default:
				if ( $grab_open || $is_close )
					$tag .= $symbol;

				if ( ! $is_open && ! $is_close )
					$stripped++;
		}

		$i++;
	}

	while ( $tags )
		$result .= "</" . array_pop( $tags ) . ">";

	return $result;
}

function wpj_option_has_value( $option_name = '', $default = '' ) {
	$current_opt = get_option( $option_name );

	if ( $option_name ) {
		if ( ! empty( trim( $current_opt ) ) ) {
			return $current_opt;
		} elseif ( $default ) {
			return $default;
		}
	}

	return 0;
}

function wpj_add_content_to_htaccess( $file_name = ".htaccess", $code_desc = "WPJ htaccess", $content = array() ) {
	try {
		if ( file_exists(  ABSPATH . 'wp-admin/includes/file.php' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/file.php' );
		}

		if ( file_exists(  ABSPATH . 'wp-admin/includes/misc.php' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/misc.php' );
		}

		if ( function_exists( 'get_home_path' ) && function_exists( 'insert_with_markers' ) && $content ) {
			$file_path = get_home_path() . $file_name;
			return insert_with_markers( $file_path, $code_desc, $content );
		} else {
			return 'We can\'t find the path to your files. Contact support';
		}
	} catch ( Exception $e ) { return strtoupper( $code_desc ) . '. We couldn\'t load the code. Contact support.'; }
}

function wpjobster_mimes_type(){
	$mt = array(
		'123'         => 'application/vnd.lotus-1-2-3',
		'3dml'        => 'text/vnd.in3d.3dml',
		'3g2'         => 'video/3gpp2',
		'3gp'         => 'video/3gpp',
		'7z'          => 'application/x-7z-compressed',
		'aab'         => 'application/x-authorware-bin',
		'aac'         => 'audio/x-aac',
		'aam'         => 'application/x-authorware-map',
		'aas'         => 'application/x-authorware-seg',
		'abw'         => 'application/x-abiword',
		'ac'          => 'application/pkix-attr-cert',
		'acc'         => 'application/vnd.americandynamics.acc',
		'ace'         => 'application/x-ace-compressed',
		'acu'         => 'application/vnd.acucobol',
		'adp'         => 'audio/adpcm',
		'aep'         => 'application/vnd.audiograph',
		'afp'         => 'application/vnd.ibm.modcap',
		'ahead'       => 'application/vnd.ahead.space',
		'ai'          => 'application/postscript',
		'aif'         => 'audio/x-aiff',
		'air'         => 'application/vnd.adobe.air-application-installer-package+zip',
		'ait'         => 'application/vnd.dvb.ait',
		'ami'         => 'application/vnd.amiga.ami',
		'apk'         => 'application/vnd.android.package-archive',
		'application' => 'application/x-ms-application',
		'apr'         => 'application/vnd.lotus-approach',
		'asf'         => 'video/x-ms-asf',
		'aso'         => 'application/vnd.accpac.simply.aso',
		'atc'         => 'application/vnd.acucorp',
		'atom'        => 'application/atom+xml',
		'atomcat'     => 'application/atomcat+xml',
		'atomsvc'     => 'application/atomsvc+xml',
		'atx'         => 'application/vnd.antix.game-component',
		'au'          => 'audio/basic',
		'avi'         => 'video/x-msvideo',
		'aw'          => 'application/applixware',
		'azf'         => 'application/vnd.airzip.filesecure.azf',
		'azs'         => 'application/vnd.airzip.filesecure.azs',
		'azw'         => 'application/vnd.amazon.ebook',
		'bcpio'       => 'application/x-bcpio',
		'bdf'         => 'application/x-font-bdf',
		'bdm'         => 'application/vnd.syncml.dm+wbxml',
		'bed'         => 'application/vnd.realvnc.bed',
		'bh2'         => 'application/vnd.fujitsu.oasysprs',
		'bin'         => 'application/octet-stream',
		'bmi'         => 'application/vnd.bmi',
		'bmp'         => 'image/bmp',
		'box'         => 'application/vnd.previewsystems.box',
		'btif'        => 'image/prs.btif',
		'bz'          => 'application/x-bzip',
		'bz2'         => 'application/x-bzip2',
		'c'           => 'text/x-c',
		'c11amc'      => 'application/vnd.cluetrust.cartomobile-config',
		'c11amz'      => 'application/vnd.cluetrust.cartomobile-config-pkg',
		'c4g'         => 'application/vnd.clonk.c4group',
		'cab'         => 'application/vnd.ms-cab-compressed',
		'car'         => 'application/vnd.curl.car',
		'cat'         => 'application/vnd.ms-pki.seccat',
		'ccxml'       => 'application/ccxml+xml',
		'cdbcmsg'     => 'application/vnd.contact.cmsg',
		'cdkey'       => 'application/vnd.mediastation.cdkey',
		'cdmia'       => 'application/cdmi-capability',
		'cdmic'       => 'application/cdmi-container',
		'cdmid'       => 'application/cdmi-domain',
		'cdmio'       => 'application/cdmi-object',
		'cdmiq'       => 'application/cdmi-queue',
		'cdx'         => 'chemical/x-cdx',
		'cdxml'       => 'application/vnd.chemdraw+xml',
		'cdy'         => 'application/vnd.cinderella',
		'cer'         => 'application/pkix-cert',
		'cgm'         => 'image/cgm',
		'chat'        => 'application/x-chat',
		'chm'         => 'application/vnd.ms-htmlhelp',
		'chrt'        => 'application/vnd.kde.kchart',
		'cif'         => 'chemical/x-cif',
		'cii'         => 'application/vnd.anser-web-certificate-issue-initiation',
		'cil'         => 'application/vnd.ms-artgalry',
		'cla'         => 'application/vnd.claymore',
		'class'       => 'application/java-vm',
		'clkk'        => 'application/vnd.crick.clicker.keyboard',
		'clkp'        => 'application/vnd.crick.clicker.palette',
		'clkt'        => 'application/vnd.crick.clicker.template',
		'clkw'        => 'application/vnd.crick.clicker.wordbank',
		'clkx'        => 'application/vnd.crick.clicker',
		'clp'         => 'application/x-msclip',
		'cmc'         => 'application/vnd.cosmocaller',
		'cmdf'        => 'chemical/x-cmdf',
		'cml'         => 'chemical/x-cml',
		'cmp'         => 'application/vnd.yellowriver-custom-menu',
		'cmx'         => 'image/x-cmx',
		'cod'         => 'application/vnd.rim.cod',
		'cpio'        => 'application/x-cpio',
		'cpt'         => 'application/mac-compactpro',
		'crd'         => 'application/x-mscardfile',
		'crl'         => 'application/pkix-crl',
		'cryptonote'  => 'application/vnd.rig.cryptonote',
		'csh'         => 'application/x-csh',
		'csml'        => 'chemical/x-csml',
		'csp'         => 'application/vnd.commonspace',
		'css'         => 'text/css',
		'csv'         => 'text/csv',
		'cu'          => 'application/cu-seeme',
		'curl'        => 'text/vnd.curl',
		'cww'         => 'application/prs.cww',
		'dae'         => 'model/vnd.collada+xml',
		'daf'         => 'application/vnd.mobius.daf',
		'davmount'    => 'application/davmount+xml',
		'dcurl'       => 'text/vnd.curl.dcurl',
		'dd2'         => 'application/vnd.oma.dd2+xml',
		'ddd'         => 'application/vnd.fujixerox.ddd',
		'deb'         => 'application/x-debian-package',
		'der'         => 'application/x-x509-ca-cert',
		'dfac'        => 'application/vnd.dreamfactory',
		'dir'         => 'application/x-director',
		'dis'         => 'application/vnd.mobius.dis',
		'djvu'        => 'image/vnd.djvu',
		'dmg'         => 'application/x-apple-diskimage',
		'dna'         => 'application/vnd.dna',
		'doc'         => 'application/msword',
		'docm'        => 'application/vnd.ms-word.document.macroenabled.12',
		'docx'        => 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
		'dotm'        => 'application/vnd.ms-word.template.macroenabled.12',
		'dotx'        => 'application/vnd.openxmlformats-officedocument.wordprocessingml.template',
		'dp'          => 'application/vnd.osgi.dp',
		'dpg'         => 'application/vnd.dpgraph',
		'dra'         => 'audio/vnd.dra',
		'dsc'         => 'text/prs.lines.tag',
		'dssc'        => 'application/dssc+der',
		'dtb'         => 'application/x-dtbook+xml',
		'dtd'         => 'application/xml-dtd',
		'dts'         => 'audio/vnd.dts',
		'dtshd'       => 'audio/vnd.dts.hd',
		'dvi'         => 'application/x-dvi',
		'dwf'         => 'model/vnd.dwf',
		'dwg'         => 'image/vnd.dwg',
		'dxf'         => 'image/vnd.dxf',
		'dxp'         => 'application/vnd.spotfire.dxp',
		'ecelp4800'   => 'audio/vnd.nuera.ecelp4800',
		'ecelp7470'   => 'audio/vnd.nuera.ecelp7470',
		'ecelp9600'   => 'audio/vnd.nuera.ecelp9600',
		'edm'         => 'application/vnd.novadigm.edm',
		'edx'         => 'application/vnd.novadigm.edx',
		'efif'        => 'application/vnd.picsel',
		'ei6'         => 'application/vnd.pg.osasli',
		'eml'         => 'message/rfc822',
		'emma'        => 'application/emma+xml',
		'eol'         => 'audio/vnd.digital-winds',
		'eot'         => 'application/vnd.ms-fontobject',
		'epub'        => 'application/epub+zip',
		'es'          => 'application/ecmascript',
		'es3'         => 'application/vnd.eszigno3+xml',
		'esf'         => 'application/vnd.epson.esf',
		'etx'         => 'text/x-setext',
		'exe'         => 'application/x-msdownload',
		'exi'         => 'application/exi',
		'ext'         => 'application/vnd.novadigm.ext',
		'ez2'         => 'application/vnd.ezpix-album',
		'ez3'         => 'application/vnd.ezpix-package',
		'f'           => 'text/x-fortran',
		'f4v'         => 'video/x-f4v',
		'fbs'         => 'image/vnd.fastbidsheet',
		'fcs'         => 'application/vnd.isac.fcs',
		'fdf'         => 'application/vnd.fdf',
		'fe_launch'   => 'application/vnd.denovo.fcselayout-link',
		'fg5'         => 'application/vnd.fujitsu.oasysgp',
		'fh'          => 'image/x-freehand',
		'fig'         => 'application/x-xfig',
		'fli'         => 'video/x-fli',
		'flo'         => 'application/vnd.micrografx.flo',
		'flv'         => 'video/x-flv',
		'flw'         => 'application/vnd.kde.kivio',
		'flx'         => 'text/vnd.fmi.flexstor',
		'fly'         => 'text/vnd.fly',
		'fm'          => 'application/vnd.framemaker',
		'fnc'         => 'application/vnd.frogans.fnc',
		'fpx'         => 'image/vnd.fpx',
		'fsc'         => 'application/vnd.fsc.weblaunch',
		'fst'         => 'image/vnd.fst',
		'ftc'         => 'application/vnd.fluxtime.clip',
		'fti'         => 'application/vnd.anser-web-funds-transfer-initiation',
		'fvt'         => 'video/vnd.fvt',
		'fxp'         => 'application/vnd.adobe.fxp',
		'fzs'         => 'application/vnd.fuzzysheet',
		'g2w'         => 'application/vnd.geoplan',
		'g3'          => 'image/g3fax',
		'g3w'         => 'application/vnd.geospace',
		'gac'         => 'application/vnd.groove-account',
		'gdl'         => 'model/vnd.gdl',
		'geo'         => 'application/vnd.dynageo',
		'gex'         => 'application/vnd.geometry-explorer',
		'ggb'         => 'application/vnd.geogebra.file',
		'ggt'         => 'application/vnd.geogebra.tool',
		'ghf'         => 'application/vnd.groove-help',
		'gif'         => 'image/gif',
		'gim'         => 'application/vnd.groove-identity-message',
		'gmx'         => 'application/vnd.gmx',
		'gnumeric'    => 'application/x-gnumeric',
		'gph'         => 'application/vnd.flographit',
		'gqf'         => 'application/vnd.grafeq',
		'gram'        => 'application/srgs',
		'grv'         => 'application/vnd.groove-injector',
		'grxml'       => 'application/srgs+xml',
		'gsf'         => 'application/x-font-ghostscript',
		'gtar'        => 'application/x-gtar',
		'gtm'         => 'application/vnd.groove-tool-message',
		'gtw'         => 'model/vnd.gtw',
		'gv'          => 'text/vnd.graphviz',
		'gxt'         => 'application/vnd.geonext',
		'h261'        => 'video/h261',
		'h263'        => 'video/h263',
		'h264'        => 'video/h264',
		'hal'         => 'application/vnd.hal+xml',
		'hbci'        => 'application/vnd.hbci',
		'hdf'         => 'application/x-hdf',
		'hlp'         => 'application/winhlp',
		'hpgl'        => 'application/vnd.hp-hpgl',
		'hpid'        => 'application/vnd.hp-hpid',
		'hps'         => 'application/vnd.hp-hps',
		'hqx'         => 'application/mac-binhex40',
		'htke'        => 'application/vnd.kenameaapp',
		'html'        => 'text/html',
		'hvd'         => 'application/vnd.yamaha.hv-dic',
		'hvp'         => 'application/vnd.yamaha.hv-voice',
		'hvs'         => 'application/vnd.yamaha.hv-script',
		'i2g'         => 'application/vnd.intergeo',
		'icc'         => 'application/vnd.iccprofile',
		'ice'         => 'x-conference/x-cooltalk',
		'ico'         => 'image/x-icon',
		'ics'         => 'text/calendar',
		'ief'         => 'image/ief',
		'ifm'         => 'application/vnd.shana.informed.formdata',
		'igl'         => 'application/vnd.igloader',
		'igm'         => 'application/vnd.insors.igm',
		'igs'         => 'model/iges',
		'igx'         => 'application/vnd.micrografx.igx',
		'iif'         => 'application/vnd.shana.informed.interchange',
		'imp'         => 'application/vnd.accpac.simply.imp',
		'ims'         => 'application/vnd.ms-ims',
		'ipfix'       => 'application/ipfix',
		'ipk'         => 'application/vnd.shana.informed.package',
		'irm'         => 'application/vnd.ibm.rights-management',
		'irp'         => 'application/vnd.irepository.package+xml',
		'itp'         => 'application/vnd.shana.informed.formtemplate',
		'ivp'         => 'application/vnd.immervision-ivp',
		'ivu'         => 'application/vnd.immervision-ivu',
		'jad'         => 'text/vnd.sun.j2me.app-descriptor',
		'jam'         => 'application/vnd.jam',
		'jar'         => 'application/java-archive',
		'java'        => 'text/x-java-source',
		'jisp'        => 'application/vnd.jisp',
		'jlt'         => 'application/vnd.hp-jlyt',
		'jnlp'        => 'application/x-java-jnlp-file',
		'joda'        => 'application/vnd.joost.joda-archive',
		'jpeg'        => 'image/jpeg',
		'jpg'         => 'image/jpeg',
		'jpgv'        => 'video/jpeg',
		'jpm'         => 'video/jpm',
		'js'          => 'application/javascript',
		'json'        => 'application/json',
		'karbon'      => 'application/vnd.kde.karbon',
		'kfo'         => 'application/vnd.kde.kformula',
		'kia'         => 'application/vnd.kidspiration',
		'kml'         => 'application/vnd.google-earth.kml+xml',
		'kmz'         => 'application/vnd.google-earth.kmz',
		'kne'         => 'application/vnd.kinar',
		'kon'         => 'application/vnd.kde.kontour',
		'kpr'         => 'application/vnd.kde.kpresenter',
		'ksp'         => 'application/vnd.kde.kspread',
		'ktx'         => 'image/ktx',
		'ktz'         => 'application/vnd.kahootz',
		'kwd'         => 'application/vnd.kde.kword',
		'lasxml'      => 'application/vnd.las.las+xml',
		'latex'       => 'application/x-latex',
		'lbd'         => 'application/vnd.llamagraphics.life-balance.desktop',
		'lbe'         => 'application/vnd.llamagraphics.life-balance.exchange+xml',
		'les'         => 'application/vnd.hhe.lesson-player',
		'link66'      => 'application/vnd.route66.link66+xml',
		'lrm'         => 'application/vnd.ms-lrm',
		'ltf'         => 'application/vnd.frogans.ltf',
		'lvp'         => 'audio/vnd.lucent.voice',
		'lwp'         => 'application/vnd.lotus-wordpro',
		'm21'         => 'application/mp21',
		'm3u'         => 'audio/x-mpegurl',
		'm3u8'        => 'application/vnd.apple.mpegurl',
		'm4v'         => 'video/x-m4v',
		'ma'          => 'application/mathematica',
		'mads'        => 'application/mads+xml',
		'mag'         => 'application/vnd.ecowin.chart',
		'mathml'      => 'application/mathml+xml',
		'mbk'         => 'application/vnd.mobius.mbk',
		'mbox'        => 'application/mbox',
		'mc1'         => 'application/vnd.medcalcdata',
		'mcd'         => 'application/vnd.mcd',
		'mcurl'       => 'text/vnd.curl.mcurl',
		'mdb'         => 'application/x-msaccess',
		'mdi'         => 'image/vnd.ms-modi',
		'meta4'       => 'application/metalink4+xml',
		'mets'        => 'application/mets+xml',
		'mfm'         => 'application/vnd.mfmp',
		'mgp'         => 'application/vnd.osgeo.mapguide.package',
		'mgz'         => 'application/vnd.proteus.magazine',
		'mid'         => 'audio/midi',
		'mif'         => 'application/vnd.mif',
		'mj2'         => 'video/mj2',
		'mlp'         => 'application/vnd.dolby.mlp',
		'mmd'         => 'application/vnd.chipnuts.karaoke-mmd',
		'mmf'         => 'application/vnd.smaf',
		'mmr'         => 'image/vnd.fujixerox.edmics-mmr',
		'mny'         => 'application/x-msmoney',
		'mods'        => 'application/mods+xml',
		'movie'       => 'video/x-sgi-movie',
		'mp4'         => 'application/mp4',
		'mp4'         => 'video/mp4',
		'mp4a'        => 'audio/mp4',
		'mpc'         => 'application/vnd.mophun.certificate',
		'mpeg'        => 'video/mpeg',
		'mpga'        => 'audio/mpeg',
		'mpkg'        => 'application/vnd.apple.installer+xml',
		'mpm'         => 'application/vnd.blueice.multipass',
		'mpn'         => 'application/vnd.mophun.application',
		'mpp'         => 'application/vnd.ms-project',
		'mpy'         => 'application/vnd.ibm.minipay',
		'mqy'         => 'application/vnd.mobius.mqy',
		'mrc'         => 'application/marc',
		'mrcx'        => 'application/marcxml+xml',
		'mscml'       => 'application/mediaservercontrol+xml',
		'mseq'        => 'application/vnd.mseq',
		'msf'         => 'application/vnd.epson.msf',
		'msh'         => 'model/mesh',
		'msl'         => 'application/vnd.mobius.msl',
		'msty'        => 'application/vnd.muvee.style',
		'mts'         => 'model/vnd.mts',
		'mus'         => 'application/vnd.musician',
		'musicxml'    => 'application/vnd.recordare.musicxml+xml',
		'mvb'         => 'application/x-msmediaview',
		'mwf'         => 'application/vnd.mfer',
		'mxf'         => 'application/mxf',
		'mxl'         => 'application/vnd.recordare.musicxml',
		'mxml'        => 'application/xv+xml',
		'mxs'         => 'application/vnd.triscape.mxs',
		'mxu'         => 'video/vnd.mpegurl',
		'n-gage'      => 'application/vnd.nokia.n-gage.symbian.install',
		'n3'          => 'text/n3',
		'nbp'         => 'application/vnd.wolfram.player',
		'nc'          => 'application/x-netcdf',
		'ncx'         => 'application/x-dtbncx+xml',
		'ngdat'       => 'application/vnd.nokia.n-gage.data',
		'nlu'         => 'application/vnd.neurolanguage.nlu',
		'nml'         => 'application/vnd.enliven',
		'nnd'         => 'application/vnd.noblenet-directory',
		'nns'         => 'application/vnd.noblenet-sealer',
		'nnw'         => 'application/vnd.noblenet-web',
		'npx'         => 'image/vnd.net-fpx',
		'nsf'         => 'application/vnd.lotus-notes',
		'oa2'         => 'application/vnd.fujitsu.oasys2',
		'oa3'         => 'application/vnd.fujitsu.oasys3',
		'oas'         => 'application/vnd.fujitsu.oasys',
		'obd'         => 'application/x-msbinder',
		'oda'         => 'application/oda',
		'odb'         => 'application/vnd.oasis.opendocument.database',
		'odc'         => 'application/vnd.oasis.opendocument.chart',
		'odf'         => 'application/vnd.oasis.opendocument.formula',
		'odft'        => 'application/vnd.oasis.opendocument.formula-template',
		'odg'         => 'application/vnd.oasis.opendocument.graphics',
		'odi'         => 'application/vnd.oasis.opendocument.image',
		'odm'         => 'application/vnd.oasis.opendocument.text-master',
		'odp'         => 'application/vnd.oasis.opendocument.presentation',
		'ods'         => 'application/vnd.oasis.opendocument.spreadsheet',
		'odt'         => 'application/vnd.oasis.opendocument.text',
		'oga'         => 'audio/ogg',
		'ogv'         => 'video/ogg',
		'ogx'         => 'application/ogg',
		'onetoc'      => 'application/onenote',
		'opf'         => 'application/oebps-package+xml',
		'org'         => 'application/vnd.lotus-organizer',
		'osf'         => 'application/vnd.yamaha.openscoreformat',
		'osfpvg'      => 'application/vnd.yamaha.openscoreformat.osfpvg+xml',
		'otc'         => 'application/vnd.oasis.opendocument.chart-template',
		'otf'         => 'application/x-font-otf',
		'otg'         => 'application/vnd.oasis.opendocument.graphics-template',
		'oth'         => 'application/vnd.oasis.opendocument.text-web',
		'oti'         => 'application/vnd.oasis.opendocument.image-template',
		'otp'         => 'application/vnd.oasis.opendocument.presentation-template',
		'ots'         => 'application/vnd.oasis.opendocument.spreadsheet-template',
		'ott'         => 'application/vnd.oasis.opendocument.text-template',
		'oxt'         => 'application/vnd.openofficeorg.extension',
		'p'           => 'text/x-pascal',
		'p10'         => 'application/pkcs10',
		'p12'         => 'application/x-pkcs12',
		'p7b'         => 'application/x-pkcs7-certificates',
		'p7m'         => 'application/pkcs7-mime',
		'p7r'         => 'application/x-pkcs7-certreqresp',
		'p7s'         => 'application/pkcs7-signature',
		'p8'          => 'application/pkcs8',
		'par'         => 'text/plain-bas',
		'paw'         => 'application/vnd.pawaafile',
		'pbd'         => 'application/vnd.powerbuilder6',
		'pbm'         => 'image/x-portable-bitmap',
		'pcf'         => 'application/x-font-pcf',
		'pcl'         => 'application/vnd.hp-pcl',
		'pclxl'       => 'application/vnd.hp-pclxl',
		'pcurl'       => 'application/vnd.curl.pcurl',
		'pcx'         => 'image/x-pcx',
		'pdb'         => 'application/vnd.palm',
		'pdf'         => 'application/pdf',
		'pfa'         => 'application/x-font-type1',
		'pfr'         => 'application/font-tdpfr',
		'pgm'         => 'image/x-portable-graymap',
		'pgn'         => 'application/x-chess-pgn',
		'pgp'         => 'application/pgp-encrypted',
		'pgp'         => 'application/pgp-signature',
		'pic'         => 'image/x-pict',
		'pjpeg'       => 'image/pjpeg',
		'pki'         => 'application/pkixcmp',
		'pkipath'     => 'application/pkix-pkipath',
		'plb'         => 'application/vnd.3gpp.pic-bw-large',
		'plc'         => 'application/vnd.mobius.plc',
		'plf'         => 'application/vnd.pocketlearn',
		'pls'         => 'application/pls+xml',
		'pml'         => 'application/vnd.ctc-posml',
		'png'         => 'image/png',
		'x-png'       => 'image/x-png',
		'x-citrix-png'=> 'image/x-citrix-png',
		'pnm'         => 'image/x-portable-anymap',
		'portpkg'     => 'application/vnd.macports.portpkg',
		'potm'        => 'application/vnd.ms-powerpoint.template.macroenabled.12',
		'potx'        => 'application/vnd.openxmlformats-officedocument.presentationml.template',
		'ppam'        => 'application/vnd.ms-powerpoint.addin.macroenabled.12',
		'ppd'         => 'application/vnd.cups-ppd',
		'ppm'         => 'image/x-portable-pixmap',
		'ppsm'        => 'application/vnd.ms-powerpoint.slideshow.macroenabled.12',
		'ppsx'        => 'application/vnd.openxmlformats-officedocument.presentationml.slideshow',
		'ppt'         => 'application/vnd.ms-powerpoint',
		'pptm'        => 'application/vnd.ms-powerpoint.presentation.macroenabled.12',
		'pptx'        => 'application/vnd.openxmlformats-officedocument.presentationml.presentation',
		'prc'         => 'application/x-mobipocket-ebook',
		'pre'         => 'application/vnd.lotus-freelance',
		'prf'         => 'application/pics-rules',
		'psb'         => 'application/vnd.3gpp.pic-bw-small',
		'psd'         => 'image/vnd.adobe.photoshop',
		'psf'         => 'application/x-font-linux-psf',
		'pskcxml'     => 'application/pskc+xml',
		'ptid'        => 'application/vnd.pvi.ptid1',
		'pub'         => 'application/x-mspublisher',
		'pvb'         => 'application/vnd.3gpp.pic-bw-var',
		'pwn'         => 'application/vnd.3m.post-it-notes',
		'pya'         => 'audio/vnd.ms-playready.media.pya',
		'pyv'         => 'video/vnd.ms-playready.media.pyv',
		'qam'         => 'application/vnd.epson.quickanime',
		'qbo'         => 'application/vnd.intu.qbo',
		'qfx'         => 'application/vnd.intu.qfx',
		'qps'         => 'application/vnd.publishare-delta-tree',
		'qt'          => 'video/quicktime',
		'qxd'         => 'application/vnd.quark.quarkxpress',
		'ram'         => 'audio/x-pn-realaudio',
		'rar'         => 'application/x-rar-compressed',
		'ras'         => 'image/x-cmu-raster',
		'rcprofile'   => 'application/vnd.ipunplugged.rcprofile',
		'rdf'         => 'application/rdf+xml',
		'rdz'         => 'application/vnd.data-vision.rdz',
		'rep'         => 'application/vnd.businessobjects',
		'res'         => 'application/x-dtbresource+xml',
		'rgb'         => 'image/x-rgb',
		'rif'         => 'application/reginfo+xml',
		'rip'         => 'audio/vnd.rip',
		'rl'          => 'application/resource-lists+xml',
		'rlc'         => 'image/vnd.fujixerox.edmics-rlc',
		'rld'         => 'application/resource-lists-diff+xml',
		'rm'          => 'application/vnd.rn-realmedia',
		'rmp'         => 'audio/x-pn-realaudio-plugin',
		'rms'         => 'application/vnd.jcp.javame.midlet-rms',
		'rnc'         => 'application/relax-ng-compact-syntax',
		'rp9'         => 'application/vnd.cloanto.rp9',
		'rpss'        => 'application/vnd.nokia.radio-presets',
		'rpst'        => 'application/vnd.nokia.radio-preset',
		'rq'          => 'application/sparql-query',
		'rs'          => 'application/rls-services+xml',
		'rsd'         => 'application/rsd+xml',
		'rss'         => 'application/rss+xml',
		'rtf'         => 'application/rtf',
		'rtx'         => 'text/richtext',
		's'           => 'text/x-asm',
		'saf'         => 'application/vnd.yamaha.smaf-audio',
		'sbml'        => 'application/sbml+xml',
		'sc'          => 'application/vnd.ibm.secure-container',
		'scd'         => 'application/x-msschedule',
		'scm'         => 'application/vnd.lotus-screencam',
		'scq'         => 'application/scvp-cv-request',
		'scs'         => 'application/scvp-cv-response',
		'scurl'       => 'text/vnd.curl.scurl',
		'sda'         => 'application/vnd.stardivision.draw',
		'sdc'         => 'application/vnd.stardivision.calc',
		'sdd'         => 'application/vnd.stardivision.impress',
		'sdkm'        => 'application/vnd.solent.sdkm+xml',
		'sdp'         => 'application/sdp',
		'sdw'         => 'application/vnd.stardivision.writer',
		'see'         => 'application/vnd.seemail',
		'seed'        => 'application/vnd.fdsn.seed',
		'sema'        => 'application/vnd.sema',
		'semd'        => 'application/vnd.semd',
		'semf'        => 'application/vnd.semf',
		'ser'         => 'application/java-serialized-object',
		'setpay'      => 'application/set-payment-initiation',
		'setreg'      => 'application/set-registration-initiation',
		'sfd-hdstx'   => 'application/vnd.hydrostatix.sof-data',
		'sfs'         => 'application/vnd.spotfire.sfs',
		'sgl'         => 'application/vnd.stardivision.writer-global',
		'sgml'        => 'text/sgml',
		'sh'          => 'application/x-sh',
		'shar'        => 'application/x-shar',
		'shf'         => 'application/shf+xml',
		'sis'         => 'application/vnd.symbian.install',
		'sit'         => 'application/x-stuffit',
		'sitx'        => 'application/x-stuffitx',
		'skp'         => 'application/vnd.koan',
		'sldm'        => 'application/vnd.ms-powerpoint.slide.macroenabled.12',
		'sldx'        => 'application/vnd.openxmlformats-officedocument.presentationml.slide',
		'slt'         => 'application/vnd.epson.salt',
		'sm'          => 'application/vnd.stepmania.stepchart',
		'smf'         => 'application/vnd.stardivision.math',
		'smi'         => 'application/smil+xml',
		'snf'         => 'application/x-font-snf',
		'spf'         => 'application/vnd.yamaha.smaf-phrase',
		'spl'         => 'application/x-futuresplash',
		'spot'        => 'text/vnd.in3d.spot',
		'spp'         => 'application/scvp-vp-response',
		'spq'         => 'application/scvp-vp-request',
		'src'         => 'application/x-wais-source',
		'sru'         => 'application/sru+xml',
		'srx'         => 'application/sparql-results+xml',
		'sse'         => 'application/vnd.kodak-descriptor',
		'ssf'         => 'application/vnd.epson.ssf',
		'ssml'        => 'application/ssml+xml',
		'st'          => 'application/vnd.sailingtracker.track',
		'stc'         => 'application/vnd.sun.xml.calc.template',
		'std'         => 'application/vnd.sun.xml.draw.template',
		'stf'         => 'application/vnd.wt.stf',
		'sti'         => 'application/vnd.sun.xml.impress.template',
		'stk'         => 'application/hyperstudio',
		'stl'         => 'application/vnd.ms-pki.stl',
		'str'         => 'application/vnd.pg.format',
		'stw'         => 'application/vnd.sun.xml.writer.template',
		'sub'         => 'image/vnd.dvb.subtitle',
		'sus'         => 'application/vnd.sus-calendar',
		'sv4cpio'     => 'application/x-sv4cpio',
		'sv4crc'      => 'application/x-sv4crc',
		'svc'         => 'application/vnd.dvb.service',
		'svd'         => 'application/vnd.svd',
		'svg'         => 'image/svg+xml',
		'swf'         => 'application/x-shockwave-flash',
		'swi'         => 'application/vnd.aristanetworks.swi',
		'sxc'         => 'application/vnd.sun.xml.calc',
		'sxd'         => 'application/vnd.sun.xml.draw',
		'sxg'         => 'application/vnd.sun.xml.writer.global',
		'sxi'         => 'application/vnd.sun.xml.impress',
		'sxm'         => 'application/vnd.sun.xml.math',
		'sxw'         => 'application/vnd.sun.xml.writer',
		't'           => 'text/troff',
		'tao'         => 'application/vnd.tao.intent-module-archive',
		'tar'         => 'application/x-tar',
		'tcap'        => 'application/vnd.3gpp2.tcap',
		'tcl'         => 'application/x-tcl',
		'teacher'     => 'application/vnd.smart.teacher',
		'tei'         => 'application/tei+xml',
		'tex'         => 'application/x-tex',
		'texinfo'     => 'application/x-texinfo',
		'tfi'         => 'application/thraud+xml',
		'tfm'         => 'application/x-tex-tfm',
		'thmx'        => 'application/vnd.ms-officetheme',
		'tiff'        => 'image/tiff',
		'tmo'         => 'application/vnd.tmobile-livetv',
		'torrent'     => 'application/x-bittorrent',
		'tpl'         => 'application/vnd.groove-tool-template',
		'tpt'         => 'application/vnd.trid.tpt',
		'tra'         => 'application/vnd.trueapp',
		'trm'         => 'application/x-msterminal',
		'tsd'         => 'application/timestamped-data',
		'tsv'         => 'text/tab-separated-values',
		'ttf'         => 'application/x-font-ttf',
		'ttl'         => 'text/turtle',
		'twd'         => 'application/vnd.simtech-mindmapper',
		'txd'         => 'application/vnd.genomatix.tuxedo',
		'txf'         => 'application/vnd.mobius.txf',
		'txt'         => 'text/plain',
		'ufd'         => 'application/vnd.ufdl',
		'umj'         => 'application/vnd.umajin',
		'unityweb'    => 'application/vnd.unity',
		'uoml'        => 'application/vnd.uoml+xml',
		'uri'         => 'text/uri-list',
		'ustar'       => 'application/x-ustar',
		'utz'         => 'application/vnd.uiq.theme',
		'uu'          => 'text/x-uuencode',
		'uva'         => 'audio/vnd.dece.audio',
		'uvh'         => 'video/vnd.dece.hd',
		'uvi'         => 'image/vnd.dece.graphic',
		'uvm'         => 'video/vnd.dece.mobile',
		'uvp'         => 'video/vnd.dece.pd',
		'uvs'         => 'video/vnd.dece.sd',
		'uvu'         => 'video/vnd.uvvu.mp4',
		'uvv'         => 'video/vnd.dece.video',
		'vcd'         => 'application/x-cdlink',
		'vcf'         => 'text/x-vcard',
		'vcg'         => 'application/vnd.groove-vcard',
		'vcs'         => 'text/x-vcalendar',
		'vcx'         => 'application/vnd.vcx',
		'vis'         => 'application/vnd.visionary',
		'viv'         => 'video/vnd.vivo',
		'vsd'         => 'application/vnd.visio',
		'vsdx'        => 'application/vnd.visio2013',
		'vsf'         => 'application/vnd.vsf',
		'vtu'         => 'model/vnd.vtu',
		'vxml'        => 'application/voicexml+xml',
		'wad'         => 'application/x-doom',
		'wav'         => 'audio/x-wav',
		'wax'         => 'audio/x-ms-wax',
		'wbmp'        => 'image/vnd.wap.wbmp',
		'wbs'         => 'application/vnd.criticaltools.wbs+xml',
		'wbxml'       => 'application/vnd.wap.wbxml',
		'weba'        => 'audio/webm',
		'webm'        => 'video/webm',
		'webp'        => 'image/webp',
		'wg'          => 'application/vnd.pmi.widget',
		'wgt'         => 'application/widget',
		'wm'          => 'video/x-ms-wm',
		'wma'         => 'audio/x-ms-wma',
		'wmd'         => 'application/x-ms-wmd',
		'wmf'         => 'application/x-msmetafile',
		'wml'         => 'text/vnd.wap.wml',
		'wmlc'        => 'application/vnd.wap.wmlc',
		'wmls'        => 'text/vnd.wap.wmlscript',
		'wmlsc'       => 'application/vnd.wap.wmlscriptc',
		'wmv'         => 'video/x-ms-wmv',
		'wmx'         => 'video/x-ms-wmx',
		'wmz'         => 'application/x-ms-wmz',
		'woff'        => 'application/x-font-woff',
		'wpd'         => 'application/vnd.wordperfect',
		'wpl'         => 'application/vnd.ms-wpl',
		'wps'         => 'application/vnd.ms-works',
		'wqd'         => 'application/vnd.wqd',
		'wri'         => 'application/x-mswrite',
		'wrl'         => 'model/vrml',
		'wsdl'        => 'application/wsdl+xml',
		'wspolicy'    => 'application/wspolicy+xml',
		'wtb'         => 'application/vnd.webturbo',
		'wvx'         => 'video/x-ms-wvx',
		'x3d'         => 'application/vnd.hzn-3d-crossword',
		'xap'         => 'application/x-silverlight-app',
		'xar'         => 'application/vnd.xara',
		'xbap'        => 'application/x-ms-xbap',
		'xbd'         => 'application/vnd.fujixerox.docuworks.binder',
		'xbm'         => 'image/x-xbitmap',
		'xdf'         => 'application/xcap-diff+xml',
		'xdm'         => 'application/vnd.syncml.dm+xml',
		'xdp'         => 'application/vnd.adobe.xdp+xml',
		'xdssc'       => 'application/dssc+xml',
		'xdw'         => 'application/vnd.fujixerox.docuworks',
		'xenc'        => 'application/xenc+xml',
		'xer'         => 'application/patch-ops-error+xml',
		'xfdf'        => 'application/vnd.adobe.xfdf',
		'xfdl'        => 'application/vnd.xfdl',
		'xhtml'       => 'application/xhtml+xml',
		'xif'         => 'image/vnd.xiff',
		'xlam'        => 'application/vnd.ms-excel.addin.macroenabled.12',
		'xls'         => 'application/vnd.ms-excel',
		'xlsb'        => 'application/vnd.ms-excel.sheet.binary.macroenabled.12',
		'xlsm'        => 'application/vnd.ms-excel.sheet.macroenabled.12',
		'xlsx'        => 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
		'xltm'        => 'application/vnd.ms-excel.template.macroenabled.12',
		'xltx'        => 'application/vnd.openxmlformats-officedocument.spreadsheetml.template',
		'xml'         => 'application/xml',
		'xo'          => 'application/vnd.olpc-sugar',
		'xop'         => 'application/xop+xml',
		'xpi'         => 'application/x-xpinstall',
		'xpm'         => 'image/x-xpixmap',
		'xpr'         => 'application/vnd.is-xpr',
		'xps'         => 'application/vnd.ms-xpsdocument',
		'xpw'         => 'application/vnd.intercon.formnet',
		'xslt'        => 'application/xslt+xml',
		'xsm'         => 'application/vnd.syncml+xml',
		'xspf'        => 'application/xspf+xml',
		'xul'         => 'application/vnd.mozilla.xul+xml',
		'xwd'         => 'image/x-xwindowdump',
		'xyz'         => 'chemical/x-xyz',
		'yaml'        => 'text/yaml',
		'yang'        => 'application/yang',
		'yin'         => 'application/yin+xml',
		'zaz'         => 'application/vnd.zzazz.deck+xml',
		'zip'         => 'application/zip',
		'zir'         => 'application/vnd.zul',
		'zmm'         => 'application/vnd.handheld-entertainment+xml',
		'N/A'         => 'application/andrew-inset'
	);

	return $mt;
}

/**
 * Returns the distance between two points, in km or miles, based on site options.
 * False if wrong parameters.
 *
 * Parameters:
 * $p1 = array( lat, lng );
 * $p2 = array( lat, lng );
 */
function wpj_calculate_distance( $p1, $p2 ) {
	if ( isset( $p1[0] ) && is_numeric( $p1[0] )
		&& isset( $p1[1] ) && is_numeric( $p1[1] )
		&& isset( $p2[0] ) && is_numeric( $p2[0] )
		&& isset( $p2[1] ) && is_numeric( $p2[1] )
	) {
		$units = get_option( 'wpjobster_locations_unit' ) == 'kilometers' ? 6371 : 3959;

		global $wpdb;
		$sql = "SELECT {$units} * acos( cos( radians( {$p1[0]} ) ) * cos( radians( {$p2[0]} ) ) * cos( radians ( {$p2[1]} ) - radians( {$p1[1]} ) ) + sin( radians({$p1[0]}) ) * sin( radians ( {$p2[0]} ) ) ) as distance";
		$result = $wpdb->get_row( $sql );

		return $result->distance;
	}

	return false;
}

function wpj_get_distance_to( $type, $id ) {
	if ( $type == 'post' || $type == 'job' || $type == 'request' ) {
		$lat = get_post_meta( $id, 'lat', true );
		$lng = get_post_meta( $id, 'long', true );
	} elseif ( $type == 'user' ) {
		$lat = get_user_meta( $id, 'wpj_user_latitude', true );
		$lng = get_user_meta( $id, 'wpj_user_longitude', true );
	} else {
		return false;
	}

	$q_lat = WPJ_Form::get( 'latitude', WPJ_Form::cookie( 'wpj_lat', '' ) );
	$q_lng = WPJ_Form::get( 'longitude', WPJ_Form::cookie( 'wpj_lng', '' ) );

	if ( ! $q_lat || ! $q_lng ) {
		 return false;
	}

	if ( false !== $distance = wpj_calculate_distance(
		array( $lat, $lng ),
		array( $q_lat, $q_lng )
	) ) {
		$dec_sep = get_option( 'wpjobster_decimal_sum_separator' );
		if ( empty( $dec_sep ) ) { $dec_sep = '.'; }
		$tho_sep = get_option( 'wpjobster_thousands_sum_separator' );
		if ( empty( $tho_sep ) ) { $tho_sep = ','; }

		if ( get_option( 'wpjobster_locations_unit' ) == 'miles' ) {
			return sprintf( __( '%s miles away', 'wpjobster' ), number_format( round( $distance, 1 ), 1, $dec_sep, $tho_sep ) );
		} else {
			return sprintf( __( '%s km away', 'wpjobster' ), number_format( round( $distance, 1 ), 1, $dec_sep, $tho_sep ) );
		}
	}

	return false;
}

function wpj_get_distance_between( $p1, $p2 ) {
	if ( isset( $p1[0] ) && is_numeric( $p1[0] )
		&& isset( $p1[1] ) && is_numeric( $p1[1] )
		&& isset( $p2[0] ) && is_numeric( $p2[0] )
		&& isset( $p2[1] ) && is_numeric( $p2[1] )
	) {
		if ( $distance = wpj_calculate_distance(
			array( $p1[0], $p1[1] ),
			array( $p2[0], $p2[1] )
		) ) {
			$dec_sep = get_option( 'wpjobster_decimal_sum_separator' );
			if ( empty( $dec_sep ) ) { $dec_sep = '.'; }
			$tho_sep = get_option( 'wpjobster_thousands_sum_separator' );
			if ( empty( $tho_sep ) ) { $tho_sep = ','; }

			if ( get_option( 'wpjobster_locations_unit' ) == 'miles' ) {
				return sprintf( __( '%s miles', 'wpjobster' ), number_format( round( $distance, 1 ), 1, $dec_sep, $tho_sep ) );
			} else {
				return sprintf( __( '%s km', 'wpjobster' ), number_format( round( $distance, 1 ), 1, $dec_sep, $tho_sep ) );
			}
		}
	}

	return false;
}

function wpj_get_user_ip() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}

	return $ip;
}

function wpj_is_timestamp( $timestamp = '' ) {
	return ( ( string ) ( int ) $timestamp === $timestamp )
		&& ( $timestamp <= PHP_INT_MAX )
		&& ( $timestamp >= ~PHP_INT_MAX );
}

function wpj_validate_input_content( $input ) {
	return nl2br( strip_tags( htmlspecialchars( $input ) ) );
}

function wpj_site_homepage_use_tabs( $return_array = false ) {
	$use = false;

	$homepage_id = function_exists( 'wpj_as_user_homepage_loggedin' ) ? wpj_as_user_homepage_loggedin( false ) : get_option( 'main_page_url_user' );

	$pages = array(
		get_option( 'wpjobster_my_account_page_id' ),
		get_option( 'wpjobster_my_account_shopping_page_id' ),
		get_option( 'wpjobster_my_account_sales_page_id' ),
		get_option( 'wpjobster_my_account_payments_page_id' ),
		get_option( 'wpjobster_my_account_personal_info_page_id' ),
		get_option( 'wpjobster_my_account_reviews_page_id' ),
		get_option( 'wpjobster_my_requests_page_id' )
	);

	if ( in_array( $homepage_id, $pages ) ) {
		$use = true;
	}

	if ( $return_array ) {
		return array( 'hid' => $homepage_id, 'use' => $use );
	}

	return $use;
}

function wpj_get_acf_field_by_slug( $field_name, $field_slug, $page ) {
	$fields = '';
	if ( $page == 'user' ) {
		$fields = get_field( $field_name, get_option( 'wpjobster_user_profile_page_id' ) );
	} elseif ( $page == 'request' ) {
		$fields = get_field( 'request_fields', get_option( 'wpjobster_new_request_page_id' ) );
	} elseif ( $page == 'job' ) {
		$fields = get_field( 'job_fields', get_option( 'wpjobster_post_new_page_id' ) );
	}

	if ( $fields ) {
		foreach ( $fields as $key => $field ) {
			if ( $field['acf_fc_layout'] == $field_slug ) {
				return $field;
			}
		}
	}

	return false;
}