<?php
function wpj_get_user_jobs_count( $uid = '', $order_status = 'active' ) {

	if ( $order_status ) {
		if ( $order_status == 'active' ) {
			$args = array(
				'posts_per_page' => '-1',
				'post_type'      => 'job',
				'meta_query'     => array( array(
					'key'     => 'active',
					'value'   => '1',
					'compare' => '='
				) )
			);
		} elseif ( $order_status == 'inactive' ) {
			$args = array(
				'posts_per_page' => '-1',
				'post_status'    => array( 'draft','publish' ),
				'post_type'      => 'job',
				'meta_query'     => array( array(
					'key'     => 'active',
					'value'   => '0',
					'compare' => '='
				) )
			);
		} elseif ( $order_status == 'under-review' ) {
			$args = array(
				'posts_per_page' => '-1',
				'post_status'    => 'draft',
				'post_type'      => 'job',
				'meta_query'     => array( array(
					'key'     => 'under_review',
					'value'   => '1',
					'compare' => '='
				) )
			);
		} elseif ( $order_status == 'rejected' ) {
			$args = array(
				'posts_per_page' => '-1',
				'post_status'    => 'pending',
				'post_type'      => 'job'
			);
		}

		if ( ! $uid ) $uid = get_current_user_id();

		if ( $uid && $uid != 'all' ) $args['author'] = $uid;

		if ( isset( $args ) ) {
			$result = new WP_Query( $args );
			return apply_filters( 'wpj_user_jobs_' . $order_status . '_count_filter', $result->post_count );
		}

		if ( $order_status == 'in-queue' ) {
			global $wpdb;

			$pid = $uid;

			$query = "
				SELECT posts.ID
				FROM {$wpdb->prefix}posts posts, {$wpdb->prefix}job_orders orders
				WHERE posts.ID                      = '{$pid}'
					AND posts.ID                    = orders.pid
					AND orders.date_finished        = '0'
					AND request_cancellation        = '0'
					AND force_cancellation          = '0'
					AND accept_cancellation_request = '0'
					AND payment_status              = 'completed'
					AND closed                      = '0'
			";

			return apply_filters( 'wpj_user_jobs_in_queue_count_filter', count( $wpdb->get_results( $query ) ) );
		}
	}

	return 0;

}

function wpj_get_site_jobs_count( $order_status = 'all' ) {
	if ( $order_status == 'open' ) {
		$query = new WP_Query("meta_key=closed&meta_value=0&post_type=job&order=DESC&orderby=id&posts_per_page=-1&paged=1");
	} elseif ( $order_status == 'closed' ) {
		$query = new WP_Query("meta_key=closed&meta_value=1&post_type=job&order=DESC&orderby=id&posts_per_page=-1&paged=1");
	} else {
		$query = new WP_Query("post_type=job&order=DESC&orderby=id&posts_per_page=-1&paged=1");
	}

	return $query->post_count;
}

function get_number_of_extras_by_job( $post_id ) {
	$all_extras = 0;

	for ( $k_extras = 1; $k_extras <= 10; $k_extras++ ) {
		$extra_price = get_post_meta( $post_id, 'extra' . $k_extras . '_price', true );
		if ( trim( $extra_price ) != '' && trim( $extra_price ) != '0' ) {
			$all_extras++;
		}
	}

	return $all_extras;
}

function wpj_get_deactivated_jobs_by_reason( $uid = '', $reason = '' ) {
	$posts = get_posts( array(
		'post_type'      => 'job',
		'posts_per_page' => -1,
		'post_status'    => array( 'draft', 'publish', 'pending' ),
		'author'         => $uid,
		'meta_query'     => array(
			'relation' => 'AND',
			array(
				'key'     => 'active',
				'value'   => "0",
				'compare' => '=',
			),
			array(
				'key'     => 'deactivation_reason',
				'value'   => $reason,
				'compare' => '=',
			),
		),
	) );

	return $posts;
}