<?php
//--------------------------------------
// IMAGES
//--------------------------------------
function validate_image_file( $url ) {
	$curl = curl_init();

	curl_setopt_array( $curl, array(
		CURLOPT_HEADER         => true,
		CURLOPT_NOBODY         => true,
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_FOLLOWLOCATION => true,
		CURLOPT_URL            => $url
	) );

	curl_exec( $curl );

	$contentType = curl_getinfo( $curl, CURLINFO_CONTENT_TYPE );

	curl_close( $curl );

	$imgTypeArr = explode( '/', $contentType );
	$imgType = $imgTypeArr[0];

	if ( $imgType == 'image' ) {
		return true;
	} else {
		return false;
	}
}

function wpjobster_get_first_post_image_by( $pid, $by = '', $w = 100, $h = 100 ) {

	$first_image = get_post_meta( $pid, 'job_first_image', true );

	if ( $first_image ) {
		if ( $by == 'url' ) {
			if ( wpj_get_attachment_image_url( $first_image, array( $w, $h ) ) ) {
				return wpj_get_attachment_image_url( $first_image, array( $w, $h ) );
			}

		} else {
			if ( wp_get_attachment_image_src( $first_image ) ) {
				return $first_image;
			}

		}
	}

	$exclude = array(); // build the exclude list

	$args = array(
		'order'       => 'ASC',
		'post_type'   => 'attachment',
		'post_parent' => get_the_ID(),
		'meta_key'    => 'another_reserved1',
		'meta_value'  => '1',
		'numberposts' => -1,
		'post_status' => null
	);

	$attachments = get_posts( $args );

	if ( $attachments ) {
		foreach ( $attachments as $attachment ) {
			$url = $attachment->ID;
			array_push( $exclude, $url );
		}

	}

	$no_pic = false;

	if ( function_exists( 'wpjobster_get_job_images' ) ) {
		$attachments = wpjobster_get_job_images( $pid, 1, $exclude );

		if ( $attachments ) {
			foreach ( $attachments as $attachment ) {
				update_post_meta( $pid, 'job_first_image', $attachment->ID );

				if ( $by == 'url' ) {
					return wpj_get_attachment_image_url( $attachment->ID, array( $w, $h ) );
				} else {
					return $attachment->ID;
				}
			}

		} else {
			$no_pic = true;

		}
	} else {
		$no_pic = true;

	}

	if ( $no_pic && $by == 'url' ) {
		return apply_filters( 'wpj_placeholder_image_url_filter', get_template_directory_uri() . '/assets/images/placeholder.png', 'jobs' );

	}

	return false;
}

function wpjobster_get_job_image( $pid = false, $size = "thumb_picture_size" ) {
	if ( ! $pid ) { global $post; $pid = $post->ID; }

	$pic_id = wpjobster_get_first_post_image_by( $pid );
	if ( $pic_id != false ) {
		$img = wpj_get_attachment_image_url( $pic_id, $size );
	} else {
		$image_src = get_theme_mod( 'no_image_icon_options_job' ) != '' ? get_theme_mod( 'no_image_icon_options_job' ) : get_template_directory_uri() . '/assets/images/placeholder.png';
		$img = apply_filters( 'wpj_placeholder_image_url_filter', $image_src, 'jobs' );
	}

	$wpjobster_video_thumbnails = get_theme_mod( 'enable_video_icon_cards' );
	if ( $wpjobster_video_thumbnails == 'yes' ) {
		$video_link = get_post_meta( $pid, 'video_link', true );

		if ( $video_link && is_array( $video_link ) ) {
			foreach ( $video_link as $key => $value ) {
				if ( $value && wpj_get_video_url_type( $value ) ) {
					$img = get_video_thumb( $value );
				}
			}
		}
	}

	return $img;
}

function wpjobster_get_job_images( $pid, $limit = -1, $exclude = array() ) {

	$args = array(
		'post_type'      => 'attachment',
		'post_parent'    => $pid,
		'exclude'        => $exclude,
		'post_mime_type' => 'image',
		'numberposts'    => $limit,

		'meta_query' => array(
			'relation' => 'AND',
			array(
				'relation' => 'OR',
				array( //check to see if images_order has been filled out
					'key'     => 'images_order',
					'compare' => 'EXISTS',
				),
				array( //if no images_order has been added show these posts too
					'key'     => 'images_order',
					'compare' => 'NOT EXISTS',
				),
			),
			array(
				'relation' => 'OR',
				array(
					'key'     => 'is_cover',
					'value'   => 1,
					'compare' => '!='
				),
				array(
					'key'     => 'is_cover',
					'compare' => 'NOT EXISTS',
				),
			),
			array(
				'relation' => 'OR',
				array(
					'key'     => 'is_portfolio',
					'value'   => 1,
					'compare' => '!='
				),
				array(
					'key'     => 'is_portfolio',
					'compare' => 'NOT EXISTS',
				),
			),
			array(
				'relation' => 'OR',
				array(
					'key'     => 'is_review',
					'value'   => 1,
					'compare' => '!='
				),
				array(
					'key'     => 'is_review',
					'compare' => 'NOT EXISTS',
				),
			),
		),
		'orderby' => 'meta_value_num date',
		'order'   => 'ASC'
	);

	$attachments = get_posts( $args );

	return $attachments;
}

function wpjobster_get_portfolio_images( $uid, $limit = -1, $exclude = array() ) {
	$args = array(
		'post_type'      => 'attachment',
		'post_parent'    => null,
		'author'         => $uid,
		'exclude'        => $exclude,
		'post_mime_type' => 'image',
		'numberposts'    => $limit,

		'meta_query' => array(
			'relation' => 'AND',
			array(
				'relation' => 'OR',
				array( //check to see if images_order has been filled out
					'key'     => 'images_order',
					'compare' => 'EXISTS',
				),
				array( //if no images_order has been added show these posts too
					'key'     => 'images_order',
					'compare' => 'NOT EXISTS',
				),
			),
			array(
				'key'     => 'is_portfolio',
				'value'   => 1,
				'compare' => '=='
			),
		),
		'orderby' => 'meta_value_num date',
		'order'   => 'ASC',
	);

	$attachments = get_posts( $args );

	return $attachments;
}

function wpjobster_get_review_images( $pid, $limit = -1, $exclude = array() ) {
	if ( ! is_numeric( $limit ) ) {
		$limit = -1;
	}

	$args = array(
		'post_type'      => 'attachment',
		'post_parent'    => $pid,
		'exclude'        => $exclude,
		'post_mime_type' => 'image',
		'numberposts'    => $limit,

		'meta_query' => array(
			array(
				'key'     => 'is_review',
				'value'   => 1,
				'compare' => '=='
			),
		),
		'orderby' => 'meta_value_num date',
		'order'   => 'DESC',
	);
	$attachments = get_posts($args);
	return $attachments;
}

function wpjobster_get_review_images_and_details( $pid, $limit = -1 ) {
	global $wpdb;
	$uid = get_post_field( 'post_author', $pid );

	if ( -1 == $limit || ! is_numeric( $limit ) ) {
		$limit = 1000; // -1 is not supported to retrieve all
	}

	$result = $wpdb->get_results( $wpdb->prepare(
		"
		SELECT DISTINCT ratings.sample ID,
						ratings.reason review,
						orders.uid uid,
						ratings.datemade datemade
		FROM {$wpdb->prefix}job_ratings ratings,
			 {$wpdb->prefix}job_orders orders,
			 {$wpdb->prefix}posts posts
		WHERE posts.ID = orders.pid
			AND ( posts.ID = %d
				OR ratings.pid IN (
					SELECT custom_offer
					FROM {$wpdb->prefix}job_pm pm,
						 {$wpdb->prefix}job_ratings jr
					WHERE associate_job_id = %d
						AND custom_offer = jr.pid
				)
			)
			AND ratings.awarded = '1'
			AND orders.id = ratings.orderid
			AND posts.post_author = %d
			AND ratings.sample != ''
		ORDER BY datemade DESC
		LIMIT %d
		",
		$pid, $pid, $uid, $limit
	) );

	return $result;
}

function wpj_get_attachment_image_url( $attachment_id, $size = 'thumbnail', $icon = false, $attr = '' ) {
	$image = wp_get_attachment_image_src( $attachment_id, $size, $icon, $attr );

	$url = '';
	if ( $image ) {
		list( $url, $width, $height, $is_intermediate ) = $image;
	}

	return $url;
}

function wpjobster_get_post_images_ids( $pid, $limit = -1 ) {

	$exclude = array(); // build the exclude list

	$args = array(
		'order'       => 'ASC',
		'post_type'   => 'attachment',
		'post_parent' => get_the_ID(),
		'meta_key'    => 'another_reserved1',
		'meta_value'  => '1',
		'numberposts' => -1,
		'post_status' => null
	);

	$attachments = get_posts( $args );

	if ( $attachments ) {
		foreach ( $attachments as $attachment ) {
			$url = $attachment->ID;
			array_push( $exclude, $url );
		}
	}

	$arr = array(); $i = 0;
	$attachments = wpjobster_get_job_images( $pid, $limit, $exclude );

	if ( $attachments ) {
		foreach ( $attachments as $attachment ) {
			$url = $attachment->ID;
			array_push( $arr, $url );
		}
	}

	return $arr;
}

if ( ! function_exists( 'wpjobster_get_avatar' ) ) {
	function wpjobster_get_avatar( $uid, $w = 150, $h = 150 ) {
		$user = get_user_by( 'id', $uid );

		if ( is_array( $w ) ) {
			$h = $w[1];
			$w = $w[0];
		}

		$avatar_id = get_user_meta( $uid, 'avatar_id', true );
		$avatar    = get_user_meta( $uid, 'avatar', true );

		$no_image_src = get_theme_mod( 'no_image_icon_options_user' ) != '' ? get_theme_mod( 'no_image_icon_options_user' ) : get_template_directory_uri() . '/assets/images/noav.jpg';

		if ( ! empty( $avatar_id ) && is_numeric( $avatar_id ) ) {

			$image_url = wpj_get_attachment_image_url( $avatar_id, array( $w, $h ) );
			return $image_url && file_exists( get_attached_file( $avatar_id ) ) ? $image_url : $no_image_src;

		} elseif ( ! empty( $avatar ) ) {

			$avatar_id = wpjobster_get_attachment_id_from_url( $avatar );
			if ( $avatar_id ) {

				$image_url = wpj_get_attachment_image_url( $avatar_id, array( $w, $h ) );
				return $image_url && file_exists( get_attached_file( $avatar_id ) ) ? $image_url : $no_image_src;

			} else {

				if ( wpj_url_is_image( $avatar ) ) {

					return $avatar;

				} else {

					$image_size = ( $w || $h ) ? array( 'size' => $w ? $w : $h ) : array();
					$image_url  = isset( $user->user_email ) ? get_avatar_url( $user->user_email, $image_size ) : '';
					return $image_url ? $image_url : $no_image_src;

				}
			}

		} else {

			$image_size = ( $w || $h ) ? array( 'size' => $w ? $w : $h ) : array();
			$image_url  = isset( $user->user_email ) ? get_avatar_url( $user->user_email, $image_size ) : '';
			return $image_url ? $image_url : $no_image_src;

		}
	}
}

function wpj_get_image_max_upload_size( $image_type = '' ) {
	if ( $image_type == 'profile' ) {
		$wpj_max_size = get_option( 'wpjobster_profile_max_img_upload_size' );
	} else {
		$wpj_max_size = get_option( 'wpjobster_max_img_upload_size' );
	}

	$wp_max_size = wp_max_upload_size();

	if ( ! is_numeric( $wpj_max_size ) || ! $wpj_max_size ) {
		$wpj_max_size = 10;
	}

	if ( $wp_max_size >= $wpj_max_size ) {
		$max_size_allowed = $wpj_max_size * 1048576;
	} else {
		$max_size_allowed = $wp_max_size * 1048576; // 1024 * 1024
	}

	return $max_size_allowed;
}

//--------------------------------------
// ATTACHMENTS
//--------------------------------------
function wpj_post_has_attachments( $attachments_param = '' ) {
	$file_exists = false;

	if ( $attachments_param ) {
		$attachments = explode( ",", $attachments_param );
		if ( $attachments ) {
			foreach ( $attachments as $attachment ) {
				if ( get_attached_file ( $attachment ) != "" ) {
					$file_exists = true;
				}
			}
		}
	}

	if ( $file_exists  ) {
		return true;
	} else {
		return false;
	}
}

function wpj_list_attachments( $attachments_arr = '', $pid = '', $meta_name = '', $title = false, $title_label = 'Attachments', $file_size = true, $delete_action = true ) { ?>

	<div class="pm-attachments">

		<?php if ( $title ) { ?>
			<div class="pm-attachments-title"><?php echo $title_label; ?></div>
		<?php } ?>

		<?php if ( $attachments_arr ) {

			$attachments = explode( ",", $attachments_arr );
			if ( $attachments ) {
				foreach ( $attachments as $attachment ) {
					if ( get_attached_file ( $attachment ) != "" ) { ?>

						<div class="div_div2" id="image_ss<?php echo $attachment; ?>">

							<div class="pm-attachment-rtl">
								<a class="download-req" target="_blank" href="<?php echo get_bloginfo( 'url' ) . '/?secure_download=' . $attachment . wpjobster_get_token(); ?>" download><?php echo substr( get_the_title( $attachment ), 0, 20 ); ?>...</a>

								<?php if ( $file_size ) { ?>
									<span class="pm-filesize">( <?php echo size_format( filesize( get_attached_file ( $attachment ) ) ); ?> )</span>
								<?php }

								if ( $delete_action ) { ?>
									<a class="remove-img-req" href="javascript: void(0)" onclick="delete_this_file( <?php echo $attachment; ?>, <?php echo $pid; ?>, '<?php echo $meta_name; ?>' );"></a>
								<?php } ?>
							</div>

						</div>

					<?php }
				}
			}
		} ?>

	</div>

<?php }

function wpj_save_attachemtns( $attachments_arr = '', $pid = '', $meta_name = '', $action = '', $meta_type = 'post' ) {
	if ( $attachments_arr != "" ) {
		if ( $action == 'edit' ) {

			$post_attachments_arr     = explode( ",", $attachments_arr );

			if ( $meta_type == 'user' ) {
				$existing_attachments = get_user_meta( $pid, $meta_name, true );
			} else {
				$existing_attachments = get_post_meta( $pid, $meta_name, true );
			}

			$existing_attachments_arr = explode( ",", $existing_attachments );

			$attachments_arr          = array_merge( $post_attachments_arr, $existing_attachments_arr );

			$final_attachments        = implode( ",", $attachments_arr );

			if ( $meta_type == 'user' ) {
				update_user_meta( $pid, $meta_name, $final_attachments );
			} else {
				update_post_meta( $pid, $meta_name, $final_attachments );
			}

		} else {

			if ( $meta_type == 'user' ) {
				add_user_meta( $pid, $meta_name, $attachments_arr, true );
			} else {
				add_post_meta( $pid, $meta_name, $attachments_arr, true );
			}

		}

		$attachments_arr = is_array( $attachments_arr ) ? $attachments_arr : explode( ",", $attachments_arr );
		if ( $attachments_arr ) {
			foreach ( $attachments_arr as $key => $attachment ) {
				if ( $meta_type == 'user' ) {
					update_user_meta( $attachment, 'is_' . $meta_name, 1 );
				} else {
					update_post_meta( $attachment, 'is_' . $meta_name, 1 );
				}
			}
		}
	}
}

add_action( 'init', 'wpj_delete_attachments' );
function wpj_delete_attachments(){
	if ( isset( $_GET['_ad_delete_pid'] ) ) {

		if ( is_user_logged_in() && ! is_demo_admin() ) {
			$attachment_id = $_GET['_ad_delete_pid'];
			$post          = get_post( $attachment_id );

			global $current_user;
			$current_user = wp_get_current_user();

			if ( $post->post_author == $current_user->ID || user_can( $current_user, "manage_options" ) ) {
				wp_delete_post( $attachment_id );

				if ( isset( $_GET['cover_parent'] ) && $_GET['cover_parent'] ) {
					delete_post_meta( $_GET['cover_parent'], "cover-image" );
				}

				if ( isset( $_GET['pid'] ) && $_GET['pid'] ) {
					$pid       = $_GET['pid'];
					$meta_name = $_GET['meta_name'];

					$attachments_arr = get_post_meta( $pid, $meta_name, true );
					$attachments     = explode( ",", $attachments_arr );
					$new_arr         = array_diff( $attachments, array( $attachment_id ) );
					if ( isset( $new_arr ) && $new_arr != "" ) {
						$new_val = implode( ",", $new_arr );
					} else {
						$new_val = "";
					}
					update_post_meta( $pid, $meta_name, $new_val );

					do_action( 'wpj_delete_job_extra', $pid, $attachment_id );
				}
			}
		}
		exit;
	}
}

add_action( 'init', 'wpj_download_attachemnts' );
function wpj_download_attachemnts(){
	if ( isset( $_GET['secure_download'] ) && is_numeric( $_GET['secure_download'] ) ) {
		global $wpdb;
		global $current_user;
		$attachment_id = $_GET['secure_download'];

		$direct_download = 0;
		$allowed_users = array();

		$pm_id = get_post_meta( $attachment_id, 'pm_id', true );
		$message_id = get_post_meta( $attachment_id, 'message_id', true );
		$job_id = get_post_meta( $attachment_id, 'job_id', true );
		$direct_download = 0;

		if ( $pm_id && is_numeric( $pm_id ) ) {
			$p_message = $wpdb->get_row( "select * from {$wpdb->prefix}job_pm where id = '$pm_id'" );

			$allowed_users[] = $p_message->initiator; // sender
			$allowed_users[] = $p_message->user; // receiver

		} elseif ( $message_id && is_numeric( $message_id ) ) {
			// get message
			$o_message = $wpdb->get_row( "select * from {$wpdb->prefix}job_chatbox where id = '$message_id'" );

			// get order based on message id, then post based on order pid
			$order = $wpdb->get_row( "select * from {$wpdb->prefix}job_orders where id = '{$o_message->oid}'" );
			$post = get_post( $order->pid );

			$allowed_users[] = $post->post_author; // seller
			$allowed_users[] = $order->uid; // buyer

		} elseif ( $job_id && is_numeric( $job_id ) ) {
			// add job author to the array
			$post = get_post( $job_id );
			$allowed_users[] = $post->post_author; // seller

			// loop and add to the array all the buyers of this job
			$all_orders = $wpdb->get_results( "select * from {$wpdb->prefix}job_orders where pid = '$job_id'" );
			foreach( $all_orders as $order ) {
				$allowed_users[] = $order->uid; // buyer
			}

		} else {
			// no user specified for this download
			$direct_download = 1;
		}

		if ( ! is_user_logged_in() ) {
			if ( isset( $_GET['auth_token'] ) ) {
				$auth_token_transient = get_post_meta_transient( $_GET['secure_download'], 'wpj_authentication_token' );
				if ( $_GET['auth_token'] == $auth_token_transient ) {
					$direct_download = 1;
				}
			}
		}

		if ( user_can( $current_user, 'manage_options' ) || in_array( $current_user->ID, $allowed_users ) || $direct_download ) {
			$file = get_attached_file( $attachment_id );
			if ( $file ) {
				$filename = basename( $file );

				$fp = @fopen( $file, 'rb' );

				if (strstr( $_SERVER['HTTP_USER_AGENT'], "MSIE") ) {
					header( 'Content-Type: "application/octet-stream"' );
					header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
					header( 'Expires: 0' );
					header( 'Cache-Control: must-revalidate, post-check=0, pre-check=0' );
					header( 'Content-Transfer-Encoding: binary' );
					header( 'Pragma: public' );
					header( 'Content-Length: ' . filesize( $file ) );
				} else {
					header( 'Content-Type: "application/octet-stream"' );
					header( 'Content-Disposition: attachment; filename="' . $filename . '"' );
					header( 'Content-Transfer-Encoding: binary' );
					header( 'Expires: 0' );
					header( 'Pragma: no-cache' );
					header( 'Content-Length: ' . filesize( $file ) );
				}

				fpassthru( $fp );
				fclose( $fp );

				exit; // all good
			} else {
				exit( __( 'Wrong attachment ID!', 'wpjobster' ) );
			}
		}
		exit( __( 'You are not allowed to download this!', 'wpjobster' ) );

	}
}

function wpjobster_get_attachment_id_from_url( $attachment_url = '' ) {
	global $wpdb;

	$attachment_id = false;

	if ( '' == $attachment_url ) { return; }

	$upload_dir_paths = wp_upload_dir();

	if ( substr( $upload_dir_paths['baseurl'], 0, 8 ) != substr( $attachment_url, 0, 8 ) ) {
		if ( substr( $upload_dir_paths['baseurl'], 0, 8 ) === 'https://' ) {
			$attachment_url = substr_replace( $attachment_url, 'https://', 0, 7 );
		} else {
			$attachment_url = substr_replace( $attachment_url, 'http://', 0, 8 );
		}
	}

	if ( false !== strpos( $attachment_url, $upload_dir_paths['baseurl'] ) ) {
		$attachment_url = preg_replace( '/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $attachment_url );

		$attachment_url = str_replace( $upload_dir_paths['baseurl'] . '/', '', $attachment_url );

		$attachment_id = $wpdb->get_var( $wpdb->prepare( "
			SELECT wposts.ID
			FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta
			WHERE wposts.ID = wpostmeta.post_id
				AND wpostmeta.meta_key = '_wp_attached_file'
				AND wpostmeta.meta_value = '%s'
				AND wposts.post_type = 'attachment'", $attachment_url
		) );
	}

	return $attachment_id;
}

//--------------------------------------
// WYSIWYG
//--------------------------------------
function wpj_show_wysiwyg_content( $pid = '', $name = '', $id = '', $toolbar_id = '', $class = '', $placeholder = '', $value = '', $d_validate = '', $action = '', $indx = '', $required = false, $disabled = false ) {

	if ( $action == 'profile_information' ) {
		$minLength = get_option( 'wpjobster_characters_personalinfo_min' );
		$maxLength = get_option( 'wpjobster_characters_personalinfo_max' );
	} elseif ( $action == 'packages' ) {
		$minLength = get_option( 'wpjobster_characters_job_package_description_min' );
		$maxLength = get_option( 'wpjobster_characters_job_package_description_max' );
	} else {
		$minLength = get_option( 'wpjobster_characters_description_min' );
		$maxLength = get_option( 'wpjobster_characters_description_max' );
	}
	$max_chr_description = $maxLength; ?>

	<div class="relative">
		<textarea
			placeholder="<?php echo $placeholder; ?>"
			id="<?php echo $id; ?>"
			rows="6"
			cols="45"
			<?php echo $required ? 'required' : ''; ?>
			<?php echo $disabled ? 'disabled' : ''; ?>
			class="<?php echo $class; ?> wysiwyg-description-textarea <?php echo wpj_aoe_get_rejected_input( 'description' ); ?>"
			minlength="<?php echo $minLength; ?>"
			maxlength="<?php echo $maxLength; ?>"
			data-validate="<?php echo $d_validate; ?>"
			name="<?php echo $name; ?>"><?php echo $value; ?></textarea>

		<div id="<?php echo $toolbar_id; ?>" class="wysiwyg-description-toolbar">
			<a data-wysihtml5-command="bold"><i class="bordered bold icon"></i></a>
			<a data-wysihtml5-command="italic"><i class="bordered italic icon"></i></a>
			<a data-wysihtml5-command="underline"><i class="bordered underline icon"></i></a>
			<a data-wysihtml5-command="insertUnorderedList"><i class="bordered unordered list icon"></i></a>
			<a data-wysihtml5-command="insertOrderedList"><i class="bordered ordered list icon"></i></a>
		</div>

		<?php if ( $action != 'packages' ) { ?>
			<div class="char-count lighter"> / <?php echo $max_chr_description . ' ' . __( 'Characters', 'wpjobster' ); ?></div>
		<?php }

		if ( $action == 'job_edit' ) {
			$rejected_description = wpj_aoe_get_rejected_input( 'description' ) == 'rejected-input' ? 1 : '';
		} ?>

		<script>
			window.addEventListener( 'load', function() {
				wpj_init_wysiwyg_textarea( '<?php echo $action; ?>', '<?php echo $max_chr_description; ?>', '<?php echo $pid ? get_post_status( $pid ) : ""; ?>', '<?php echo isset( $rejected_description ) ? $rejected_description : ""; ?>', '<?php echo $indx; ?>', '<?php echo $id; ?>' );
			});
		</script>

	</div>

<?php }

function wpj_description_parser( $desc ) {
	$description = trim( wp_kses( $desc, array(
		'br'     => array(),
		'b'      => array(),
		'i'      => array(),
		'u'      => array(),
		'ul'     => array(),
		'ol'     => array(),
		'strong' => array(),
		'em'     => array(),
		'p'      => array(),
		'span'   => array(),
		'li'     => array(),
	) ) );

	return stripslashes( $description );
}

//--------------------------------------
// VIDEO
//--------------------------------------
function get_video_thumb( $video_url ) {

	if ( get_video_type( $video_url ) == 'youtube' ) {
		$protocol = is_ssl() ? "https://" : "http://";
		$thumb = $protocol . 'img.youtube.com/vi/' . get_youtube_id( $video_url ) . '/mqdefault.jpg';
		return $thumb;

	} elseif ( get_video_type( $video_url ) == 'vimeo' ) {

		$headers = array( 'Content-Type: application/json' );
		$url = "https://vimeo.com/api/oembed.json?url=" . $video_url;

		$ch = curl_init();
		curl_setopt( $ch, CURLOPT_URL, $url );
		curl_setopt( $ch, CURLOPT_POST, false );
		curl_setopt( $ch, CURLOPT_HTTPHEADER, $headers );
		curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
		curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
		$response = curl_exec( $ch );
		curl_close( $ch );

		$data = json_decode( $response );

		if ( $data ) {
			$thumb = $data->thumbnail_url;
			return $thumb;
		}

	}

	return false;
}

function get_youtube_id( $youtube_url ) {
	$url = parse_url( $youtube_url );

	if ( $url['host'] !== 'youtube.com' &&
		$url['host'] !== 'www.youtube.com'&&
		$url['host'] !== 'youtu.be'&&
		$url['host'] !== 'www.youtu.be')
	return '';

	if ( $url['host'] === 'youtube.com' || $url['host'] === 'www.youtube.com' ) {
		parse_str( parse_url( $youtube_url, PHP_URL_QUERY ), $query_string );
		return ! empty( $query_string["v"] ) ? $query_string["v"] : false;
	}

	$youtube_id = substr( $url['path'], 1 );
	if ( strpos( $youtube_id, '/' ) )
		$youtube_id = substr( $youtube_id, 0, strpos( $youtube_id, '/' ) );

	return $youtube_id;
}

function wpj_get_video_url_type( $url ) {
	$yt_rx = '/^((?:https?:)?\/\/)?((?:www|m)\.)?((?:youtube\.com|youtu.be))(\/(?:[\w\-]+\?v=|embed\/|v\/)?)([\w\-]+)(\S+)?$/';
	$has_match_youtube = preg_match( $yt_rx, $url, $yt_matches );

	$vm_rx = '/(https?:\/\/)?(www\.)?(player\.)?vimeo\.com\/([a-z]*\/)*([‌​0-9]{6,11})[?]?.*/';
	$has_match_vimeo = preg_match( $vm_rx, $url, $vm_matches );

	//Then we want the video id which is:
	if ( $has_match_youtube ) { return 'youtube'; }
	elseif ( $has_match_vimeo ) { return 'vimeo'; }

	return false;
}