<?php
/**
 * Messages - helper functions
 */

/* Insert message to database */
function wpj_insert_private_message( $args ) {

	global $current_user;
	$current_user  = wp_get_current_user();
	$current_time  = current_time( 'timestamp', 1 );

	$defaults = array(
		'content'              => '',
		'datemade'             => $current_time,
		'initiator'            => $current_user->ID,
		'user'                 => 0,
		'attached'             => '',
		'custom_offer'         => 0,
		'associate_request_id' => 0,
		'associate_job_id'     => 0,
	);

	$args = wp_parse_args( $args, $defaults );

	global $wpdb;
	$wpdb->query( $wpdb->prepare(
		"
		INSERT INTO {$wpdb->prefix}job_pm
			( content, datemade, initiator, user, attached, custom_offer, associate_request_id, associate_job_id )
		VALUES
			( %s, %d, %d, %d, %s, %d, %d, %d )
		",
		$args['content'],
		$args['datemade'],
		$args['initiator'],
		$args['user'],
		$args['attached'],
		$args['custom_offer'],
		$args['associate_request_id'],
		$args['associate_job_id']
	) );

	$this_pm = $wpdb->insert_id;

	if ( $args['attached'] ) {
		$pm_files_array = explode( ',', $args['attached'] );
		if ( $pm_files_array ) {
			foreach ( $pm_files_array as $attachment ) {
				add_post_meta( $attachment, 'pm_id', $this_pm );

				if ( $args['custom_offer'] == -1 ) {
					add_post_meta( $attachment, 'is_custom_offer', $this_pm );
				} else {
					add_post_meta( $attachment, 'is_private_message', $this_pm );
				}
			}
		}
	}

	if ( $args['custom_offer'] == -1 ) {
		$reason = 'new_request';
	} elseif ( $args['custom_offer'] > 0 ) {
		$reason = 'new_offer';
	} else {
		$reason = 'new_message';
	}

	$user_data = get_userdata( $args['initiator'] );

	wpj_notify_user_translated( $reason, $args['user'], array( '##sender_username##' => wpj_get_user_display_type( $user_data->ID ), '##private_message_link##' => wpj_get_pm_link( $args['initiator'] ) ) );

	$messages = get_user_meta( $args['user'], 'messages_number', true );
	if ( is_numeric( $messages ) ) {
		$messages = $messages + 1;
		update_user_meta( $args['user'], 'messages_number', $messages );
		update_user_meta( $args['user'], 'messages_time', $current_time );
	} else {
		wpj_refresh_user_notifications( $args['user'], 'messages' );
	}

	do_action( 'wpj_after_pm_is_sent', $this_pm, 'messages' );

	return $this_pm;
}

/* Get private message by ID */
function wpj_get_private_message( $id ) {

	global $wpdb;
	$message = $wpdb->get_row( $wpdb->prepare(
		"
		SELECT DISTINCT *
		FROM {$wpdb->prefix}job_pm
		WHERE id = %d
		",
		$id
	) );

	return $message;
}

/* Mark message as read */
function wpj_read_private_message( $message ) {
	if ( ! is_object( $message ) ) {
		$message = wpj_get_private_message( $message );
	}

	$tm = current_time( 'timestamp', 1 );

	global $wpdb;
	$wpdb->query( $wpdb->prepare(
		"
		UPDATE {$wpdb->prefix}job_pm
		SET rd = %d, readdate = %d
		WHERE id = %d
		",
		1, $tm, $message->id
	) );

	if ( $message->rd != 1 ) {
		$messages_number = get_user_meta( $message->user, 'messages_number', true );
		if ( is_numeric( $messages_number ) ) {
			$messages_number = $messages_number - 1;
			update_user_meta( $message->user, 'messages_number', $messages_number );
		} else {
			wpj_refresh_user_notifications( $message->user, 'messages' );
		}
	}

	return;
}

/* Check if conversation is archived */
function wpj_is_conversation_archived( $user_id = '', $current_user_id = '' ) {
	if ( ! $current_user_id ) { $current_user_id = get_current_user_id(); }

	if ( ! $user_id ) { return false; }

	global $wpdb;
	$r = $wpdb->get_results( "
		SELECT *
		FROM {$wpdb->prefix}job_pm
		WHERE ( user = '{$user_id}' AND initiator = '{$current_user_id}' )
		OR ( initiator = '{$user_id}' AND user = '{$current_user_id}' )
	" );

	if ( isset( $r[0] ) && (
		( $r[0]->initiator == $current_user_id && $r[0]->archived_to_source == 1 ) ||
		( $r[0]->user == $current_user_id && $r[0]->archived_to_destination == 1 )
	) ) {
		return true;
	}

	return false;
}

/* Check if two users have conversation */
function wpj_users_have_conversations( $usr1, $usr2 ) {
	if ( $usr1 && $usr2 ) {
		global $wpdb;

		$r = $wpdb->get_results( "
			SELECT *
			FROM {$wpdb->prefix}job_pm
			WHERE ( user = '{$usr1}' AND initiator = '{$usr2}' )
			OR ( initiator = '{$usr1}' AND user = '{$usr2}' )
		" );

		if ( isset( $r[0] ) ) { return true; }
	}

	return false;
}

/* Get count of unread messages by receiver ID */
function wpjobster_get_unread_number_messages( $receiver_id = '' ) {
	global $wpdb;

	if ( ! $receiver_id ) { $receiver_id = get_current_user_id(); }

	$r = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_pm WHERE user = {$receiver_id} AND show_to_destination = '1' AND rd = '0' " );

	return count( $r );
}

/* Get count of unread messages between two users */
function wpjobster_get_unread_number_messages_from_user( $sender_id, $receiver_id = '' ) {
	global $wpdb;

	if ( ! $receiver_id ) { $receiver_id = get_current_user_id(); }

	$r = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_pm WHERE user = {$receiver_id} AND initiator = {$sender_id} AND show_to_source = '1' AND rd = '0'" );

	return count( $r );
}

function wpj_update_user_notifications( $uid, $type, $number, $notify_id = '' ) {
	if ( ! $uid ) {
		global $current_user;
		$current_user  = wp_get_current_user();
		$uid = $current_user->ID;
	}

	if ( $uid ) {
		if ( $type == 'messages' || $type == 'notifications' ) {
			$type_number = get_user_meta( $uid, $type . '_number', true );
			if ( is_numeric( $type_number ) && is_numeric( $number ) ) {
				$type_number = $type_number + $number;
				update_user_meta( $uid, $type . '_number', $type_number );
			} else {
				$type_number = wpj_refresh_user_notifications( $uid, $type );
			}

			do_action( 'wpj_after_notification_is_sent', $notify_id, $type, $uid );

			return $type_number;

		} else {
			wpj_refresh_user_notifications( $uid );
			return true;
		}
	}

	return false;
}

function wpj_refresh_user_notifications( $uid = 0, $type = '' ) {
	if ( ! $uid ) {
		global $current_user;
		$current_user  = wp_get_current_user();
		$uid = $current_user->ID;
	}

	if ( $uid ) {
		if ( ! $type || $type == 'messages' ) {
			global $wpdb;
			$messages_number = $wpdb->get_var( $wpdb->prepare(
				"
				SELECT COUNT(*)
				FROM {$wpdb->prefix}job_pm
				WHERE user = %d
					AND show_to_destination = %d
					AND rd = %d
				",
				$uid, 1, 0
			) );
			update_user_meta( $uid, 'messages_number', $messages_number );
		}
		if ( ! $type || $type == 'notifications' ) {
			$args = array(
				'limit'  => 100,
				'offset' => 0,
				'uid'    => $uid,
				'status' => 'unread',
			);
			$notifications_number = count( wpjobster_get_notifications( $args ) );
			update_user_meta( $uid, 'notifications_number', $notifications_number );
		}

		if ( ! $type ) {
			return true;
		} elseif ( $type == 'messages' ) {
			return $messages_number;
		} elseif ( $type == 'notifications' ) {
			return $notifications_number;
		}
	}

	return false;
}

add_action( 'wp_head', 'wpj_refresh_user_notifications_cron' );
function wpj_refresh_user_notifications_cron() {
	global $current_user;
	$current_user = wp_get_current_user();
	if ( $current_user->ID ) {
		$current_time = current_time( 'timestamp', 1 );
		$timeout = get_user_meta( $current_user->ID, 'notifications_cron_timeout', true );
		if ( $current_time > $timeout || 0==0) {
			wpj_refresh_user_notifications( $current_user->ID );
			$new_timeout = $current_time + 3600; // + 1h * 60m * 60s
			update_user_meta( $current_user->ID, 'notifications_cron_timeout', $new_timeout );
		}
	}
}

function wpj_get_message_author_id( $message_id ) {
	if ( ! is_object( $message_id ) ) {
		$message = wpj_get_private_message( $message_id );
	}

	return ! empty( $message->initiator ) ? $message->initiator : false;
}