<?php
/**
 *   0 - marked as paid
 *  -1 - marked as delivered
 *  -2 - marked as completed
 *  -8 - the seller requested cancellation
 *  -9 - the buyer requested cancellation
 * -10 - the buyer accepted mutual cancellation
 * -11 - the buyer declined mutual cancellation
 * -12 - the seller accepted mutual cancellation
 * -13 - the seller declined mutual cancellation
 * -14 - transaction was cancelled by admin
 * -15 - buyer request modification
 * -16 - mutual cancellation was aborted by seller
 * -17 - mutual cancellation was aborted by buyer
 * -18 - buyer rating
 * -19 - seller rating
 * -21 - pending order cancelled by seller
 * -22 - pending order cancelled by buyer
 * -31 - new custom extra added
 * -32 - custom extra cancelled
 * -33 - custom extra declined
 * -34 - custom extra accepted
 * -35 - order cancellation by buyer( delivery time expired );
 * -36 - new tips added
 * -37 - tips payment succes
 * -38 - tips payment failed
 * -39 - the seller requested arbitration
 * -40 - the buyer requested arbitration
 * -41 - arbitration in favor of seller - message for seller
 * -42 - arbitration in favor of seller - message for buyer
 * -43 - arbitration in favor of buyer - message for seller
 * -44 - arbitration in favor of buyer - mesage for buyer
 * -45 - arbitration was aborted by seller
 * -46 - arbitration was aborted by buyer
 * -47 - order accepted by seller
 * -48 - order rejected by seller
 * -49 - the seller requested extended delivery time
 * -50 - the seller cancelled extended delivery time
 * -51 - the buyer accepted requested extended delivery time
 * -52 - the buyer declined requested extended delivery time
 * -53 - milestone delivered
 * -54 - milestone completed

 **/
function wpj_get_notification_message_by_id( $notification_id = '', $page = '' ) {
	global $wpdb, $current_user;

	$query = "
		SELECT chatbox.id id, orders.id oid, posts.ID pid, posts.post_author sid, orders.uid bid, chatbox.uid code, chatbox.datemade tm, chatbox.rd_receiver rd, orders.date_made otm
		FROM {$wpdb->prefix}job_chatbox chatbox, {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
		WHERE chatbox.oid = orders.id
		AND posts.ID = orders.pid
		AND chatbox.id = {$notification_id}
	";

	$data = $wpdb->get_results( $query );
	$row  = $data[0];

	$current_user = wp_get_current_user();
	$current_uid  = $current_user->ID;

	$transaction_number = wpjobster_camouflage_order_id( $row->oid, $row->otm );
	$notification_date  = wpj_date( get_option( 'date_format' ) . ' - ' . get_option( 'time_format' ), $row->tm );

	$buyer  = get_userdata( $row->bid );
	$seller = get_userdata( $row->sid );

	$buyer_username = is_object( $buyer ) ? wpj_get_user_display_type( $buyer->ID ) : __( 'a deleted user', 'wpjobster' );
	$seller_username = is_object( $seller ) ? wpj_get_user_display_type( $seller->ID ) : __( 'a deleted user', 'wpjobster' );

	if ( $current_uid == $row->sid ) {
		$displayname = $page == 'api' ? $seller_username : $buyer_username;
	} elseif ( $current_uid == $row->bid ) {
		$displayname = $page == 'api' ? $buyer_username : $seller_username;
	} else {
		$displayname = __( 'a deleted user', 'wpjobster' );
	}

	$code = $row->code;

	if ( $code > 0 ) {
		$user = get_userdata( $code );
		if ( $user && is_object( $user ) ) {
			if ( is_super_admin( $code ) ) { $displayname = wpj_get_user_display_type( $user->ID ); }

			$content = __( 'You have a new message from %2$s related to transaction %1$s', 'wpjobster' );
		} else {
			$content = __( 'Order %1$s was updated by %2$s', 'wpjobster' );
		}
		$icon_class = 'sent green';
	} else {
		if ( $code == 0 ) {
			$content    = __( 'You have a new order from %2$s. Order ID: %1$s.', 'wpjobster' );
			$icon_class = 'sent green';
		} elseif ( $code == -1 ) {
			$content    = __( '%2$s has delivered the order %1$s', 'wpjobster' );
			$icon_class = 'delivered green';
		} elseif ( $code == -2 ) {
			$content    = __( 'Order %1$s was marked complete by %2$s', 'wpjobster' );
			$icon_class = 'accepted green';
		} elseif ( $code == -8 || $code == -9 ) {
			$content    = __( '%2$s has requested to cancel order %1$s', 'wpjobster' );
			$icon_class = 'declined red';
		} elseif ( $code == -10 || $code == -12 ) {
			$content    = __( '%2$s has accepted cancellation request for order %1$s', 'wpjobster' );
			$icon_class = 'accepted green';
		} elseif ( $code == -11 || $code == -13 ) {
			$content    = __( '%2$s has declined cancellation request for order %1$s', 'wpjobster' );
			$icon_class = 'declined2 red';
		} elseif ( $code == -14 ) {
			$content    = __( 'Order %1$s was cancelled by admin', 'wpjobster' );
			$icon_class = 'admin-action red';
		} elseif ( $code == -15 ) {
			$content    = __( '%2$s has requested modification for order %1$s', 'wpjobster' );
			$icon_class = 'modification orange';
		} elseif ( $code == -16 || $code == -17 ) {
			$content    = __( '%2$s has aborted cancellation for order %1$s', 'wpjobster' );
			$icon_class = 'declined2 red';
		} elseif ( $code == -18 ) {
			$content    = __( '%2$s has rated your order %1$s', 'wpjobster' );
			$icon_class = 'star orange';
		} elseif ( $code == -19 ) {
			$content    = __( '%2$s has replied to your feedback for order %1$s', 'wpjobster' );
			$icon_class = 'star orange';
		} elseif ( $code == -21 || $code == -22 ) {
			if ( $current_uid == $row->bid ) {
				$content = __( 'You have Cancelled the pending order ID: %1$s', 'wpjobster' );
			} else {
				$content = __( '%2$s has Cancelled the pending order ID: %1$s', 'wpjobster' );
			}
			$icon_class = 'declined2 red';
		} elseif ( $code == -31 ) {
			$content    = apply_filters( 'wpj_added_new_custom_extra_string_filter', __( '%2$s added new custom extra for order %1$s', 'wpjobster' ), $row );
			$icon_class = 'sent green';
		} elseif ( $code == -32 ) {
			$content    = apply_filters( 'wpj_cancelled_custom_extra_string_filter', __( '%2$s cancelled custom extra for order %1$s', 'wpjobster' ), $row );
			$icon_class = 'declined red';
		} elseif ( $code == -33 ) {
			$content    = apply_filters( 'wpj_declined_custom_extra_string_filter', __( '%2$s declined custom extra for order %1$s', 'wpjobster' ), $row );
			$icon_class = 'declined red';
		} elseif ( $code == -34 ) {
			$content    = apply_filters( 'wpj_accepted_custom_extra_string_filter', __( '%2$s accepted custom extra for order %1$s', 'wpjobster' ), $row );
			$icon_class = 'accepted green';
		} elseif ( $code == -35 ) {
			$content    = __( '%2$s cancelled the order %1$s', 'wpjobster' );
			$icon_class = 'declined red';
		} elseif ( $code == -37 ) {
			$content    = __( '%2$s added new tips for order %1$s', 'wpjobster' );
			$icon_class = 'accepted green';
		} elseif ( $code == -39 || $code == -40 ) {
			$content    = __( '%2$s has requested arbitration the order %1$s', 'wpjobster' );
			$icon_class = 'arbitration green';
		} elseif ( $code == -41 || $code == -42 ) {
			if ( $current_uid == $row->sid ) {
				$content    = __( 'Arbitration was decided in your favor', 'wpjobster' );
				$icon_class = 'admin-action green';
			} else {
				$content    = __( 'Arbitration was decided in favor of %2$s', 'wpjobster' );
				$icon_class = 'admin-action green';
			}
		} elseif ( $code == -43 || $code == -44 ) {
			if ( $current_uid == $row->bid ) {
				$content    = __( 'Arbitration was decided in your favor', 'wpjobster' );
				$icon_class = 'admin-action green';
			} else {
				$content    = __( 'Arbitration was decided in favor of %2$s', 'wpjobster' );
				$icon_class = 'admin-action green';
			}
		} elseif ( $code == -45 || $code == -46 ) {
			$content    = __( '%2$s has aborted arbitration for order %1$s', 'wpjobster' );
			$icon_class = 'declined2 red';
		} elseif ( $code == -49 ) {
			$content    = __( '%2$s has requested an extension of the delivery time for order %1$s', 'wpjobster' );
			$icon_class = 'modification orange';
		} elseif ( $code == -50 ) {
			$content    = __( '%2$s has aborted extension of the delivery time for order %1$s', 'wpjobster' );
			$icon_class = 'declined2 red';
		} elseif ( $code == -51 ) {
			$content    = __( '%2$s has accepted extension of the delivery time for order %1$s', 'wpjobster' );
			$icon_class = 'accepted green';
		} elseif ( $code == -52 ) {
			$content    = __( '%2$s has declined extension of the delivery time for order %1$s', 'wpjobster' );
			$icon_class = 'declined2 red';
		} else {
			$content    = __( 'Order %1$s was updated', 'wpjobster' );
			$icon_class = 'sent';
		}
	}

	$notification_filter = apply_filters( 'wpj_notification_content_filter', array( 'content' => $content, 'icon_class' => $icon_class ), $code );

	$content = sprintf( $notification_filter['content'], $transaction_number, $displayname );

	$notifications = array(
		'content'    => $content,
		'icon_class' => $notification_filter['icon_class'],
		'date'       => $notification_date
	);

	return $notifications;
}

// LIVE NOTIFICATIONS ENABLED
if ( ! function_exists( 'wpjobster_live_notifications_enabled' ) ) {
	function wpjobster_live_notifications_enabled() {
		if ( get_option( 'wpjobster_enable_live_notifications' ) == 'yes' && is_user_logged_in() ) {
			return true;
		}
		return false;
	}
}

// NOTIFICATIONS LIST
function wpjobster_get_notifications( $args = null ) {
	global $wpdb;

	$defaults = array(
		'limit'   => 10,
		'offset'  => 0,
		'orderby' => 'date',
		'order'   => 'desc',
		'uid'     => '',
		'status'  => '',
	);

	$args = wp_parse_args( $args, $defaults );

	$limit   = esc_sql( $args['limit'] );
	$offset  = esc_sql( $args['offset'] );
	$orderby = esc_sql( $args['orderby'] );
	$order   = esc_sql( $args['order'] );
	$uid     = esc_sql( $args['uid'] );
	$status  = $args['status'];

	if ( $status == 'unread' ) {
		$status_sql = "AND chatbox.rd_receiver='0'";
	} elseif ( $status == 'read' ) {
		$status_sql = "AND chatbox.rd_receiver='1'";
	} else {
		$status_sql = "";
	}

	if ( ! $uid ) { $uid = get_current_user_id(); }

	$buyer_uid  = implode( ", ", wpj_get_chatbox_uid_by_user_type( 'buyer' ) );
	$seller_uid = implode( ", ", wpj_get_chatbox_uid_by_user_type( 'seller' ) );

	$s = "
		SELECT chatbox.id id, orders.id oid, posts.ID pid, posts.post_author sid, orders.uid bid, chatbox.uid code, chatbox.datemade tm, chatbox.rd_receiver rd, orders.date_made otm
		FROM {$wpdb->prefix}job_chatbox chatbox, {$wpdb->prefix}job_orders orders, $wpdb->posts posts
		WHERE chatbox.oid = orders.id AND posts.ID = orders.pid
		AND chatbox.uid != '{$uid}' {$status_sql}
		AND (posts.post_author = '{$uid}' OR orders.uid='{$uid}')
		AND (chatbox.uid > 0
			OR (posts.post_author = '{$uid}' AND (chatbox.uid IN ({$seller_uid})))
			OR (orders.uid = '{$uid}' AND (chatbox.uid IN ({$buyer_uid})))
		)
		ORDER BY tm DESC LIMIT {$limit} OFFSET {$offset}
	";

	$notifications = $wpdb->get_results( $s );

	return $notifications;
}