<?php
/**
 * Jobster helper functions
 */

function wpj_get_post_id( $pid = '' ) {

	if ( $pid && is_numeric( $pid ) ) return $pid;

	if ( ! empty( $_POST['jobid'] ) ) return $_POST['jobid'];
	if ( ! empty( $_GET['jobid'] ) ) return $_GET['jobid'];

	if ( ! empty( $_POST['pid'] ) ) return $_POST['pid'];
	if ( ! empty( $_GET['pid'] ) ) return $_GET['pid'];

	if ( ! empty( $_POST['post_id'] ) ) return $_POST['post_id'];
	if ( ! empty( $_GET['post_id'] ) ) return $_GET['post_id'];

	if ( wpj_get_payment_info_by_url( 'pid' ) ) return wpj_get_payment_info_by_url( 'pid' );

	if ( get_the_ID() ) return get_the_ID();

	global $post; if ( ! empty( $post->ID ) ) return $post->ID;

	return 0;

}

/**
 * Retrieve seller ID for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return int
 */
function wpj_get_seller_id( $order ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}
	$post_id = isset( $order->pid ) ? $order->pid : 0;
	$seller_id = $post_id ? get_post_field( 'post_author', $post_id ) : 0;

	return $seller_id;
}


/**
 * Retrieve buyer ID for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return int
 */
function wpj_get_buyer_id( $order ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}
	$seller_id = isset( $order->uid ) ? $order->uid : 0;

	return $seller_id;
}

/**
 * Retrieve payment object for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param array
 * @return object
 */
function wpj_get_payment( $args ) {

	$defaults = array(
		'id' => false,
		'payment_type' => 'job_purchase',
		'payment_type_id' => false,
	);

	$args = wp_parse_args( $args, $defaults );

	$id = $args['id'];
	$payment_type = $args['payment_type'];
	$payment_type_id = $args['payment_type_id'];

	global $wpdb;

	if ( $id ) {
		$payment = $wpdb->get_row( $wpdb->prepare(
			"
			SELECT * FROM {$wpdb->prefix}job_payment_received
			WHERE id = %d
			",
			$id
		) );
		return $payment;

	} elseif ( $payment_type_id ) {
		$payment = $wpdb->get_row( $wpdb->prepare(
			"
			SELECT * FROM {$wpdb->prefix}job_payment_received
			WHERE payment_type = %s
				AND payment_type_id = %d
			",
			$payment_type, $payment_type_id
		) );
		return $payment;
	}

	return false;
}

function wpj_get_buyer_by_payment_type( $oid = '', $payment_type = '' ) {
	if ( $payment_type == 'topup' ) {
		$order = wpjobster_get_topup_order_by( 'id', $oid );
		return $order->user_id;
	} elseif ( $payment_type == 'feature' ) {
		$order = wpjobster_get_featured_order_by( 'id', $oid );
		return $order[0]->user_id;
	} elseif ( $payment_type == 'custom_extra' ) {
		$order = wpj_get_custom_extras( $oid );
		return $order->user_id;
	} elseif ( $payment_type == 'tips' ) {
		$order = wpj_get_tips( $oid );
		return $order->user_id;
	} elseif ( $payment_type == 'subscription' ) {
		$order = wpjobster_get_subscription_order_by( 'id', $oid, 'all' );
		return $order->user_id;
	} else {
		return wpj_get_buyer_id( $oid );
	}
}

/* Get chatbox row by id */
function wpj_get_chatbox_message( $id = '' ) {

	global $wpdb;
	$message = $wpdb->get_row( $wpdb->prepare(
		"
		SELECT DISTINCT *
		FROM {$wpdb->prefix}job_chatbox
		WHERE id = %d
		",
		$id
	) );

	return $message;
}

/* Check if two users have transactions */
function wpj_users_have_transactions( $usr1 = '', $usr2 = '' ) {
	if ( $usr1 && $usr2 ) {
		global $wpdb;

		$r = $wpdb->get_results( "
			SELECT *
			FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
			WHERE orders.pid = posts.ID
			AND ( orders.uid = '{$usr1}' AND posts.post_author = '{$usr2}' )
			OR ( orders.uid = '{$usr2}' AND posts.post_author = '{$usr1}' )
		" );

		if ( isset( $r[0] ) ) { return true; }
	}

	return false;
}

/* Get chatbox uid number by user type */
function wpj_get_chatbox_uid_by_user_type( $user_type = '' ) {
	if ( $user_type == 'buyer' ) {
		$buyer = array( -1, -8, -12, -13, -16, -19, -22, -31, -32, -39, -41, -43, -45, -49, -50 );
		return apply_filters( 'wpj_chatbox_buyer_uid_filter', $buyer );
	} elseif ( $user_type == 'seller' ) {
		$seller = array( 0, -2, -9, -10, -11, -14, -15, -17, -18, -21, -33, -34, -35, -37, -40, -42, -44, -46, -51, -52 );
		return apply_filters( 'wpj_chatbox_seller_uid_filter', $seller );
	}

	return false;
}

function wpj_get_chatbox_hidden_notifications_uid() {
	return apply_filters( 'wpj_chatbox_hidden_notifications_uid_filter', array( -32, -33, -34, -37, -38 ) );
}

function wpj_get_custom_extras_amount( $row = '', $ret = '' ) {
	$total_amount = 0;
	$total_fees   = 0;
	$total_tax    = 0;

	if ( $row->custom_extras ) {
		$custom_extras = json_decode( $row->custom_extras );
		if ( $custom_extras ) {
			$i = 0;
			foreach ( $custom_extras as $custom_extra ) {
				if ( $custom_extra->paid ) {
					$custom_extra_ord = wpj_get_custom_extra( $row->id, $i );

					if ( isset( $custom_extra_ord->id ) ) {
						$custom_extra_payment = wpj_get_payment( array(
							'payment_type'    => 'custom_extra',
							'payment_type_id' => $custom_extra_ord->id,
						) );

						$total_amount += $custom_extra_payment->amount;
						$total_fees   += $custom_extra_payment->fees;
						$total_tax    += $custom_extra_payment->tax;
					}
				}
				$i++;
			}
		}
	}

	if ( $ret == 'amount' ) { return $total_amount; }
	elseif ( $ret == 'fees' ) { return $total_fees; }
	elseif ( $ret == 'tax' ) { return $total_tax; }
	else { return $total_amount + $total_fees + $total_tax; }
}

function wpj_get_total_order_price( $row ) {

	if ( ! is_object( $row ) ) {
		$row = wpjobster_get_order( $row );
	}

	$raw_amount      = $row->mc_gross;
	$processing_fees = $row->processing_fees;
	$tax_amount      = $row->tax_amount;

	// check custom extras
	$custom_extras = json_decode( $row->custom_extras );
	if ( $custom_extras ) {
		$i = 0;
		foreach ( $custom_extras as $custom_extra ) {
			if ( $custom_extra->paid ) {
				$custom_extra_order = wpj_get_custom_extra( $row->id, $i );
				$custom_extra_payment = wpj_get_payment( array(
					'payment_type'    => 'custom_extra',
					'payment_type_id' => $custom_extra_order->id,
				) );

				$raw_amount      += $custom_extra_payment->amount;
				$processing_fees += $custom_extra_payment->fees;
				$tax_amount      += $custom_extra_payment->tax;
			}
			$i++;
		}
	}

	// check tips
	$tips = json_decode( $row->tips );
	if ( $tips ) {
		$j = 0;
		foreach ( $tips as $tip ) {
			if ( $tip->paid ) {
				$tips_order = wpj_get_tip( $row->id, $j );
				$tips_payment = wpj_get_payment( array(
					'payment_type'    => 'tips',
					'payment_type_id' => $tips_order->id,
				) );

				$raw_amount      += $tips_payment->amount;
				$processing_fees += $tips_payment->fees;
				$tax_amount      += $tips_payment->tax;
			}
			$j++;
		}
	}

	$admin_fee = wpjobster_calculate_fee( $raw_amount, $row->id, wpj_get_seller_id( $row->id ) );

	return array(
		'amount'            => $raw_amount,
		'admin_commission'  => $admin_fee,
		'seller_commission' => $raw_amount - $row->admin_fee,
		'buyer_fee'         => $processing_fees,
		'tax'               => $tax_amount
	);
}

function wpj_get_order_expected_time( $order = '' ) {

	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	if ( $order ) {

		$order_payment_data = wpj_get_payment( array(
			'payment_type'    => 'job_purchase',
			'payment_type_id' => $order->id,
		) );

		if ( $order_payment_data ) {

			if ( $order_payment_data->payment_made_on && $order_payment_data->payment_made_on != 0 ) {
				$date = $order_payment_data->payment_made_on;

			} else {
				$date = $order_payment_data->datemade;

			}

		} else {
			$date = date( 'D M d Y H:i:s O' );

		}

		$order_expected_delivery = $order->expected_delivery;

		if ( $order_expected_delivery && $order_expected_delivery != 0 ) {
			$timer_date = date( 'D M d Y H:i:s O', $order_expected_delivery );

		} elseif ( $order->extra_fast != 0 ) {
			$timer_date = date( 'D M d Y H:i:s O', $date + ( 24 * 3600 * get_post_meta( $order->pid, 'extra_fast_days', true ) ) );

		} else {
			$timer_date = date( 'D M d Y H:i:s O', $date + ( 24 * 3600 * get_post_meta( $order->pid, 'max_days', true ) ) );

		}

		return $timer_date;

	}

	return false;
}

function wpj_is_order_time_up( $order = '' ) {

	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	$current_date = strtotime( date( 'Y-m-d H:i:s' ) );
	$order_date   = strtotime( wpj_get_order_expected_time( $order->id ) );

	if ( wpj_bool_option( 'wpjobster_enable_delivery_time', true ) && get_post_meta( $order->pid, 'max_days', true ) ) {
		if ( $current_date <= $order_date ){
			return 0;
		} else {
			return 1;
		}
	} else {
		return 0;
	}

}