<?php
//----------------------------------------------------
// there are 4 functions used to format numbers
//----------------------------------------------------

/* ---------------------------------------------------------------------------

wpjobster_formats();           => both decimal and thousands separator from options
							   => foreign exchange

wpjobster_formats_classic();   => both decimal and thousands separator from options
							   => default currency

wpjobster_formats_special_exchange();   => for database, only decimal "." separator
										=> foreign exchange

wpjobster_formats_special();            => for database, only decimal "." separator
										=> default currency

--------------------------------------------------------------------------- */

function wpjobster_formats( $number, $cents = 1, $currency = '' ) { // cents: 0=never, 1=if needed, 2=always

	if ( isset( $currency ) && $currency != '' ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $currency );
	} elseif ( isset( $_GET['site_currency'] ) ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $_GET['site_currency'] );
	} elseif ( isset( $_COOKIE["site_currency"] ) ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $_COOKIE["site_currency"] );
	}

	$dec_sep = get_option( 'wpjobster_decimal_sum_separator' );

	if ( empty( $dec_sep ) ) $dec_sep = '.';
	$tho_sep = get_option( 'wpjobster_thousands_sum_separator' );

	if ( empty( $tho_sep ) ) $tho_sep = ',';

	if ( is_numeric( $number ) ) { // a number

		if ( ! $number ) { // zero
			$money = ( $cents == 2 ? '0' . $dec_sep . '00' : '0' ); // output zero
		} else { // value
			if ( floor( $number ) == $number ) { // whole number
				$money = number_format( $number, ( $cents == 2 ? 2 : 0 ), $dec_sep, $tho_sep ); // format
			} else { // cents
				$money = number_format( round( $number, 2 ), ( $cents == 0 ? 0 : 2 ), $dec_sep, $tho_sep ); // format
			} // integer or decimal
		} // value

		return $money;
	} // numeric
}

// for display, both separators, no exchange currency
function wpjobster_formats_classic( $number, $cents = 1 ) { // cents: 0=never, 1=if needed, 2=always

	$dec_sep = get_option( 'wpjobster_decimal_sum_separator' );

	if ( empty( $dec_sep ) ) $dec_sep = '.';
	$tho_sep = get_option( 'wpjobster_thousands_sum_separator' );

	if ( empty( $tho_sep ) ) $tho_sep = ',';

	if ( is_numeric( $number ) ) { // a number

		if ( ! $number ) { // zero
			$money = ( $cents == 2 ? '0' . $dec_sep . '00' : '0' ); // output zero
		} else { // value

			if ( floor( $number ) == $number ) { // whole number
				$money = number_format( $number, ( $cents == 2 ? 2 : 0 ), $dec_sep, $tho_sep ); // format
			} else { // cents
				$money = number_format( round( $number, 2 ), ( $cents == 0 ? 0 : 2 ), $dec_sep, $tho_sep ); // format
			} // integer or decimal
		} // value

		return $money;
	} // numeric
}

// for database, no thousands separator. eg: 100000.00 no exchange currency
function wpjobster_formats_special( $number, $cents = 1 ) { // cents: 0=never, 1=if needed, 2=always

	$dec_sep = '.';
	$tho_sep = '';

	if ( is_numeric( $number ) ) { // a number

		if ( ! $number ) { // zero
			$money = ( $cents == 2 ? '0' . $dec_sep . '00' : '0' ); // output zero
		} else { // value

			if ( floor( $number ) == $number ) { // whole number
				$money = number_format( $number, ( $cents == 2 ? 2 : 0 ), $dec_sep, '' ); // format
			} else { // cents
				$money = number_format( round( $number, 2 ), ( $cents == 0 ? 0 : 2 ), $dec_sep, '' ); // format
			} // integer or decimal
		} // value

		return $money;
	} // numeric
}

// for database, no thousands separator. eg: 100000.00 + exchange foreign currency
function wpjobster_formats_special_exchange( $number, $cents = 1, $currency = '' ) { // cents: 0=never, 1=if needed, 2=always

	if ( isset( $currency ) && $currency != '' ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $currency );
	} elseif ( isset( $_GET['site_currency'] ) ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $_GET['site_currency'] );
	} elseif ( isset( $_COOKIE["site_currency"] ) ) {
		$number = get_exchange_value( $number, get_option( 'wpjobster_currency_1' ), $_COOKIE["site_currency"] );
	}

	$dec_sep = '.';
	$tho_sep = '';

	if ( is_numeric( $number ) ) { // a number
		if ( ! $number ) { // zero
			$money = ( $cents == 2 ? '0' . $dec_sep . '00' : '0' ); // output zero
		} else { // value
			if ( floor( $number ) == $number ) { // whole number
				$money = number_format( $number, ( $cents == 2 ? 2 : 0 ), $dec_sep, '' ); // format
			} else { // cents
				$money = number_format( round( $number, 2 ), ( $cents == 0 ? 0 : 2 ), $dec_sep, '' ); // format
			} // integer or decimal
		} // value

		return $money;
	} // numeric
} // formatMoney

function wpjobster_formats_mm( $number, $cents = 1 ) {
	// does nothing else than the regular function
	return wpjobster_formats( $number, $cents );
}

function wpjobster_show_price_in_front() {
	$opt = get_option( 'wpjobster_currency_position' );

	if ( $opt == "front" ) return true;

	return false;
}

function wpjobster_get_show_price( $price, $cents = 2, $use_free = false ) {
	$decimals = get_option( 'wpjobster_decimals' );
	if ( $decimals == 'ifneeded' ) {
		$cents = 1;
	} elseif ( $decimals == 'never' ) {
		$cents = 0;
	}

	$currency_position      = get_option( 'wpjobster_currency_position' );
	$currency_symbol_space  = wpj_bool_option( 'wpjobster_currency_symbol_space' );
	$replace_zero_with_free = wpj_bool_option( 'wpjobster_replace_zero_with_free' );

	$space    = ( $currency_symbol_space ) ? " " : $space = "";
	$currency = wpjobster_get_currency_symbol( wpjobster_get_currency() );

	if ( $price == 0 && $use_free && $replace_zero_with_free ) {
		return __( 'Free', 'wpjobster' );
	} elseif ( $currency_position == "front" ) {
		return $currency . $space . wpjobster_formats( $price, $cents );
	} else {
		return wpjobster_formats( $price, $cents ) . $space . $currency;
	}
}

// the same thing as without 2
function wpjobster_get_show_price2( $price, $cents = 2 ) {
	$decimals = get_option( 'wpjobster_decimals' );
	if ( $decimals == "ifneeded" ) {
		$cents = 1;
	} elseif ( $decimals == "never" ) {
		$cents = 0;
	}

	$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
	$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );
	$space                           = $wpjobster_currency_symbol_space == 'no' ? "" : " ";
	$currency                        = wpjobster_get_currency_symbol( wpjobster_get_currency() );

	if ( $wpjobster_currency_position == "front" ) return $currency . $space . wpjobster_formats_mm( $price, $cents );

	return wpjobster_formats_mm( $price, $cents ) . $space . $currency;
}

// price in default currency + symbol
function wpjobster_get_show_price_classic( $price, $cents = 2 ) {
	$decimals = get_option( 'wpjobster_decimals' );
	if ( $decimals == "ifneeded" ) {
		$cents = 1;
	} elseif ( $decimals == "never" ) {
		$cents = 0;
	}

	$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
	$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );
	$space                           = $wpjobster_currency_symbol_space == 'no' ? "" : " ";
	$currency                        = wpjobster_get_currency_symbol( wpjobster_get_currency_classic() );

	if ( $wpjobster_currency_position == "front" ) return apply_filters( 'wpj_price_classic_filter', $currency .  $space . wpjobster_formats_classic( $price, $cents ), $price, $cents );
	return apply_filters( 'wpj_price_classic_filter', wpjobster_formats_classic( $price, $cents ) .  $space . $currency, $price, $cents );
}

// price exactly as we say
function wpjobster_get_show_price_precise( $price, $cents = 2, $currency = '' ) {
	$decimals = get_option( 'wpjobster_decimals' );
	if ( $decimals == "ifneeded" ) {
		$cents = 1;
	} elseif ( $decimals == "never" ) {
		$cents = 0;
	}

	$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
	$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );
	$space                           = $wpjobster_currency_symbol_space == 'no' ? "" : " ";

	if ( ! $currency ) { $currency = wpjobster_get_currency(); }
	$currency = wpjobster_get_currency_symbol( $currency );

	if ( $wpjobster_currency_position == "front" ) return $currency .  $space . wpjobster_formats_classic( $price, $cents );
	return wpjobster_formats_classic( $price, $cents ) .  $space . $currency;
}

function wpjobster_deciphere_amount_classic( $pipeseparatedprice, $cents = 2 ) {
	$pipeseparatedprice = str_replace( ',', '.', $pipeseparatedprice );
	$amn = explode( '|', $pipeseparatedprice );

	$decimals = get_option( 'wpjobster_decimals' );
	if ( $decimals == "ifneeded" ) {
		$cents = 1;
	} elseif ( $decimals == "never" ) {
		$cents = 0;
	}

	$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
	$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );
	$space                           = $wpjobster_currency_symbol_space == 'no' ? "" : " ";
	$currency                        = wpjobster_get_currency_symbol( $amn[0] );

	if ( $wpjobster_currency_position == "front" ) return $currency . $space . wpjobster_formats_classic( $amn[1], $cents );
	return wpjobster_formats_classic( $amn[1], $cents ) . $space . $currency;
}

function wpj_get_job_price_types() {
	return apply_filters( 'wpj_job_price_type_filter', array( 'fixed', 'hourly', 'daily', 'weekly', 'monthly', 'package', 'custom' ) );
}

function wpj_get_job_no_days_price_types() {
	return apply_filters( 'wpj_job_no_days_price_type_filter', array( 'package' ) );
}

function wpj_is_job_price_type_enabled( $price_type = '' ) {
	$wpjobster_packages = get_option( 'wpjobster_packages_enabled' );
	$lvl_sts            = wpj_get_user_feature_value( 'packages', 'packages', 'no', get_current_user_id() );

	$packages = $wpjobster_packages == "yes" && $lvl_sts == 'yes' ? 'yes' : 'no';

	if (
		( get_option( 'wpjobster_enable_' . $price_type . '_rate', true ) == 'yes' && $price_type != 'package' )
		|| ( $price_type == 'package' && $packages == 'yes' )
	) {
		$price_type_enabled = true;
	} else {
		$price_type_enabled = false;
	}

	return apply_filters( 'wpj_job_price_type_enabled_filter', $price_type_enabled, $price_type );
}

function wpj_exist_job_price_type_enabled() {
	$price_type_arr = wpj_get_job_price_types();

	$wpjobster_packages = get_option( 'wpjobster_packages_enabled' );
	$lvl_sts            = wpj_get_user_feature_value( 'packages', 'packages', 'no', get_current_user_id() );

	$packages = $wpjobster_packages == "yes" && $lvl_sts == 'yes' ? 'yes' : 'no';

	$show_price_type = false;

	foreach ( $price_type_arr as $key => $price_type ) {
		if (
			( get_option( 'wpjobster_enable_' . $price_type . '_rate', true ) == 'yes' && $price_type != 'package' )
			|| ( $price_type == 'package' && $packages == 'yes' )
		) {

			$show_price_type = true;
		}
	}

	return apply_filters( 'wpj_exist_job_price_type_enabled_filter', $show_price_type );
}

function wpj_is_job_price_type_custom_only_enabled() {
	$price_type_arr = wpj_get_job_price_types();

	$wpjobster_packages = get_option( 'wpjobster_packages_enabled' );
	$lvl_sts            = wpj_get_user_feature_value( 'packages', 'packages', 'no', get_current_user_id() );

	$packages = $wpjobster_packages == "yes" && $lvl_sts == 'yes' ? 'yes' : 'no';

	$custom_rate_only = true;

	foreach ( $price_type_arr as $key => $price_type ) {
		if ( $price_type != 'package' && $price_type != 'custom'
			&& get_option( 'wpjobster_enable_' . $price_type . '_rate', true ) == 'yes'
		) {
			$custom_rate_only = false;
		}
	}

	if ( $custom_rate_only && $packages == 'yes' ) {
		$custom_rate_only = false;
	}

	if ( $custom_rate_only && get_option( 'wpjobster_enable_custom_rate', true ) == 'yes' ) {
		$custom_rate_only = true;
	} else {
		$custom_rate_only = false;
	}

	return apply_filters( 'wpj_exist_job_price_type_custom_only_enabled_filter', $custom_rate_only );
}