<?php
function wpj_get_sales_orders_count( $uid = '', $order_status = 'active' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	if ( $order_status ) {
		if ( $order_status == 'active' ) {

			$query = "
				SELECT DISTINCT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE posts.post_author      = '{$uid}'
					AND posts.ID             = orders.pid
					AND orders.done_seller   = '0'
					AND orders.done_buyer    = '0'
					AND orders.date_finished = '0'
					AND orders.closed        = '0'
					AND payment_status      != 'pending'
				ORDER BY orders.id DESC
			";

		} elseif ( $order_status == 'pending-payment' ) {

			$query = "
				SELECT DISTINCT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE posts.post_author      = '{$uid}'
					AND posts.ID             = orders.pid
					AND orders.done_seller   = '0'
					AND orders.done_buyer    = '0'
					AND orders.date_finished = '0'
					AND orders.closed        = '0'
					AND ( payment_status     = 'pending'
						OR payment_status    = 'processing' )
				ORDER BY orders.id DESC
			";

		} elseif ( $order_status == 'delivered' ) {

			$query = "
				SELECT DISTINCT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE posts.post_author    = '{$uid}'
					AND posts.ID           = orders.pid
					AND orders.done_seller = '1'
					AND orders.done_buyer  = '0'
					AND orders.closed      = '0'
				ORDER BY orders.id DESC
			";

		} elseif ( $order_status == 'completed' ) {

			$query = "
				SELECT DISTINCT *
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE posts.post_author    = '{$uid}'
					AND posts.ID           = orders.pid
					AND orders.done_seller = '1'
					AND orders.done_buyer  = '1'
					AND orders.closed      = '0'
				ORDER BY orders.id DESC
			";

		} elseif ( $order_status == 'cancelled' ) {

			$query = "
				SELECT DISTINCT *
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE posts.post_author = '{$uid}'
					AND posts.ID        = orders.pid
					AND orders.closed   = '1'
				ORDER BY orders.id DESC
			";

		}

		if ( isset( $query ) ) {
			return apply_filters( 'wpj_sales_' . $order_status . '_orders_count_filter', count( $wpdb->get_results( $query ) ) );
		}
	}

	return 0;

}

function wpj_get_sales_pending_clearance_price( $uid = '' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$query = "
		SELECT *, mc_gross AS pending_clearance, orders.id AS oid, orders.tips AS tips, orders.custom_extras AS custom_extras
		FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
		WHERE posts.post_author        = {$uid}
			AND posts.ID               = orders.pid
			AND orders.done_seller     = '1'
			AND orders.done_buyer      = '1'
			AND orders.completed       = '1'
			AND orders.closed          = '0'
			AND orders.clearing_period = '2'
	";
	$g_pending_clearance = $wpdb->get_results( $query , OBJECT );

	$total_pending_clearance = 0; $total_tips = 0; $total_custom_extras = 0;

	foreach ( $g_pending_clearance as $gpc ) {
		$total_pending_clearance += apply_filters( 'wpj_pending_clearance_seller_update_filter', $gpc->pending_clearance, $gpc );

		// custom extras total
		$custom_extras = json_decode( $gpc->custom_extras );
		if ( $custom_extras ) { $i = 0;
			foreach ( $custom_extras as $custom_extra ) {
				if ( $custom_extra->paid ) {
					$custom_extra_ord     = wpj_get_custom_extra( $gpc->oid, $i );
					$custom_extra_payment = wpj_get_payment( array(
						'payment_type'    => 'custom_extra',
						'payment_type_id' => $custom_extra_ord->id
					) );

					$total_custom_extras += $custom_extra_payment->amount;
				} $i++;
			}
		}

		// tips
		$tips = json_decode( $gpc->tips );
		if ( $tips ) { $i = 0;
			foreach ( $tips as $tip ) {
				if ( $tip->paid ) {
					$tips_ord     = wpj_get_tip( $gpc->oid, $i );
					$tips_payment = wpj_get_payment( array(
						'payment_type'    => 'tips',
						'payment_type_id' => $tips_ord->id,
					) );

					$total_tips += $tips_payment->amount;
				} $i++;
			}
		}
	}

	$total_amount = $total_pending_clearance + $total_custom_extras + $total_tips;
	$total_pending_clearance = $total_amount - wpjobster_calculate_fee( $total_amount, '', $uid );

	return $total_pending_clearance > 0 ? wpjobster_get_show_price( $total_pending_clearance ) : "0";

}

function wpj_get_sales_total_withdrawals_price( $uid = '' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$query = "
		SELECT SUM(amount) AS total_withdrawals
		FROM {$wpdb->prefix}job_withdraw withdrawals
		WHERE withdrawals.uid    = {$uid}
			AND withdrawals.done = '1'
	";
	$g_total_withdrawals = $wpdb->get_results($query , OBJECT);

	return $g_total_withdrawals[0]->total_withdrawals > 0 ? wpjobster_get_show_price( $g_total_withdrawals[0]->total_withdrawals ) : "0";

}

function wpj_update_sales_total_earned_price( $uid = '', $current_order_price = 0, $force_recheck = false ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$user_total_earnings = get_user_meta( $uid, 'user_total_earnings', true );

	if ( $user_total_earnings && $current_order_price && ! $force_recheck ) {
		update_user_meta( $uid, 'user_total_earnings', $user_total_earnings + $current_order_price );
	} else {
		$query = "
			SELECT SUM(mc_gross) AS total_earnings
			FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
			WHERE posts.post_author        = {$uid}
				AND posts.ID               = orders.pid
				AND orders.done_seller     = '1'
				AND orders.done_buyer      = '1'
				AND orders.completed       = '1'
				AND orders.closed          = '0'
				AND ( orders.clearing_period = '1' || orders.clearing_period = '2' )
		";

		$result = $wpdb->get_results( $query , OBJECT );

		if ( isset( $result[0] ) ) {
			update_user_meta( $uid, 'user_total_earnings', $result[0]->total_earnings );
		}
	}
}
