<?php
function wpj_get_shopping_orders_count( $uid = '', $order_status = 'active' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	if ( $order_status ) {
		if ( $order_status == 'active' ) {

			$query = "
				SELECT id
				FROM {$wpdb->prefix}job_orders
				WHERE uid               = {$uid}
					AND done_seller     = '0'
					AND done_buyer      = '0'
					AND date_finished   = '0'
					AND closed          = '0'
					AND payment_status != 'pending'
			";

		} elseif ( $order_status == 'pending-review' ) {

			$query = "
				SELECT id
				FROM {$wpdb->prefix}job_orders
				WHERE uid           = {$uid}
					AND done_seller = '1'
					AND done_buyer  = '0'
					AND closed      = '0'
			";

		} elseif ( $order_status == 'completed' ) {

			$query = "
				SELECT id
				FROM {$wpdb->prefix}job_orders
				WHERE uid           = {$uid}
					AND completed   = '1'
					AND done_seller = '1'
					AND done_buyer  = '1'
					AND closed      = '0'
				ORDER BY id DESC
			";

		} elseif ( $order_status == 'pending-payment' ) {

			$query = "
				SELECT id
				FROM {$wpdb->prefix}job_orders
				WHERE uid                 = {$uid}
					AND done_seller       = '0'
					AND done_buyer        = '0'
					AND date_finished     = '0'
					AND closed            = '0'
					AND ( payment_status  = 'pending'
						OR payment_status = 'processing' )
			";

		} elseif ( $order_status == 'cancelled' ) {

			$query = "
				SELECT id
				FROM {$wpdb->prefix}job_orders
				WHERE uid      = {$uid}
					AND closed = '1'
				ORDER BY id DESC
			";

		} elseif ( $order_status == 'active_custom_offer' ) {

			$query = "
				SELECT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE orders.pid               = posts.ID
					AND orders.uid             = {$uid}
					AND orders.done_seller     = '0'
					AND orders.done_buyer      = '0'
					AND orders.date_finished   = '0'
					AND orders.closed          = '0'
					AND orders.payment_status != 'pending'
					AND posts.post_type        = 'offer'
			";

		} elseif ( $order_status == 'completed_custom_offer' ) {

			$query = "
				SELECT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE orders.pid           = posts.ID
					AND orders.uid         = {$uid}
					AND orders.completed   = '1'
					AND orders.done_seller = '1'
					AND orders.done_buyer  = '1'
					AND orders.closed      = '0'
					AND posts.post_type    = 'offer'
				ORDER BY orders.id DESC
			";

		} elseif ( $order_status == 'cancelled_custom_offer' ) {

			$query = "
				SELECT orders.id
				FROM {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
				WHERE orders.pid        = posts.ID
				AND orders.uid          = {$uid}
					AND orders.closed   = '1'
					AND posts.post_type = 'offer'
				ORDER BY orders.id DESC
			";

		}

		if ( isset( $query ) ) {
			return apply_filters( 'wpj_shopping_' . $order_status . '_orders_count_filter', count( $wpdb->get_results( $query ) ) );
		}
	}

	return 0;

}

function wpj_get_shopping_total_spent_price( $uid = '' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$query = "
		SELECT * FROM {$wpdb->prefix}job_orders WHERE uid = {$uid} AND done_seller = '0' AND done_buyer = '0' AND date_finished = '0' AND closed = '0' AND payment_status != 'pending'

		UNION ALL

		SELECT * FROM {$wpdb->prefix}job_orders WHERE uid = {$uid} AND ( completed = '1' OR done_seller = '1' )
	";

	$total_spent_results = $wpdb->get_results( $query );

	$transaction_amount_total = 0;

	if ( $total_spent_results ) {
		foreach ( $total_spent_results as $key => $row ) {

			$trans_amount = explode( '|', $row->final_paidamount );

			if ( $trans_amount[0] && $trans_amount[0] != wpjobster_get_currency_classic() ) {
				$currency_from = $trans_amount[0];
				$currency_to   = wpjobster_get_currency_classic();

				$transaction_amount = get_exchange_value( $trans_amount[1], $currency_from, $currency_to );
			} else {
				$transaction_amount = $trans_amount[1];
			}

			$transaction_amount_total += floatval( $transaction_amount );
		}
	}

	return $transaction_amount_total > 0 ? wpjobster_get_show_price( $transaction_amount_total ) : "0";

}

function wpj_get_shopping_active_orders_price( $uid = '' ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$query = "
		SELECT *
		FROM {$wpdb->prefix}job_orders orders
		WHERE orders.uid           = {$uid}
			AND orders.done_seller = '0'
			AND orders.done_buyer  = '0'
			AND orders.closed      = '0'
	";
	$result = $wpdb->get_results( $query );

	$pending_clearance = 0;
	if ( $result ) {
		foreach ( $result as $key => $row ) {
			$pending_clearance += apply_filters( 'wpj_pending_clearance_buyer_update_filter', $row->mc_gross, $row );
		}
	}

	return $pending_clearance > 0 ? wpjobster_get_show_price( $pending_clearance ) : "0";

}

function wpj_update_shopping_completed_orders_price( $uid = '', $current_order_price = 0, $force_recheck = false ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	global $wpdb;

	$user_total_spendings = get_user_meta( $uid, 'user_total_spendings', true );

	if ( $user_total_spendings && $current_order_price && ! $force_recheck ) {
		update_user_meta( $uid, 'user_total_spendings', $user_total_spendings + $current_order_price );
	} else {
		$query = "
			SELECT SUM(mc_gross) AS total_spendings
			FROM {$wpdb->prefix}job_orders orders
			WHERE orders.uid = {$uid}
				AND orders.completed   = '1'
				AND orders.done_buyer  = '1'
				AND orders.done_seller = '1'
				AND orders.closed      = '0'
		";

		$result = $wpdb->get_results( $query, OBJECT );

		if ( isset( $result[0] ) ) {
			update_user_meta( $uid, 'user_total_spendings', $result[0]->total_spendings );
		}
	}

}