<?php
function user( $id = "", $k = "ID", $v = array() ) {

	if ( ! $id ) {
		$id = get_current_user_id();
	}

	$u = array(
		"Full texts",
		"ID",
		"user_login",
		"user_pass",
		"user_nicename",
		"user_email",
		"user_url",
		"user_registered",
		"user_activation_key",
		"user_status",
		"display_name"
	);

	if ( ! in_array( $k, $u ) ) {
		if ( isset( $v ) && is_array( $v ) ) {
			return str_replace( '<br />', '', htmlspecialchars_decode( get_user_meta( $id, $k, 1 ) ) );
		} else {
			update_user_meta( $id, $k, $v );
		}
	} else {
		if ( isset( $v ) && is_array( $v ) ) {
			$user_info = get_userdata( $id );
			return is_object( $user_info ) ? str_replace( '<br />', '', htmlspecialchars_decode ( $user_info->$k ) ) : "";
		} else {
			wp_update_user( array( "ID" => $id, $k => $v ) );
		}
	}
}

function wpj_get_user_account_pages() {
	$pages = array(
		get_option( 'wpjobster_my_account_page_id', false ),
		get_option( 'wpjobster_my_account_shopping_page_id', false ),
		get_option( 'wpjobster_my_account_sales_page_id', false ),
		get_option( 'wpjobster_my_account_payments_page_id', false ),
		get_option( 'wpjobster_my_account_priv_mess_page_id', false ),
		get_option( 'wpjobster_my_account_personal_info_page_id', false ),
		get_option( 'wpjobster_my_account_reviews_page_id', false ),
		get_option( 'wpjobster_my_requests_page_id', false ),
		get_option( 'wpjobster_my_account_all_notifications_page_id', false ),
		get_option( 'wpjobster_my_favorites_page_id', false )
	);

	$pages = apply_filters( 'wpj_user_account_pages_filter', $pages );

	return $pages;
}

function wpj_get_user_name_by_id( $uid = '', $return = '' ) {
	if ( $uid ) {

		$user_arr = get_userdata( $uid );

		if ( ! empty( $user_arr->user_login ) ) {

			if ( $user_arr->first_name && $user_arr->last_name ) {
				$name = $user_arr->first_name . ' ' . $user_arr->last_name;
			} else if ( $user_arr->last_name ) {
				$name = $user_arr->last_name;
			} else if ( $user_arr->first_name ) {
				$name = $user_arr->first_name;
			} else {
				$name = $user_arr->user_login;
			}

			if ( $return ) {
				if ( $return == 'first_name' && $user_arr->first_name ) {
					$name = $user_arr->first_name;
				} elseif ( $return == 'last_name' && $user_arr->last_name ) {
					$name = $user_arr->last_name;
				} elseif ( $return == 'full_name' && $user_arr->first_name && $user_arr->last_name ) {
					$name = $user_arr->first_name . ' ' . $user_arr->last_name;
				} elseif ( $return == 'full_name_inverted' && $user_arr->last_name && $user_arr->first_name ) {
					$name = $user_arr->last_name . ' ' . $user_arr->first_name;
				} elseif ( $return == 'username' && $user_arr->user_login ) {
					$name = $user_arr->user_login;
				} elseif ( $return == 'display_name' && $user_arr->display_name ) {
					$name = $user_arr->display_name;
				} else {
					$name = $user_arr->user_login;
				}
			}

			return $name;

		} else {
			return sprintf( __( 'Deleted User (ID: %d)', 'wpjobster' ), $uid );
		}

	}

	return __( 'No name', 'wpjobster' );
}

function wpj_get_user_display_type( $uid = '' ) {
	$op_type = get_option( 'wpjobster_display_name_publicly' );

	if ( $op_type == 'first_name' ) {
		$ret = wpj_get_user_name_by_id( $uid, 'first_name' );
	} elseif ( $op_type == 'last_name' ) {
		$ret = wpj_get_user_name_by_id( $uid, 'last_name' );
	} elseif ( $op_type == 'display_name' ) {
		$ret = wpj_get_user_name_by_id( $uid, 'display_name' );
	} elseif ( $op_type == 'first_last_name' ) {
		$ret = wpj_get_user_name_by_id( $uid, 'full_name' );
	} elseif ( $op_type == 'last_first_name' ) {
		$ret = wpj_get_user_name_by_id( $uid, 'full_name_inverted' );
	}

	if ( empty( $ret ) ) {
		$ret = wpj_get_user_name_by_id( $uid, 'username' );
	}

	return apply_filters( 'wpj_display_name_publicly_filter', $ret, $uid );
}

function wpj_is_user_allowed_post_job( $uid = '', $job_price = 0 ) {

	if ( ! $uid ) { $uid = get_current_user_id(); }

	$is_allowed = true;

	if ( get_option( 'wpjobster_cod_enable' ) == 'yes' && wpj_is_COD_only_payment() ) {

		if ( number_format( wpjobster_get_credits( $uid ), 2 ) < wpjobster_calculate_fee( $job_price, '', $uid ) ) {

			$is_allowed = false;

		}
	}

	return apply_filters( 'wpj_is_user_allowed_post_job_filter', $is_allowed, $uid, $job_price );
}

function wpj_get_user_social_media_providers() {
	$providers = array(
		'dribbble'      => array( 'name' => __( 'Dribbble', 'wpjobster' ),      'icon' => 'dribbble' ),
		'facebook'      => array( 'name' => __( 'Facebook', 'wpjobster' ),      'icon' => 'facebook f' ),
		'github'        => array( 'name' => __( 'Github', 'wpjobster' ),        'icon' => 'github' ),
		'google'        => array( 'name' => __( 'Google', 'wpjobster' ),        'icon' => 'google' ),
		'instagram'     => array( 'name' => __( 'Instagram', 'wpjobster' ),     'icon' => 'instagram' ),
		'linkedin'      => array( 'name' => __( 'Linkedin', 'wpjobster' ),      'icon' => 'linkedin' ),
		'stackoverflow' => array( 'name' => __( 'Stackoverflow', 'wpjobster' ), 'icon' => 'stack overflow' ),
		'tumblr'        => array( 'name' => __( 'Tumblr', 'wpjobster' ),        'icon' => 'tumblr' ),
		'twitter'       => array( 'name' => __( 'Twitter', 'wpjobster' ),       'icon' => 'twitter' ),
	);

	return apply_filters( 'user_social_media_providers_filter', $providers );
}