<?php
function wpj_get_featured_info( $page, $pid ) {
	$taxonomy = 'job_cat';
	$terms    = get_the_terms( $pid, $taxonomy );
	$t        = $terms[0];
	$term     = get_term_by( 'id', $t->term_id, $taxonomy );
	$p        = get_term( $term->parent, $taxonomy );

	if ( empty( $p->term_id ) ) {
		$t              = $terms[0];
		$category_id    = $t->term_id;
		$t              = isset( $terms[1] ) ? $terms[1] : '';
		$subcategory_id = isset( $t->term_id ) ? $t->term_id : '';
	} else {
		$t              = $terms[1];
		$category_id    = $t->term_id;
		$t              = $terms[0];
		$subcategory_id = $t->term_id;
	}

	if ( $page == 'homepage' ) {
		$max_number_key   = 'wpjobster_featured_homepage';
		$until_key        = 'home_featured_until';
		$featured_now_key = 'home_featured_now';
	} elseif ( $page == 'category' ) {
		$max_number_key   = 'wpjobster_featured_category';
		$until_key        = 'category_featured_until';
		$featured_now_key = 'category_featured_now';
	} elseif ( $page == 'subcategory' ) {
		$max_number_key   = 'wpjobster_featured_subcategory';
		$until_key        = 'subcategory_featured_until';
		$featured_now_key = 'subcategory_featured_now';
	}

	return array(
		'taxonomy'         => $taxonomy,
		'category_id'      => $category_id,
		'subcategory_id'   => $subcategory_id,
		'max_number_key'   => $max_number_key,
		'until_key'        => $until_key,
		'featured_now_key' => $featured_now_key
	);
}

if ( ! function_exists( 'get_featured_start_date' ) ) {
	function get_featured_start_date( $page, $pid ){
		$f_info = wpj_get_featured_info( $page, $pid );

		$featured_by_type = wpj_get_all_featured_jobs_by_type( $page );
		if ( $featured_by_type['count'] < get_option( $f_info['max_number_key'] ) ) {
			return get_midnight_date_timestamp( time() );
		} else {
			$tax_query = array();

			if ( $page == 'category' ) {
				$tax_query = array(
					array(
						'taxonomy' => $f_info['taxonomy'],
						'terms'    => $f_info['category_id'],
						'field'    => 'term_id',
					)
				);
			} elseif ( $page == 'subcategory' ) {
				$tax_query = array(
					array(
						'taxonomy' => $f_info['taxonomy'],
						'terms'    => $f_info['subcategory_id'],
						'field'    => 'term_id',
					)
				);
			}

			$meta_query = array(
				array(
					'key'     => $f_info['until_key'],
					'value'   => "z",
					'compare' => '!='
				)
			);

			$args = array(
				'post_type'      => 'job',
				'posts_per_page' => $f_info['max_number_key'],
				'tax_query'      => $tax_query,
				'meta_query'     => $meta_query,
				'meta_key'       => $f_info['until_key'],
				'orderby'        => 'meta_value_num',
				'order'          => 'DESC',
			);
			$loop = new WP_Query( $args );

			$loop_posts = $loop->posts;
			if ( $loop->have_posts() ) {
				// Avoid setting up postdata with $loop->the_post(), because reset doesn't work in admin!
				foreach ( $loop_posts as $loop_post ) {
					$start_date = get_midnight_date_timestamp( strtotime( "+1 day", get_post_meta( $loop_post->ID, $f_info['until_key'], true ) ) );
				}
			}

			return isset( $start_date ) ? $start_date : strtotime( date( 'Y-m-d H:i:s' ) );
		}
	}
}

if ( ! function_exists( 'get_featured_end_date' ) ) {
	function get_featured_end_date( $start_date ) {
		return get_midnight_date_timestamp( strtotime( '+' . ( get_option( 'wpjobster_featured_interval' ) - 1 ) . ' day', intval( $start_date ) ) );
	}
}

if ( ! function_exists( 'get_featured_start_date_from_end_date' ) ) {
	function get_featured_start_date_from_end_date( $end_date ) {
		return get_midnight_date_timestamp( strtotime( '-'.( get_option( 'wpjobster_featured_interval' ) - 1 ) . ' day', intval( $end_date ) ) );
	}
}

if ( ! function_exists( 'update_featured_after_pay' ) ) {
	function update_featured_after_pay( $page, $pid ) {
		$f_info = wpj_get_featured_info( $page, $pid );

		$h_start_date = get_featured_start_date( $page, $pid );
		$interval = get_option( 'wpjobster_featured_interval' ) - 1;
		$new_date = strtotime( '+' . $interval . ' day', $h_start_date );

		update_post_meta( $pid, $f_info['until_key'], $new_date );

		if ( $h_start_date == get_midnight_date_timestamp( time() ) ) {
			update_post_meta( $pid, $f_info['featured_now_key'], 'y' );
		}
	}
}

if ( ! function_exists( 'wpjobster_get_allfeatured_info_by_postid' ) ) {
	function wpjobster_get_allfeatured_info_by_postid( $pid, $via = "email", $all_featured_info = "" ) {

		$date_format = get_option( 'date_format' );

		if ( get_post_meta( $pid, 'home_featured_until', true ) != 'z' && get_post_meta( $pid, 'home_featured_until', true ) != '' ) {
			$dt = get_post_meta( $pid, 'home_featured_until', true );

			if ( $via == 'email' ) $all_featured_info .= '<p>';
				$all_featured_info .= __( "Featured on homepage between: ", "wpjobster" );

				if ( $via == 'email' ) $all_featured_info .= '<strong>';
					$all_featured_info .= wpj_date( $date_format, get_featured_start_date_from_end_date( $dt ) ) . " - " . wpj_date( $date_format, $dt );
				if ( $via == 'email' ) $all_featured_info .= '</strong>';

			if ( $via == 'email' ) $all_featured_info .= '</p>';
		}

		if ( get_post_meta( $pid, 'category_featured_until', true ) != 'z' && get_post_meta( $pid, 'category_featured_until', true ) !='' ) {
			$dt = get_post_meta( $pid, 'category_featured_until', true );

			if ( $via == 'email' ) $all_featured_info .= '<p>';
				$all_featured_info .= __( "Featured on category page between: ", "wpjobster" );

				if ( $via == 'email' ) $all_featured_info .= '<strong>';
					$all_featured_info .= wpj_date( $date_format, get_featured_start_date_from_end_date( $dt ) ) . " - " . wpj_date( $date_format, $dt );
				if ( $via == 'email' ) $all_featured_info .= '</strong>';

			if ( $via == 'email' ) $all_featured_info .= '</p>';
		}

		if ( get_post_meta( $pid, 'subcategory_featured_until', true ) != 'z' && get_post_meta( $pid, 'subcategory_featured_until', true ) != '' ) {
			$dt = get_post_meta( $pid, 'subcategory_featured_until', true );

			if ( $via == 'email' ) $all_featured_info .= '<p>';
				$all_featured_info .= __( "Featured on subcategory page between: ", "wpjobster" );

				if ( $via == 'email' ) $all_featured_info .= '<strong>';
					$all_featured_info .= wpj_date( $date_format, get_featured_start_date_from_end_date( $dt ) ) . " - " . wpj_date( $date_format, $dt );
				if ( $via == 'email' ) $all_featured_info .= '</strong>';

			if ( $via == 'email' ) $all_featured_info .= '</p>';
		}

		return $all_featured_info;
	}
}

function wpj_get_all_featured_jobs_by_type( $type = "home" ) {
	$type = $type == 'homepage' ? 'home' : $type;

	$args = array(
		'posts_per_page' => '-1',
		'post_type'      => 'job',
		'post_status'    => 'publish',
		'meta_query'     => array(
			array(
				'key'     => $type . '_featured_now',
				'value'   => 'y',
				'type'    => 'meta_value',
				'compare' => '='
			),
		),
	);
	$the_query = new WP_Query( $args );

	if ( $the_query->have_posts() ) {
		return array( 'query' => $the_query, 'count' => $the_query->post_count );
	} else {
		return array( 'query' => '', 'count' => 0 );
	}
}

function wpj_get_feature_job_status() {
	$class = ''; $message = '';

	if ( isset( $_GET['status'] ) ) {
		if ( $_GET['status'] == 'success' ) {
			$class = 'success';
			$message = __( 'Your payment was successful', 'wpjobster' ) . '!';
		}
		if ( $_GET['status'] == 'fail' ) {
			$class = 'negative';
			if ( WPJ_Form::get( 'message' ) == 'credits_err' ) {
				$message = __( 'You don\'t have enough money in your balance. Choose one of the other payment methods.', 'wpjobster' );
			} else {
				$message = __( 'Payment failed! Please try again.', 'wpjobster' );
			}
		}
	}

	return $class && $message ? array( 'class' => $class, 'message' => $message ) : '';
}

function wpj_get_feature_job_sql_query( $feature, $pid, $uid ) {
	global $wpdb;

	$sql_feature = "
		SELECT *
		FROM {$wpdb->prefix}job_featured_orders
		WHERE job_id = '{$pid}'
			AND user_id = '{$uid}'
			AND payment_status = 'pending'
			AND feature_pages LIKE '%{$feature}%'
		LIMIT 1
	";

	$rows = $wpdb->get_results( $sql_feature );

	return $rows;
}

function wpj_show_feature_job_bank_transfer( $row ) {

	do_action( "wpjobster_feature_before_bank_details_display", $row );

	if ( $row->payment_gateway_name == 'banktransfer' ) {
		do_action( "wpjobster_before_bank_details_display", $row ); ?>

		<div class="job_post white-cnt">
			<div class="">
				<div class="padding-cnt">
					<strong><?php _e( 'Bank Details', 'wpjobster' ); ?>:</strong><br>
					<?php echo nl2br( get_option( 'wpjobster_bank_details' ) ); ?><br>
				</div>
			</div>
		</div>

		<?php do_action( "wpjobster_after_bank_details_display", $row );
	}
}

function wpj_show_feature_job_cancel_payment( $row ) { ?>

	<span>
		<a class="redlink" onclick="wpj_cancel_featured_order( '<?php echo $row->id; ?>', '<?php echo $row->payment_gateway_name; ?>' );" href="javascript:void(0);" ><?php _e( 'Cancel', 'wpjobster' ); ?></a>
	</span>

<?php }

function wpj_show_feature_job_tax_and_fees( $home_fees_and_tax, $category_fees_and_tax, $subcategory_fees_and_tax ) {
	$arr = array( $home_fees_and_tax, $category_fees_and_tax, $subcategory_fees_and_tax );

	if ( in_array( false, $arr, true ) ) {

		// Processing Fee
		$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
		if ( $buyer_processing_fees_enabled != 'disabled' ) {
			if ( $buyer_processing_fees_enabled == 'percent' ) {
				$wpjobster_buyer_processing_fees_percent = get_option( 'wpjobster_buyer_processing_fees_percent' );
				$percent_string = "(" . $wpjobster_buyer_processing_fees_percent . "%)";
				$wpjobster_buyer_processing_fees = 0;
			} else {
				$wpjobster_buyer_processing_fees_percent = 0;
				$percent_string = "";
				$wpjobster_buyer_processing_fees = get_option( 'wpjobster_buyer_processing_fees' );
			}

			if ( $buyer_processing_fees_enabled ) { ?>
				<div class="sixteen wide column">
					<div class="processing-fees-title">
						<?php wpjobster_display_processing_fees_label(); ?>
						<span id="buyer-processing-fee" class="processingfee-amount extra-price-inside"><?php echo wpjobster_get_show_price( $wpjobster_buyer_processing_fees ); ?></span>
					</div>
				</div>

				<div class="ui fitted divider"></div>
			<?php }
		}

		// Tax Fee
		$wpjobster_enable_site_tax = get_option( 'wpjobster_enable_site_tax' );
		if ( $wpjobster_enable_site_tax == 'yes' ) {
			$country_code = user( get_current_user_id(), 'country_code' );
			$wpjobster_tax_percent = wpjobster_get_tax( $country_code );
			$wpjobster_tax_percent = ( float )$wpjobster_tax_percent; ?>

			<div class="sixteen wide column">
				<?php echo sprintf( __( 'Tax (%s%s)', 'wpjobster'), $wpjobster_tax_percent, '&#37;' ); ?>:
				<span class="tax-amount right" >
					<?php if ( ! isset( $wpjobster_tax_amount ) ) $wpjobster_tax_amount = 0;
					echo wpjobster_get_show_price( $wpjobster_tax_amount ); ?>
				</span>

			</div>

		<?php }
	} // END if ( in_array( false, $arr, true ) )
}

function wpj_show_feature_job_total_price() {
	$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
	if ( $buyer_processing_fees_enabled != 'disabled' ) {
		if ( $buyer_processing_fees_enabled == 'percent' ) {
			$wpjobster_buyer_processing_fees_percent = get_option( 'wpjobster_buyer_processing_fees_percent' );
			$wpjobster_buyer_processing_fees = 0;
		} else {
			$wpjobster_buyer_processing_fees_percent = 0;
			$wpjobster_buyer_processing_fees = get_option( 'wpjobster_buyer_processing_fees' );
		}
	}

	$wpjobster_enable_processingfee_tax = get_option('wpjobster_enable_processingfee_tax');

	$wpjobster_thousands_sum_separator = get_option( 'wpjobster_thousands_sum_separator' );
	if ( empty( $wpjobster_thousands_sum_separator ) ) $wpjobster_thousands_sum_separator = ',';

	$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
	$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );

	$wpjobster_decimal_sum_separator = get_option( 'wpjobster_decimal_sum_separator' );
	if (empty($wpjobster_decimal_sum_separator)) $wpjobster_decimal_sum_separator = '.';

	if ( get_option( 'wpjobster_enable_site_tax' ) == 'yes' ) {
		$wpjobster_tax_percent = wpjobster_get_tax( user( get_current_user_id(), 'country_code' ) );
		$wpjobster_tax_percent = ( float )$wpjobster_tax_percent;
	} else {
		$wpjobster_tax_percent = 0;
	} ?>

	<div class="four wide column">
		<div id="total_payable" class="payment-total-price" >
			<?php _e( 'Total:','wpjobster' ); ?>&nbsp;
			<span
				id='showtotal'
				data-decimaldisplay="<?php echo get_option( 'wpjobster_decimals' ); ?>"
				data-thousands="<?php echo $wpjobster_thousands_sum_separator;?>"
				data-decimal="<?php echo $wpjobster_decimal_sum_separator;?>"
				data-space="<?php echo $wpjobster_currency_symbol_space;?>"
				data-cur="<?php echo wpjobster_get_currency(); ?>"
				data-symbol="<?php echo wpjobster_get_currency_symbol( wpjobster_get_currency() ); ?>"
				data-processingfeesenable="<?php echo $buyer_processing_fees_enabled; ?>"
				data-processingfeesfixed="<?php echo isset( $wpjobster_buyer_processing_fees ) ? wpjobster_formats_special_exchange( $wpjobster_buyer_processing_fees ) : 0; ?>"
				data-processingfeespercent="<?php echo isset( $wpjobster_buyer_processing_fees_percent ) ? $wpjobster_buyer_processing_fees_percent : 0; ?>"
				data-processingfeetax="<?php echo $wpjobster_enable_processingfee_tax ? $wpjobster_enable_processingfee_tax : 0; ?>"
				data-position="<?php  echo $wpjobster_currency_position; ?>"
				data-tax="<?php echo $wpjobster_tax_percent;?>"
				class="payment-item-price total"
				id="payment-item-price">
			</span>
		</div>
	</div>
<?php }

add_action( 'wp_ajax_nopriv_featured_order_cancel', 'featured_order_cancel_fun' );
add_action( 'wp_ajax_featured_order_cancel', 'featured_order_cancel_fun' );
if( ! function_exists( 'featured_order_cancel_fun' ) ) {
	function featured_order_cancel_fun( $order_id = '' ) {
		if ( ! $order_id ) {
			$order_id = $_REQUEST['order_id'];
		}

		global $wpdb;

		// some basic security checks
		global $current_user;
		$current_user = wp_get_current_user();

		$sql = "update ".$wpdb->prefix."job_featured_orders set payment_status='cancelled' where id= ". $order_id . " limit 1";
		$wpdb->query( $sql );

		do_action( 'wpj_after_order_is_cancelled', $order_id, 'feature' );

		die();
	}
}

if ( ! function_exists( 'notify_after_featured_pay' ) ) {
	function notify_after_featured_pay( $pid, $uid, $total, $payed_amt ) {

		$post = get_post( $pid );

		$user_data = get_userdata( $uid );

		wpj_notify_user_translated( 'featured_new', $uid, array( '##job_link##' => urldecode( get_permalink( $pid ) ), '##job_name##' => $post->post_title, '##all_featured_info##' => wpjobster_get_allfeatured_info_by_postid( $pid ) ) );

		wpj_notify_user_translated( 'featured_admin_new', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##job_link##' => urldecode( get_permalink( $pid ) ), '##job_name##' => $post->post_title, '##all_featured_info##' => wpjobster_get_allfeatured_info_by_postid( $pid ) ) );

		$reason = __( 'Feature job', 'wpjobster' ) . ': <a href="' . get_permalink( $pid ) . '">' . $post->post_title . '</a>';
		wpjobster_add_history_log( '0', $reason, $total, $uid, '', '', 10, $pid, $payed_amt );

	}
}
