<?php
// Load more notifications
add_action( 'wp_ajax_wpjobster_ajax_notifications', 'wpjobster_ajax_notifications' );
add_action( 'wp_ajax_nopriv_wpjobster_ajax_notifications', 'wpjobster_ajax_notifications' );
function wpjobster_ajax_notifications() {

	$limit = ( isset( $_POST['limit'] ) ) ? $_POST['limit'] : 10;
	$offset = ( isset( $_POST['offset'] ) ) ? $_POST['offset'] : 10;

	$args = array( 'limit' => $limit, 'offset' => $offset );

	$notifications = wpjobster_get_notifications( $args );
	$notifications_count = count( $notifications );

	ob_start();
	wpjobster_display_notifications( $notifications );
	$content = ob_get_clean();

	$output = array( 'content' => $content, 'count' => $notifications_count );

	wp_die( json_encode( $output ) );

}

function wpjobster_display_notifications( $notifications ) {
	if ( count( $notifications ) > 0 ) {
		foreach ( $notifications as $row ) {
			$notifications_arr  = wpj_get_notification_message_by_id( $row->id );
			$is_unread          = $row->rd ? 0 : 1;
			$first_column_width = $is_unread ? 'thirteen' : 'sixteen';  ?>

			<li class="cf <?php echo 'wpj-notification-' . $row->id; echo $row->rd ? ' wpj-notification-read' : ' wpj-notification-unread'; ?>">
				<div class="ui grid">
					<div class="<?php echo $first_column_width; ?> wide column">
						<a href="<?php echo get_bloginfo('url') . "/?jb_action=chat_box&oid=" . $row->oid; ?>" class="cf">
							<div class="wpj-notification-icon nh-notification-icon <?php echo $notifications_arr['icon_class']; ?>"></div>
							<div class="wpj-notification-right">
								<?php echo $notifications_arr['content']; ?>
								<div class="wpj-notification-date"><?php echo $notifications_arr['date']; ?></div>
							</div>
						</a>
					</div>

					<?php if ( $is_unread ) { ?>
						<div class="three wide column right aligned">
							<?php if ( ! $row->rd ) { echo '<i class="x icon wpj-mark-notification-as-read" data-value="' . $row->id . '"></i>'; } ?>
						</div>
					<?php } ?>
				</div>
			</li>

		<?php }
	}

	return count( $notifications );
}

// Mark single notification as read
add_action( 'wp_ajax_mark_notification_as_read', 'wpjobster_mark_notifications_as_read' );
add_action( 'wp_ajax_nopriv_mark_notification_as_read', 'wpjobster_mark_notifications_as_read' );
if ( ! function_exists( 'wpjobster_mark_notifications_as_read' ) ) {
	function wpjobster_mark_notifications_as_read(){
		global $current_user, $wpdb;
		$current_user = wp_get_current_user();
		$uid          = $current_user->ID;

		if ( isset( $_POST['notification_id'] ) ) {

			// get only unread notifications belonging to this user
			$notifications = wpjobster_get_notifications( array(
				'limit'  => 10000, //reasonable limit
				'uid'    => $uid,
				'status' => 'unread',
			) );

			// build a list of IDs rather than querying in loop, for performance
			$allowed_to_read = array();
			foreach ( $notifications as $notification ) {
				$allowed_to_read[] = $notification->id;
			}

			$notification_id = '';
			if ( in_array( $_POST['notification_id'], $allowed_to_read ) ) {
				$notification_id = $_POST['notification_id'];
			}

			// update read status
			if ( $notification_id ) {
				$wpdb->query( "UPDATE {$wpdb->prefix}job_chatbox SET rd_receiver='1' WHERE id = {$notification_id}" );
			}

			wpj_refresh_user_notifications( $uid, 'notifications' );
		}

		wp_die();
	}
}

// Mark all notifications as read
if ( ! function_exists( 'wpjobster_mark_all_notifications_as_read' ) ) {
	function wpjobster_mark_all_notifications_as_read() {
		$uid = get_current_user_id();

		if ( ! empty ( $_POST['wpj-read-all-cnt'] ) ) {

			// get only unread notifications belonging to this user
			$notifications = wpjobster_get_notifications( array(
				'limit'  => 10000, //reasonable limit
				'uid'    => $uid,
				'status' => 'unread',
			) );

			// build a list of IDs rather than querying in loop, for performance
			$i = 0; $sql_in = '';
			if ( $notifications ) {
				foreach ( $notifications as $notification ) {
					if ( ++$i > 1 ) {
						$sql_in = $sql_in . ', ';
					}
					$sql_in = $sql_in . $notification->id;
				}
			}

			// update read status
			if ( ! empty( $sql_in ) ) {
				global $wpdb;
				$wpdb->query( "UPDATE {$wpdb->prefix}job_chatbox SET rd_receiver = '1' WHERE id IN ({$sql_in}) " );
			}

			wpj_refresh_user_notifications( $uid, 'notifications' );
		}
	}
}
