<?php
function wpj_get_current_tab_user_settings() {
	global $wp_query;

	$pg   = isset( $wp_query->query_vars['pg'] ) ? urldecode( $wp_query->query_vars['pg'] ) : 'home';
	$tabs = apply_filters( 'wpj_user_settings_tab_filter', array( 'home', 'social-media-accounts', 'security', 'payments', 'additional-details' ) );

	if ( ! in_array( $pg, $tabs ) ) { $pg = 'home'; }

	return $pg;
}

function wpj_save_personal_info_data() {

	global $wp_rewrite, $wp_query;

	$uid = get_current_user_id();

	$wpjobster_characters_personalinfo_max = get_option( "wpjobster_characters_personalinfo_max" );
	$wpjobster_characters_personalinfo_max = empty( $wpjobster_characters_personalinfo_max ) || $wpjobster_characters_personalinfo_max == 0 ? 500 : $wpjobster_characters_personalinfo_max;

	$wpjobster_characters_personalinfo_min = get_option( "wpjobster_characters_personalinfo_min" );
	$wpjobster_characters_personalinfo_min = empty( $wpjobster_characters_personalinfo_min ) || $wpjobster_characters_personalinfo_min == 0 ? 0 : $wpjobster_characters_personalinfo_min;

	if ( isset( $_POST['save-info'] ) ) {

		$ok = 1;
		$post_new_error = '';

		if ( ! is_demo_user() ) {

			// Phone verification
			if ( isset( $_POST['cell_number'] ) ) {
				if ( user( $uid, 'cell_number' ) != $_POST['cell_number'] ) {
					update_user_meta( $uid, 'uz_phone_verification', 0 );
				}
			}

			// Country field
			if ( isset( $_POST['country_code'] ) ) {
				$country_name = get_country_name( wpj_validate_input_content( $_POST['country_code'] ) );
				update_user_meta( $uid, 'country', $country_name );
			}

			// Custom fields
			$custom_field = new WPJ_Custom_Fields( $uid, 'up' );
			$custom_field->saveFieldsContent();

			// $_POST fields
			$data = array( "tax_id", "address", "cell_number", "city", "zip", "timezone_select" );

			// Bank fields
			foreach ( array(
				"bank_bank_name",
				"bank_bank_address",
				"bank_account_name",
				"bank_account_number",
				"bank_account_currency",
				"bank_additional_info"
			) as $bank_field ) {

				if ( apply_filters( 'wpj_payments_display_' . $bank_field . '_field', true ) ) { array_push( $data, $bank_field ); }

			}

			// Social media fileds
			if ( get_option( 'wpjobster_enable_user_social_media' ) == 'yes' ) {
				$providers = wpj_get_user_social_media_providers();
				if ( $providers ) {
					foreach ( $providers as $key => $provider ) {
						if ( ! empty( $_POST['social_media_' . $key] ) ) {
							update_user_meta( $uid, 'social_media_' . $key, preg_replace( "(^https?://)", "", $_POST['social_media_' . $key] ) );
						}
					}
				}
			}

			// Other fields
			if ( get_option("wpjobster_enable_country_select" ) != "no" ) { array_push( $data, "country_code" ); }
			if ( get_option( "wpjobster_enable_state_select") != "no" ) { array_push( $data, "state" ); }
			if ( count( get_preferred_languages() ) > 1 ) { array_push( $data, "preferred_language" ); }

			if ( ! user( $uid, 'first_name' ) )     { array_push( $data, "first_name" );     }
			if ( ! user( $uid, 'last_name' ) )      { array_push( $data, "last_name" );      }
			if ( ! user( $uid, 'paypal_email' ) )   { array_push( $data, "paypal_email" );   }
			if ( ! user( $uid, 'payoneer_email' ) ) { array_push( $data, "payoneer_email" ); }
			if ( ! user( $uid, 'payoneer_card' ) )  { array_push( $data, "payoneer_card" );  }

			foreach ( $data as $k ) {
				if ( isset( $_POST[$k] ) ) {
					update_user_meta( $uid, $k, wpj_validate_input_content( $_POST[$k] ) );
				}
			}

			do_action( 'wpjobster_save_withdraw_personalinfo_gateway', $uid );

			if ( isset( $_POST['lat'] ) && $_POST['lat'] != ''
				&& isset( $_POST['long'] ) && $_POST['long'] != '' ) {
				update_user_meta( $uid, 'wpj_user_latitude', $_POST['lat'] );
				update_user_meta( $uid, 'wpj_user_longitude', $_POST['long'] );
			}

		}

		// Password field
		if ( isset( $_POST['current_password'] ) || isset( $_POST['password'] ) || isset( $_POST['repeat_password'] ) ) {

			$user = get_user_by( 'id', $uid );

			if ( empty( $_POST['current_password'] ) || ! wp_check_password( $_POST['current_password'], $user->data->user_pass, $user->ID ) ) {
				$ok = 0; echo '<div class="error-wpj">' . __( 'Your old password was incorrectly typed.', 'wpjobster' ) . '</div>';
			} elseif ( empty( $_POST['password'] ) ) {
				$ok = 0; echo '<div class="error-wpj">' . __( 'You cannot use a blank password.', 'wpjobster' ) . '</div>';
			} elseif ( empty( $_POST['repeat_password'] ) ) {
				$ok = 0; echo '<div class="error-wpj">' . __( 'You must enter the same password twice in order to confirm it.', 'wpjobster' ) . '</div>';
			} elseif ( $_POST['password'] != $_POST['repeat_password'] ) {
				$ok = 0; echo '<div class="error-wpj">' . __( 'Passwords do not match.', 'wpjobster' ) . '</div>';
			} elseif ( $_POST['current_password'] == $_POST['password'] ) {
				$ok = 0; echo '<div class="error-wpj">' . __( 'Password must differ from old password.', 'wpjobster' ) . '</div>';
			} else {
				wp_set_password( $_POST['password'], $uid );
			}
		}

		// Email field
		if ( isset( $_POST['email'] ) ) {
			if ( ! empty( $_POST['email'] ) ) {
				$user_info = get_userdata( $uid );
				$old_email = $user_info->user_email;
				$new_email = trim( $_POST['email'] );

				if ( $old_email != $new_email ) {
					if ( email_exists( $new_email ) ) {
						echo '<div class="error-wpj">' . __( 'This email is already registered, please choose another one.', 'wpjobster' ) . '</div>';
					} else {

						if ( ! is_demo_user() ) {
							wp_update_user( array( 'ID' => $uid, 'user_email' => $new_email ) );

							update_user_meta( $uid, 'uz_email_verification', 0 );

							$email_key = wpjobster_email_verification_init( $uid );
							$email_key_processed = hash( "sha256", $user_info->user_nicename . $email_key, false );
							$email_verification  = get_bloginfo( 'url' ) . "/?jb_action=verify_email&username=" . $user_info->user_nicename . "&key=" . $email_key_processed;

							if ( get_option( 'wpjobster_verify_email' ) != 'no' ) {
								wpj_notify_user_translated( 'user_verification', $uid, array( '##email_verification##' => $email_verification, '##receiver_email##' => $new_email ) );
							}

							do_action( 'wpj_after_mail_save', $uid );
						}

					}
				}
			}
		}

		do_action( 'wpjobster_user_profile_extra_fields_update', $uid );

		$ok = apply_filters( 'wpj_validation_profile_extra_fields', $ok );

		$post_new_error = apply_filters( 'wpj_validation_profile_extra_fields_error_messages', $post_new_error );

		if ( $ok ) {

			echo '<div class="saved_thing">';
				_e( "Information saved!", "wpjobster" );
			echo '</div>';

		} else {

			if ( is_array( $post_new_error ) && $ok == 0 ) {
				echo '<div class="errrs">';
					foreach ( $post_new_error as $e ) {
						echo '<div class="newad_error">' . $e . '</div>';
					}
				echo '</div>';

			}

		}

		echo '<div class="ui hidden divider"></div>';
	}

	do_action( 'wpj_validation_profile_extra_fields_onload' );

}

function wpj_get_up_custom_fields_content() {
	$user_page_id = get_option( 'wpjobster_user_profile_page_id' );

	$white = array();
	$white_sidebar = get_field( 'white_sidebar', $user_page_id );
	if ( have_rows( 'white_sidebar', $user_page_id ) ) {
		foreach ( $white_sidebar as $w_key => $w_value ) {
			if ( strpos( $w_value['acf_fc_layout'], 'custom_field' ) !== false ) {
				$white[] = $w_value;
			}
		}
	}

	$transparent = array();
	$transparent_sidebar = get_field( 'transparent_sidebar', $user_page_id );
	if ( have_rows( 'transparent_sidebar', $user_page_id ) ) {
		foreach ( $transparent_sidebar as $t_key => $t_value ) {
			if ( strpos( $t_value['acf_fc_layout'], 'custom_field' ) !== false ) {
				$transparent[] = $t_value;
			}
		}
	}

	$main = array();
	$main_content = get_field( 'main_content', $user_page_id );
	if ( have_rows( 'main_content', $user_page_id ) ) {
		foreach ( $main_content as $m_key => $m_value ) {
			if ( strpos( $m_value['acf_fc_layout'], 'custom_field' ) !== false ) {
				$main[] = $m_value;
			}
		}
	}

	return array_merge( $white, $transparent, $main );
}
