<?php

 /* Force cancellation
 *
 * 0 - active/completed order
 * 1 - closed from admin
 * 2 - delivery time expired
 * 3 - mutual cancellation
 * 4 - arbitration
 * 5 - user ban
 * 6 - rejected by seller
 * 7 - autoclose
 */
function wpj_get_cancellation_number_by_type( $cancel_type ) {
	$force_cancellation = 0;

	if ( $cancel_type ) {
		if ( $cancel_type == 'closed' )      { $force_cancellation = 1; }
		if ( $cancel_type == 'expired' )     { $force_cancellation = 2; }
		if ( $cancel_type == 'mutual' )      { $force_cancellation = 3; }
		if ( $cancel_type == 'arbitration' ) { $force_cancellation = 4; }
		if ( $cancel_type == 'ban' )         { $force_cancellation = 5; }
		if ( $cancel_type == 'rejected' )    { $force_cancellation = 6; }
		if ( $cancel_type == 'autoclose' )   { $force_cancellation = 7; }
	}

	return $force_cancellation;
}

function wpj_get_order_cancellation_message( $row ) {
	if ( $row->force_cancellation == 1 ) {
		$cancelled_by = __( 'Order cancelled by Admin', 'wpjobster' );
		$reason       = __( 'Order Closed', 'wpjobster' );
	} elseif ( $row->force_cancellation == 2 ) {
		$cancelled_by = __( 'Order cancelled by Buyer', 'wpjobster' );
		$reason       = __( 'Order Expired', 'wpjobster' );
	} elseif ( $row->force_cancellation == 3 ) {
		$cancelled_by = __( 'Order cancelled by User', 'wpjobster' );
		$reason       = __( 'Mutual Cancellation', 'wpjobster' );
	} elseif ( $row->force_cancellation == 4 ) {
		$cancelled_by = __( 'Order cancelled by Admin', 'wpjobster' );
		$reason       = __( 'Arbitration', 'wpjobster' );
	} elseif ( $row->force_cancellation == 5 ) {
		$cancelled_by = __( 'Order cancelled by Admin', 'wpjobster' );
		$reason       = __( 'User Ban', 'wpjobster' );
	} elseif ( $row->force_cancellation == 6 ) {
		$cancelled_by = __( 'Order cancelled by Seller', 'wpjobster' );
		$reason       = __( 'Order Rejected', 'wpjobster' );
	} elseif ( $row->force_cancellation == 7 ) {
		$cancelled_by = __( 'Order cancelled by System', 'wpjobster' );
		$reason       = __( 'Autoclosed because the seller didn\'t respond', 'wpjobster' );
	} else {
		$cancelled_by = __( 'Order cancelled', 'wpjobster' );
		$reason       = '';
	}

	return array( 'message' => $cancelled_by, 'reason' => $reason );
}

/* Cancel order by id */
function wpj_cancel_order_by_id ( $orderid = '', $cancel_type = '', $from_cron = false ) {
	if ( $orderid && $cancel_type ) {

		global $wpdb;

		// Action before
		do_action( 'wpj_before_order_is_cancelled', $orderid, 'job_purchase', $cancel_type );

		// Order row
		$row = wpjobster_get_order_details_by_orderid( $orderid );

		// Force cancellation
		$force_cancellation = wpj_get_cancellation_number_by_type( $cancel_type );

		if ( $row ) {

			// Post
			$post = get_post( $row->pid );

			// Time
			$timestamp = current_time( 'timestamp', 1 );

			// Refund
			wpj_refund_payment( $row, $orderid, $from_cron );

			// Mutual columns
			if ( $cancel_type == 'mutual' ) {
				$more_columns = ", accept_cancellation_request = '1', date_accept_cancellation = '{$timestamp}'";
			} else {
				$more_columns = ", request_cancellation_from_seller = '0', request_cancellation_from_buyer = '0'";
			}

			// Insert to orders
			if ( apply_filters( 'wpj_change_order_data_filter', true, $orderid, $cancel_type ) ) {
				$query = "
					UPDATE {$wpdb->prefix}job_orders
					SET
						closed = '1',
						force_cancellation = '{$force_cancellation}',
						date_closed = '{$timestamp}',
						payment_status = 'cancelled'
						{$more_columns}
					WHERE id = '{$orderid}'
				";

				$wpdb->query( $query );
			}

			// Custom offer
			if ( wpj_is_custom_offer( $row->pid ) ) {
				wpj_custom_offer_mark_inactive( $cancel_type, $row->pid, $post->post_author );
			}

		}

		// Action after
		do_action( 'wpj_after_order_is_cancelled', $orderid, 'job_purchase' );
	}

	return false;
}

/* Cancel all user orders */
function wpj_cancel_all_orders_by_user( $uid ) {
	global $wpdb;

	$results = $wpdb->get_results( "
		SELECT orders.id as order_id
			FROM {$wpdb->prefix}job_orders orders
		INNER JOIN {$wpdb->prefix}posts posts
			ON posts.ID = orders.pid
		WHERE closed = 0
			AND completed = 0
			AND ( orders.uid = {$uid}
				OR posts.post_author = {$uid} )
		GROUP BY orders.ID
	" );

	foreach ( $results as $key => $row ) {
		wpj_cancel_order_by_id( $row->order_id, 'ban' );
	}
}

/* Request mutual cancellation */
add_action( 'wp_ajax_nopriv_request_mutual_cancelation', 'wpj_request_mutual_cancelation' );
add_action( 'wp_ajax_request_mutual_cancelation', 'wpj_request_mutual_cancelation' );
function wpj_request_mutual_cancelation() {

	$orderid = isset( $_POST['orderid'] ) ? $_POST['orderid'] : '';

	if ( $orderid && is_user_logged_in() ) {

		global $wpdb, $wp_rewrite, $wp_query;

		$r = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_orders WHERE id = '{$orderid}'" );
		if ( $r ) {

			$pid     = $r[0]->pid;
			$post    = get_post( $pid );
			$message = isset( $_POST['message_to_buyer'] ) ? addslashes( $_POST['message_to_buyer'] ) : '';
			$tm      = current_time( 'timestamp', 1 );

			if ( isset( $_POST['process_action'] ) ) {
				if ( $_POST['process_action'] == 'confirm_cancellation_from_seller' ) { // Seller
					$uid_val            = -8;
					$to_user            = $r[0]->uid;
					$from_user          = $post->post_author;
					$email_reason       = 'cancel_seller';
					$email_offer_reason = 'cancel_offer_seller';
					$db_message_to      = 'message_to_buyer';
					$db_request_from    = 'request_cancellation_from_seller';
				} elseif ( $_POST['process_action'] == 'confirm_cancellation_from_buyer' ) { // Buyer
					$uid_val            = -9;
					$to_user            = $post->post_author;
					$from_user          = $r[0]->uid;
					$email_reason       = 'cancel_buyer';
					$email_offer_reason = 'cancel_offer_buyer';
					$db_message_to      = 'message_to_seller';
					$db_request_from    = 'request_cancellation_from_buyer';
				}
			}

			if ( isset( $uid_val ) && ! is_demo_user() ) {
				$result = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_chatbox WHERE content = '{$message}' AND uid = '{$uid_val}' AND oid = {$orderid}" );

				if ( $wpdb->num_rows <= 0 ) {

					// Insert to orders
					$wpdb->query( "UPDATE {$wpdb->prefix}job_orders SET {$db_message_to} = '{$message}', {$db_request_from} = '1', accept_cancellation_request = '0', date_request_cancellation = '{$tm}' WHERE id = '{$orderid}'" );

					// Insert to chatbox
					$wpdb->insert(
						$wpdb->prefix . 'job_chatbox',
						array(
							'datemade' => current_time( 'timestamp', 1 ),
							'uid'      => $uid_val,
							'oid'      => $orderid,
							'content'  => $message
						),
						array( '%d', '%d', '%d', '%s' )
					);

					// Update notifications
					$this_notification = $wpdb->insert_id;
					wpj_update_user_notifications( $to_user, 'notifications', +1, $this_notification );

					// Send emails
					$from_user_data = get_userdata( $from_user );
					if ( wpj_is_custom_offer( $pid ) ) {
						wpj_custom_offer_cancelled( $email_offer_reason, $pid, $orderid, $to_user );
					} else {
						wpj_notify_user_translated( $email_reason, $to_user, array(
							'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $r[0]->date_made ),
							'##transaction_page_link##' => wpj_get_order_link( $orderid ),
							'##sender_username##'       => wpj_get_user_display_type( $from_user_data->ID ),
							'##job_name##'              => $post->post_title,
							'##job_link##'              => urldecode( get_permalink( $pid ) )
						) );
					}

				}
			}
		}
	}

	die();
}

/* Abort mutual cancellation */
add_action( 'wp_ajax_nopriv_abort_mutual_cancelation', 'wpj_abort_mutual_cancelation' );
add_action( 'wp_ajax_abort_mutual_cancelation', 'wpj_abort_mutual_cancelation' );
function wpj_abort_mutual_cancelation() {

	$orderid = isset( $_POST['orderid'] ) ? $_POST['orderid'] : '';

	if ( $orderid && is_user_logged_in() ) {

		global $wpdb, $wp_query;

		$r = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_orders WHERE id = '{$orderid}'" );
		if ( $r ) {

			$row  = $r[0];
			$pid  = $row->pid;
			$post = get_post( $pid );
			$tm   = current_time( 'timestamp', 1 );

			if ( $post->post_author == get_current_user_id() && $row->request_cancellation_from_seller == 1  ) { // Seller
				$uid_val            = -16;
				$to_user            = $row->uid;
				$from_user          = $post->post_author;
				$email_reason       = 'cancel_abort_seller';
				$email_offer_reason = 'cancel_offer_abort_seller';
				$db_request_from    = 'request_cancellation_from_seller';
			} elseif ( $row->uid == get_current_user_id() && $row->request_cancellation_from_buyer == 1 ) { // Buyer
				$uid_val            = -17;
				$to_user            = $post->post_author;
				$from_user          = $row->uid;
				$email_reason       = 'cancel_abort_buyer';
				$email_offer_reason = 'cancel_offer_abort_buyer';
				$db_request_from    = 'request_cancellation_from_buyer';
			}

			if ( isset( $uid_val ) && ! is_demo_user() ) {
				// Insert to orders
				$wpdb->query( "UPDATE {$wpdb->prefix}job_orders SET {$db_request_from} = '0' WHERE id = '{$orderid}'" );

				// Insert to chatbox
				$wpdb->insert(
					$wpdb->prefix . 'job_chatbox',
					array(
						'datemade' => current_time( 'timestamp', 1 ),
						'uid'      => $uid_val,
						'oid'      => $orderid,
						'content'  => ''
					),
					array( '%d', '%d', '%d', '%s' )
				);

				// Update notifications
				$this_notification = $wpdb->insert_id;
				wpj_update_user_notifications( $to_user, 'notifications', +1, $this_notification );

				// Send emails
				$from_user_data = get_userdata( $from_user );
				if ( wpj_is_custom_offer( $pid ) ) {
					wpj_custom_offer_cancelled( $email_offer_reason, $pid, $orderid, $to_user );
				} else {
					wpj_notify_user_translated( $email_reason, $to_user, array(
						'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $row->date_made ),
						'##transaction_page_link##' => wpj_get_order_link( $orderid ),
						'##sender_username##'       => wpj_get_user_display_type( $from_user_data->ID ),
						'##job_name##'              => $post->post_title,
						'##job_link##'              => urldecode( get_permalink( $pid ) )
					) );
				}
			}
		}
	}

	die();
}

/* Response mutual cancellation */
add_action( 'wp_ajax_nopriv_answer_mutual_cancellation', 'wpj_answer_mutual_cancellation' );
add_action( 'wp_ajax_answer_mutual_cancellation', 'wpj_answer_mutual_cancellation' );
function wpj_answer_mutual_cancellation() {

	$orderid = isset( $_POST['orderid'] ) ? $_POST['orderid'] : '';
	$accept  = isset( $_POST['accept'] ) ? $_POST['accept'] : '';

	if ( $orderid && $accept && is_user_logged_in() ) {

		global $wpdb, $wp_query;

		$r = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_orders WHERE id = '{$orderid}'" );
		if ( $r ) {
			$row       = $r[0];
			$pid       = $row->pid;
			$post      = get_post( $pid );
			$date_made = $row->date_made;
			$tm        = current_time( 'timestamp', 1 );
			$ccc       = __( 'Mutual cancellation', 'wpjobster' );

			if ( $row->uid == get_current_user_id() && $row->request_cancellation_from_seller == 1 ) { // Buyer

				if ( $accept == 'yes' ) {
					$uid_val            = -10;
					$email_reason       = 'cancel_acc_buyer';
					$email_offer_reason = 'cancel_offer_acc_buyer';
				} elseif ( $accept == 'no' ) {
					$uid_val             = -11;
					$email_reason        = 'cancel_decl_buyer';
					$email_offer_reason  = 'cancel_offer_decl_buyer';
				}

				$to_user   = $post->post_author;
				$from_user = $row->uid;

			} elseif ( $post->post_author == get_current_user_id() && $row->request_cancellation_from_buyer == 1 ) { // Seller

				if ( $accept == 'yes' ) {
					$uid_val            = -12;
					$email_reason       = 'cancel_acc_seller';
					$email_offer_reason = 'cancel_offer_acc_seller';
				} elseif ( $accept == 'no' ) {
					$uid_val             = -13;
					$email_reason        = 'cancel_decl_seller';
					$email_offer_reason  = 'cancel_offer_decl_seller';
				}

				$from_user = $post->post_author;
				$to_user   = $row->uid;

			}

			if ( isset( $uid_val ) && ! is_demo_user() ) {

				if ( $accept == 'yes' ) {

					// Cancel the order
					wpj_cancel_order_by_id( $orderid, 'mutual' );

				} else {

					// Insert to orders
					$wpdb->query( "UPDATE {$wpdb->prefix}job_orders SET request_cancellation_from_seller = '0', request_cancellation_from_buyer = '0', accept_cancellation_request = '-1' WHERE id = '{$orderid}'" );
				}

				// Insert to chatbox
				$wpdb->insert(
					$wpdb->prefix . 'job_chatbox',
					array(
						'datemade' => current_time( 'timestamp', 1 ),
						'uid'      => $uid_val,
						'oid'      => $orderid,
						'content'  => $ccc
					),
					array( '%d', '%d', '%d', '%s' )
				);

				// Update notifications
				$this_notification = $wpdb->insert_id;
				wpj_update_user_notifications( $to_user, 'notifications', +1, $this_notification );

				// Send emails
				$from_user_data = get_userdata( $from_user );
				if ( wpj_is_custom_offer( $pid ) ) {
					wpj_custom_offer_cancelled( $email_offer_reason, $pid, $orderid, $to_user );
				} else {
					wpj_notify_user_translated( $email_reason, $to_user, array(
						'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $row->date_made ),
						'##transaction_page_link##' => wpj_get_order_link( $orderid ),
						'##sender_username##'       => wpj_get_user_display_type( $from_user_data->ID ),
						'##job_name##'              => $post->post_title,
						'##job_link##'              => urldecode( get_permalink( $pid ) )
					) );
				}

			}
		}
	}

	die();

}

/* Cancel job pending order */
add_action( 'wp_ajax_nopriv_cancel_pending_order', 'wpj_cancel_pending_order' );
add_action( 'wp_ajax_cancel_pending_order', 'wpj_cancel_pending_order' );
function wpj_cancel_pending_order() {
	global $wpdb;

	$order_id = isset( $_POST['order_id'] ) ? $_POST['order_id'] : '';
	$process  = isset( $_POST['process'] ) ? $_POST['process'] : '';

	$order = wpjobster_get_order_details_by_orderid( $order_id );

	if ( $order_id
		&& $process == 'cancel'
		&& $order->uid == get_current_user_id()
		&& $order->payment_status == 'pending'
	) {
		$tm  = current_time( 'timestamp', 1 );
		$ccc = __( 'Pending cancelled', 'wpjobster' );

		// Cancel the order
		wpj_cancel_order_by_id( $order_id, 'pending' );

		// Insert order to chatbox
		$wpdb->insert(
			$wpdb->prefix . 'job_chatbox',
			array(
				'datemade' => current_time( 'timestamp', 1 ),
				'uid'      => -21,
				'oid'      => $order_id,
				'content'  => $ccc
			),
			array( '%d', '%d', '%d', '%s' )
		);

		// Update notifications
		$this_notification = $wpdb->insert_id;
		wpj_update_user_notifications( wpj_get_seller_id( $order_id ), 'notifications', +1, $this_notification );

		// Insert order to chatbox
		$wpdb->insert(
			$wpdb->prefix . 'job_chatbox',
			array(
				'datemade' => current_time( 'timestamp', 1 ),
				'uid'      => -22,
				'oid'      => $order_id,
				'content'  => $ccc
			),
			array( '%d', '%d', '%d', '%s' )
		);

		// Update notifications
		$this_notification = $wpdb->insert_id;
		wpj_update_user_notifications( wpj_get_buyer_id( $order_id ), 'notifications', +1, $this_notification );
	}
}

/* Cancel topup pending order */
add_action( 'wp_ajax_nopriv_cancel_topup_pending_order', 'wpj_cancel_topup_pending_order' );
add_action( 'wp_ajax_cancel_topup_pending_order', 'wpj_cancel_topup_pending_order' );
if ( ! function_exists( 'wpj_cancel_topup_pending_order' ) ) {
	function wpj_cancel_topup_pending_order( $order_id = '', $payment_gateway = '' ) {

		if ( ! $order_id ) { $order_id = $_REQUEST['order_id']; }
		if ( ! $payment_gateway ) { $payment_gateway = $_REQUEST['payment_gateway']; }

		global $wpdb;

		$uid = get_current_user_id();

		$wpdb->query( "UPDATE {$wpdb->prefix}job_topup_orders SET payment_status = 'cancelled' WHERE id = {$order_id} AND payment_gateway_name = '{$payment_gateway}' AND user_id = {$uid} LIMIT 1" );

		do_action( 'wpj_after_order_is_cancelled', $order_id, 'topup' );

		die();
	}
}

/* Order cancellation action when the time expire */
add_action( 'wp_ajax_nopriv_cancel_expired_order', 'wpj_cancel_expired_order' );
add_action( 'wp_ajax_cancel_expired_order', 'wpj_cancel_expired_order' );
function wpj_cancel_expired_order() {
	global $wpdb;

	$orderid = isset( $_POST['orderid'] ) ? $_POST['orderid'] : '';

	if ( $orderid ) {

		$chat_box = new WPJobsterChatBox( $orderid, 'job_purchase' );

		// Select current order
		$result = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}job_orders WHERE id = {$orderid}" );
		$row    = $result[0];

		$timestamp = current_time( 'timestamp', 1 );
		$ccc       = __( 'Expired', 'wpjobster' );
		$post      = get_post( $row->pid );

		if ( wpj_is_order_time_up( $orderid ) == 1 && ( $post->post_author == get_current_user_id() || $row->uid == get_current_user_id() ) ) {

			// Cancel the order
			wpj_cancel_order_by_id( $orderid, 'expired' );

			// Insert order to chatbox
			$wpdb->insert(
				$wpdb->prefix . 'job_chatbox',
				array(
					'datemade' => current_time( 'timestamp', 1 ),
					'uid'      => -35,
					'oid'      => $orderid,
					'content'  => $ccc
				),
				array( '%d', '%d', '%d', '%s' )
			);

			// Update notifications
			$this_notification = $wpdb->insert_id;
			wpj_update_user_notifications( $row->uid, 'notifications', +1, $this_notification );

			// Send email
			$buyer_data  = get_userdata( $row->uid );
			$seller_data = get_userdata( $post->post_author );
			if ( wpj_is_custom_offer( $row->pid ) ) {
				wpj_notify_user_translated( 'cancel_offer_acc_seller', $row->uid, array(
					'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $row->date_made ),
					'##transaction_page_link##' => wpj_get_order_link( $orderid ),
					'##sender_username##'       => wpj_get_user_display_type( $seller_data->ID ),
					'##job_name##'              => $post->post_title,
					'##job_link##'              => urldecode( get_permalink( $row->pid ) )
				) );
			} else {
				wpj_notify_user_translated( 'cancel_ord_expired_seller', $post->post_author, array(
					'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $row->date_made ),
					'##transaction_page_link##' => wpj_get_order_link( $orderid ),
					'##sender_username##'       => wpj_get_user_display_type( $buyer_data->ID ),
					'##job_name##'              => $post->post_title,
					'##job_link##'              => urldecode( get_permalink( $row->pid ) )
				) );

				wpj_notify_user_translated( 'cancel_ord_expired_buyer', $row->uid, array(
					'##transaction_number##'    => wpjobster_camouflage_order_id( $orderid, $row->date_made ),
					'##transaction_page_link##' => wpj_get_order_link( $orderid ),
					'##sender_username##'       => wpj_get_user_display_type( $seller_data->ID ),
					'##job_name##'              => $post->post_title,
					'##job_link##'              => urldecode( get_permalink( $row->pid ) )
				) );
			}

		}

	}

	die();

}
