<?php
/**
 * Retrieve expected_delivery for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return int
 */
function wpj_get_expected_delivery( $order ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	// insert expected delivery if not exist
	if ( ! $order->expected_delivery ) {
		$date_made = $order->date_made;
		$max_days = get_post_meta( $order->pid, 'max_days', true );

		if ( $order->extra_fast != 0 ) {
			$max_days = $order->extra_fast_days;
		}

		if ( $order->extra1 > 0 ) $max_days += $order->extra1_days;
		if ( $order->extra2 > 0 ) $max_days += $order->extra2_days;
		if ( $order->extra3 > 0 ) $max_days += $order->extra3_days;
		if ( $order->extra4 > 0 ) $max_days += $order->extra4_days;
		if ( $order->extra5 > 0 ) $max_days += $order->extra5_days;
		if ( $order->extra6 > 0 ) $max_days += $order->extra6_days;
		if ( $order->extra7 > 0 ) $max_days += $order->extra7_days;
		if ( $order->extra8 > 0 ) $max_days += $order->extra8_days;
		if ( $order->extra9 > 0 ) $max_days += $order->extra9_days;
		if ( $order->extra10 > 0 ) $max_days += $order->extra10_days;

		if ( $order->extra_revision_days > 0 ) $max_days += $order->extra_revision_days;

		$expected = $date_made + ( 24 * 3600 * $max_days );
		$expected = apply_filters( 'wpj_expected_delivery_filter', $expected, $order );

		global $wpdb;
		$wpdb->query(
			"
			UPDATE {$wpdb->prefix}job_orders
			SET expected_delivery='$expected'
			WHERE id='$order->id'
			"
		);
		$order->expected_delivery = $expected;
	}

	return $order->expected_delivery;
}

/**
 * Update expected_delivery for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return int
 */
function wpj_update_expected_delivery( $order, $new_date ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	global $wpdb;
	$wpdb->query( "
		UPDATE {$wpdb->prefix}job_orders
		SET expected_delivery = '{$new_date}'
		WHERE id = '{$order->id}'
	" );

	return true;
}

/**
 * Add number of days to expected_delivery for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return int
 */
function wpj_update_expected_delivery_add_days( $order, $days ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	$expected = wpj_get_expected_delivery( $order );
	$expected = apply_filters( 'wpj_expected_delivery_add_days_filter', $expected + ( 24 * 3600 * $days ), $order, $days );

	global $wpdb;
	$wpdb->query(
		"
		UPDATE {$wpdb->prefix}job_orders
		SET expected_delivery='$expected'
		WHERE id='$order->id'
		"
	);

	return $expected;
}

add_action( 'wpjobster_job_payment_completed', 'wpjobster_set_order_delivery_time', 10, 2 );
function wpjobster_set_order_delivery_time( $order, $from = '' ) {
	if ( ! is_object( $order ) ) {
		$order = wpjobster_get_order( $order );
	}

	$date_paid     = time();
	$delivery_days = get_post_meta( $order->pid, 'max_days', true );

	if ( $order->extra_fast != 0 ) {
		$delivery_days = $order->extra_fast_days;
	}

	if ( $order->extra1 > 0 ) $delivery_days += $order->extra1_days;
	if ( $order->extra2 > 0 ) $delivery_days += $order->extra2_days;
	if ( $order->extra3 > 0 ) $delivery_days += $order->extra3_days;
	if ( $order->extra4 > 0 ) $delivery_days += $order->extra4_days;
	if ( $order->extra5 > 0 ) $delivery_days += $order->extra5_days;
	if ( $order->extra6 > 0 ) $delivery_days += $order->extra6_days;
	if ( $order->extra7 > 0 ) $delivery_days += $order->extra7_days;
	if ( $order->extra8 > 0 ) $delivery_days += $order->extra8_days;
	if ( $order->extra9 > 0 ) $delivery_days += $order->extra9_days;
	if ( $order->extra10 > 0 ) $delivery_days += $order->extra10_days;

	if ( $order->extra_revision_days > 0 ) $delivery_days += $order->extra_revision_days;

	$delivery_days = apply_filters( 'wpj_delivery_days_filter', $delivery_days, $order );

	$expected_delivery = $date_paid + ( 24 * 3600 * $delivery_days );
	$expected_delivery = apply_filters( 'wpj_expected_delivery_filter', $expected_delivery, $order );

	wpj_update_expected_delivery( $order, $expected_delivery );
}
