<?php
/**
 * Retrieve custom extras object for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @return object
 */
function wpj_get_custom_extras( $order ) {
	if ( is_object( $order ) ) {
		$order_id = $order->id;
	} else {
		$order_id = $order;
	}

	global $wpdb;
	$custom_extras = $wpdb->get_results( $wpdb->prepare(
		"
		SELECT * FROM {$wpdb->prefix}job_custom_extra_orders
		WHERE order_id = %d
		ORDER BY custom_extra_id ASC
		",
		$order_id
	) );

	return $custom_extras;
}


/**
 * Retrieve single custom extra for a particular order
 *
 * @since Jobster v4.0.0
 *
 * @param object|int
 * @param int
 * @return object
 */
function wpj_get_custom_extra( $order, $custom_extra_id ) {
	if ( is_object( $order ) ) {
		$order_id = $order->id;
	} else {
		$order_id = $order;
	}

	global $wpdb;
	$custom_extra = $wpdb->get_row( $wpdb->prepare(
		"
		SELECT * FROM {$wpdb->prefix}job_custom_extra_orders
		WHERE order_id = %d
			AND custom_extra_id = %d
		",
		$order_id, $custom_extra_id
	) );

	return $custom_extra;
}

/**
 * Retrieve tips object for a particular order
 *
 * @since Jobster v5.3.0
 *
 * @param object|int
 * @return object
 */
function wpj_get_tips( $order ) {
	if ( is_object( $order ) ) {
		$order_id = $order->id;
	} else {
		$order_id = $order;
	}

	global $wpdb;
	$tips = $wpdb->get_results( $wpdb->prepare(
		"
		SELECT * FROM {$wpdb->prefix}job_tips_orders
		WHERE order_id = %d
		ORDER BY tips_id ASC
		",
		$order_id
	) );

	return $tips;
}


/**
 * Retrieve single tips for a particular order
 *
 * @since Jobster v5.3.0
 *
 * @param object|int
 * @param int
 * @return object
 */
function wpj_get_tip( $order, $tips_id ) {
	if ( is_object( $order ) ) {
		$order_id = $order->id;
	} else {
		$order_id = $order;
	}

	global $wpdb;
	$tips = $wpdb->get_row( $wpdb->prepare(
		"
		SELECT * FROM {$wpdb->prefix}job_tips_orders
		WHERE order_id = %d
			AND tips_id = %d
		",
		$order_id, $tips_id
	) );

	return $tips;
}

// GET FEATURED ORDER
if ( ! function_exists( 'wpjobster_get_featured_order_by' ) ) {
	function wpjobster_get_featured_order_by( $column_name='', $val='' ) {

		$val = esc_sql( $val );

		if ( is_numeric( $val ) ) {
			global $wpdb;
			$pref = $wpdb->prefix;

			$sql = "SELECT * FROM {$wpdb->prefix}job_featured_orders WHERE ".$column_name." = ".$val;
			$result = $wpdb->get_results( $sql );

			return $result;
		}

		return false;
	}
}

// GET TOPUP ORDER
if ( ! function_exists( 'wpjobster_get_topup_order_by' ) ) {
	function wpjobster_get_topup_order_by( $column_name='', $val='' ) {

		$val = esc_sql( $val );

		if ( is_numeric( $val ) ) {
			global $wpdb;
			$pref = $wpdb->prefix;

			$sql = "SELECT * FROM {$wpdb->prefix}job_topup_orders WHERE ".$column_name." = ".$val;
			$result = $wpdb->get_row( $sql );

			return $result;
		}

		return false;
	}
}

// GET SUBSCRIPTION ORDER
if ( ! function_exists( 'wpjobster_get_subscription_order_by' ) ) {
	function wpjobster_get_subscription_order_by( $column_name='id', $val='', $status='active', $type_of_return='single' ) {

		$val = esc_sql( $val );

		if ( is_numeric( $val ) ) {
			global $wpdb;
			$pref = $wpdb->prefix;

			if ( $status == 'all' ) {
				$sql = "SELECT * FROM {$wpdb->prefix}job_subscription_orders WHERE " . $column_name . " = '" . $val . "'";
			} else {
				$sql = "SELECT * FROM {$wpdb->prefix}job_subscription_orders WHERE " . $column_name . " = '" . $val . "' AND subscription_status='" . $status . "' LIMIT 1";
			}

			if( $type_of_return == 'multiple' ){
				$result = $wpdb->get_results( $sql );
			}else{
				$result = $wpdb->get_row( $sql );
			}

			return $result;
		}

		return false;
	}
}

// GET CUSTOM EXTRA ORDER
if ( ! function_exists( 'wpjobster_get_custom_extra_order_by' ) ) {
	function wpjobster_get_custom_extra_order_by( $column_name = '', $val = '' ) {

		$val = esc_sql( $val );

		if ( is_numeric( $val ) ) {
			global $wpdb;
			$pref = $wpdb->prefix;

			$sql = "SELECT * FROM {$wpdb->prefix}job_custom_extra_orders WHERE " . $column_name . " = " . $val;
			$result = $wpdb->get_row( $sql );

			return $result;
		}

		return false;
	}
}

// GET TIPS ORDER
if ( ! function_exists( 'wpjobster_get_tips_order_by' ) ) {
	function wpjobster_get_tips_order_by( $column_name = '', $val = '' ) {

		$val = esc_sql( $val );

		if ( is_numeric( $val ) ) {
			global $wpdb;
			$pref = $wpdb->prefix;

			$sql = "SELECT * FROM {$wpdb->prefix}job_tips_orders WHERE " . $column_name . " = " . $val;
			$result = $wpdb->get_row( $sql );

			return $result;
		}

		return false;
	}
}
