<?php
/* ADD PID TO LAST CHECKOUT VIEW */
if ( ! function_exists( 'wpj_update_last_checkout_viewed' ) ) {
	function wpj_update_last_checkout_viewed( $pid = '', $action = '' ) {
		if ( is_user_logged_in() ) {
			$last_viewed = get_user_meta( get_current_user_id(), 'last_checkout_viewed', true );

			if ( ! is_array( $last_viewed ) ) { $last_viewed = array(); }

			$last_viewed = array_diff( $last_viewed, array( $pid ) );
			if ( $action != 'remove' ) { array_unshift( $last_viewed, $pid ); }
			array_splice( $last_viewed, 10 );

			update_user_meta( get_current_user_id(), 'last_checkout_viewed', $last_viewed );
		}
	}
}

/* REMOVE PID FROM LAST CHECKOUT VIEW */
add_action( 'wpjobster_job_payment_completed', function( $oid ) {
	$order = wpjobster_get_order_details_by_orderid( $oid );
	$pid   = $order->pid;
	wpj_update_last_checkout_viewed( $pid, 'remove' );
});

function wpj_get_payment_info_by_url( $var = '' ) {

	$total_order_price = 0;

	$pid = $payment_type = $order = $custom_extra = $tip = false;

	$redirect_link = get_bloginfo( 'url' );

	$custom_amount_enabled = apply_filters( "wpjobster_check_custom_amount_enabled", 0 );

	$oid = WPJ_Form::get( 'oid', '' );

	// Job purchase
	if ( isset( $_GET['jobid'] ) ) {
		$payment_type  = 'job_purchase';
		$pid           = WPJ_Form::get( 'jobid' );

		$redirect_link = get_permalink( $pid );

		$_SESSION['confirmationpagevisited'] = $pid;
	}

	// Custom extra purchase
	if ( $oid && isset( $_GET['custom_extra'] ) ) {
		$payment_type    = 'custom_extra';
		$order           = wpjobster_get_order_details_by_orderid( $oid );
		$pid             = $order->pid;

		$custom_extra_id = WPJ_Form::get( 'custom_extra', '' );
		$custom_extras   = json_decode( $order->custom_extras );
		$custom_extra    = $custom_extras[$custom_extra_id];

		$redirect_link   = wpj_get_order_link( $oid );

		$_SESSION['confirmationpagevisited'] = $oid;
	}

	// Tips purchase
	if ( $oid && isset( $_GET['tips'] ) ) {
		$payment_type  = 'tips';
		$order         = wpjobster_get_order_details_by_orderid( $oid );
		$pid           = $order->pid;

		$tips_id       = WPJ_Form::get( 'tips', '' );
		$tips          = json_decode( $order->tips );
		$tip           = $tips[$tips_id];

		$redirect_link = wpj_get_order_link( $oid );

		$_SESSION['confirmationpagevisited'] = $oid;
	}

	// Job Price
	$main_amount = 1;
	$sample_prc  = 0;
	if ( $payment_type == 'job_purchase' ) {
		$sample_prc = get_post_meta( $pid, "price", true );
		if ( ! is_numeric( $sample_prc ) || $sample_prc < 0 ) {
			$sample_prc = get_option( 'wpjobster_job_fixed_amount' );
		}
		$sample_prc = apply_filters( 'wpjobster_purchase_this_job_price', $sample_prc, $pid );

	} elseif ( $payment_type == 'custom_extra' ) {
		$sample_prc = $custom_extra->price;

	} elseif ( $payment_type == 'tips' ) {
		$sample_prc = $tip->amount;
	}

	$main_amount = WPJ_Form::post( 'main_value_inp', 1 );
	$main_amount = ( $main_amount == 'undefined' ) ? 1 : $main_amount;

	$sample_prc = $sample_prc * $main_amount;
	$sample_prc = apply_filters( 'wpj_sample_prc_filter', $sample_prc, $pid );

	$total_order_price += $sample_prc;

	// Extras
	$sample_extras = 0;
	$extra_job_add = $extra_job_arr = array();
	$extrs2 = $extrs_amounts = $extrs_amounts2 = $extrs = '';

	if ( $payment_type == 'job_purchase' ) { $h = 0;

		// Extra
		for ( $k = 1; $k <= 10; $k ++ ) {
			$extra_price   = get_post_meta( $pid, 'extra' . $k . '_price', true );
			$extra_content = get_post_meta( $pid, 'extra' . $k . '_content', true );

			if ( ! empty( $extra_price ) && ! empty( $extra_content ) ) {
				if ( ! empty( $_POST[ 'extra' . $k ] ) ) {

					$extra_job_add[$h]['content']  = $extra_content;
					$extra_job_add[$h]['price']    = $extra_price;
					$extra_job_add[$h]['amount']   = $_POST[ 'extra' . $k ];
					$extra_job_add[$h]['extra_nr'] = $k;
					$h ++;

					$extra_job_arr[ 'extra_job' . $pid ][$h]['extra_nr'] = $k;
					$extra_job_arr[ 'extra_job' . $pid ][$h]['price']    = $extra_price;
					$extra_job_arr[ 'extra_job' . $pid ][$h]['amount']   = $_POST[ 'extra' . $k ];

					$sample_extras += $extra_price * $_POST[ 'extra' . $k ];
				}
			}
		}

		if ( $extra_job_arr ) {
			foreach ( $extra_job_arr['extra_job' . $pid] as $ar_and ) {
				$extrs          .= $ar_and['extra_nr'] . '|';
				$extrs2         .= $ar_and['extra_nr'] . '_';
				$extrs_amounts  .= $ar_and['amount'] . '|';
				$extrs_amounts2 .= $ar_and['amount'] . '_';
			}
		}

		// Extra Fast Delivery
		if ( ! empty( $_POST['extrafast'] ) ) {
			$extra_fast_price  = get_post_meta( $pid, 'extra_fast_price', true );
			$extra_fast_amount = WPJ_Form::post( 'extrafast', 1 );

			$sample_extras += $extra_fast_price * $extra_fast_amount;

			$extrs            .= 'f|';
			$extrs2           .= 'f_';
			$extrs_amounts    .= $extra_fast_amount . '|';
			$extrs_amounts2   .= $extra_fast_amount . '_';
		}

		// Additional Revision
		if ( ! empty( $_POST['extrarevision'] ) ) {
			$extra_revision_price  = get_post_meta( $pid, 'extra_revision_price', true );
			$extra_revision_amount = WPJ_Form::post( 'extrarevision', 1 );

			$sample_extras += $extra_revision_price * $extra_revision_amount;

			$extrs                .= 'r|';
			$extrs2               .= 'r_';
			$extrs_amounts        .= $extra_revision_amount . '|';
			$extrs_amounts2       .= $extra_revision_amount . '_';
		}

	}

	$sample_extras = apply_filters( 'wpj_sample_extras_filter', $sample_extras, $pid );

	$total_order_price += $sample_extras;

	// Shipping
	$shipping = 0;
	if ( $payment_type == 'job_purchase' ) {
		$shipping = get_post_meta( $pid, 'shipping', true );
	}
	if ( ! $shipping ) { $shipping = 0; }

	$total_order_price += $shipping;

	// Processing fees
	$buyer_processing_fees = wpjobster_get_site_processing_fee( $sample_prc, $sample_extras, $shipping );

	$total_order_price += $buyer_processing_fees;

	// Tax
	$wpjobster_tax_amount = wpjobster_get_site_tax( $sample_prc, $sample_extras, $shipping, $buyer_processing_fees );

	$total_order_price += $wpjobster_tax_amount;

	$vars_arr = array(
		'redirect_link'         => $redirect_link,
		'payment_type'          => $payment_type,
		'uid'                   => get_current_user_id(),
		'pid'                   => $pid,
		'post'                  => ! empty( $pid ) ? get_post( $pid ) : array(),
		'order'                 => $order,
		'oid'                   => $oid,
		'custom_extra'          => $custom_extra,
		'tip'                   => $tip,
		'custom_amount_enabled' => $custom_amount_enabled,
		'sample_prc'            => $sample_prc,
		'main_amount'           => $main_amount,
		'extra_job_add'         => $extra_job_add,
		'extra_job_arr'         => $extra_job_arr,
		'sample_extras'         => $sample_extras,
		'extrs'                 => $extrs,
		'extrs2'                => $extrs2,
		'extrs_amounts'         => $extrs_amounts,
		'extrs_amounts2'        => $extrs_amounts2,
		'shipping'              => $shipping,
		'buyer_processing_fees' => $buyer_processing_fees,
		'wpjobster_tax_amount'  => $wpjobster_tax_amount,
		'total_order_price'     => $total_order_price
	);

	return $var ? $vars_arr[$var] : $vars_arr;
}

// Job Title
function wpj_purchase_this_show_job_title() {
	if ( wpj_get_payment_info_by_url( 'payment_type' ) == 'custom_extra' ) {
		$order = wpj_get_payment_info_by_url( 'order' );
		echo $order->job_title;
	} else {
		$pid  = wpj_get_payment_info_by_url( 'pid' );
		$post = wpj_get_payment_info_by_url( 'post' );

		if ( wpj_is_custom_offer( $pid ) ) {
			echo apply_filters( 'wpjobster_purchase_this_job_title', wpj_get_custom_offer_title( $pid, $post->post_author ), $pid );
		} else {
			echo '<a href="' . get_permalink( $pid ) . '">' . apply_filters( 'wpjobster_purchase_this_job_title', get_the_title( $pid ), $pid ) . '</a>';
		}
	}
}

// Job Category
function wpj_purchase_this_show_job_categories() {

	$payment_type = wpj_get_payment_info_by_url( 'payment_type' );
	$pid          = wpj_get_payment_info_by_url( 'pid' );
	$custom_extra = wpj_get_payment_info_by_url( 'custom_extra' );
	$tip          = wpj_get_payment_info_by_url( 'tip' );

	if ( $payment_type == 'job_purchase' ) {
		echo apply_filters( 'wpjobster_purchase_this_job_categories', wpjobster_display_job_categories(), $pid );
	} elseif ( $payment_type == 'custom_extra' ) {
		echo apply_filters( 'wpj_custom_extra_string_filter', __( "Custom extra: ", "wpjobster" ) ) . ' ' . wpj_apply_filter_to_string( $custom_extra->description, false, 'joblistings' );
	} elseif ( $payment_type == 'tips' ) {
		echo __( "Tips", "wpjobster" ) . ( $tip->reason ? ": " . wpj_apply_filter_to_string( $tip->reason, false, 'joblistings' ) : "" );
	}

}

// Job Price
function wpj_purchase_this_show_job_price() {
	$main_amount = wpj_get_payment_info_by_url( 'main_amount' );
	$sample_prc  = wpj_get_payment_info_by_url( 'sample_prc' );

	if ( get_option( 'wpjobster_purchase_this_extra_enabled' ) != 'yes') {
		if ( $main_amount > 1 ) {
			echo '<span class="amount-nr">' . $main_amount . "<span class='x-sign'> x </span></span>";
		}
	}

	if ( $sample_prc > 0 ) {
		echo wpjobster_get_show_price( $sample_prc );
	} else {
		if ( wpj_bool_option( 'wpjobster_replace_zero_with_free' ) ) {
			echo __( 'Free', 'wpjobster' );
		} else {
			echo wpjobster_get_show_price( $sample_prc );
		}
	}
}

// Extras
function wpj_purchase_this_show_extras() {

	$extra_job_add = wpj_get_payment_info_by_url( 'extra_job_add' );

	if ( count( $extra_job_add ) > 0 ) {
		if ( $extra_job_add ) {
			foreach ( $extra_job_add as $extra_job_add_item ) { ?>

				<div class="ui fitted divider"></div>

				<div class="cf extra-item sixteen wide column" data-extranr="<?php echo $extra_job_add_item['extra_nr']; ?>" data-extraamount="<?php echo $extra_job_add_item['amount']; ?>">

					<?php echo $extra_job_add_item['content']; ?>

					<span class="payment-item-price">
						<?php if ( $extra_job_add_item['amount'] > 1 ) {
							echo '<span class="amount-nr">' . $extra_job_add_item['amount'] . " <span class='x-sign'>x</span> </span>";
						}
						echo wpjobster_get_show_price( $extra_job_add_item['price'] ); ?>
					</span>
				</div>
			<?php }
		}
	}
}

// Extra Fast Delivery & Additional Revision
function wpj_purchase_this_show_extra_fast_revision() { ?>

	<div class="ui two column stackable grid">
		<?php $pid  = wpj_get_payment_info_by_url( 'pid' );

		// Extra Fast Delivery
		if ( ! empty( $_POST['extrafast'] ) ) {
			$extra_fast_price  = get_post_meta( $pid, 'extra_fast_price', true );
			$extra_fast_amount = WPJ_Form::post( 'extrafast', 1 ); ?>

			<div class="ui fitted divider"></div>

			<div class="cf extra-item sixteen wide column" data-extranr="fast" data-extraamount="<?php echo $extra_fast_amount; ?>">

				<?php echo __( 'Extra fast delivery', 'wpjobster' ); ?>

				<span class="payment-item-price">
					<?php if ( $extra_fast_amount > 1 ) {
						echo '<span class="amount-nr">' . $extra_fast_amount . "<span class='x-sign'> x </span></span>";
					}
					echo wpjobster_get_show_price( $extra_fast_price ); ?>
				</span>
			</div>
		<?php }

		// Additional Revision
		if ( ! empty( $_POST['extrarevision'] ) ) {
			$extra_revision_price  = get_post_meta( $pid, 'extra_revision_price', true );
			$extra_revision_amount = WPJ_Form::post( 'extrarevision', 1 ); ?>

			<div class="ui fitted divider"></div>

			<div class="cf extra-item sixteen wide column" data-extranr="revision" data-extraamount="<?php echo $extra_revision_amount; ?>">

				<?php echo __( 'Extra revision', 'wpjobster' ); ?>

				<span class="payment-item-price">
					<?php if ( $extra_revision_amount > 1 ) {
						echo '<span class="amount-nr">' . $extra_revision_amount . "<span class='x-sign'> x </span></span>";
					}
					echo wpjobster_get_show_price( $extra_revision_price ); ?>
				</span>
			</div>
		<?php } ?>

	</div>
<?php }

// Redirects
function wpj_purchase_this_redirects() {

	$post         = wpj_get_payment_info_by_url( 'post' );
	$order        = wpj_get_payment_info_by_url( 'order' );
	$custom_extra = wpj_get_payment_info_by_url( 'custom_extra' );
	$tip          = wpj_get_payment_info_by_url( 'tip' );

	if ( ! is_user_logged_in() ) {
		wp_redirect( get_bloginfo( 'url' ) . "/wp-login.php?redirect_to=" . urlencode( wpj_get_payment_info_by_url( 'redirect_link' ) ) );
		exit;
	}

	if ( ! isset( $_POST['purchaseformvalidation'] ) ) {
		wp_redirect( wpj_get_payment_info_by_url( 'redirect_link' ) );
		exit;
	}

	if ( wpj_get_payment_info_by_url( 'pid' ) && $post->post_author == get_current_user_id() ) {
		wp_redirect( get_bloginfo( 'url' ) );
		exit;
	}

	if ( wpj_get_payment_info_by_url( 'payment_type' ) == 'job_purchase' && wpj_is_custom_offer( wpj_get_payment_info_by_url( 'pid' ) ) ) {
		wpj_check_offer_veracity( wpj_get_payment_info_by_url( 'pid' ), $post->post_author );
	}

	if ( wpj_get_payment_info_by_url( 'payment_type' ) == 'custom_extra' ) {
		if ( $order->uid != get_current_user_id() ) {
			wp_redirect( get_bloginfo( 'url' ) );
			exit;
		}
		if ( ! $custom_extra || $custom_extra->paid == true || $custom_extra->declined == true || $custom_extra->cancelled == true ) {
			wp_redirect( wpj_get_payment_info_by_url( wpj_get_payment_info_by_url( 'oid' ) ) );
			exit;
		}
	}

	if ( wpj_get_payment_info_by_url( 'payment_type' ) == 'tips' ) {
		if ( $order->uid != get_current_user_id() ) {
			wp_redirect( get_bloginfo( 'url' ) );
			exit;
		}
		if ( ! $tip || $tip->paid == true ) {
			wp_redirect( wpj_get_order_link( wpj_get_payment_info_by_url( 'oid' ) ) );
			exit;
		}
	}
}

function wpjobster_display_processing_fees_label() {
	// displays the label according to the processing fee type
	if ( get_option( 'wpjobster_enable_buyer_processing_fees' ) == 'percent' ) {
		echo sprintf( __( 'Processing Fees (%s%s):', 'wpjobster' ), get_option( 'wpjobster_buyer_processing_fees_percent' ), '&#37;' );
	} else {
		echo __( 'Processing Fees:', 'wpjobster' );
	}
}