<?php
//----------------------------------------
// LEFT SIDE - SIDEBAR
//----------------------------------------

/* LAST VIEW */
if ( ! function_exists( 'wpj_update_last_viewed' ) ) {
	function wpj_update_last_viewed() {
		global $post, $current_user;

		setup_postdata( $post );

		if ( get_post_type( $post->ID ) == 'job' ) {
			update_post_meta( $post->ID, '_last_viewed', current_time( 'mysql' ) );

			if ( is_user_logged_in() ) {
				$last_viewed = get_user_meta( $current_user->ID, 'last_viewed', true );

				if ( ! is_array( $last_viewed ) ) {
					$last_viewed = array();
				}

				$last_viewed = array_diff( $last_viewed, array( get_the_ID() ) );
				array_unshift( $last_viewed, get_the_ID() );
				array_splice( $last_viewed, 10 );

				update_user_meta( $current_user->ID, 'last_viewed', $last_viewed );
			}
		}
	}
}

/* COVER IMAGE */
if ( ! function_exists( 'wpj_display_cover_image' ) ) {
	function wpj_display_cover_image() {
		global $wp_query;

		$cover_image_id = get_post_meta( get_the_ID(), 'cover-image', true );

		if ( $cover_image_id && ! empty($cover_image_id ) ) { ?>

			<div class="ui gird">
				<div class="sixteen wide column">
					<div class="single-job-cover-top">
						<?php $cover_image_url = wpj_get_attachment_image_url( $cover_image_id , 'job_cover_image' ); ?>
						<img src="<?php echo $cover_image_url; ?>" />
					</div>
				</div>
			</div>

		<?php }
	}
}

/* LOCATION */
if ( ! function_exists( 'wpj_get_single_job_location' ) ) {
	function wpj_get_single_job_location() {
		global $wp_query;

		$location_display = get_post_meta( get_the_ID(), 'location_input', true );

		if ( get_option( 'wpjobster_location' ) == 'yes' && ! empty( $location_display ) ) { ?>

			<div class="job-location job-geo-location" id="job_address">
				<div class="marker location">
					<a href="https://google.com/maps/place/<?php echo $location_display; ?>" target="_blank" ><?php echo $location_display; ?></a>
				</div>
			</div>

		<?php }
	}
}

/* RATING */
if ( ! function_exists( 'wpj_get_single_job_rating' ) ) {
	function wpj_get_single_job_rating( $job_id = false ) {
		global $wp_query;

		if ( $job_id == false ) { $job_id = get_the_ID(); }

		$ratinggrade = wpjobster_get_job_rating( $job_id );
		$ratinggrade = $ratinggrade / 20;

		$rating_count = get_option( 'wpjobster_job_min_rating' );
		$rating_count = $rating_count && is_numeric( $rating_count ) ? $rating_count : 3;

		echo '<div class="job-rating-top">';

			if ( $ratinggrade != 0 ) {
				if ( wpjobster_get_job_ratings_number( $job_id ) >= $rating_count ) {
					echo wpjobster_show_stars_our_of_number( $ratinggrade );
				} else {
					echo __( "Not enough ratings", "wpjobster" );
				}
			} else {
				echo __( 'Not rated yet', 'wpjobster' );
			}

		echo '</div>';

		echo '<div class="job-rating-top-text">';
			if ( wpjobster_get_job_ratings_number( $job_id ) >= $rating_count ) {
				echo wpjobster_get_job_ratings_number( $job_id ) . " " .  _n( "review", "reviews", wpjobster_get_job_ratings_number( $job_id ), "wpjobster" );
			}
		echo '</div>';

	}
}

/* QUEUE */
if ( ! function_exists( 'wpj_get_single_job_order_queue' ) ) {
	function wpj_get_single_job_order_queue() {
		global $wp_query;

		$pid = get_the_ID();

		if ( ( wpjobster_job_fake_queue( $pid ) > 0 ) || ( wpj_get_user_jobs_count( $pid, 'in-queue' ) > 0 ) ) {
			if ( wpjobster_job_fake_queue( $pid ) > 0 ) { ?>

				<div class="queue-order">
					<?php echo __( "Orders in queue", "wpjobster" ) . ': ' . wpjobster_job_fake_queue( $pid ); ?>
				</div>

			<?php } elseif ( wpj_get_user_jobs_count( $pid, 'in-queue' ) > 0) { ?>

				<div class="queue-order">
					<?php echo __( "Orders in queue", "wpjobster" ) . ': ' . wpj_get_user_jobs_count( $pid, 'in-queue' ); ?>
				</div>

			<?php }
		}
	}
}

/* DELIVERY TIME */
if ( ! function_exists( 'wpj_get_single_job_delivery_time' ) ) {
	function wpj_get_single_job_delivery_time() {

		global $wp_query;

		$instant  = get_post_meta( get_the_ID(), "instant", true );
		$max_days = get_post_meta( get_the_ID(), "max_days", true );

		if ( $instant == 1 ) {
			$deliv_msg = __( 'Instant', 'wpjobster' );
		} elseif ( $max_days > 0 ) {
			$deliv_msg = sprintf( _n( '%d day', '%d days', $max_days, 'wpjobster' ), $max_days );
		} else {
			$deliv_msg = '';
		} ?>

		<div class="single-job-delivery-time"><?php echo apply_filters( 'wpj_single_job_delivery_days', $deliv_msg, get_the_ID() ); ?></div>

	<?php }
}

/* IMAGE & VIDEO */
if ( ! function_exists( 'wpj_get_single_job_thumbnail_carousel' ) ) {
	function wpj_get_single_job_thumbnail_carousel( $preview = false ) {
		global $wp_query;

		$video_arr       = get_post_meta( get_the_ID(), 'video_link', true );
		$images_arr      = wpjobster_get_post_images_ids( get_the_ID(), get_option( 'wpjobster_default_nr_of_pics' ) );
		$slider_elements = wpj_multidimensional_array_has_value( $video_arr ) ? count( $images_arr ) + 1 : count( $images_arr );

		if ( get_option( 'wpjobster_enable_review_work_samples' ) == 'yes' ) {
			$review_samples  = wpjobster_get_review_images_and_details( get_the_ID(), get_option( 'wpjobster_max_review_work_samples' ) );
			$slider_elements = $slider_elements + count( $review_samples );
		} ?>

		<div class="cf">

			<?php // Slider
			if ( $slider_elements > 0 ) { $i = 1; ?>

				<div class="wpj-carousel owl-carousel owl-theme">

					<?php // Video
					if ( $video_arr ) {
						foreach ( $video_arr as $key => $value ) {
							if ( $value && wpj_get_video_url_type( $value ) ) { ?>

								<a class="owl-video" data-hash="slide<?php echo $i; ?>" href="<?php echo $value; ?>"></a>

							<?php } $i++;
						}
					}

					// Images
					$counter = 0;
					foreach ( $images_arr as $imageid ) {
						$image_src = wpj_get_attachment_image_url( $imageid, 'job_slider_image' );

						if ( $counter > 0 ) {
							$lazy_class = 'bx-lazy owl-lazy';
							$lazy_src = get_template_directory_uri() . '/assets/images/blank.gif';
						} else {
							$lazy_class = '';
							$lazy_src = $image_src;
						} ?>

						<div class="bx-lazy-container" data-hash="slide<?php echo $i; ?>">
							<img src="<?php echo $lazy_src; ?>" class="job-blurry-bg <?php echo $lazy_class; ?>" data-src="<?php echo $image_src; ?>" />
							<img src="<?php echo $lazy_src; ?>" class="job-slider-img <?php echo $lazy_class; ?>" data-src="<?php echo $image_src; ?>" />
						</div>

						<?php $counter++; $i++;
					}

					// Review work samples
					if ( get_option( 'wpjobster_enable_review_work_samples' ) == 'yes' ) {
						foreach ( $review_samples as $sample ) {
							$reviewer = get_userdata( $sample->uid );
							$image_src = wpj_get_attachment_image_url( $sample->ID, 'job_slider_image' );
							$lazy_class = 'bx-lazy owl-lazy';
							$lazy_src = get_template_directory_uri() . '/assets/images/blank.gif';
							?>

							<div class="bx-lazy-container" data-hash="slide<?php echo $i; ?>">
								<img src="<?php echo $lazy_src; ?>" class="job-blurry-bg <?php echo $lazy_class; ?>" data-src="<?php echo $image_src; ?>" />
								<img src="<?php echo $lazy_src; ?>" class="job-slider-img <?php echo $lazy_class; ?>" data-src="<?php echo $image_src; ?>" />
								<div class="work-sample-caption">
									<blockquote><?php echo $sample->review; ?></blockquote>
									<small><?php echo sprintf( __( 'Reviewed by %1$s %2$s', "wpjobster" ), wpj_get_user_display_type( $reviewer->ID ), wpj_seconds_to_words( time() - $sample->datemade, false, true ) ); ?></small>
								</div>
							</div>

							<?php $counter++; $i++;
						}
					} ?>

				</div>

			<?php }

			// Thumbnail preview list
			if ( $slider_elements > 1 && ! $preview ) { $i = 1; ?>

				<div class="image-gallery-slider-pager-container">
					<div class="image-gallery-slider-pager">

						<?php // Video
						if ( $video_arr ) {
							foreach ( $video_arr as $key => $value ) {
								if ( $value && wpj_get_video_url_type( $value ) ) { ?>

									<a href="#slide<?php echo $i; ?>" class="video-thumbnail">
										<div class="pager-bg-thumb" style="background-image: url('<?php echo get_video_thumb( $value ); ?>');"></div>
									</a>

								<?php } $i++;
							}
						}

						// Images
						foreach ( $images_arr as $imageid ) {
							$sliderthumb = wpj_get_attachment_image_url( $imageid, array( 42, 42 ) ); ?>

							<a href="#slide<?php echo $i; ?>">
								<div class="pager-bg-thumb" style="background-image: url('<?php echo $sliderthumb; ?>');"></div>
							</a>

							<?php $i++;
						}

						// Review work samples
						if ( get_option( 'wpjobster_enable_review_work_samples' ) == 'yes' ) {
							foreach ( $review_samples as $sample ) {
								$sliderthumb = wpj_get_attachment_image_url( $sample->ID, array( 42, 42 ) ); ?>

								<a href="#slide<?php echo $i; ?>">
									<div class="pager-bg-thumb" style="background-image: url('<?php echo $sliderthumb; ?>');"></div>
								</a>

								<?php $i++;
							}
						} ?>

					</div>
				</div>

			<?php } ?>

		</div>

	<?php }
}

/* SOCIAL MEDIA */
if ( ! function_exists( 'wpj_get_social_icons' ) ) {
	function wpj_get_social_icons( $include_favorites = true ) { ?>

		<div class="social-icons-floating cf">

			<?php if ( $include_favorites ) { ?>

				<div class="ui segment cf">
					<?php echo wpj_show_add_to_favorite_btn(); ?>
				</div>

			<?php } ?>

			<div class="ui segment cf easy-social-share">
				<div class="">
					<?php echo do_shortcode( '[easy-social-share]' ); ?>
				</div>
			</div>

		</div>

	<?php }
}

/* AUDIO */
if ( ! function_exists( 'wpj_get_single_job_audio' ) ) {
	function wpj_get_single_job_audio() {
		global $wp_query;

		$pid_audio = get_the_ID();

		$args = array(
			'post_type'      => 'attachment',
			'post_parent'    => $pid_audio,
			'post_mime_type' => 'audio',
			'numberposts'    => -1,
			'orderby'        => 'meta_value_num date',
			'order'          => 'ASC'
		);

		$attachments_audio = get_posts( $args );

		if ( ! empty( $attachments_audio ) && get_option( 'wpjobster_audio' ) == "yes" ) { ?>

			<div class="ui segment">
				<div class="the_content cf">
					<div class="icon-before-title info-icon single-job-audio-title js-toggle-arrow">
						<h2><?php _e( "Audio", "wpjobster" ); ?></h2>
					</div>

					<div class="ui divider"></div>

					<div class="audio-margin-bottom-helper">

						<?php foreach ( $attachments_audio as $attachment_audio ) { ?>

							<div id="jquery_jplayer_<?php echo $attachment_audio->ID; ?>" class="jp-jplayer"></div>

							<div id="jp_container_<?php echo $attachment_audio->ID; ?>" class="jp-flat-audio" role="application" aria-label="media player">

								<div class="jp-play-control jp-control">
									<button class="jp-play jp-button" role="button" aria-label="play" tabindex="0"></button>
								</div>

								<div class="jp-bar">
									<div class="jp-seek-bar jp-seek-bar-display"></div>
									<div class="jp-seek-bar">
										<div class="jp-play-bar"></div>
										<div class="jp-details"><span class="jp-title" aria-label="title"></span></div>
										<div class="jp-timing"><span class="jp-duration" role="timer" aria-label="duration"></span></div>
									</div>
								</div>

								<div class="jp-no-solution">
									<?php _e( 'Media Player Error', 'wpjobster' ); ?><br />
									<?php _e( 'Update your browser or Flash plugin', 'wpjobster' ); ?>
								</div>

							</div>

						<?php } ?>

					</div>
				</div>
			</div>

		<?php } else { return 0; }
	}
}

/* JOB PREVIEW */
if ( ! function_exists( 'wpj_get_single_job_preview' ) ) {
	function wpj_get_single_job_preview() {
		global $wp_query;

		$job_any_attachments = get_post_meta( get_the_ID(), 'preview_job_attchments', true );
		if ( wpj_post_has_attachments( $job_any_attachments ) ) { ?>

			<div class="ui segment">

				<div class="icon-before-title info-icon single-job-preview-title js-toggle-arrow">
					<h2><?php _e( "Job Preview",'wpjobster' ); ?></h2>
				</div>

				<div class="ui divider"></div>

				<div class="file-to-download">
					<?php wpj_list_attachments( $job_any_attachments, get_the_ID(), '', '', '', true, false ); ?>
				</div>

			</div>

		<?php }
	}
}

/* MAPS */
if ( ! function_exists( 'wpj_get_single_job_map_display' ) ) {
	function wpj_get_single_job_map_display() {
		global $wp_query;

		if ( get_option( 'wpjobster_location' ) == 'yes'
			&& get_option( 'wpjobster_location_display_map' ) == 'yes'
			&& get_post_meta( get_the_ID(), 'location_input', true ) ) {
			if ( get_option( 'wpjobster_location_display_map_user_choice' ) != "yes"
				|| ( get_option( 'wpjobster_location_display_map_user_choice' ) == "yes" && get_post_meta( get_the_ID(), "display_map", true ) == "yes" ) ) { ?>

				<div class="ui segment">
					<div class="icon-before-title info-icon single-job-map-title js-toggle-arrow">
						<h2><?php _e( "Map",'wpjobster' ); ?></h2>
					</div>

					<div class="ui divider"></div>

					<div id="job_map"></div>
				</div>

			<?php }
		}
	}
}

/* PACKAGES MOBILE */
if ( ! function_exists( 'wpj_get_single_job_packages_mobile' ) ) {
	function wpj_get_single_job_packages_mobile() {
		$pid = get_the_ID();
		$wpjobster_packages = get_option('wpjobster_packages_enabled');
		$packages = get_post_meta( $pid, 'job_packages', true );

		if ( $wpjobster_packages == 'yes' && $packages == 'yes' ) { ?>

			<div id="mobile-packages" class="mobile-packages"><?php

				if ( $wpjobster_packages == "yes" ) {

					$packages              = array( __( 'basic', 'wpjobster' ), __( 'standard', 'wpjobster' ), __( 'premium', 'wpjobster' ) );
					$package_name          = get_post_meta( $pid, 'package_name', true );
					$package_description   = get_post_meta( $pid, 'package_description', true );
					$package_max_days      = get_post_meta( $pid, 'package_max_days', true );
					$package_price         = get_post_meta( $pid, 'package_price', true );
					$package_revisions     = get_post_meta( $pid, 'package_revisions', true );
					$package_custom_fields = get_post_meta( $pid, 'package_custom_fields', true ); ?>

					<div class="ui pointing secondary pacakges-tabs menu">
						<?php $i = 0;
						foreach ( $packages as $key => $package ) { $i++; ?>
							<a class="<?php if ( $key == 1 ) echo 'active'; ?> item" data-tab="<?php echo $package; ?>">
								<span class="pck-tab-title"><?php echo ucfirst( $package ); ?></span>
							</a>
						<?php } ?>
					</div>

					<?php foreach ( $packages as $key_c => $package ) {
						$class = ( $key_c == 1 ) ? 'right labeled' : '';
						$display = ( $key_c == 1 ) ? 'block' : 'none'; ?>

						<div class="ui <?php if ( $key_c == 1 ) echo 'active'; ?> packages-mobile tab segment" data-tab="<?php echo $package; ?>">
							<div class="pck-name"><?php echo $package_name[$key_c]; ?></div>
							<div class="pck-price"><?php echo wpjobster_get_show_price($package_price[$key_c]); ?></div>
							<div class="pck-description"><?php echo wpj_apply_filter_to_string( $package_description[$key_c], false, 'joblistings' ); ?></div>
							<div class="pck-include">
								<div class="pck-include-title"><?php echo __( 'What\'s included?', 'wpjobster' ); ?></div>
								<ul class="pck-include-list"><?php

									if ( $package_custom_fields ) {
										foreach ( $package_custom_fields as $field ) {
											if ( $field[$package] == 'on' ) {
												echo '<li><i class="checkmark icon"></i>' . $field['name'] . '</li>';
											}
										}
									} ?>

									<li>
										<?php echo '<i class="checkmark icon"></i>' . __( 'Revisions', 'wpjobster') . ': ';
										if ( $package_revisions[$key_c] == 'unlimited' ) {
											echo __( 'Unlimited', 'wpjobster' );
										} elseif ( $package_revisions[$key_c] == 'no_revision' ) {
											echo '0';
										} else {
											echo $package_revisions[$key_c];
										} ?>
									</li>
									<li><?php
										echo '<i class="checkmark icon"></i>' . __( 'Delivery time', 'wpjobster') . ': ';
										echo sprintf( _n( '%d day', '%d days', $package_max_days[$key_c], 'wpjobster' ), $package_max_days[$key_c] );
									?></li>
								</ul>
							</div>

							<button class="ui large fluid icon button uppercase pck-mobile-select-package <?php echo $key_c . ' ' . $class; ?>">
								<?php echo __( 'Select this package', 'wpjobster' ); ?>
								<i class="checkmark icon" style="display: <?php echo $display; ?>"></i>
							</button>
						</div>
					<?php }
				} ?>
			</div>
		<?php }
	}
}

/* PACKAGES PC */
if ( ! function_exists( 'wpj_get_single_job_packages' ) ) {
	function wpj_get_single_job_packages() {
		$pid = get_the_ID();
		$wpjobster_packages = get_option( 'wpjobster_packages_enabled' );
		$packages = get_post_meta( $pid, 'job_packages', true );

		if ( $wpjobster_packages == 'yes' && $packages == 'yes' ) { ?>
			<div id="pc-packages" class="pc-packages">
				<?php if ( $wpjobster_packages == "yes" ) {
					$package_name          = get_post_meta( $pid, 'package_name', true );
					$package_description   = get_post_meta( $pid, 'package_description', true );
					$package_max_days      = get_post_meta( $pid, 'package_max_days', true );
					$package_price         = get_post_meta( $pid, 'package_price', true );
					$package_revisions     = get_post_meta( $pid, 'package_revisions', true );
					$package_custom_fields = get_post_meta( $pid, 'package_custom_fields', true ); ?>

					<table class="ui celled definition table">
						<thead>
							<tr>
								<th></th>
								<th id="pck-basic"><?php echo __( 'BASIC', 'wpjobster'); ?></th>
								<th id="pck-standard"><?php echo __( 'STANDARD', 'wpjobster'); ?></th>
								<th id="pck-premium"><?php echo __( 'PREMIUM', 'wpjobster'); ?></th>
							</tr>
						</thead>

						<tbody>
							<tr>
								<td><?php echo __( 'Name', 'wpjobster'); ?>
								</td>
								<?php if ( $package_name ) {
									foreach ( $package_name as $p_n_key => $p_name ) { ?>
										<td class="pck-name"><?php echo $p_name; ?></td>
									<?php }
								} ?>
							</tr>
							<tr>
								<td><?php echo __( 'Description', 'wpjobster'); ?>
								</td>
								<?php if ( $package_description ) {
									foreach ( $package_description as $p_d_key => $p_desc ) { ?>
										<td><?php echo wpj_apply_filter_to_string( $p_desc, false, 'joblistings' ); ?></td>
									<?php }
								} ?>
							</tr>
							<?php if( $package_custom_fields ) {
								foreach ( $package_custom_fields as $key => $value ) { ?>
									<tr class="sn-custom-fields">
										<td><?php echo $value['name']; ?>
										</td>
										<td class="pck-center">
											<?php if ( $value['basic'] == 'on' ) {
												echo '<i class="checkmark icon"></i>';
											} else {
												echo '<i class="remove icon"></i>';
											} ?>
										</td>
										<td class="pck-center">
											<?php if ( $value['standard'] == 'on' ) {
												echo '<i class="checkmark icon"></i>';
											} else {
												echo '<i class="remove icon"></i>';
											} ?>
										</td>
										<td class="pck-center">
											<?php if ( $value['premium'] == 'on' ) {
												echo '<i class="checkmark icon"></i>';
											} else {
												echo '<i class="remove icon"></i>';
											} ?>
										</td>
									</tr>
								<?php }
							} ?>
							<tr>
								<td><?php echo __( 'Delivery time', 'wpjobster'); ?>
								</td>
								<?php if ( $package_max_days ) {
									foreach ( $package_max_days as $p_md_key => $p_max_days ) { ?>
										<td class="pck-center"><?php echo sprintf( _n( '%d day', '%d days',$p_max_days, 'wpjobster' ), $p_max_days); ?></td>
									<?php }
								} ?>
							</tr>
							<tr>
								<td><?php echo __( 'Revisions', 'wpjobster'); ?>
								</td>
								<?php if ( $package_revisions ) {
									foreach ( $package_revisions as $p_r_key => $p_rev ) { ?>
										<td class="pck-center">
											<?php if ( $p_rev == 'unlimited' ) {
												echo __( 'Unlimited', 'wpjobster' );
											} elseif ( $p_rev == 'no_revision' ) {
												echo '0';
											} else {
												echo $p_rev;
											} ?>
										</td>
									<?php }
								} ?>
							</tr>
							<tr>
								<td><?php echo __( 'Price', 'wpjobster'); ?>
								</td>
								<?php if ( $package_max_days ) {
									foreach ( $package_price as $p_p_key => $p_price ) { ?>
										<td data-price="<?php echo wpjobster_formats_special_exchange( $p_price ); ?>" class="pck-center pck-price"><?php echo wpjobster_get_show_price( $p_price ); ?></td>
									<?php }
								} ?>
							</tr>
							<tr>
								<td><?php echo __( 'Order', 'wpjobster'); ?>
								</td>
								<?php if ( $package_max_days ) {
									foreach ( $package_price as $p_p_key => $p_price ) { ?>
										<td class="pck-center pck-order">
											<div class="ui radio checkbox" style="display: none">
												<input type="radio" name="package_price" class="package_price">
												<label></label>
											</div>
											<button class="ui fluid primary button uppercase"><?php echo __( 'Select', 'wpjobster' ); ?></button>
										</td>
									<?php }
								} ?>
							</tr>
						</tbody>
					</table>
				<?php } ?>
			</div>
		<?php }
	}
}

/* BUY BTN - ORDER ADDITIONAL */
if ( ! function_exists( 'get_single_job_order_additional' ) ) {
	function get_single_job_order_additional( $page = '' ) {
		global $wp_query, $post, $current_user;

		$pid  = $page == 'purchase_this' ? WPJ_Form::get( 'jobid', get_the_ID() ) : get_the_ID();
		$post = $page == 'purchase_this' ? get_post( WPJ_Form::get( 'jobid', get_the_ID() ) ) : $post;
		$allow_extra = get_option( 'wpjobster_purchase_this_extra_enabled' ) == 'yes' || $page == 'single_job' ? true : false;

		$current_user = wp_get_current_user();
		$uid          = $post->post_author;

		$author_vacation = get_user_vacation( $uid );
		if ( $author_vacation && $author_vacation['mode'] == 1 ) {
			$author_vacation_reason = $author_vacation['reason'];
		} else {
			$author_vacation = false;
		}

		$prc = get_post_meta( $pid, "price", true );
		$prc = apply_filters( 'wpjobster_single_job_price', $prc, $pid );

		$extra_job_add = array();
		$h   = 0;
		$sts = 0;

		// Create array for "Extras" content
		if ( wpj_get_user_feature_status( 'wpjobster_enable_extra', 'wpjobster_subscription_noof_extras_enabled' ) != "no" ) {
			$sts = wpj_get_user_feature_value( 'extras', 'noof_extras', 0, $uid );
		}

		$extra_price = 0;
		for ( $k = 1; $k <= $sts; $k++ ) {
			$extra_price   = get_post_meta( get_the_ID(), 'extra' . $k . '_price',   true );
			$extra_content = get_post_meta( get_the_ID(), 'extra' . $k . '_content', true );
			$extra_enabled = get_post_meta( get_the_ID(), 'extra' . $k . '_enabled', true );

			if ( ! empty( $extra_price ) && ! empty( $extra_content ) ) {
				$extra_job_add[$h]['content']  = $extra_content;
				$extra_job_add[$h]['price']    = $extra_price;
				$extra_job_add[$h]['extra_nr'] = $k;
				$extra_job_add[$h]['enabled']  = $extra_enabled;
				$h++;
			}
		}

		$author_vacation = apply_filters( 'wpj_author_vacation_filter', $author_vacation, $pid );

		if ( ! $author_vacation ) {

			$wpjobster_enable_site_tax = get_option( 'wpjobster_enable_site_tax' );
			if ( get_post_meta( $pid, "active", true ) == 1 || get_post_type( $pid ) == "offer" ) {

				// Order Additional - Price Separators Vars
				$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
				$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );

				$wpjobster_decimal_sum_separator = get_option( 'wpjobster_decimal_sum_separator' );
				if ( empty( $wpjobster_decimal_sum_separator ) ) $wpjobster_decimal_sum_separator = '.';

				$wpjobster_thousands_sum_separator = get_option( 'wpjobster_thousands_sum_separator' );
				if ( empty( $wpjobster_thousands_sum_separator ) ) $wpjobster_thousands_sum_separator = ',';

				// Order Additional - Shipping Vars
				$shipping = get_post_meta( get_the_ID(), 'shipping', true );
				if ( $shipping == '' ) $shipping = 0;

				// Order Additional - Processing fees & Tax Vars
				if ( $wpjobster_enable_site_tax == 'yes' ) {
					$cur_uid      = get_current_user_id();
					$country_code = get_user_meta( $cur_uid, "country_code", true );

					$wpjobster_tax_percent = wpjobster_get_tax( $country_code );

					$wpjobster_enable_processingfee_tax = get_option( 'wpjobster_enable_processingfee_tax' );
					$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
					if ( $wpjobster_enable_processingfee_tax == 'yes' && $buyer_processing_fees_enabled != 'disabled' ) {
						$wpjobster_enable_processingfee_tax = 'yes';
					} else {
						$wpjobster_enable_processingfee_tax = 'no';
					}
				} else {
					$wpjobster_tax_percent = 0;
					$wpjobster_enable_processingfee_tax = 'no';
				}

				$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
				if ( $buyer_processing_fees_enabled != 'disabled' ) {
					$buyer_processing_fees = wpjobster_get_site_processing_fee( $prc, $extra_price, $shipping );
					update_user_meta( $uid, 'wpjobster_buyer_chargable_fees', $buyer_processing_fees );
				} else {
					$buyer_processing_fees = 0;
				}

				// Order Additional - Extras Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_multiples', 'wpjobster_subscription_job_multiples_enabled' ) == "yes" ) {
					$job_amount_max = wpj_get_user_feature_value( 'jobmultiples', 'job_multiples', '', $uid );

					if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_multiples', 'wpjobster_subscription_extra_multiples_enabled' ) == "yes" ) {
						$extra_amount_max = wpj_get_user_feature_value( 'extramultiples', 'extra_multiples', '', $uid );
					} else {
						$extra_amount_max = 1;
					}
				} else {
					$job_amount_max = 1;
					$extra_amount_max = 1;
				}

				// Order Additional - Extra fast Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_fast_delivery', 'wpjobster_subscription_ex_fast_delivery_enabled' ) != "no" ) {
					$extra_fast_enabled       = get_post_meta( $pid, 'extra_fast_enabled', true );
					$fast_delivery_amount_max = wpj_get_user_feature_value( 'fast_delivery_multiples', 'fast_del_multiples', '', $uid );
				} else {
					$extra_fast_enabled       = '';
					$fast_delivery_amount_max = 1;
				}

				// Order Additional - Extra revision Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_additional_revision', 'wpjobster_subscription_additional_revision_enabled' ) != "no" ) {
					$extra_revision_enabled = get_post_meta( $pid, 'extra_revision_enabled', true );
					$add_rev_amount_max     = wpj_get_user_feature_value( 'add_rev_multiples', 'add_rev_multiples', '', $uid );
				} else {
					$extra_revision_enabled = '';
					$add_rev_amount_max     = 1;
				} ?>

				<div class="order-extras cf">
					<?php if ( $page == 'single_job' ) {
						// Order Additional - Title
						$force_allow = apply_filters( 'wpj_force_allow_filter', false, 'single_job' );
						if ( $extra_fast_enabled || $extra_revision_enabled || $extra_job_add || $shipping || $buyer_processing_fees || $wpjobster_enable_site_tax == 'yes' || $force_allow ) { ?>

							<div class="icon-before-title info-icon sigle-job-additional-title js-toggle-arrow">
								<h2><?php _e( "Order Additional", "wpjobster" ); ?></h2>
							</div>

							<div class="ui divider"></div>

						<?php }
					} ?>

					<form id="purchase-form" method="post" name="myFormPurchase2" action="<?php echo get_bloginfo( 'url' ) . '/?jb_action=purchase_this&jobid=' . $pid; ?>" class="cf">
						<input type="hidden" name="purchaseformvalidation" value="ok" />
						<input type="hidden" name="pck_price_val" class="pck_price_val" value="<?php echo WPJ_Form::post( 'pck_price_val', '' ); ?>" />
						<input type="hidden" name="pck_deliv_val" class="pck_deliv_val" />

						<div class="order-extras-inside">
							<ul class="job-order-items">
								<?php
								$quantity = wpj_get_user_feature_status( 'wpjobster_enable_multiples', 'wpjobster_subscription_job_multiples_enabled' );

								$is_price_type = false;
								if ( get_post_meta( $pid, 'price_type', true ) && get_post_meta( $pid, 'price_type', true ) != 'fixed' ) {
									$is_price_type = true;
								}

								if ( $page == 'single_job' ) { ?>

									<!-- Order Additional - Quantity -->
									<li class="cf">
										<label class="main_amount_box">
											<?php if ( $is_price_type ) { ?>
												<span><?php echo apply_filters( 'wpj_price_type_filter', sprintf( __( '%s Rate', 'wpjobster' ), ucfirst( wpjobster_translate_string( get_post_meta( $pid, 'price_type', true ) ) ) ), $pid ); ?></span>
											<?php } else { ?>
												<span><?php _e( 'Job Quantity', 'wpjobster' ); ?></span>
											<?php } ?>

											<span class="extra-price-inside extra-price-resp"><?php echo wpjobster_get_show_price( $prc ); ?></span>

											<?php if ( ! $is_price_type ) { echo '<br>'; } ?>

											<?php if ( $quantity == 'yes' && $job_amount_max > 1 ) {
												if ( $is_price_type ) { ?>
													<br />
													<span class="sn-job-rate-text">

														<?php echo sprintf( __( 'Number of %s:', 'wpjobster' ), ucfirst( wpjobster_translate_string( wpj_change_rate_word( get_post_meta( $pid, 'price_type', true ), 'plural' ) ) ) ); ?>

													</span>
												<?php } ?>
												<span class="amount_section" <?php if ( $is_price_type ) { echo 'style="margin-top: 5px;"'; } ?>>
													<a href="#" class="amount_rmv">&minus;</a>
													<input type="text" name="main_value_inp" class="main_value_inp current_amount main_amount" data-max="<?php echo $job_amount_max; ?>" value="1">
													<a href="#" class="amount_add">+</a>
												</span>
											<?php } ?>
										</label>
									</li>

								<?php } elseif ( $page == 'purchase_this' ) {

									// PURCHASE THIS PAGE ?>
									<div class="ui two column stackable grid">

										<?php do_action( 'wpjobster_before_message_purchase_gig_job', $pid ); ?>

										<div class="twelve wide column">
											<div class="flex-parent flex-thumb-text">
												<div>
													<div class="job-avatar">
														<img width="100" height="100" class="round-avatar" src="<?php echo wpjobster_get_job_image($pid, 101, 101); ?>" />
													</div>
												</div>
												<div>
													<div class="job-title-purchase">
														<h2><?php wpj_purchase_this_show_job_title(); ?></h2>
													</div>
													<div class="payment-job-categories">
														<?php wpj_purchase_this_show_job_categories(); ?>
													</div>
												</div>
											</div>
										</div>
										<div class="four wide column">
											<?php $main_amount = WPJ_Form::post( 'main_value_inp', 1 ); ?>
											<div class="job-price-purchase payment-main-item" data-mainamount="<?php echo $main_amount; ?>">
												<?php wpj_purchase_this_show_job_price();

												if ( isset( $_GET['tips'] ) ) {
													echo __( ' tip', 'wpjobster' );
												} elseif ( isset( $_GET['custom_extra'] ) ) {
													echo apply_filters( 'wpj_custom_extra_lower_string_filter', __( ' custom extra', 'wpjobster' ) );
												} elseif ( $is_price_type ) {
													echo ' ' . wpjobster_translate_string( get_post_meta( $pid, 'price_type', true ) );
												}

												if ( $quantity == 'yes' ) { ?>
													<div class="purchase-this-quantity">
														<label class="main_amount_box">
															<?php if ( $quantity == 'yes' ) {
																$value_job_quantity = $main_amount ? 'value=' . $main_amount : 1; ?>

																<span class="amount_section">
																	<?php if ( $is_price_type ) {
																		echo '<span>' . ucfirst( wpj_change_rate_word( wpjobster_translate_string( get_post_meta( $pid, 'price_type', true ) ), 'plural' ) ) . ':&nbsp;&nbsp;</span>';
																	}
																	if ( $allow_extra ) { ?><a href="#" class="amount_rmv">&minus;</a><?php } ?>
																	<input type="text" name="main_value_inp" class="main_value_inp current_amount main_amount" <?php if ( !$allow_extra ) { echo 'disabled'; } ?>  data-max="<?php echo $job_amount_max; ?>" <?php echo $value_job_quantity; ?> />
																	<?php if ( $allow_extra ) { ?><a href="#" class="amount_add">+</a><?php } ?>
																</span>
															<?php } ?>
														</label>
													</div>
												<?php } ?>

											</div>
										</div>
									</div>

									<?php do_action( 'list_request_custom_offer_details', $pid, 'send', 'purchase_this' ); ?>

									<div class="ui hidden divider"></div>

									<?php // END - PURCHASE THIS PAGE
								}

								// Order Additional - Extra Fast Delivery
								if ( $extra_fast_enabled && $fast_delivery_amount_max > 0 ) {
									$extra_fast_price  = get_post_meta($pid, 'extra_fast_price', true);
									$extra_fast_chk    = WPJ_Form::post( 'extrafast', '' );
									$checked_fast      = $extra_fast_chk ? 'checked' : '';
									$checked_fast_inp  = $extra_fast_chk ? 'checked=""' : '';
									$extra_fast_amount = WPJ_Form::post( 'extrafast', 1 );

									if ( $allow_extra || $extra_fast_chk ) { ?>
										<li class="cf extra_nb_fast">
											<label>
												<div class="ui <?php echo $checked_fast; ?> checkbox <?php if ( !$allow_extra ) { echo 'disabled'; } ?>">
													<input class="uzextracheck chk_extrafast" type="checkbox" name="extrafast" id="extrafast" value="1" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> data-price="<?php echo wpjobster_formats_special_exchange($extra_fast_price); ?>" <?php echo $checked_fast_inp; ?> />
													<label></label>
												</div>

												<div class="wpj-buy-extra-details extra-item" data-extranr="fast" data-extraamount="<?php echo $extra_fast_amount; ?>">
													<span><?php echo __( 'Extra fast delivery', 'wpjobster' ); ?></span>

													<span class="extra-price-inside extra-price-resp"><?php echo wpjobster_get_show_price($extra_fast_price); ?></span>
													<br>
													<span class="description"><?php $max_deliv = get_post_meta($pid, 'extra_fast_days', true); echo sprintf( _n( ' (%d day)', '(%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>

													<?php if ( $fast_delivery_amount_max > 1 ) {
														$value_fast = $extra_fast_amount ? 'value=' . $extra_fast_amount : ''; ?>

														<span class="amount_section" data-amountnb="fast">
															<?php if ( $allow_extra ) { ?><a href="#" class="amount_rmv">&minus;</a><?php } ?>
															<input type="text" <?php echo $value_fast; ?> data-max="<?php echo $fast_delivery_amount_max; ?>" class="current_amount hid_extrafast" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> name="hid_extrafast" />
															<?php if ( $allow_extra ) { ?><a href="#" class="amount_add">+</a><?php } ?>
														</span>
													<?php } ?>
												</div>
											</label>
										</li>
									<?php }
								}

								// Order Additional - Additional Revision
								if ( $extra_revision_enabled && $add_rev_amount_max > 0 ) {
									$extra_revision_multiples_enabled = get_post_meta($pid, 'extra_revision_multiples_enabled', true);
									$extra_revision_price             = get_post_meta($pid, 'extra_revision_price', true);
									$extra_revision_chk               = WPJ_Form::post( 'extrarevision', '' );
									$checked_rev                      = $extra_revision_chk ? 'checked' : '';
									$checked_rev_inp                  = $extra_revision_chk ? 'checked=""' : '';
									$extra_revision_amount            = WPJ_Form::post( 'extrarevision', 1 );

									if ( $allow_extra || $extra_revision_chk ) { ?>
										<li class="cf extra_nb_revision">
											<label>
												<div class="ui <?php echo $checked_rev; ?> checkbox <?php if ( !$allow_extra ) { echo 'disabled'; } ?>">
													<input class="uzextracheck chk_extrarevision" type="checkbox" name="extrarevision" id="extrarevision" value="1" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> data-price="<?php echo wpjobster_formats_special_exchange($extra_revision_price); ?>" <?php echo $checked_rev_inp; ?> />
													<label></label>
												</div>

												<div class="wpj-buy-extra-details extra-item" data-extranr="revision" data-extraamount="<?php echo $extra_revision_amount; ?>">
													<span><?php echo __( 'Extra revision', 'wpjobster' ); ?></span>

													<span class="extra-price-inside extra-price-resp"><?php echo wpjobster_get_show_price($extra_revision_price); ?></span>
													<br>
													<span class="description"><?php $max_deliv = get_post_meta($pid, 'extra_revision_days', true); echo sprintf( _n( '(+%d day)', '(+%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>
													<?php if ( $add_rev_amount_max > 1 && get_post_meta( $pid, 'extra_revision_multiples_enabled', true ) ) {
														$value_revision = $extra_revision_amount ? 'value=' . $extra_revision_amount : ''; ?>

														<span class="amount_section" data-amountnb="revision">
															<?php if ( $allow_extra ) { ?><a href="#" class="amount_rmv">&minus;</a><?php } ?>
															<input <?php echo $value_revision; ?> type="text" class="current_amount hid_extrarevision" data-max="<?php echo $add_rev_amount_max; ?>" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> name="hid_extrarevision" />
															<?php if ( $allow_extra ) { ?><a href="#" class="amount_add">+</a><?php } ?>
														</span>
													<?php } ?>
												</div>
											</label>
										</li>
									<?php }
								}

								// Order Additional - Extras
								$i = 0;
								if ( $extra_job_add ) {
									foreach ( $extra_job_add as $extra_job_add_item ) { $i++;
										// update values for older existing jobs
										if ( ! get_post_meta( $pid, "max_days_ex_" . $i, true ) ) {
											update_post_meta( $pid, 'max_days_ex_' . $i, "instant" );
										}

										$enabled = get_post_meta( $pid, 'extra' . $i . '_extra_enabled', false );
										if ( isset( $enabled[0] ) ) {
											$enabled = $enabled[0];
										} else {
											update_post_meta( $pid, 'extra' . $i . '_extra_enabled', true );
											$enabled = 1;
										}

										if ( $enabled ) {
											$extra_chk         = WPJ_Form::post( 'extra' . $i, '' );
											$checked_extra     = $extra_chk ? 'checked' : '';
											$checked_extra_inp = $extra_chk ? 'checked=""' : '';
											$extra_amount      = WPJ_Form::post( 'extra' . $i, 1 );

											if ( $allow_extra || $extra_chk ) { ?>
												<li class="cf extralibot extra_nb_<?php echo $extra_job_add_item['extra_nr']; ?>">
													<label>
														<div class="ui <?php echo $checked_extra; ?> checkbox <?php if ( !$allow_extra ) { echo 'disabled'; } ?>">
															<input class="uzextracheck chk_extra<?php echo $extra_job_add_item['extra_nr']; ?>" type="checkbox" name="extra<?php echo $extra_job_add_item['extra_nr']; ?>" id="extra<?php echo $extra_job_add_item['extra_nr']; ?>" value="1" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> data-price="<?php echo wpjobster_formats_special_exchange( $extra_job_add_item['price'] ); ?>" <?php echo $checked_extra_inp; ?> />
															<label></label>
														</div>

														<div class="wpj-buy-extra-details extra-item" data-extranr="<?php echo $i; ?>" data-extraamount="<?php echo $extra_amount; ?>">
															<span><?php echo wpj_apply_filter_to_string( $extra_job_add_item['content'], false, 'joblistings' ); ?></span>

															<span class="extra-price-inside extra-price-resp"><?php echo wpjobster_get_show_price( $extra_job_add_item['price'] ); ?></span>
															<br>
															<span class="description"><?php $max_deliv = get_post_meta($pid, 'max_days_ex_'.$i, true); echo sprintf( _n( '(+%d day)', '(+%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>
															<?php if ( $quantity == 'yes' && $extra_job_add_item['enabled'] && $extra_amount_max > 1 ) {
																$value_extra = $extra_amount ? 'value=' . $extra_amount : ''; ?>

																<span class="amount_section" data-amountnb="<?php echo $extra_job_add_item['extra_nr']; ?>">
																	<?php if ( $allow_extra ) { ?><a href="#" class="amount_rmv">&minus;</a><?php } ?>
																	<input <?php echo $value_extra; ?> type="text" data-amountnb="<?php echo $extra_job_add_item['extra_nr']; ?>" class="current_amount hid_extra<?php echo $extra_job_add_item['extra_nr']; ?>" <?php if ( !$allow_extra ) { echo 'disabled'; } ?> name="hid_extra<?php echo $extra_job_add_item['extra_nr']; ?>" data-max="<?php echo $extra_amount_max; ?>" />
																	<?php if ( $allow_extra ) { ?><a href="#" class="amount_add">+</a><?php } ?>
																</span>
															<?php } ?>
														</div>
													</label>

													<?php do_action( 'wpj_after_extra_display', $pid, $i ); ?>

												</li>
											<?php }
										}
									}
								} ?>
							</ul>

							<?php do_action( 'list_before_shipping_price', $page );

							// Order Additional - Shipping
							if ( $shipping ) {
								if( get_option( 'wpjobster_enable_shipping' ) != 'no' ) { ?>
									<div class="js-shipping shipping">
										<?php _e( "Shipping:", 'wpjobster' ); ?>
										<span class="extra-price-inside"><?php echo wpjobster_get_show_price( $shipping ); ?></span>
									</div>
								<?php }
							}

							// Order Additional - Processing fees
							if ( $buyer_processing_fees ) {
								if ( get_option( 'wpjobster_enable_buyer_processing_fees' ) != 'disabled' ) {
									if ( isset( $buyer_processing_fees ) ) { ?>
										<div class="js-processingfees shipping">
											<?php wpjobster_display_processing_fees_label(); ?>
											<span class="processingfee-amount extra-price-inside"><?php echo wpjobster_get_show_price( $buyer_processing_fees ); ?></span>
										</div>
									<?php }
								}
							}

							// Order Additional - Tax
							do_action( 'list_before_tax_price', $page );

							$tax_amount = wpjobster_get_site_tax( $prc, $extra_price, $shipping, $buyer_processing_fees );
							if ( $tax_amount ){
								if ( isset( $wpjobster_enable_site_tax ) && $wpjobster_enable_site_tax == 'yes' ) {
									$wpjobster_enable_processingfee_tax = get_option( 'wpjobster_enable_processingfee_tax' );
									if ( $wpjobster_enable_processingfee_tax == 'yes' && $buyer_processing_fees_enabled != 'disabled' ) {
										$wpjobster_enable_processingfee_tax = 'yes';
									} ?>

									<div class="shipping js-processingtax"><?php echo sprintf( __( 'Tax (%s%s)', 'wpjobster' ), $wpjobster_tax_percent, '&#37;' ); ?>: <span class="tax-amount extra-price-inside"><?php echo wpjobster_get_show_price( $tax_amount ); ?></span></div>
									<?php
								} else {
									$wpjobster_tax_percent = 0;
									$wpjobster_enable_processingfee_tax = "no";
								}
							}

							do_action( 'list_after_tax_price', $prc, $page ); ?>

						</div>

						<?php $is_post_author = $post->post_author == $current_user->ID ? true : false;

						// Order Additional - Buy button
						$submit_data = apply_filters( 'wpj_buy_job_submit_form_filter', 'data-submit=""', 'login-link', $post->post_author );
						if ( is_user_logged_in() ) {
							$submit_action = isset( $submit_data['action'] ) ? $submit_data['action'] : 'data-submit=""';
							$submit_class  = isset( $submit_data['class'] ) ? $submit_data['class'] : '';
						} else {
							$submit_action = isset( $submit_data['action'] ) ? $submit_data['action'] : '';
							$submit_class  = isset( $submit_data['class'] ) ? $submit_data['class'] : 'login-link';
						}

						if ( $page == 'single_job' ) { ?>
							<div class="cf">

								<a data-pid="<?php echo $pid; ?>" href="" class="ui primary <?php if ( $is_post_author ) echo 'disabled'; ?> huge fluid button <?php echo $submit_class; ?> uppercase <?php if ( !$extra_job_add && !$shipping ) echo ' no-arrow'; ?>" <?php echo $submit_action; ?>>

									<?php echo $is_post_author ? __( 'This is your own job', 'wpjobster' ) : __( 'Buy Now For', 'wpjobster' ); ?>
									<strong class="total"

										data-price                 = "<?php echo wpjobster_formats_special_exchange( $prc ); ?>"
										data-shipping              = "<?php echo wpjobster_formats_special_exchange( $shipping ); ?>"
										data-cur                   = "<?php echo wpjobster_get_currency(); ?>"

										data-symbol                = "<?php echo wpjobster_get_currency_symbol( wpjobster_get_currency() ); ?>"
										data-position              = "<?php echo $wpjobster_currency_position; ?>"
										data-space                 = "<?php echo $wpjobster_currency_symbol_space; ?>"
										data-decimal               = "<?php echo $wpjobster_decimal_sum_separator; ?>"
										data-thousands             = "<?php echo $wpjobster_thousands_sum_separator; ?>"
										data-decimaldisplay        = "<?php echo get_option( 'wpjobster_decimals' ); ?>"

										data-processingfeesenable  = "<?php echo get_option( 'wpjobster_enable_buyer_processing_fees' ); ?>"
										data-processingfeesfixed   = "<?php echo wpjobster_formats_special_exchange( get_option( 'wpjobster_buyer_processing_fees' ) ); ?>"
										data-processingfeespercent = "<?php echo get_option( 'wpjobster_buyer_processing_fees_percent' ); ?>"

										data-processingfeetax      = "<?php echo $wpjobster_enable_processingfee_tax; ?>"
										data-tax                   = "<?php echo $wpjobster_tax_percent; ?>"
										data-zerowithfree          = "<?php echo get_option( 'wpjobster_replace_zero_with_free' ); ?>"
										data-freestr               = "<?php echo __( "Free", "wpjobster" ); ?>"

									>
										<?php
										if( $prc > 0 ) {
											echo wpjobster_get_show_price( $prc );
										} else {
											if ( wpj_bool_option( 'wpjobster_replace_zero_with_free' ) ) {
												_e( 'Free', 'wpjobster' );
											} else {
												echo wpjobster_get_show_price( $prc );
											}
										}
										?>
									</strong>
								</a>
							</div>

						<?php } elseif ( $page == 'purchase_this' ) { ?>

							<div class="ui two column stackable grid">
								<div class="twelve wide column payment-gateways">
									<?php wpj_display_gateway_payment_button( 'job_purchase', $pid ); ?>
								</div>

								<div class="four wide column payment-total">
									<div class="total-payment-purchase">
										<?php echo __( 'Total:','wpjobster' ); ?>
										<strong class="total"
											data-price                 = "<?php echo wpjobster_formats_special_exchange( $prc ); ?>"
											data-shipping              = "<?php echo wpjobster_formats_special_exchange( $shipping ); ?>"
											data-cur                   = "<?php echo wpjobster_get_currency(); ?>"

											data-symbol                = "<?php echo wpjobster_get_currency_symbol( wpjobster_get_currency() ); ?>"
											data-position              = "<?php echo $wpjobster_currency_position; ?>"
											data-space                 = "<?php echo $wpjobster_currency_symbol_space; ?>"
											data-decimal               = "<?php echo $wpjobster_decimal_sum_separator; ?>"
											data-thousands             = "<?php echo $wpjobster_thousands_sum_separator; ?>"
											data-decimaldisplay        = "<?php echo get_option( 'wpjobster_decimals' ); ?>"

											data-processingfeesenable  = "<?php echo get_option( 'wpjobster_enable_buyer_processing_fees' ); ?>"
											data-processingfeesfixed   = "<?php echo wpjobster_formats_special_exchange( get_option( 'wpjobster_buyer_processing_fees' ) ); ?>"
											data-processingfeespercent = "<?php echo get_option( 'wpjobster_buyer_processing_fees_percent' ); ?>"

											data-processingfeetax      = "<?php echo $wpjobster_enable_processingfee_tax; ?>"
											data-tax                   = "<?php echo $wpjobster_tax_percent; ?>"
											data-zerowithfree          = "<?php echo get_option( 'wpjobster_replace_zero_with_free' ); ?>"
											data-freestr               = "<?php echo __( "Free", "wpjobster" ); ?>"
										>
											<?php
											if( $prc > 0 ) {
												echo wpjobster_get_show_price( $prc );
											} else {
												if ( wpj_bool_option( 'wpjobster_replace_zero_with_free' ) ) {
													_e( 'Free', 'wpjobster' );
												} else {
													echo wpjobster_get_show_price( $prc );
												}
											}
											?>
										</strong>
									</div>
								</div>
							</div>
						<?php } ?>
					</form>
				</div>
			<?php } else { ?>
				<span class="ui huge fluid uppercase disabled button"><?php _e( 'Job deactivated', 'wpjobster' ); ?></span>
			<?php } ?>
		<?php } elseif ( $author_vacation ) { ?>
			<span class="ui huge fluid uppercase disabled button"><?php echo $author_vacation_reason; ?></span>
		<?php }
	}
}

/* FEEDBACK */
if ( ! function_exists( 'wpj_get_single_job_feedback' ) ) {
	function wpj_get_single_job_feedback() {

		global $wpdb, $wp_query, $post, $current_user;

		$total_per_load = 3;
		$pid            = get_the_ID();
		$current_user   = wp_get_current_user();
		$uid            = $post->post_author;


		$query_feedback_total = "
			SELECT DISTINCT *, ratings.datemade datemade
			FROM {$wpdb->prefix}job_ratings ratings, {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
			WHERE posts.ID=orders.pid
			AND ( posts.ID={$pid}
				OR ratings.pid IN (
					SELECT custom_offer
					FROM {$wpdb->prefix}job_pm pm, {$wpdb->prefix}job_ratings jr
					WHERE associate_job_id = {$pid}
					AND custom_offer = jr.pid
				)
			)
			AND ratings.awarded='1'
			AND orders.id=ratings.orderid
			AND posts.post_author={$uid}
			ORDER BY datemade DESC
		";
		$r_feedback_total = $wpdb->get_results( $query_feedback_total );
		$r_seller_total   = count( $r_feedback_total );

		$query = "
			SELECT DISTINCT *, ratings.datemade datemade
			FROM {$wpdb->prefix}job_ratings ratings, {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
			WHERE posts.ID=orders.pid
			AND ( posts.ID={$pid}
				OR ratings.pid IN (
					SELECT custom_offer
					FROM {$wpdb->prefix}job_pm pm, {$wpdb->prefix}job_ratings jr
					WHERE associate_job_id = {$pid}
					AND custom_offer = jr.pid
				)
			)
			AND ratings.awarded='1'
			AND orders.id=ratings.orderid
			AND posts.post_author={$uid}
			ORDER BY datemade DESC
			LIMIT {$total_per_load}
		";
		$r = $wpdb->get_results ( $query );

		if ( count( $r ) > 0 ) { ?>
			<input type="hidden" id="uid" value="<?php echo $uid ?>">
			<input type="hidden" id="pid" value="<?php echo $pid ?>">
			<input type="hidden" id="total_per_load" value="<?php echo $total_per_load ?>">

			<div class="ui segment">
				<div class="icon-before-title single-job-feedback-title js-toggle-arrow">
					<h2><?php _e( "Feedback",'wpjobster' ); ?></h2>
				</div>

				<div class="ui divider"></div>

				<div style="" class="feedbacks_box_all">
					<div class="feedbacks_box visible_feedbacks_box first_feedbacks_box" id="all-feedback-box" style="display:block">

						<?php $cnt = 0; // counter/incrementor
						foreach ( $r as $row ) {
							$cnt++;
							$post  = $row->pid;
							$post  = get_post( $post );
							$user2 = get_userdata( $row->uid );
							// first two are visible ?>

							<div class="feed cf">
								<div>
									<a href="" class="left p10r job-feedback-picture <?php echo ! $row->reason ? 'middle-align' : ''; ?>">
										<img width="45" height="45" border="0" class="round-avatar" src="<?php echo wpjobster_get_avatar( $user2->ID, 46, 46 ); ?>" />
									</a>

									<div class="left job-feedback-content flex-parent wpj-review-work-sample-wrapper">

										<div>
											<div class="left cb p5b w100">
												<a class="left" href="<?php echo wpj_get_user_profile_link( $user2->user_login ); ?>"><?php echo wpj_get_user_display_type( $user2->ID ); if( $row->pid != $pid ){ echo " <span class='lighter light_grey'>(custom job)</span> "; } ?></a>
												<div class="left p10l">
													<div class="single-job-rating-stars">
														<?php echo wpjobster_show_stars_our_of_number( $row->grade ); ?>
													</div>
												</div>
												<span class="grey-time p10l right">
													<?php echo wpj_date( get_option( 'date_format' ), $row->datemade ); ?>
												</span>
											</div>

											<div class="cb">
												<p><?php echo wpj_apply_filter_to_string( stripslashes( $row->reason ), false, 'joblistings' ); ?></p>
											</div>
										</div>

										<?php if ( isset( $row->sample ) ) { wpj_display_work_sample_preview( $row->sample ); } ?>
									</div>
								</div>
							</div>

							<?php $query_seller = "
								SELECT DISTINCT *, ratings.datemade, orders.uid AS buyer_id, datemade
								FROM {$wpdb->prefix}job_ratings_by_seller ratings, {$wpdb->prefix}job_orders orders, {$wpdb->prefix}posts posts
								WHERE posts.ID=orders.pid
								AND ( posts.ID={$pid}
									OR ratings.pid IN (
										SELECT custom_offer
										FROM {$wpdb->prefix}job_pm pm, {$wpdb->prefix}job_ratings jr
										WHERE associate_job_id = {$pid}
										AND custom_offer = jr.pid
									)
								)
								AND ratings.awarded='1'
								AND orders.id=ratings.orderid
								AND posts.post_author={$uid}
								AND orders.id={$row->orderid}
								ORDER BY datemade DESC
								LIMIT 3
							";

							$r_seller = $wpdb->get_results( $query_seller );
							if ( $r_seller ) {
								$row_seller = $r_seller[0];
								$user3 = get_userdata( $uid ); ?>

								<!-- Feedback by seller -->
								<div class="feed cf feedback-answer">
									<div>
										<a href="" class="left p10r job-feedback-picture"><img width="35" height="35" border="0" class="round-avatar" src="<?php echo wpjobster_get_avatar($user3->ID,46,46); ?>" /></a>
										<div class="left job-feedback-content">
											<div class="left cb p5b w100">
												<a  class="left" href="<?php echo wpj_get_user_profile_link( $user3->user_login ); ?>"><?php echo wpj_get_user_display_type( $user3->ID ); if( $row_seller->pid != $pid ){ echo " <span class='lighter light_grey'>(custom job)</span> "; } ?></a>
												<div class="left p10l">
													<div class="single-job-rating-stars">
														<?php echo wpjobster_show_stars_our_of_number($row_seller->grade); ?>
													</div>
												</div>
												<span class="grey-time p10l right"></span>
											</div>

											<div class="cb">
												<p><?php echo wpj_apply_filter_to_string( stripslashes( $row_seller->reason ), false, 'joblistings' ); ?></p>
											</div>
										</div>
									</div>
								</div>

							<?php }// if seller rating
						} ?>

					</div><!-- close feedbacks_box -->

				</div><!-- close feedbacks_box_all -->

				<!-- show load more button only if exists more than 2 feedbacks -->
				<?php if( $r_seller_total > $total_per_load ) { ?>

					<a data-rel='3' href="javascript:void(0)" id="load-more-feedback" class="btn w100 show_more-notneeeded bigger grey_btn">
						<?php _e( "Load More Feedback", 'wpjobster' ); ?>
					</a>

				<?php } ?>

			</div>

		<?php }

		wp_reset_query();
		wp_reset_postdata();

	}
}

/* RECOMMENDED JOBS */
if ( ! function_exists( 'wpj_get_single_job_other_jobs' ) ) {
	function wpj_get_single_job_other_jobs() {
		global $wp_query, $post;

		$the_id = get_the_ID();
		$uid    = $post->post_author;
		$author = get_userdata( $uid );

		$active = array(
			'key'     => 'active',
			'value'   => "1",
			'compare' => '='
		);

		$closed = array(
			'key'     => 'closed',
			'value'   => "0",
			'compare' => '='
		);

		$args = array(
			'author'         => $uid,
			'meta_query'     => array( $closed, $active ),
			'posts_per_page' => 3,
			'paged'          => 1,
			'post_type'      => 'job',
			'order'          => "DESC" ,
			'orderby'        =>"date",
			'post__not_in'   => array( $the_id )
		);

		$the_query = new WP_Query( $args );

		if ( $the_query->have_posts() ) { ?>

			<div class="ui segment">
				<div class="single-job-other-jobs-title js-toggle-arrow">
					<h2><?php echo sprintf( __( "Other jobs by %s", 'wpjobster' ), wpj_get_user_display_type( $author->ID )  ); ?></h2>
				</div>

				<div class="ui divider"></div>

				<?php show_posts( "", 0, $the_query, 3, wpj_get_job_card_style(), 'ui three cards' ); ?>
			</div>

		<?php }

		wp_reset_postdata();
		wp_reset_query();
	}
}


//----------------------------------------
// RIGHT SIDE - SIDEBAR
//----------------------------------------


/* SIDEBAR */
function wpj_show_single_job_right_side() { ?>

	<!-- Job User Level -->
	<div class="ui segment" <?php if ( wp_is_mobile() ) { echo "style='margin-top: 0 !important;'"; } ?>>
		<?php echo wpj_get_single_job_user_level(); ?>
	</div>

	<!-- Job Security -->
	<div class="ui segment">
		<div class="secure-info-badge">
			<h3><?php _e( "100% Secure", "wpjobster" ); ?></h3>
			<div><?php _e( "Job is done or money back", "wpjobster" ); ?></div>
		</div>
	</div>

	<!-- Job Terms -->
	<div class="ui segment">
		<ul class="green-list">
			<li><?php _e("You pay only the listed price without any hidden costs.", "wpjobster"); ?></li>
			<li><?php _e("We keep your money until you are happy with the delivered work.", "wpjobster"); ?></li>
			<li><?php _e("The job will be done or your money will be returned.", "wpjobster"); ?></li>
		</ul>
		<div class="center">
			<a href="<?php echo get_permalink(get_option("wpjobster_how_it_works_page_id")); ?>" class="custom-link-class"><?php _e("How it works", "wpjobster"); ?></a>
		</div>
	</div>

	<?php if ( get_the_tags() || get_option( 'wpjobster_enable_job_views' ) == 'yes' ) { ?>

		<div class="sidebar-job-tags cf ui segment">

			<!-- Job Tags -->
			<?php if ( get_the_tags() ) {
				echo '<h4>' . __( "Related Topics", "wpjobster" ) . '</h4>';
				the_tags( '', '', '' );
			} ?>

			<!-- Job Views -->
			<?php if ( get_option( 'wpjobster_enable_job_views' ) == 'yes' ) {
				echo '<h4>' . __( "Views:", "wpjobster" ) . '&nbsp;' . wpj_job_view_counter( get_the_ID() ) . '</h4>';
			} ?>

		</div>

	<?php } ?>

	<!-- Job Widget -->
	<?php if ( is_active_sidebar( 'single-job-widgets-area' ) ) { ?>
		<div class="ui segment">
			<div id="single-job-widgets-area" class="primary-sidebar widget-area" role="complementary">
				<ul>
					<?php dynamic_sidebar( 'single-job-widgets-area' ); ?>
				</ul>
			</div>
		</div>
	<?php }
}

/* SIDEBAR - PACKAGES */
if ( ! function_exists( 'wpj_get_job_packages_sidebar' ) ) {
	function wpj_get_job_packages_sidebar() {
		$pid = get_the_ID();
		$wpjobster_packages = get_option('wpjobster_packages_enabled');
		$packages = get_post_meta( $pid, 'job_packages', true );

		if ( $wpjobster_packages == 'yes' && $packages == 'yes' ) {
			wpj_get_sidebar_package_content( __( 'Premium', 'wpjobster' ), 2 );
			wpj_get_sidebar_package_content( __( 'Standard', 'wpjobster' ), 1 );
			wpj_get_sidebar_package_content( __( 'Basic', 'wpjobster' ), 0 );
		}
	}
}

/* SIDEBAR - PACKAGES FNC - CONTENT */
if ( ! function_exists( 'wpj_get_sidebar_package_content' ) ) {
	function wpj_get_sidebar_package_content( $name, $arr_key ) {
		$pid = get_the_ID();

		$package_name          = get_post_meta( $pid, 'package_name', true );
		$package_description   = get_post_meta( $pid, 'package_description', true );
		$package_max_days      = get_post_meta( $pid, 'package_max_days', true );
		$package_price         = get_post_meta( $pid, 'package_price', true );
		$package_revisions     = get_post_meta( $pid, 'package_revisions', true );
		$package_custom_fields = get_post_meta( $pid, 'package_custom_fields', true );

		$act     = ( $arr_key == 1 ) ? 'active' : '';
		$sel     = ( $arr_key == 1 ) ? 'selected' : '';
		$class   = ( $arr_key == 1 ) ? 'right labeled' : '';
		$display = ( $arr_key == 1 ) ? 'block' : 'none'; ?>

		<div class="ui segment packages-sidebar <?php echo $sel; ?>">
			<div class="ui accordion">

				<div class="title <?php echo $act; ?>">
					<div class="pck-sidebar-title">
						<span class="pck-price-sidebar"><?php echo wpjobster_get_show_price( $package_price[$arr_key] ); ?></span>
						<span class="pck-title-sidebar"><?php echo $name; ?></span>
						<div class="right"><i class="dropdown icon mt-5"></i></div>
					</div>
				</div>

				<div class="content <?php echo $act; ?>">
					<p class="transition hidden">
						<div class="bold">
							<i class="wait icon"></i>
							<?php echo sprintf( _n( '%d Day Delivery', '%d Days Delivery',$package_max_days[$arr_key], 'wpjobster' ), $package_max_days[$arr_key]); ?>

							<br>

							<i class="refresh icon"></i>
							<?php if ( $package_revisions[$arr_key] == 'unlimited' ) {
								echo __( 'Unlimited Revisions', 'wpjobster' );
							} else {
								echo sprintf( _n( '%d Revision', '%d Revisions',$package_revisions[$arr_key], 'wpjobster' ), $package_revisions[$arr_key]);
							} ?>
						</div>

						<div class="pck-sidebar-name"><?php echo mb_strtoupper( $package_name[$arr_key] ); ?></div>
						<div class="pck-sidebar-desc"><?php echo wpj_apply_filter_to_string( $package_description[$arr_key], false, 'joblistings' ); ?></div>
						<div class="pck-sidebar-fields">
							<?php if ( $package_custom_fields ) {
								foreach ($package_custom_fields as $value) {
									if ( $value[strtolower($name)] == 'on' ) {
										echo '<p>';
											echo '<i class="checkmark icon"></i>';
											echo $value['name'];
										echo '</p>';

									}
								}
							} ?>
						</div>

						<button class="ui large fluid icon button uppercase pck-sidebar-select-package <?php echo $arr_key . ' ' . $class; ?>">
							<?php echo __( 'Select this package', 'wpjobster' ); ?>
							<i class="checkmark icon" style="display: <?php echo $display; ?>"></i>
						</button>

						<a class="pck-sidebar-compare-packages" href="#job-packages"><?php echo __( 'Compare Packages', 'wpjobster' ); ?></a>
					</p>
				</div>

			</div>
		</div>
	<?php }
}

/* SIDEBAR - BUY BTN */
if ( ! function_exists( 'wpj_get_single_job_buy_btn_sidebar' ) ) {
	function wpj_get_single_job_buy_btn_sidebar() {
		global $wp_query, $post, $current_user;

		$pid          = get_the_ID();
		$current_user = wp_get_current_user();
		$uid          = $post->post_author;

		$author_vacation = get_user_vacation( $uid );
		if ( $author_vacation && $author_vacation['mode'] == 1 ) {
			$author_vacation_reason = $author_vacation['reason'];
		} else {
			$author_vacation = false;
		}

		$prc = get_post_meta( get_the_ID(), "price", true );
		$prc = apply_filters( 'wpjobster_single_job_price', $prc, get_the_ID() );

		$extra_job_add = array();
		$h   = 0;
		$sts = 0;

		// Create array for "Extras" content
		if ( wpj_get_user_feature_status( 'wpjobster_enable_extra', 'wpjobster_subscription_noof_extras_enabled' ) != "no" ) {
			$sts = wpj_get_user_feature_value( 'extras', 'noof_extras', 0, $uid );
		}

		$extra_price = 0;
		for ( $k = 1; $k <= $sts; $k++ ) {
			$extra_price   = get_post_meta( get_the_ID(), 'extra' . $k . '_price',   true );
			$extra_content = get_post_meta( get_the_ID(), 'extra' . $k . '_content', true );
			$extra_enabled = get_post_meta( get_the_ID(), 'extra' . $k . '_enabled', true );

			if ( ! empty( $extra_price ) && ! empty( $extra_content ) ) {
				$extra_job_add[$h]['content']  = $extra_content;
				$extra_job_add[$h]['price']    = $extra_price;
				$extra_job_add[$h]['extra_nr'] = $k;
				$extra_job_add[$h]['enabled']  = $extra_enabled;
				$h++;
			}
		}

		$author_vacation = apply_filters( 'wpj_author_vacation_filter', $author_vacation, $pid );

		if ( ! $author_vacation ) {

			$wpjobster_enable_site_tax = get_option( 'wpjobster_enable_site_tax' );
			if ( get_post_meta( $pid, "active", true ) == 1 ) {

				// Sidebar - Price Separators Vars
				$wpjobster_currency_position     = get_option( 'wpjobster_currency_position' );
				$wpjobster_currency_symbol_space = get_option( 'wpjobster_currency_symbol_space' );

				$wpjobster_decimal_sum_separator = get_option( 'wpjobster_decimal_sum_separator' );
				if ( empty( $wpjobster_decimal_sum_separator ) ) $wpjobster_decimal_sum_separator = '.';

				$wpjobster_thousands_sum_separator = get_option( 'wpjobster_thousands_sum_separator' );
				if ( empty( $wpjobster_thousands_sum_separator ) ) $wpjobster_thousands_sum_separator = ',';

				// Sidebar - Shipping Vars
				$shipping = get_post_meta( get_the_ID(), 'shipping', true );
				if ( ! $shipping ) $shipping = 0;

				// Sidebar - Processing fees & Tax Vars
				if ( $wpjobster_enable_site_tax == 'yes' ) {
					$cur_uid      = get_current_user_id();
					$country_code = get_user_meta( $cur_uid, "country_code", true );

					$wpjobster_tax_percent = wpjobster_get_tax( $country_code );

					$wpjobster_enable_processingfee_tax = get_option( 'wpjobster_enable_processingfee_tax' );
					$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
					if ( $wpjobster_enable_processingfee_tax == 'yes' && $buyer_processing_fees_enabled != 'disabled' ) {
						$wpjobster_enable_processingfee_tax = 'yes';
					} else {
						$wpjobster_enable_processingfee_tax = 'no';
					}
				} else {
					$wpjobster_tax_percent = 0;
					$wpjobster_enable_processingfee_tax = 'no';
				}

				$buyer_processing_fees_enabled = get_option( 'wpjobster_enable_buyer_processing_fees' );
				if ( $buyer_processing_fees_enabled != 'disabled' ) {
					$buyer_processing_fees = wpjobster_get_site_processing_fee( $prc, $extra_price, $shipping );
					update_user_meta( $uid, 'wpjobster_buyer_chargable_fees', $buyer_processing_fees );
				} else {
					$buyer_processing_fees = 0;
				}

				// Sidebar - Extras Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_multiples', 'wpjobster_subscription_job_multiples_enabled' ) == "yes" ) {
					$job_amount_max = wpj_get_user_feature_value( 'jobmultiples', 'job_multiples', '', $uid );

					if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_multiples', 'wpjobster_subscription_extra_multiples_enabled' ) == "yes" ) {
						$extra_amount_max = wpj_get_user_feature_value( 'extramultiples', 'extra_multiples', '', $uid );
					} else {
						$extra_amount_max = 1;
					}
				} else {
					$job_amount_max = 1;
					$extra_amount_max = 1;
				}

				// Sidebar - Extra fast Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_fast_delivery', 'wpjobster_subscription_ex_fast_delivery_enabled' ) != "no" ) {
					$extra_fast_enabled       = get_post_meta( $pid, 'extra_fast_enabled', true );
					$fast_delivery_amount_max = wpj_get_user_feature_value( 'fast_delivery_multiples', 'fast_del_multiples', '', $uid );
				} else {
					$extra_fast_enabled       = '';
					$fast_delivery_amount_max = 1;
				}

				// Sidebar - Extra revision Vars
				if ( wpj_get_user_feature_status( 'wpjobster_enable_extra_additional_revision', 'wpjobster_subscription_additional_revision_enabled' ) != "no" ) {
					$extra_revision_enabled = get_post_meta( $pid, 'extra_revision_enabled', true );
					$add_rev_amount_max     = wpj_get_user_feature_value( 'add_rev_multiples', 'add_rev_multiples', '', $uid );
				} else {
					$extra_revision_enabled = '';
					$add_rev_amount_max     = 1;
				}

				$is_post_author = $post->post_author == $current_user->ID ? true : false;

				// Sidebar - Packages
				if ( ! wpj_is_mobile() ) {
					wpj_get_job_packages_sidebar();
				}

				// Sidebar - Buy Button
				$submit_data = apply_filters( 'wpj_buy_job_submit_form_filter', 'data-submit="[name=myFormPurchase]"', 'login-link', $post->post_author );
				if ( is_user_logged_in() ) {
					$submit_action = isset( $submit_data['action'] ) ? $submit_data['action'] : 'data-submit="[name=myFormPurchase]"';
					$submit_class  = isset( $submit_data['class'] ) ? $submit_data['class'] : '';
				} else {
					$submit_action = isset( $submit_data['action'] ) ? $submit_data['action'] : '';
					$submit_class  = isset( $submit_data['class'] ) ? $submit_data['class'] : 'login-link';
				} ?>

				<div class="sidebar-buy-job">
					<a data-pid="<?php echo $pid; ?>" href="" class="ui primary <?php if ( $is_post_author ) echo 'disabled'; ?> huge fluid <?php if ( ! wp_is_mobile() ) { echo 'icon right labeled'; } ?> button <?php echo $submit_class; ?> uppercase nomargin <?php if ( ! $extra_job_add && ! $shipping ) echo ' no-arrow'; ?>" <?php echo $submit_action; ?>>

						<?php echo $is_post_author ? __( 'This is your own job', 'wpjobster' ) : __( 'Buy Now For', 'wpjobster' ); ?>

						<strong class="total"

							data-price                 = "<?php echo wpjobster_formats_special_exchange( $prc ); ?>"
							data-shipping              = "<?php echo wpjobster_formats_special_exchange( $shipping ); ?>"
							data-cur                   = "<?php echo wpjobster_get_currency(); ?>"

							data-symbol                = "<?php echo wpjobster_get_currency_symbol( wpjobster_get_currency() ); ?>"
							data-position              = "<?php echo $wpjobster_currency_position; ?>"
							data-space                 = "<?php echo $wpjobster_currency_symbol_space; ?>"
							data-decimal               = "<?php echo $wpjobster_decimal_sum_separator; ?>"
							data-thousands             = "<?php echo $wpjobster_thousands_sum_separator; ?>"
							data-decimaldisplay        = "<?php echo get_option( 'wpjobster_decimals' ); ?>"

							data-processingfeesenable  = "<?php echo $buyer_processing_fees_enabled; ?>"
							data-processingfeesfixed   = "<?php echo wpjobster_formats_special_exchange( get_option( 'wpjobster_buyer_processing_fees' ) ); ?>"
							data-processingfeespercent = "<?php echo get_option( 'wpjobster_buyer_processing_fees_percent' ); ?>"

							data-processingfeetax      = "<?php echo $wpjobster_enable_processingfee_tax; ?>"
							data-tax                   = "<?php echo $wpjobster_tax_percent; ?>"
							data-zerowithfree          = "<?php echo get_option( 'wpjobster_replace_zero_with_free' ); ?>"
							data-freestr               = "<?php echo __( "Free", "wpjobster" ); ?>"

						>
							<?php
								if( $prc > 0 ) {
									echo wpjobster_get_show_price($prc);
								} else {
									if ( wpj_bool_option( 'wpjobster_replace_zero_with_free' ) ) {
										_e( 'Free','wpjobster' );
									} else {
										echo wpjobster_get_show_price( $prc );
									}
								}
							?>
						</strong>

						<?php if ( ! wp_is_mobile() ) { ?>
							<i class="caret down icon"></i>
						<?php } ?>
					</a>

					<!-- Sidebar - Job Details - Hover Form -->
					<div class="sidebar-buy-job-form">
						<form class="ui form" method="post" name="myFormPurchase" action="<?php echo get_bloginfo( 'url' ) . '/?jb_action=purchase_this&jobid=' . get_the_ID(); ?>">
							<input type="hidden" name="purchaseformvalidation" value="ok" />
							<input type="hidden" name="main_value_inp" class="main_value_inp" value="1">
							<input type="hidden" name="pck_price_val" class="pck_price_val" value="<?php echo WPJ_Form::post( 'pck_price_val', '' ); ?>" />
							<input type="hidden" name="pck_deliv_val" class="pck_deliv_val" />

							<?php $force_allow = apply_filters( 'wpj_force_allow_filter', false, 'single_job' );
							if ( $extra_fast_enabled || $extra_revision_enabled || $extra_job_add || $shipping || $buyer_processing_fees || $wpjobster_enable_site_tax == 'yes' || $force_allow ) { ?>

								<ul class="ui segment right_button_buy">

									<?php // Sidebar - Job Qunatity
									$quantity = wpj_get_user_feature_status( 'wpjobster_enable_multiples', 'wpjobster_subscription_job_multiples_enabled' );

									$is_price_type = false;
									if ( get_post_meta( $pid, 'price_type', true ) && get_post_meta( $pid, 'price_type', true ) != 'fixed' ) {
										$is_price_type = true;
									} ?>

									<li class="main_li_nopad">
										<label class="main_amount_box">

											<?php if ( $is_price_type ) { ?>
												<span><?php echo apply_filters( 'wpj_price_type_filter', sprintf( __( '%s Rate', 'wpjobster' ), ucfirst( wpjobster_translate_string( get_post_meta( $pid, 'price_type', true ) ) ) ), $pid ); ?></span>
											<?php } else { ?>
												<span><?php _e( 'Job Quantity', 'wpjobster' ); ?></span>
											<?php } ?>

											<span class="extra-price-inside"><?php echo wpjobster_get_show_price($prc); ?></span>

											<?php if ( ! $is_price_type ) { echo '<br>'; } ?>

											<?php if ( $quantity == 'yes' && $job_amount_max > 1 ) {
												if ( $is_price_type ) { ?>
													<br />
													<span class="sn-job-rate-text">

														<?php echo sprintf( __( 'Number of %s:', 'wpjobster' ), ucfirst( wpjobster_translate_string( wpj_change_rate_word( get_post_meta( $pid, 'price_type', true ), 'plural' ) ) ) ); ?>

													</span>
												<?php } ?>

												<span class="amount_section" <?php if ( $is_price_type ) { echo 'style="margin-top: 5px;"'; } ?>>
													<a href="#" class="amount_rmv">&minus;</a>
													<input type="text" name="main_value_inp" class="main_value_inp current_amount main_amount" data-max="<?php echo $job_amount_max; ?>" value="1">
													<a href="#" class="amount_add">+</a>
												</span>
											<?php } ?>
										</label>
									</li>

									<?php // Sidebar - Extra Fast Delivery
									if ( $extra_fast_enabled && $fast_delivery_amount_max > 0 ) {
										$extra_fast_price = get_post_meta( $pid, 'extra_fast_price', true) ;
										$max_deliv        = get_post_meta( $pid, 'extra_fast_days', true );

										if ( $extra_fast_price && $max_deliv ) { ?>
											<li class="cf extra_nb_fast">
												<label>
													<div class="ui checkbox">
														<input class="uzextracheck chk_extrafast" type="checkbox" name="extrafast" id="extrafast" value="1" data-price="<?php echo wpjobster_formats_special_exchange($extra_fast_price); ?>"/>
														<label></label>
													</div>

													<div class="wpj-buy-extra-details">
														<span><?php echo __( 'Extra fast delivery', 'wpjobster' ); ?></span>

														<span class="extra-price-inside"><?php echo wpjobster_get_show_price($extra_fast_price); ?></span>
														<br><span class="description"><?php echo sprintf( _n( '(%d day)', '(%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>

														<?php if ( $fast_delivery_amount_max > 1 ) { ?>
															<span class="amount_section" data-amountnb="fast">
																<a href="#" class="amount_rmv">&minus;</a>
																<input type="text" class="hid_extrafast current_amount main_amount" name="hid_extrafast" data-max="<?php echo $fast_delivery_amount_max; ?>" value="1" />
																<a href="#" class="amount_add">+</a>
															</span>
														<?php } ?>
													</div>
												</label>
											</li>
										<?php }
									}

									// Sidebar - Additional Revision
									if ( $extra_revision_enabled && $add_rev_amount_max > 0 ) {
										$extra_revision_price = get_post_meta( $pid, 'extra_revision_price', true );
										$max_deliv            = get_post_meta( $pid, 'extra_revision_days', true );

										if ( $extra_revision_price && $max_deliv ) { ?>
											<li class="cf extra_nb_revision">
												<label>
													<div class="ui checkbox">
														<input class="uzextracheck chk_extrarevision" type="checkbox" name="extrarevision" id="extrarevision" value="1" data-price="<?php echo wpjobster_formats_special_exchange( $extra_revision_price ); ?>"/>
														<label></label>
													</div>

													<div class="wpj-buy-extra-details">
														<span><?php echo __( 'Extra revision', 'wpjobster' ); ?></span>

														<span class="extra-price-inside"><?php echo wpjobster_get_show_price($extra_revision_price); ?></span>
														<br><span class="description"><?php echo sprintf( _n( '(+%d day)', '(+%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>

														<?php if ( $add_rev_amount_max > 1 && get_post_meta( $pid, 'extra_revision_multiples_enabled', true ) ) { ?>
															<span class="amount_section" data-amountnb="revision">
																<a href="#" class="amount_rmv">&minus;</a>
																<input type="text" class="hid_extrarevision current_amount"	name="hid_extrarevision" data-max="<?php echo $add_rev_amount_max; ?>" value="1" />
																<a href="#" class="amount_add">+</a>
															</span>
														<?php } ?>
													</div>
												</label>
											</li>
										<?php }
									}

									// Sidebar - Extras
									$i = 0;
									if ( $extra_job_add ) {
										foreach ( $extra_job_add as $extra_job_add_item ) { $i++;
											$enabled = get_post_meta( $pid, 'extra' . $i . '_extra_enabled', false );
											if ( isset( $enabled[0] ) ) {
												$enabled = $enabled[0];
											} else {
												update_post_meta( $pid, 'extra' . $i . '_extra_enabled', true );
												$enabled = 1;
											}
											if ( $enabled ) { ?>
												<li class="cf extrali extra_nb_<?php echo $extra_job_add_item['extra_nr']; ?>">
													<label>
														<div class="ui checkbox">
															<input class="uzextracheck chk_extra<?php echo $extra_job_add_item['extra_nr']; ?>" type="checkbox"
																name="extra<?php echo $extra_job_add_item['extra_nr']; ?>"
																id="extra<?php echo $extra_job_add_item['extra_nr']; ?>" value="1"
																data-price="<?php echo wpjobster_formats_special_exchange( $extra_job_add_item['price'] ); ?>"/>
															<label></label>
														</div>

														<div class="wpj-buy-extra-details">
															<span><?php echo wpj_apply_filter_to_string( $extra_job_add_item['content'], false, 'joblistings' ); ?></span>

															<span class="extra-price-inside"><?php echo wpjobster_get_show_price( $extra_job_add_item['price'] ); ?></span>
															<br><span class="description"><?php $max_deliv = get_post_meta($pid, 'max_days_ex_'.$i, true); echo sprintf( _n( '(+%d day)', '(+%d days)', $max_deliv, 'wpjobster' ), $max_deliv ); ?></span>

															<?php if ( $quantity == 'yes' && $extra_job_add_item['enabled'] && $extra_amount_max > 1 ) { ?>
																<span class="amount_section" data-amountnb="<?php echo $extra_job_add_item['extra_nr']; ?>">
																	<a href="#" class="amount_rmv">&minus;</a>
																	<input type="text" class="current_amount hid_extra<?php echo $extra_job_add_item['extra_nr']; ?>" name="hid_extra<?php echo $extra_job_add_item['extra_nr']; ?>" data-max="<?php echo $extra_amount_max; ?>" value="1" />
																	<a href="#" class="amount_add">+</a>
																</span>
															<?php } ?>
														</div>
													</label>

													<?php do_action( 'wpj_after_extra_display', $pid, $i ); ?>

												</li>
											<?php }
										}
									}

									// Sidebar - Shipping
									if ( $shipping ) {
										if ( get_option( 'wpjobster_enable_shipping' ) != 'no' ) { ?>
											<li class="js-shipping shipping-cost cf">
												<?php _e( "Shipping", 'wpjobster' ); ?>
												<span class="extra-price-inside"><?php echo wpjobster_get_show_price( $shipping ) ?></span>
											</li>
										<?php }
									}

									// Sidebar - Processing fees
									if ( $buyer_processing_fees ) {
										if ( $buyer_processing_fees_enabled != 'disabled' ) { ?>
											<li class="js-processingfees shipping-cost cf">
												<?php if ( $buyer_processing_fees_enabled == 'percent' ) {
													$percent_fee = get_option( 'wpjobster_buyer_processing_fees_percent' );
												} else {
													$percent_fee = "";
												}

												if ( $buyer_processing_fees_enabled == 'percent' ) {
													echo sprintf( __( 'Processing Fees (%s%s)', 'wpjobster' ), $percent_fee, '&#37;' );
												} else {
													echo __( 'Processing Fees', 'wpjobster' );
												} ?>

												<span class="processingfee-amount extra-price-inside"><?php echo wpjobster_get_show_price( $buyer_processing_fees ); ?></span>
											</li>
										<?php }
									}

									// Sidebar - Tax
									$tax_amount = wpjobster_get_site_tax( $prc, $extra_price, $shipping, $buyer_processing_fees );
									if ( $tax_amount ) {
										if ( get_option( 'wpjobster_enable_site_tax' ) != 'no' ) { ?>
											<li class="js-processingtax shipping-cost cf">
												<?php  echo sprintf( __( 'Tax (%s%s)', 'wpjobster' ), $wpjobster_tax_percent, '&#37;' ); ?>
												<span class="tax-amount extra-price-inside"><?php echo wpjobster_get_show_price( $tax_amount ); ?></span>
											</li>
										<?php }
									}

									do_action( 'list_after_tax_price', $prc, 'buy_for_popup' ); ?>

								</ul>
							<?php } ?>
						</form>
					</div>
				</div>

			<?php } else { ?>
				<span class="ui huge fluid uppercase disabled button"><?php _e( 'Job deactivated', 'wpjobster' ); ?></span>
			<?php }
		} elseif ( $author_vacation ) { ?>
			<span class="ui huge fluid uppercase disabled button"><?php echo $author_vacation_reason; ?></span>
		<?php }
	}
}

/* SIDEBAR - USER INFO */
if ( ! function_exists( 'wpj_get_single_job_user_level' ) ) {
	function wpj_get_single_job_user_level() {
		global $wp_query, $post, $current_user;

		$using_perm = wpjobster_using_permalinks();
		if ( $using_perm ) $privurl_m = get_permalink( get_option( 'wpjobster_my_account_priv_mess_page_id' ) ) . "?";
		else $privurl_m = get_bloginfo( 'url' ) . "?page_id=" . get_option( 'wpjobster_my_account_priv_mess_page_id' ) . "&";

		$pid          = get_the_ID();
		$uid          = $post->post_author;
		$user         = get_userdata( $post->post_author );
		$user_level   = wpjobster_get_user_level( $uid );
		$current_user = wp_get_current_user(); ?>

		<div class="center sj-user-level">
			<div class="ui basic notpadded segment">
				<div class="user-img-container ">

					<?php if ( wpjobster_get_user_level( $user->ID ) != 0 ) { ?>
						<div class="sidebar-user-level">

							<?php $user_level_no = wpjobster_get_user_level( $user->ID );
							$level_flag = 0;
							if ( $user_level_no == 1 ) {
								if ( get_theme_mod( 'level1_icon_options_user' ) ) {
									$icon_url = get_theme_mod('level1_icon_options_user');
									$level_flag = 1;
								}
							} elseif ( $user_level_no == 2 ) {
								if ( get_theme_mod( 'level2_icon_options_user' ) ) {
									$icon_url = get_theme_mod( 'level2_icon_options_user' );
									$level_flag = 1;
								}
							} else {
								if ( get_theme_mod( 'level3_icon_options_user' ) ) {
									$icon_url = get_theme_mod( 'level3_icon_options_user' );
									$level_flag = 1;
								}
							}

							$user_type = function_exists( 'is_account_segregation' ) ? wpj_get_user_account_type( $uid ) : __( 'Seller', 'wpjobster' );

							if ( $user_level_no == 1 ) {
								$tooltip_content = sprintf( __( "Level 1 %s", "wpjobster" ), $user_type );
							} elseif ( $user_level_no == 2 ) {
								$tooltip_content = sprintf( __( "Level 2 %s", "wpjobster" ), $user_type );
							} else {
								$tooltip_content = sprintf( __( "Top Rated %s", "wpjobster" ), $user_type );
							} ?>

							<div data-inverted="" data-tooltip="<?php echo $tooltip_content; ?>" data-position="bottom center" class="user-badge user-level-<?php echo $user_level_no; ?> z-index-bigger" <?php if ( $level_flag ) { ?>style="background-image: url(<?php echo $icon_url; ?>);" <?php } ?>></div>

						</div>
					<?php } ?>

					<a href="<?php echo wpj_get_user_profile_link( $user->user_login );?>">
						<img class="round-avatar" width="130" height="130" border="0" src="<?php echo wpjobster_get_avatar( $post->post_author, 130, 130 ); ?>" />
					</a>

					<?php do_action( 'wpj_profile_picture_extras', $user->ID ); ?>

				</div>

				<div class="user-info cf">

					<h3 class="overflow-ellipsis">
						<a style="vertical-align: middle" href="<?php echo wpj_get_user_profile_link( $user->user_login );?>">
							<?php echo apply_filters( 'wpj_single_job_username_filter', wpj_get_user_display_type( $user->ID ), $user ); ?>
						</a>
					</h3>

					<?php include ( locate_template( 'template-parts/pages/user/page-user-icons.php' ) );

					if ( wpjobster_get_seller_rating( $post->post_author ) != 0 ) { ?>

						<div class="user-info-subtitle db padding20top">

							<?php echo $rtg = wpjobster_get_seller_rating( $post->post_author ) . "% " . __( 'Reputation', 'wpjobster' ); ?>

							<div class="user-profile user-info-rating">

								<?php echo wpj_get_user_rating( $uid ); ?>

								<span class="small-rtg">
									<?php $rating_count = get_option( 'wpjobster_user_min_rating' );
									$rating_count = $rating_count && is_numeric( $rating_count ) ? $rating_count : 3;

									if ( wpjobster_get_seller_ratings_number( $post->post_author ) >= $rating_count ) {
										echo number_format( wpjobster_get_seller_avg_rating( $post->post_author ), 1 ) . ' (' . wpjobster_get_seller_ratings_number( $post->post_author ) . " " .  _n( "review", "reviews", wpjobster_get_seller_ratings_number( $post->post_author ), "wpjobster" ) . ')';
									} ?>
								</span>
							</div>

						</div>

					<?php } else { ?>

						<div class="db padding20top"><b><?php _e( "New user", "wpjobster" ); ?></b></div>

					<?php } ?>

				</div>
			</div>

			<?php if ( get_user_meta( $post->post_author, 'personal_info', true ) ) { ?>

				<div class="cf user-bio">
					<?php $desc_content = wpj_apply_filter_to_string( get_user_meta( $post->post_author, 'personal_info', true ), false, 'joblistings' );

					if ( get_option( 'wpjobster_wysiwyg_for_profile' ) != 'yes' ) {
						echo stripslashes( $desc_content );
					} else {
						echo $desc_content;
					} ?>
				</div>

			<?php } else { ?>

				<div class="main-margin cf"></div>

			<?php } ?>

			<?php do_action( 'wpj_profile_extra_fields_display_on_sidebar', $pid );?>

			<div class="cf user-info">

				<?php if ( get_option( 'wpjobster_enable_last_seen' ) != 'no' ) { ?>

					<div class="last-seen">
						<b><?php _e( "Last seen", "wpjobster" ) ?>:</b>
						<br><?php echo wpj_get_last_visit( $post->post_author ); ?>
					</div>

				<?php } ?>

				<div class="main-margin cf"></div>

				<?php if( $uid != $current_user->ID ) { ?>

					<a class="ui fluid button <?php echo ! is_user_logged_in() ? 'login-link' : ''; ?>" href="<?php echo $privurl_m; ?>username=<?php echo $user->user_nicename; ?>&job_id=<?php echo $pid; ?>"><?php _e( "Contact", "wpjobster" ); ?></a>

				<?php } ?>

			</div>
		</div>
	<?php }
}
