<?php
class WPJRequestsNewEdit {

	public static function init() {
		$class = __CLASS__;
		new $class;
	}

	public function __construct() {
		add_action( 'wp_ajax_save_request_post_autodraft', array( $this, 'savePostData' ) );
		add_action( 'wp_ajax_nopriv_save_request_post_autodraft', array( $this, 'savePostData' ) );

		$this->custom_field = new WPJ_Custom_Fields( WPJ_Form::get( 'requestid' ), 'request' );
	}

	public function Initializations() {
		global $current_user;
		$current_user = wp_get_current_user();
		$uid = $current_user->ID;

		do_action( 'wpj_post_request_init' );

		// init new post
		if ( ! isset( $_GET['requestid'] ) ) {
			$wpjobster_post_new_page_id = get_option( 'wpjobster_new_request_page_id' );

			$pid = wpjobster_get_auto_draft( $current_user->ID, 'request' );
			wp_redirect( add_query_arg( 'requestid', $pid, get_permalink( $wpjobster_post_new_page_id ) ) );
			exit;
		} else {
			$pid = WPJ_Form::get( 'requestid' );
		}

		// double check that we are on the right page
		if ( is_user_logged_in() ) {
			global $wpdb;
			$last_draft = $wpdb->get_row(
				$wpdb->prepare(
					"
					SELECT *
					FROM $wpdb->posts
					WHERE post_type = 'request'
						AND post_status = 'auto-draft'
						AND post_author = %d
					ORDER BY ID DESC
					",
					$uid
				)
			);

			if ( WPJ_Form::get( 'jb_action' ) != 'request_edit' ) {
				if ( $last_draft->ID > $pid || $uid != get_post_field( 'post_author', $pid ) ) {
					wp_redirect( add_query_arg( 'requestid', $last_draft->ID, get_permalink( $wpjobster_post_new_page_id ) ) );
					exit;
				}
			}
		} else {
			if ( isset( $_COOKIE['wpj_request_id'] ) && $pid != $_COOKIE['wpj_request_id'] ) {
				wp_redirect( add_query_arg( 'requestid', $_COOKIE['wpj_request_id'], get_permalink( $wpjobster_post_new_page_id ) ) );
				exit;
			} elseif ( ! isset( $_COOKIE['wpj_request_id'] ) ) {
				wp_redirect( get_permalink( $wpjobster_post_new_page_id ) );
				exit;
			}
		}

		$post = get_post( $pid );

		// save post data
		$this->savePostData( $pid, 'publish' );

		// check if the flexible content field has rows of data
		if ( have_rows( 'request_fields' ) ) {

			// create a multidimensional array to structure our data
			$request_fields_array = get_field_object( 'request_fields' );
			$request_fields = array();

			// set up the first element for the fields without tabs
			array_push( $request_fields, array() );
			$request_fields[0]['tab_fields'] = array();

			foreach ( $request_fields_array['value'] as $request_field ) {
				if ( $request_field['acf_fc_layout'] == 'request_tab_separator' ) {

					// prepare tab with empty array for the fields
					$request_field['tab_fields'] = array();

					// insert tab
					array_push( $request_fields, $request_field );
				} else {
					// insert fields at the end for display, including all the errors
					end( $request_fields );
					$tab_key = key( $request_fields ); // get last tab's key
					array_push( $request_fields[$tab_key]['tab_fields'], $request_field );
				} // END if tab/input
			}

			$use_tabs = ! $request_fields[0]['tab_fields'] ? true : false;
			end( $request_fields ); $last_tab = key( $request_fields ); // get last tab

			$class = $use_tabs ? 'tabs-container' : 'post-new-no-tab-wrapper';
			$last_tab_str = wpj_number_to_string( $last_tab );

			return array(
				'uid'            => $uid,
				'pid'            => $pid,
				'post'           => $post,
				'request_fields' => $request_fields,
				'use_tabs'       => $use_tabs,
				'last_tab'       => $last_tab,
				'class'          => $class,
				'last_tab_str'   => $last_tab_str
			);
		}

		return array( 'uid'  => $uid, 'pid'  => $pid, 'post' => $post );
	}

	public function getArrangemendOfFieldsByWidth( $request_fields = array(), $ret = '' ) {
		if ( $request_fields ) {
			$ji = 0;
			$ti = 0;
			$jb_action = WPJ_Form::get( 'jb_action' );
			$pid = WPJ_Form::get( 'requestid' );

			foreach ( $request_fields as $j_field ) {
				$return = $this->getFieldsContent( $j_field );
				$field  = $return['field'] != 'no' ? ' field ' : '';
				$popup  = $return['popup'] != 'no' ? ' js-tooltip-handler ' : '';
				$instr  = $return['instr'] ? $return['instr'] : '';
				$f_name = $return['f_rej_name'];
				if ( $j_field && isset( $j_field['acf_fc_layout'] ) ) {
					if ( strpos( $j_field['acf_fc_layout'], 'custom_field' ) !== false && isset( $j_field['slug'] ) ) {
						$unique_slug = 'request_cfield_' . $j_field['slug'];
					} else {
						$unique_slug = $j_field['acf_fc_layout'];
					}
				} else {
					$unique_slug = '';
				}

				if ( $j_field['width'] == 'full' ) {
					$ret .= '<div class="one fields ' . $return['parent_class'] . '">';
					$ret .= '<div id="' . $return['id'] . '" class="' . $return['class'] . $field . $popup . '" data-handler-id="' . $unique_slug . '">';
						if ( $return['label'] != 'no' ) {
							$ret .= '<label>' . $j_field['label'] . '</label>';
						}
						$ret .= $return['content'];
					$ret .= '</div>';

					if ( $return['popup'] != 'no' ) {
						if ( $jb_action == 'request_edit' ) {
							$ret .= wpj_get_popup( $instr, 'edit', 'request', $pid, $f_name, true, $j_field );
						} else {
							$ret .= wpj_get_popup( $instr, '', '', '', '', true, $j_field );
						}
					}
					$ret .= '</div>';
				}

				if ( $j_field['width'] == 'half-solo' ) {
					$ret .= '<div class="two fields ' . $return['parent_class'] . '">';
						$ret .= '<div id="' . $return['id'] . '" class="' . $return['class'] . $field . $popup . '" data-handler-id="' . $unique_slug . '">';
							if ( $return['label'] != 'no' ) {
								$ret .= '<label>' . $j_field['label'] . '</label>';
							}
							$ret .= $return['content'];
						$ret .= '</div>';

						if ( $return['popup'] != 'no' ) {
							if ( $jb_action == 'request_edit' ) {
								$ret .= wpj_get_popup( $instr, 'edit', 'request', $pid, $f_name, true, $j_field );
							} else {
								$ret .= wpj_get_popup( $instr, '', '', '', '', true, $j_field );
							}
						}

						$ret .= '<div class="field"></div>';
					$ret .= '</div>';
				}

				if ( $j_field['width'] == 'half' ) {
					if ( $ji == 0 ) { $ret .= '<div class="two fields ' . $return['parent_class'] . '">'; }

						$ret .= '<div id="' . $return['id'] . '" class="' . $return['class'] . $field . $popup . '" data-handler-id="' . $unique_slug . '">';
							if ( $return['label'] != 'no' ) {
								$ret .= '<label>' . $j_field['label'] . '</label>';
							}
							$ret .= $return['content'];
						$ret .= '</div>';

						if ( $return['popup'] != 'no' ) {
							if ( $jb_action == 'request_edit' ) {
								$ret .= wpj_get_popup( $instr, 'edit', 'request', $pid, $f_name, true, $j_field );
							} else {
								$ret .= wpj_get_popup( $instr, '', '', '', '', true, $j_field );
							}
						}

						$ji++;

					if ( $ji == 2 ) { $ret .= '</div>'; $ji = 0; }
				}

				if ( $j_field['width'] == 'third' ) {
					if ( $ti == 0 ) { $ret .= '<div class="three fields ' . $return['parent_class'] . '">'; }

						$ret .= '<div id="' . $return['id'] . '" class="' . $return['class'] . $field . $popup . '" data-handler-id="' . $unique_slug . '">';
							if ( $return['label'] != 'no' ) {
								$ret .= '<label>' . $j_field['label'] . '</label>';
							}
							$ret .= $return['content'];
						$ret .= '</div>';

						if ( $return['popup'] != 'no' ) {
							if ( $jb_action == 'request_edit' ) {
								$ret .= wpj_get_popup( $instr, 'edit', 'request', $pid, $f_name, true, $j_field );
							} else {
								$ret .= wpj_get_popup( $instr, '', '', '', '', true, $j_field );
							}
						}

						$ti++;

					if ( $ti == 3 ) { $ret .= '</div>'; $ti = 0; }
				}
			}
		}

		return $ret;
	}

	public function getFieldsContent( $fields = '', $pid = '', $include_post_value = true, $ret = '' ) {
		$f_name         = $fields['acf_fc_layout'];
		$f_label        = $fields['label'];
		$f_placeholder  = isset( $fields['placeholder'] ) ? $fields['placeholder'] : '';
		$f_instructions = isset( $fields['instructions'] ) ? $fields['instructions'] : '';

		$current_user = wp_get_current_user();
		$uid          = $current_user->ID;

		if ( ! $pid ) {
			$pid = WPJ_Form::get( 'requestid', '' );
		}
		$post = $pid ? get_post( $pid ) : array();

		$instr_field_name = $f_instructions;

		$id = ''; $class = ''; $parent_class = ''; $label = ''; $popup = ''; $field = ''; $f_rej_name = '';

		// Field Separator
		if ( $f_name == 'request_field_separator' ) { $id = 'field_separator'; $class = 'field_separator'; $label = 'no'; $popup = 'no'; $field = 'yes';
			$ret .= $this->getContentFromBuffer( $fields, 'separator', array( 'fields' => $fields, 'pid' => $pid ) );
		}

		// Custom Field
		if ( strpos( $f_name, 'custom_field' ) !== false ) { $class = "cf";

			$rcf   = $this->custom_field->getFieldsContent( $fields );

			$popup = $rcf['popup']; $label = $rcf['label'];

			$ret  .= $rcf['content'];
		}

		// Title
		if ( $f_name == 'request_title' ) { $f_rej_name = 'name';
			$post_title = WPJ_Form::post( 'request_title', ( ( isset( $post->post_title ) && $post->post_title != 'Auto Draft' ) ? $post->post_title : '' ) );
			$ret .= $this->getContentFromBuffer( $fields, 'title', array( 'post_value' => $post_title, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
		}

		// Description
		if ( $f_name == 'request_description' ) { $f_rej_name = 'description';
			$post_description = WPJ_Form::post( 'request_description', ( ( isset( $post->post_content ) && $post->post_content != 'Auto Draft' ) ? $post->post_content : '' ) );
			$post_description = apply_filters( 'wpj_request_value_filter', $post_description, $pid, $f_rej_name );
			$post_description = $include_post_value ? $post_description : '';

			$ret .= $this->getContentFromBuffer( $fields, 'description', array( 'post_value' => $post_description, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
		}

		// Tags
		if ( $f_name == 'request_tags' ) { $f_rej_name = 'tags'; $class = "input-block";
			if ( isset( $_POST['request_tags'] ) ) {
				$post_tags = $_POST['request_tags'];
			} else {
				$request_tags = wp_get_post_tags( $pid );
				$i = 0; $post_tags = ''; $i_separator = '';
				if ( $request_tags ) {
					foreach ( $request_tags as $tag ) {
						$post_tags .= $i_separator . $tag->name; $i++;
						if ( $i > 0 ) { $i_separator = ', '; }
					}
				}
			}
			$post_tags = apply_filters( 'wpj_request_value_filter', $post_tags, $pid, $f_rej_name );
			$post_tags = $include_post_value ? $post_tags : '';

			$ret .= $this->getContentFromBuffer( $fields, 'tags', array( 'post_value' => $post_tags, 'pid' => $pid ) );
		}

		// Category
		if ( $f_name == 'request_category' ) { $id = "request_category_field";
			$post = $this->getPostCategories();
			$ret .= $this->getContentFromBuffer( $fields, 'category', array( 'post_value' => $post['category'], 'pid' => $pid ) );
		}

		// Subcategory
		if ( $f_name == 'request_subcategory' ) { $id = "request_subcategory_field";
			$post = $this->getPostCategories();
			$ret .= $this->getContentFromBuffer( $fields, 'subcategory', array( 'post_category_value' => $post['category'], 'post_subcategory_value' => $post['subcategory'], 'pid' => $pid ) );
		}

		// Deadline
		if ( $f_name == 'request_deadline' ) { $f_rej_name = 'deadline'; $label = 'no';
			if ( get_option( 'wpjobster_request_deadline' ) == "yes" ) { $label = 'yes';
				$post_deadline = WPJ_Form::post( 'request_deadline', get_post_meta( $pid, 'request_deadline', true ) );
				$post_deadline = apply_filters( 'wpj_request_value_filter', $post_deadline, $pid, $f_rej_name );
				$post_deadline = $include_post_value ? $post_deadline : '';
				$ret .= $this->getContentFromBuffer( $fields, 'deadline', array( 'post_value' => $post_deadline, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Delivery
		if ( $f_name == 'request_delivery' ) { $label = 'no';
			if ( get_option( 'wpjobster_request_max_deliv' ) == "yes" ) { $label = 'yes';
				$post_delivery = WPJ_Form::post( 'request_delivery', get_post_meta( $pid, 'request_delivery', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'delivery', array( 'post_value' => $post_delivery, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Budget From
		if ( $f_name == 'request_budget_from' ) { $f_rej_name = 'budget_from'; $label = 'no';
			if ( get_option( 'wpjobster_request_budget' ) == "yes" ) { $label = 'yes';
				$post_budget_from = WPJ_Form::post( 'request_budget_from', get_post_meta( $pid, 'request_budget_from', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'budget_from', array( 'post_value' => $post_budget_from, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Budget To
		if ( $f_name == 'request_budget_to' ) { $f_rej_name = 'budget_to'; $label = 'no';
			if ( get_option( 'wpjobster_request_budget' ) == "yes" ) { $label = 'yes';
				$post_budget_from = WPJ_Form::post( 'request_budget_to', get_post_meta( $pid, 'request_budget_to', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'budget_to', array( 'post_value' => $post_budget_from, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Upload attachments
		if ( $f_name == 'request_attachments' ) { $f_rej_name = 'attachments'; $label = 'no';
			if ( get_option( 'wpjobster_request_file_upload' ) == "yes" ) { $label = 'yes';
				$post_attachments = WPJ_Form::post( 'request_attachments', get_post_meta( $pid, 'request_attachments', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'attachments', array( 'post_value' => $post_attachments, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Autoclose
		if ( $f_name == 'request_autoclose' ) {
			$post_autoclose = WPJ_Form::post( 'request_autoclose', get_post_meta( $pid, 'request_autoclose', true ) );
			$ret .= $this->getContentFromBuffer( $fields, 'autoclose', array( 'post_value' => $post_autoclose, 'pid' => $pid ) );
		}

		// Let's meet
		if ( $f_name == 'request_lets_meet' ) { $label = 'no';
			if ( get_option( 'wpjobster_request_lets_meet' ) == "yes" ) { $label = 'yes';
				$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
				if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }
				$ret .= $this->getContentFromBuffer( $fields, 'lets_meet', array( 'post_value' => $post_lets_meet, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// Location
		if ( $f_name == 'request_location' ) { $label = 'no';
			$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
			if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }

			$wpjobster_location_display_condition = get_option( 'wpjobster_request_location_display_condition' );
			if ( $wpjobster_location_display_condition == 'ifchecked' && $post_lets_meet != 'yes' ) {
				$class = "location-item js-location-item hidden";
			}

			if ( get_option( 'wpjobster_request_location' ) == 'yes' ) {
				if ( $wpjobster_location_display_condition == 'always' || $wpjobster_location_display_condition == 'ifchecked' ) {
					$label = 'yes';

					$post_location = WPJ_Form::post( 'request_location', get_post_meta( $pid, 'request_location', true ) );
					$post_lat      = WPJ_Form::post( 'request_lat', get_post_meta( $pid, 'request_lat', true ) );
					$post_long     = WPJ_Form::post( 'request_long', get_post_meta( $pid, 'request_long', true ) );

					$post_location = apply_filters( 'wpj_request_value_filter', $post_location, $pid, 'location' );
					$post_lat      = apply_filters( 'wpj_request_value_filter', $post_lat, $pid, 'lat' );
					$post_long     = apply_filters( 'wpj_request_value_filter', $post_long, $pid, 'long' );

					$post_location = $include_post_value ? $post_location : '';
					$post_lat      = $include_post_value ? $post_lat : '';
					$post_long     = $include_post_value ? $post_long : '';

					$ret .= $this->getContentFromBuffer( $fields, 'location', array( 'post_location' => $post_location, 'post_lat' => $post_lat, 'post_long' => $post_long, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
				} else {
					$class = 'hidden';
				}
			} else {
				$class = 'hidden';
			}
		}

		// Pick Up Location
		if ( $f_name == 'request_pick_up_location' ) { $label = 'no';
			$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
			if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }

			$wpjobster_location_display_condition = get_option( 'wpjobster_request_pick_up_location_display_condition' );
			if ( $wpjobster_location_display_condition == 'ifchecked' && $post_lets_meet != 'yes' ) {
				$class = "location-item js-location-item hidden";
			}

			if ( get_option( 'wpjobster_request_pick_up_location' ) == 'yes' ) {
				if ( $wpjobster_location_display_condition == 'always' || $wpjobster_location_display_condition == 'ifchecked' ) {
					$label = 'yes';

					$post_pick_up_location = WPJ_Form::post( 'request_pick_up_location', get_post_meta( $pid, 'request_pick_up_location', true ) );
					$post_pick_up_lat      = WPJ_Form::post( 'request_pick_up_lat', get_post_meta( $pid, 'request_pick_up_lat', true ) );
					$post_pick_up_long     = WPJ_Form::post( 'request_pick_up_long', get_post_meta( $pid, 'request_pick_up_long', true ) );

					$ret .= $this->getContentFromBuffer( $fields, 'pick_up_location', array( 'post_pick_up_location' => $post_pick_up_location, 'post_pick_up_lat' => $post_pick_up_lat, 'post_pick_up_long' => $post_pick_up_long, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
				} else {
					$class = 'hidden';
				}
			} else {
				$class = 'hidden';
			}
		}

		// Drop Off Location
		if ( $f_name == 'request_drop_off_location' ) { $label = 'no';
			$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
			if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }

			$wpjobster_location_display_condition = get_option( 'wpjobster_request_drop_off_location_display_condition' );
			if ( $wpjobster_location_display_condition == 'ifchecked' && $post_lets_meet != 'yes' ) {
				$class = "location-item js-location-item hidden";
			}

			if ( get_option( 'wpjobster_request_drop_off_location' ) == 'yes' ) {
				if ( $wpjobster_location_display_condition == 'always' || $wpjobster_location_display_condition == 'ifchecked' ) {
					$label = 'yes';

					$post_drop_off_location = WPJ_Form::post( 'request_drop_off_location', get_post_meta( $pid, 'request_drop_off_location', true ) );
					$post_drop_off_lat      = WPJ_Form::post( 'request_drop_off_lat', get_post_meta( $pid, 'request_drop_off_lat', true ) );
					$post_drop_off_long     = WPJ_Form::post( 'request_drop_off_long', get_post_meta( $pid, 'request_drop_off_long', true ) );

					$ret .= $this->getContentFromBuffer( $fields, 'drop_off_location', array( 'post_drop_off_location' => $post_drop_off_location, 'post_drop_off_lat' => $post_drop_off_lat, 'post_drop_off_long' => $post_drop_off_long, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
				} else {
					$class = 'hidden';
				}
			} else {
				$class = 'hidden';
			}
		}

		// Start date
		if ( $f_name == 'request_start_date' ) { $label = 'no';
			$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
			if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }

			$wpjobster_location_display_condition = get_option( 'wpjobster_request_date_display_condition' );
			if ( $wpjobster_location_display_condition == 'ifchecked' && $post_lets_meet != 'yes' ) {
				$class = "location-item js-location-item hidden";
			}

			if ( $wpjobster_location_display_condition == 'always' || $wpjobster_location_display_condition == 'ifchecked' ) { $label = 'yes';
				$post_start_date = WPJ_Form::post( 'request_start_date', get_post_meta( $pid, 'request_start_date', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'start_date', array( 'post_value' => $post_start_date, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		// End date
		if ( $f_name == 'request_end_date' ) { $label = 'no';
			$post_lets_meet = WPJ_Form::post( 'request_lets_meet', get_post_meta( $pid, 'request_lets_meet', true ) );
			if ( isset( $_POST['aoer_form_submitted'] ) && !isset( $_POST['request_lets_meet'] ) ) { $post_lets_meet = false; }

			$wpjobster_location_display_condition = get_option( 'wpjobster_request_date_display_condition' );
			if ( $wpjobster_location_display_condition == 'ifchecked' && $post_lets_meet != 'yes' ) {
				$class = "location-item js-location-item hidden";
			}

			if ( $wpjobster_location_display_condition == 'always' || $wpjobster_location_display_condition == 'ifchecked' ) { $label = 'yes';
				$post_start_date = WPJ_Form::post( 'request_end_date', get_post_meta( $pid, 'request_end_date', true ) );
				$ret .= $this->getContentFromBuffer( $fields, 'end_date', array( 'post_value' => $post_start_date, 'placeholder' => $f_placeholder, 'pid' => $pid ) );
			} else {
				$class = 'hidden';
			}
		}

		$return_arr = array(
			'id'           => $id,
			'class'        => $class,
			'parent_class' => $parent_class,
			'label'        => $label,
			'popup'        => $popup,
			'field'        => $field,
			'instr'        => $instr_field_name,
			'f_rej_name'   => $f_rej_name,
			'content'      => $ret
		);

		return $return_arr;
	}

	public function savePostData( $pid = '', $action_type = '' ) {
		if ( isset( $_POST['aoer_form_submitted'] ) && ! is_demo_user() ) {

			$uid = get_current_user_id();

			$pid = $pid ? $pid : WPJ_Form::get( 'requestid', '' );
			if ( $action_type != 'publish' ) { $pid = $_POST['pid']; }

			$post = get_post( $pid );

			$jb_action = WPJ_Form::get( 'jb_action' );

			if ( ! isset( $_POST['post_new_or_edit_request_field'] ) || ! wp_verify_nonce( $_POST['post_new_or_edit_request_field'], 'post_new_or_edit_request_action' ) ) {

				echo '<div class="ui negative message mt20">' . __( 'Sorry, your nonce did not verify.', 'wpjobster' ) . '</div>';

			} elseif ( $jb_action == 'request_edit' && $uid != $post->post_author ) {

				echo '<div class="ui negative message mt20">' . __( 'You are not allowed to edit this request because you are not the author.', 'wpjobster' ) . '</div>';

			} elseif ( $jb_action != 'request_edit' || ( $jb_action == 'request_edit' && $uid == $post->post_author ) ) {

				// Vars
				$request_title             = WPJ_Form::post( 'request_title', mb_substr( trim( $_POST['request_description'] ), 0, 65 ) . '...' );
				$request_description       = WPJ_Form::post( 'request_description', '' );
				$request_tag               = WPJ_Form::post( 'request_tags', '' );
				$request_category          = WPJ_Form::post( 'request_category', '' );
				$request_subcategory       = WPJ_Form::post( 'subcat', '' );
				$request_deadline          = WPJ_Form::post( 'request_deadline', '' );
				$request_delivery          = WPJ_Form::post( 'request_delivery', '' );
				$request_budget_from       = WPJ_Form::post( 'request_budget_from', '' );
				$request_budget_to         = WPJ_Form::post( 'request_budget_to', '' );
				$request_attachment        = WPJ_Form::post( 'request_attachments', '' );
				$request_autoclose         = WPJ_Form::post( 'request_autoclose', '' );
				$request_lets_meet         = WPJ_Form::post( 'request_lets_meet', '' );

				$request_location          = WPJ_Form::post( 'request_location', '' );
				$request_lat               = WPJ_Form::post( 'request_lat', '' );
				$request_long              = WPJ_Form::post( 'request_long', '' );

				$request_pick_up_location  = WPJ_Form::post( 'request_pick_up_location', '' );
				$request_pick_up_lat       = WPJ_Form::post( 'request_pick_up_lat', '' );
				$request_pick_up_long      = WPJ_Form::post( 'request_pick_up_long', '' );

				$request_drop_off_location = WPJ_Form::post( 'request_drop_off_location', '' );
				$request_drop_off_lat      = WPJ_Form::post( 'request_drop_off_lat', '' );
				$request_drop_off_long     = WPJ_Form::post( 'request_drop_off_long', '' );

				$request_start_date        = WPJ_Form::post( 'request_start_date', '' );
				$request_end_date          = WPJ_Form::post( 'request_end_date', '' );

				// Metas
				update_post_meta( $pid, 'request_deadline',          trim( htmlspecialchars( $request_deadline ) ) );
				update_post_meta( $pid, 'request_delivery',          trim( htmlspecialchars( $request_delivery ) ) );
				update_post_meta( $pid, 'request_budget_from',       trim( htmlspecialchars( $request_budget_from ) ) );
				update_post_meta( $pid, 'request_budget_to',         trim( htmlspecialchars( $request_budget_to ) ) );
				update_post_meta( $pid, 'request_autoclose',         trim( htmlspecialchars( $request_autoclose ) ) );
				update_post_meta( $pid, 'request_lets_meet',         trim( htmlspecialchars( $request_lets_meet ) ) );

				update_post_meta( $pid, 'request_location',          trim( htmlspecialchars( $request_location ) ) );
				update_post_meta( $pid, 'request_lat',               trim( htmlspecialchars( $request_lat ) ) );
				update_post_meta( $pid, 'request_long',              trim( htmlspecialchars( $request_long ) ) );

				update_post_meta( $pid, 'request_pick_up_location',  trim( htmlspecialchars( $request_pick_up_location ) ) );
				update_post_meta( $pid, 'request_pick_up_lat',       trim( htmlspecialchars( $request_pick_up_lat ) ) );
				update_post_meta( $pid, 'request_pick_up_long',      trim( htmlspecialchars( $request_pick_up_long ) ) );

				update_post_meta( $pid, 'request_drop_off_location', trim( htmlspecialchars( $request_drop_off_location ) ) );
				update_post_meta( $pid, 'request_drop_off_lat',      trim( htmlspecialchars( $request_drop_off_lat ) ) );
				update_post_meta( $pid, 'request_drop_off_long',     trim( htmlspecialchars( $request_drop_off_long ) ) );

				update_post_meta( $pid, 'request_start_date',        trim( htmlspecialchars( $request_start_date ) ) );
				update_post_meta( $pid, 'request_end_date',          trim( htmlspecialchars( $request_end_date ) ) );

				// Tags
				wp_set_post_tags( $pid, trim( strip_tags( htmlspecialchars( $request_tag ) ) ) );

				// Categories
				wp_set_post_terms( $pid, $this->getCategoriesToBeSaved( $request_category, $request_subcategory ), 'request_cat' );

				// Attachments
				if ( $request_attachment != "" ) {
					if ( $jb_action == 'request_edit' ) {
						wpj_save_attachemtns( $request_attachment, $pid, 'request_attachments', 'edit' );
					} else {
						wpj_save_attachemtns( $request_attachment, $pid, 'request_attachments', 'new' );
					}
				}

				// Custom fields
				$this->custom_field->saveFieldsContent();

				// Create the post
				$request_post                 = array();
				$request_post['ID']           = $pid;
				$request_post['post_title']   = $request_title;
				$request_post['post_content'] = $request_description;

				if ( is_user_logged_in() ) {
					if ( $action_type == 'publish' ) {
						$request_post['post_status'] = 'draft';
					}
				}

				wp_update_post( $request_post );

				if ( $action_type == 'publish' ) {
					if ( is_user_logged_in() ) {
						wp_publish_post( $pid );

						$wpjobster_admin_approve_request = get_option( 'wpjobster_admin_approve_request' );

						if ( $wpjobster_admin_approve_request != "yes" ) {

							update_post_meta( $pid, 'under_review', '0' );
							update_post_meta( $pid, 'active', '1' );

							$request_post['post_status'] = 'publish';
							wp_update_post( $request_post );

							if ( ! is_admin() ) {
								$request_term   = wp_get_post_terms( $pid, 'request_cat', array( "fields" => "all" ) );
								$job_categories = get_term_by( 'name', $request_term[0]->name, 'job_cat' );

								do_action( 'wpjobster_after_request_inserted', $pid, $job_categories->term_id );
							}

							$url = add_query_arg( 'submitted', $pid, get_permalink( get_option( 'wpjobster_my_requests_page_id' ) ) );

						} else {

							update_post_meta( $pid, 'under_review', '1' );

							$request_post['post_status'] = 'draft';
							wp_update_post( $request_post );

							$url = get_permalink( get_option( 'wpjobster_my_requests_page_id' ) ) . 'in_review';
						}

						// Send e-mails
						$user_data = get_userdata( get_post_field( 'post_author', $pid ) );
						if ( $wpjobster_admin_approve_request == "yes" ) {

							wpj_notify_user_translated( 'request_admin_new', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => $request_title ) );
							wpj_notify_user_translated( 'request_new', get_post_field( 'post_author', $pid ), array( '##request_name##' => $request_title ) );

						} else {

							wpj_notify_user_translated( 'request_admin_acc', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => $request_title, '##request_link##' => get_post_permalink( $pid ) ) );

							if ( ! is_admin() ) {
								wpj_notify_user_translated( 'request_acc', get_post_field( 'post_author', $pid ), array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => $request_title, '##request_link##' => get_post_permalink( $pid ) ) );
							}

						}

						// Redirect
						$url = apply_filters( 'wpjobster_return_redirect_url_post_new_request', $url, $pid );

						wp_redirect( $url ); exit;

					} else {

						wp_redirect( wp_registration_url() );

					}

					exit;

				} else {

					die();

				}
			}
		}
	}

	public static function saveAnonymousDraft() {
		if ( isset( $_COOKIE['wpj_request_id'] ) && is_user_logged_in() ) {
			$pid = $_COOKIE['wpj_request_id'];

			global $current_user;
			$current_user = wp_get_current_user();
			$uid = $current_user->ID;

			$request_post                 = array();
			$request_post['ID']           = $pid;
			$request_post['post_author']  = $uid;

			$wpjobster_admin_approve_request = get_option( 'wpjobster_admin_approve_request' );

			if ( $wpjobster_admin_approve_request != "yes" ) {
				update_post_meta( $pid, 'under_review', '0' );
				update_post_meta( $pid, 'active', '1' );

				$post = get_post( $pid );
				if ( isset( $post->post_title ) && $post->post_title != 'Auto Draft'
					&& isset( $post->post_content ) && $post->post_content != 'Auto Draft' ) {
					$request_post['post_status'] = 'publish';

				} else {
					$request_post['post_status'] = 'draft';

				}
			} else {
				update_post_meta( $pid, 'under_review', '1' );
				$request_post['post_status'] = 'draft';
			}

			wp_publish_post( $pid );
			wp_update_post( $request_post );

			$user_data = get_userdata( $uid );

			// Send e-mails
			if ( $wpjobster_admin_approve_request == "yes" ) {
				wpj_notify_user_translated( 'request_admin_new', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => get_the_title( $pid ) ) );
				wpj_notify_user_translated( 'request_new', $uid, array( '##request_name##' => get_the_title( $pid ) ) );
			} else {
				wpj_notify_user_translated( 'request_admin_acc', 'admin', array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => get_the_title( $pid ), '##request_link##' => get_post_permalink( $pid ) ) );

				if ( ! is_admin() ) {
					wpj_notify_user_translated( 'request_acc', get_post_field( 'post_author', $pid ), array( '##username##' => wpj_get_user_display_type( $user_data->ID ), '##request_name##' => get_the_title( $pid ), '##request_link##' => get_post_permalink( $pid ) ) );
				}
			}

			setcookie( 'wpj_request_id', '', time() - 3600, '/' );

			wp_redirect( add_query_arg( 'submitted', $pid, get_permalink( get_option( 'wpjobster_my_requests_page_id' ) ) ) );
			exit;
		}
	}

	public function getPostCategories() {
		$category_value    = array();
		$subcategory_value = array();

		$meta_category = wp_get_post_terms( WPJ_Form::get( 'requestid', '' ), 'request_cat' );
		if ( is_array( $meta_category ) ) {

			if ( $meta_category ) {
				foreach ( $meta_category as $key => $value ) {
					if ( $value->parent == 0 ) {
						$category_value[] = str_replace( '-req', '', $value->slug );
					} else {
						$subcategory_value[] = str_replace( '-req', '', $value->slug );

						$term_details = get_term_by( 'id', $value->parent, 'request_cat' );
						$current_term = str_replace( '-req', '', $term_details->slug );
						if ( ! in_array( $current_term, $category_value ) ) {
							$category_value[] = $current_term;
						}
					}
				}
				$category_value = array_unique( $category_value );
			}

		} elseif ( $meta_category ) {

			if ( $meta_category[0]->parent == 0 ) {
				$category_value = $meta_category ? str_replace( '-req', '', $meta_category[0]->slug ) : '';
			} else {
				$subcategory_value = $meta_category ? str_replace( '-req', '', $meta_category[0]->slug ) : '';
				$subcategory_value = strtolower( $subcategory_value );

				$term_details = get_term_by( 'id', $meta_category[0]->parent, 'request_cat' );
				$category_value = str_replace( '-req', '', $term_details->slug );
			}

			$category_value = strtolower( $category_value );

		}

		$post_category_value = apply_filters( 'wpj_post_request_category_filter', WPJ_Form::post( 'request_category', $category_value ) );
		$post_subcategory_value = apply_filters( 'wpj_post_request_subcategory_filter', WPJ_Form::post( 'subcat', $subcategory_value ) );

		return array( 'category' => $post_category_value, 'subcategory' => $post_subcategory_value );
	}

	public function getCategoriesToBeSaved( $request_category = '', $request_subcategory = '' ) {
		if ( ! is_array( $request_category ) ) {
			$request_category = array( $request_category );
		}

		if ( ! is_array( $request_subcategory ) ) {
			$request_subcategory = array( $request_subcategory );
		}

		$post_categories = array_merge( $request_category, $request_subcategory );

		$request_category_arr = array();
		if ( $post_categories ) {
			foreach ( $post_categories as $key => $request_category_value ) {
				$job_term = get_term_by( 'slug', $request_category_value , 'job_cat' );
				if ( $job_term ) {

					$request_term = get_term_by( 'slug', $request_category_value . '-req' , 'request_cat' );

					if ( $request_term ) {
						$request_category_arr[] = $request_term->term_id;
					} else {
						if ( $job_term->parent ) {
							$job_category     = get_term_by( 'id', $job_term->parent, 'job_cat' );
							$request_category = get_term_by( 'slug', $job_category->slug . '-req', 'request_cat' );
						} else {
							$job_category     = '';
							$request_category = get_term_by( 'slug', $request_category_value . '-req', 'request_cat' );
							$include_category = true;
						}

						$request_category_id = '';
						if ( ! $request_category ) {
							if ( $job_category ) {
								$new_category = array (
									'cat_name'             => $job_category->name,
									'category_description' => '',
									'category_nicename'    => $job_category->slug . '-req',
									'category-slug'        => $job_category->slug . '-req',
									'taxonomy'             => 'request_cat'
								);
							} else {
								$new_category = array(
									'cat_name'             => $job_term->name,
									'category_description' => '',
									'category_nicename'    => $job_term->slug . '-req',
									'category-slug'        => $job_term->slug . '-req',
									'taxonomy'             => 'request_cat'
								);
							}

							require_once( ABSPATH . 'wp-load.php' );
							require_once( ABSPATH . 'wp-admin/includes/taxonomy.php' );

							$request_category_id = wp_insert_category( $new_category );
						} else {
							$request_category_id = $request_category->term_id;
						}

						if ( isset( $include_category ) ) {
							$request_category_arr[] = $request_category_id;
						}

						if ( $job_term->parent ) {
							$new_subcategory = array(
								'cat_name'             => $job_term->name,
								'category_description' => '',
								'category_nicename'    => $job_term->slug . '-req',
								'category-slug'        => $job_term->slug . '-req',
								'category_parent'      => $request_category_id,
								'taxonomy'             => 'request_cat'
							);

							require_once( ABSPATH . 'wp-load.php' );
							require_once( ABSPATH . 'wp-admin/includes/taxonomy.php' );

							$request_subcategory_id = wp_insert_category( $new_subcategory );
							$request_category_arr[] = $request_subcategory_id;
						}
					}
				}
			}
		}

		return $request_category_arr;
	}

	public function getContentFromBuffer( $fields = '', $method = '', $params = array() ) {
		ob_start();
		$this->fields_content_class = new WPJRequestsNewEditFieldsContent( $params );
		$this->fields_content_class->$method( $params );
		$content = ob_get_contents();
		ob_end_clean();

		$ret = $content;

		return $ret;
	}

	public function firstRun( $page_id = '' ) {
		$page_id = intval( $page_id );

		if ( get_option( 'wpj_request_old_meta_first_run' ) != 'done' ) {
			update_option( 'wpj_request_old_meta_first_run', 'done' );

			$posts = get_posts(
				array(
					'post_type'   => 'request',
					'post_status' => 'publish',
					'numberposts' => -1
				)
			);

			foreach ( $posts as $key => $post ) {
				$pid = $post->ID;

				update_post_meta( $pid, 'request_attachments', get_post_meta( $pid, 'req_attachments', true ) );
				update_post_meta( $pid, 'request_delivery',    get_post_meta( $pid, 'job_delivery', true ) );
				update_post_meta( $pid, 'request_budget_from', get_post_meta( $pid, 'budget_from', true ) );
				update_post_meta( $pid, 'request_budget_to',   get_post_meta( $pid, 'budget', true ) );
				update_post_meta( $pid, 'request_lets_meet',   get_post_meta( $pid, 'req_lets_meet_checked', true ) );
				update_post_meta( $pid, 'request_location',    get_post_meta( $pid, 'request_location_input', true ) );
			}
		}

		if ( get_option( 'wpj_request_instructions_first_run' ) != 'done' ) {
			update_option( 'wpj_request_instructions_first_run', 'done' );

			if ( have_rows( 'request_fields', $page_id ) ) {
				while ( have_rows( 'request_fields', $page_id ) ) {
					the_row();

					update_sub_field( 'instructions', get_field( get_row_layout() . '_instructions', 'options' ) );

					if ( get_row_layout() == 'request_delivery' ) {
						update_sub_field( 'instructions', get_field( 'request_delivery_time_instructions', 'options' ) );
					} elseif ( get_row_layout() == 'request_pick_up_location' ) {
						update_sub_field( 'instructions', get_field( 'request_pick_up_instructions', 'options' ) );
					} elseif ( get_row_layout() == 'request_drop_off_location' ) {
						update_sub_field( 'instructions', get_field( 'request_drop_off_instructions', 'options' ) );
					}
				}
			}
		}
	}

	public function autoImport() {
		if ( get_option( 'wpj_request_page_fields_first_run' ) != 'done' ) {
			update_option( 'wpj_request_page_fields_first_run', 'done' );

			require_once TEMPLATEPATH . '/lib/autoimport/autoimporter.php';

			if ( ! class_exists( 'Auto_Importer' ) ) die( 'Auto_Importer not found' );

			$args = array(
				'file'        => TEMPLATEPATH . '/lib/autoimport/content/page_post_new_edit_request.xml',
				'map_user_id' => 1
			);
			$xml_id = auto_import( $args );

			// assumption: since only one page was imported from xml, it is next id
			$page_id = intval( $xml_id ) + 1;

			update_option( 'wpjobster_new_request_page_id', $page_id );

			return $page_id;
		}
	}
}

add_action( 'admin_init', array( 'WPJRequestsNewEdit', 'init' ) );
add_action( 'init', array( 'WPJRequestsNewEdit', 'saveAnonymousDraft' ) );
