<?php
if ( ! function_exists( 'wpj_advanced_search_post_result' ) ) {
	function wpj_advanced_search_post_result() { ?>

		<div class="post_results">

			<?php $wpj_job = new WPJ_Load_More_Queries(
				array(
					'query_type'     => 'jobs',
					'query_status'   => 'all',
					'function_name'  => wpj_get_job_card_style(),
					'posts_per_page' => get_option( 'posts_per_page' ) ? get_option( 'posts_per_page' ) : 12,
					'new_class_row'  => 'ui three cards'
				)
			);

			if ( $wpj_job->have_rows() ) {
				$wpj_job->show_queries_list_func();

			} else { ?>

				<div class="sixteen wide column">
					<div class="no-results"><?php _e( 'No results found.', 'wpjobster' ); ?></div>
				</div>

			<?php } ?>

		</div>

	<?php }
}

function wpj_get_job_search_query() {

	$order = wpjobster_get_current_order_by_thing();

	$location_default = $lat_default = $lng_default = '';
	if ( get_option( 'wpjobster_html5_geolocation_enable' ) == 'yes' ) {
		$location_default = WPJ_Form::cookie( 'wpj_location', '' );
		$lat_default      = WPJ_Form::cookie( 'wpj_lat', '' );
		$lng_default      = WPJ_Form::cookie( 'wpj_lng', '' );
	}

	$term_get       = WPJ_Form::get( 'term' );
	$category_get   = WPJ_Form::get( 'category' );
	$tag_get        = WPJ_Form::get( 'tag' );
	$min_price_get  = WPJ_Form::get( 'min_price' );
	$max_price_get  = WPJ_Form::get( 'max_price' );
	$radius_get     = WPJ_Form::get( 'radius' );
	$location_get   = WPJ_Form::get( 'location', $location_default );
	$latitude_get   = WPJ_Form::get( 'latitude', $lat_default );
	$longitude_get  = WPJ_Form::get( 'longitude', $lng_default );
	$rating_get     = WPJ_Form::get( 'min_rating' );
	$price_type_get = WPJ_Form::get( 'price_type' );
	$max_days_get   = WPJ_Form::get( 'max_days' );
	$no_deliv_get   = WPJ_Form::get( 'without_delivery' );

	$units  = get_option( 'wpjobster_locations_unit' ) == 'kilometers' ? 6371 : 3959;
	$radius = ! empty( $radius_get ) ? $radius_get : get_option( 'wpj_locations_radius_default', '10' );

	if ( $category_get ) {
		$cat_childrens = array();
		$cats          = get_term_by( 'slug', $category_get, 'job_cat' );
		if ( ! empty( $cats->term_id ) ) {
			$cat_childrens   = get_terms( $cats->taxonomy, array( 'parent' => $cats->term_id, 'hide_empty' => false, 'fields' => 'ids' ) );
			$cat_childrens[] = $cats->term_id;
			$categories      = implode( ',', $cat_childrens );
		}
	}

	if ( $tag_get ) {

		if ( ! is_array( $tag_get ) ) $tag_get = array( $tag_get );

		$tag_childrens = array();
		foreach ( $tag_get as $key => $tag ) {
			$tgs = get_term_by( 'slug', $tag, 'post_tag' );
			if ( ! empty( $tgs->term_id ) ) {
				$tag_childrens[] = $tgs->term_id;
			}
		}

		if ( $tag_childrens ) {
			$tags = implode( ',', $tag_childrens );
		}
	}

	$min_price = $min_price_get ? str_replace( ",", ".", $min_price_get ) : 0;
	$max_price = $max_price_get ? str_replace( ",", ".", $max_price_get ) : '';

	$delivery_comparator = $no_deliv_get ? '=' : '<>';
	$delivery_logical_op = $no_deliv_get ? 'OR' : 'AND';

	/* BUILD QUERY */

	global $wpdb;

	$query = "SELECT p.ID, p.post_title, p.post_content, p.post_author";

	if ( $order == 'price_lowest' || $order == 'price_highest' ) {

		$query .= ", MIN( CAST( pm_price.meta_value AS UNSIGNED ) ) AS min_price ";

	}

	if ( $location_get || ( $order == 'distance' && $latitude_get && $longitude_get ) ) {

		$query .= ", {$units} * acos( cos( radians( {$latitude_get} ) ) * cos( radians( pm_lat.meta_value ) ) * cos( radians ( pm_long.meta_value ) - radians( {$longitude_get} ) ) + sin( radians( {$latitude_get} ) ) * sin( radians ( pm_lat.meta_value ) ) ) AS distance";

	}

	$query .= " FROM {$wpdb->prefix}posts p, {$wpdb->prefix}postmeta pm ";

	if ( $location_get || ( $order == 'distance' && $latitude_get && $longitude_get ) ) {

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_lat ON ( pm.post_id = pm_lat.post_id AND pm_lat.meta_key = 'lat' ) ";

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_long ON ( pm.post_id = pm_long.post_id AND pm_long.meta_key = 'long' ) ";

	}

	if ( $category_get ) {

		$query .= " INNER JOIN {$wpdb->prefix}term_relationships tr_c ON tr_c.object_id = pm.post_id ";

	}

	if ( $tag_get ) {

		$query .= " INNER JOIN {$wpdb->prefix}term_relationships tr_t ON tr_t.object_id = pm.post_id ";

	}

	if ( $rating_get || $order == 'rating' ) {

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_rating ON pm.post_id = pm_rating.post_id AND pm_rating.meta_key = 'job_rating' ";

	}

	if ( $max_days_get ) {

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_max_days ON pm.post_id = pm_max_days.post_id AND pm_max_days.meta_key = 'max_days' ";

	}

	if ( $order == 'price_lowest' || $order == 'price_highest' || $price_type_get == 'package' || $min_price_get || $max_price_get ) {

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_package ON pm.post_id = pm_package.post_id ";

	}

	if ( $price_type_get ) {

		$query .= " LEFT JOIN {$wpdb->prefix}postmeta pm_pricetype ON pm.post_id = pm_pricetype.post_id AND pm_pricetype.meta_key = 'price_type' ";

	}

	if ( $order == 'price_lowest' || $order == 'price_highest' || $min_price_get || $max_price_get ) {

		$include_price_sql = $price_type_get != 'package' ? " pm_price.meta_key = 'price' OR " : '';

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_price ON pm.post_id = pm_price.post_id AND ( {$include_price_sql} pm_price.meta_key = 'package_price_1' OR pm_price.meta_key = 'package_price_2' OR pm_price.meta_key = 'package_price_3' ) ";

	}

	if ( $order == 'views' ) {

		$query .= " INNER JOIN {$wpdb->prefix}postmeta pm_views ON pm.post_id = pm_views.post_id AND pm_views.meta_key = 'job_views_counter' ";

	}

	$query .= " WHERE p.ID = pm.post_id AND p.post_type = 'job' AND p.post_status = 'publish' AND ( pm.meta_key = 'active' AND pm.meta_value = '1' ) ";

		if ( $term_get ) {

			$query .= " AND ( p.post_title LIKE '%{$term_get}%' OR p.post_content LIKE '%{$term_get}%' ) ";

		}

		if ( $category_get && ! empty( $categories ) ) {

			$query .= " AND tr_c.term_taxonomy_id IN ({$categories}) ";

		}

		if ( $tag_get && ! empty( $tags ) ) {

			$query .= " AND tr_t.term_taxonomy_id IN ({$tags}) ";

		}

		if ( $rating_get ) {

			$query .= " AND ( pm_rating.meta_key = 'job_rating' AND pm_rating.meta_value >= {$rating_get} ) ";

		}

		if ( $price_type_get ) {

			if ( $price_type_get == 'fixed' ) {

				$query .= " AND ( pm_pricetype.post_id IS NULL OR pm_pricetype.meta_value = 'fixed' OR pm_pricetype.meta_value = '' ) ";

			} elseif ( $price_type_get == 'package' ) {

				$query .= " AND ( pm_package.meta_key = 'job_packages' AND pm_package.meta_value = 'yes' ) ";

			} else {

				$query .= " AND ( pm_pricetype.meta_value = '{$price_type_get}' ) ";

			}

		}

		if ( ! $min_price && is_numeric( $max_price ) ) {

			$query .= " AND ( ";

				if ( $price_type_get != 'package' ) {
					$query .= " (
						pm_package.meta_key = 'job_packages' AND pm_package.meta_value <> 'yes' AND pm_price.meta_key = 'price'
						AND ( pm_price.meta_value <= {$max_price} OR pm_price.meta_value = '' OR pm_price.meta_value = 0 )
					) ";

				}

				if ( ! $price_type_get ) { $query .= " OR ( "; }

					if ( ! $price_type_get || $price_type_get == 'package' ) {

						$query .= "
							( pm_package.meta_key = 'job_packages' AND pm_package.meta_value = 'yes' )
							AND (
								( pm_price.meta_key = 'package_price_1' AND pm_price.meta_value <= {$max_price} )
								OR ( pm_price.meta_key = 'package_price_2' AND pm_price.meta_value <= {$max_price} )
								OR ( pm_price.meta_key = 'package_price_3' AND pm_price.meta_value <= {$max_price} )
							)
						";

					}

				if ( ! $price_type_get ) { $query .= " ) "; }

			$query .= " ) ";

		} elseif ( $min_price_get && is_numeric( $min_price ) && ! $max_price ) {

			$include_empty_sql = $min_price == 0 ? " OR pm_price.meta_value = '' OR pm_price.meta_value = 0 " : "";

			$query .= " AND ( ";

				if ( $price_type_get != 'package' ) {
					$query .= " (
						pm_package.meta_key = 'job_packages' AND pm_package.meta_value <> 'yes' AND pm_price.meta_key = 'price'
						AND ( pm_price.meta_value >= {$min_price} {$include_empty_sql} )
					) ";

				}

				if ( ! $price_type_get ) { $query .= " OR ( "; }

					if ( ! $price_type_get || $price_type_get == 'package' ) {

						$query .= "
							( pm_package.meta_key = 'job_packages' AND pm_package.meta_value = 'yes' )
							AND (
								( pm_price.meta_key = 'package_price_1' AND pm_price.meta_value >= {$min_price} )
								OR ( pm_price.meta_key = 'package_price_2' AND pm_price.meta_value >= {$min_price} )
								OR ( pm_price.meta_key = 'package_price_3' AND pm_price.meta_value >= {$min_price} )
							)
						";

					}

				if ( ! $price_type_get ) { $query .= " ) "; }

			$query .= " ) ";

		} elseif ( is_numeric( $min_price ) && is_numeric( $max_price ) ) {

			$query .= " AND ( ";

				if ( $price_type_get != 'package' ) {
					$query .= " (
						pm_package.meta_key = 'job_packages' AND pm_package.meta_value <> 'yes' AND pm_price.meta_key = 'price'
						AND ( pm_price.meta_value BETWEEN {$min_price} AND {$max_price} )
					) ";

				}

				if ( ! $price_type_get ) { $query .= " OR ( "; }

					if ( ! $price_type_get || $price_type_get == 'package' ) {

						$query .= "
							( pm_package.meta_key = 'job_packages' AND pm_package.meta_value = 'yes' )
							AND (
								( pm_price.meta_key = 'package_price_1' AND pm_price.meta_value BETWEEN {$min_price} AND {$max_price} )
								OR ( pm_price.meta_key = 'package_price_2' AND pm_price.meta_value BETWEEN {$min_price} AND {$max_price} )
								OR ( pm_price.meta_key = 'package_price_3' AND pm_price.meta_value BETWEEN {$min_price} AND {$max_price} )
							)
						";

					}

				if ( ! $price_type_get ) { $query .= " ) "; }

			$query .= " ) ";

		}

		if ( $max_days_get ) {

			$query .= "
				AND (
					pm_max_days.meta_value <= {$max_days_get}
					{$delivery_logical_op} pm_max_days.meta_value {$delivery_comparator} 0
					{$delivery_logical_op} pm_max_days.meta_value {$delivery_comparator} ''
				)
			";

		}

		if ( $order == 'price_lowest' || $order == 'price_highest' ) {

			$query .= " AND ( ";

				if ( $price_type_get != 'package' ) {
					$query .= " ( pm_package.meta_key = 'job_packages' AND pm_package.meta_value <> 'yes' AND pm_price.meta_key = 'price' ) ";
				}

				if ( ! $price_type_get ) { $query .= " OR ( "; }

					if ( ! $price_type_get || $price_type_get == 'package' ) {
						$query .= " ( pm_package.meta_key = 'job_packages' AND pm_package.meta_value = 'yes' )
							AND ( pm_price.meta_key = 'package_price_1' OR pm_price.meta_key = 'package_price_2' OR pm_price.meta_key = 'package_price_3' ) ";
					}

				if ( ! $price_type_get ) { $query .= " ) "; }

			$query .= " ) ";

		}

	$query .= " GROUP BY p.ID ";

	if ( $location_get ) {

		$query .= " HAVING distance < {$radius} ";

	}

	if ( $order == 'new' ) {

		$query .= " ORDER BY p.post_date DESC ";

	} elseif ( $order == 'old' ) {

		$query .= " ORDER BY p.post_date ASC ";

	} elseif ( $order == 'rating' ) {

		$query .= " ORDER BY ( pm_rating.meta_value + 0 ) DESC ";

	} elseif ( $order == 'views' ) {

		$query .= " ORDER BY ( pm_views.meta_value + 0 ) DESC ";

	} elseif ( $order == 'distance' && $latitude_get && $longitude_get ) {

		$query .= " ORDER BY distance ASC ";

	} elseif ( $order == 'price_lowest' || $order == 'price_highest' ) {

		if ( $order == 'price_lowest' ) {

			$query .= " ORDER BY min_price ASC, ( pm_price.meta_value + 0 ) ASC ";

		} else {

			$query .= " ORDER BY min_price DESC, ( pm_price.meta_value + 0 ) DESC ";

		}

	}

	return $query;
}