<?php
/**
 * List Requests Shortcode [show_request_list]
 *
 * arguments      | accepts         | default
 * ----------------------------------------------------
 * directlink     | true/false      | false                 TODO
 * page           | single_request/all_requests/search_request/request_category | false
 * category       | (int/slug/name) | all
 * posts_per_page | any number      | -1
 * orderby        | any meta_key    | date
 * order          | ASC/DESC        | DESC
 * end_days_no    | any number      | 0
 */

wpj_add_shortcode( 'show_request_list', 'wpj_display_request_list_func' );
function wpj_display_request_list_func( $atts = '' ) {

	$atts = shortcode_atts( array(
		'directlink'     => '',
		'page'           => '',
		'order'          => '',
		'orderby'        => '',
		'category'       => '',
		'posts_per_page' => '',
		'end_days_no'    => '',
	), $atts );

	$directlink     = $atts['directlink'];
	$page           = $atts['page'];
	$order          = $atts['order'];
	$orderby        = $atts['orderby'];
	$category       = $atts['category'];
	$posts_per_page = $atts['posts_per_page'];
	$end_days_no    = $atts['end_days_no'];

	/* PAGE */
	if ( ! $page ) {
		global $post;
		$page = isset( $post->post_name ) ? $post->post_name : '';
	}

	/* CATEGORY */

	// by id
	$this_term = ctype_digit( $category ) || is_int( $category ) ? get_term_by( 'id', $category, 'job_cat' ) : false;

	// by slug
	if ( ! $this_term ) { $this_term = get_term_by( 'slug', $category, 'request_cat' ); }

	// by name
	if ( ! $this_term ) { $this_term = get_term_by( 'name', $category, 'request_cat' ); }

	$category_id = isset( $this_term->term_id ) && is_numeric( $this_term->term_id ) ? $this_term->term_id : false;

	$tax_query = $category_id ? array(
		array(
			'taxonomy' => 'request_cat',
			'field'    => 'term_id',
			'terms'    => array( $category_id ),
		),
	) : array();

	/* ARGS */
	$args = array(
		'post_type'   => 'request',
		'paged'       => 1,
		'post_status' => 'publish',
		'orderby'     => $orderby && $orderby != 'date' ? 'meta_value' : 'date',
		'order'       => $order == 'ASC' || $order == 'DESC' ? $order : 'DESC',
	);

	if ( $orderby ) {
		if ( $orderby == 'delivery'
			|| $orderby == 'deadline'
			|| $orderby == 'start_date'
			|| $orderby == 'end_date'
		) {
			$orderby = 'request_' . $orderby;
		}

		$args['meta_key'] = $orderby;
	}

	if ( $posts_per_page ) {
		$args['posts_per_page'] = $posts_per_page;
	}

	if ( $tax_query ) {
		$args['tax_query'] = $tax_query;
	}

	$meta_query = array();

	if ( $end_days_no ) {

		$calculated_days = strtotime( '+' . $end_days_no . 'days', current_time( 'timestamp', 1 ) );

		$end_days_args = array(
			'relation' => 'OR',
			array(
				'relation' => 'AND',
				array(
					'key'     => 'request_end_date',
					'compare' => 'EXISTS'
				),
				array(
					'key'     => 'request_end_date',
					'compare' => '!=',
					'value'   => ''
				),
				array(
					'key'     => 'request_end_date',
					'value'   => $calculated_days,
					'compare' => '<=',
				),
				array(
					'key'     => 'request_end_date',
					'value'   => current_time( 'timestamp', 1 ),
					'compare' => '>=',
				)
			),
			array(
				'relation' => 'AND',
				array(
					'key'     => 'request_deadline',
					'compare' => 'EXISTS'
				),
				array(
					'key'     => 'request_deadline',
					'compare' => '!=',
					'value'   => ''
				),
				array(
					'key'     => 'request_deadline',
					'value'   => $calculated_days,
					'compare' => '<=',
				),
				array(
					'key'     => 'request_deadline',
					'value'   => current_time( 'timestamp', 1 ),
					'compare' => '>=',
				)
			)
		);

		array_push( $meta_query, $end_days_args );

	};

	array_push( $meta_query, wpj_get_user_requests( '', 'active', 'query' ) );

	$args = $args + array(
		'function_name' => 'wpj_show_request_content',
		'params'        => array( $page, $directlink ),
		'meta_query'    => $meta_query
	);

	if ( get_option( 'wpjobster_html5_geolocation_enable' ) == 'yes'
		&& $orderby == 'distance'
	) {
		// add these out of search only if
		// browser location enabled and sort by is distance
		$args['search_args'] = array(
			'latitude'  => WPJ_Form::cookie( 'wpj_lat', '' ),
			'longitude' => WPJ_Form::cookie( 'wpj_lng', '' ),
			'location'  => WPJ_Form::cookie( 'wpj_location', '' ),
			'radius'    => '99999',
		);
	}

	$wpj_requests = new WPJ_Load_More_Posts( $args );

	$ret = '<div><div>';
	if ( $wpj_requests->have_rows() ) {
		ob_start();
		$wpj_requests->show_posts_list_func();
		$ret .= ob_get_contents();
		ob_end_clean();
	} else {
		$ret .= '<div class="ui segment">' . __( "There are no requests yet.", "wpjobster" ) . '</div>';
	}
	$ret .= '</div></div>';

	return $ret;
}
