<?php
add_action( 'init', 'wpjobster_create_post_type' );
if ( ! function_exists( 'wpjobster_create_post_type' ) ) {
	function wpjobster_create_post_type() {

		/* Post type: job */
		register_post_type( 'job',
			array(
				'labels' => array(
					'name'          => __( 'Jobs', 'wpjobster' ),
					'singular_name' => __( 'Job', 'wpjobster' ),
					'add_new'       => __( 'Add New Job', 'wpjobster' ),
					'new_item'      => __( 'New Job', 'wpjobster' ),
					'edit_item'     => __( 'Edit Job', 'wpjobster' ),
					'add_new_item'  => __( 'Add New Job', 'wpjobster' ),
					'search_items'  => __( 'Search Jobs', 'wpjobster' )
				),
				'public'               => true,
				'menu_position'        => 5,
				'register_meta_box_cb' => 'wpjobster_set_job_metaboxes',
				'has_archive'          => 'all-jobs',
				'rewrite' => array(
					'slug'       => wpj_get_job_single_permalink() . '/' . ( get_option( 'wpjobster_jobs_permalink_slug_type' ) == 'author' ? '%author%' : '%job_cat%' ),
					'with_front' => false
				),
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'comments'
				),
				'_builtin'           => false,
				'menu_icon'          => get_template_directory_uri() . "/assets/images/laptopcomputer.png",
				'publicly_queryable' => true,
				'hierarchical'       => false
			)
		);

		/* Post type: request */
		register_post_type( 'request',
			array(
				'labels' => array(
					'name'          => __( 'Requests', 'wpjobster' ),
					'singular_name' => __( 'Request', 'wpjobster' ),
					'add_new'       => __( 'Add New Request', 'wpjobster' ),
					'new_item'      => __( 'New Request', 'wpjobster' ),
					'edit_item'     => __( 'Edit Request', 'wpjobster' ),
					'add_new_item'  => __( 'Add New Request', 'wpjobster' ),
					'search_items'  => __( 'Search Requests', 'wpjobster' )
				),
				'public'               => true,
				'menu_position'        => 7,
				'register_meta_box_cb' => 'wpjobster_set_request_metaboxes',
				'has_archive'          => wpj_get_all_requests_permalink(),
				'rewrite' => array(
					'slug'       => wpj_get_request_single_permalink() . '/' . ( get_option( 'wpjobster_requests_permalink_slug_type' ) == 'author' ? '%author%' : '%request_cat%' ),
					'with_front' => false
				),
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'comments'
				),
				'_builtin'           => false,
				'menu_icon'          => get_template_directory_uri() . "/assets/images/question43.png",
				'publicly_queryable' => true,
				'hierarchical'       => false
			)
		);

		/* Post type: offer */
		register_post_type( 'offer',
			array(
				'labels' => array(
					'name'          => __( 'Custom Offers', 'wpjobster' ),
					'singular_name' => __( 'Custom Offer', 'wpjobster' ),
					'add_new'       => __( 'Add New Offer', 'wpjobster' ),
					'new_item'      => __( 'New Offer', 'wpjobster' ),
					'edit_item'     => __( 'Edit Offer', 'wpjobster' ),
					'add_new_item'  => __( 'Add New Offer', 'wpjobster' ),
					'search_items'  => __( 'Search Offer', 'wpjobster' )
				),
				'public'               => true,
				'menu_position'        => 6,
				'register_meta_box_cb' => 'wpjobster_set_offer_metaboxes',
				'has_archive'          => wpj_get_all_proposals_permalink(),
				'rewrite' => array(
					'slug'       => 'offers',
					'with_front' => false
				),
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'comments'
				),
				'_builtin'           => false,
				'menu_icon'          => get_template_directory_uri() . "/assets/images/tags2.png",
				'publicly_queryable' => true,
				'hierarchical'       => false
			)
		);

		/* Post type: news */
		register_post_type( 'news',
			array(
				"labels" => array(
					"name"               => __( "News","wpjbster" ),
					"singular_name"      => __( "News","wpjbster" ),
					"add_new"            => __( "Add New","wpjbster" ),
					"add_new_item"       => __( "Add New News","wpjbster" ),
					"edit_item"          => __( "Edit News","wpjbster" ),
					"new_item"           => __( "New News","wpjbster" ),
					"view_item"          => __( "View News","wpjbster" ),
					"search_items"       => __( "Search News","wpjbster" ),
					"not_found"          => __( "No News Found","wpjbster" ),
					"not_found_in_trash" => __( "No News Found In Trash","wpjbster" ),
					"parent_item_colon"  => __( "Parent News:","wpjbster" ),
					"menu_name"          => __( "News","wpjbster" ),
					"all_items"          => __( "All News","wpjbster" ),
				),
				"public"        => true,
				"menu_position" => 8,
				"has_archive"   => wpj_get_all_news_permalink(),
				"rewrite"       => array(
					'slug'       => wpj_get_news_single_permalink() . '/' . ( get_option( 'wpjobster_news_permalink_slug_type' ) == 'author' ? '%author%' : '%news_cat%' ),
					'with_front' => false
				),
				'supports' => array(
					'title',
					'editor',
					'author',
					'thumbnail',
					'excerpt',
					'comments'
				),
				'_builtin'           => false,
				'publicly_queryable' => true,
				'hierarchical'       => false
			)
		);

		/* Taxonomy for job: job categories */
		register_taxonomy( 'job_cat', array( 'job' ), array( 'hierarchical' => true, 'label' => __( 'Job Categories', 'wpjobster' ) ) );

		/* Taxonomy for job: tags */
		register_taxonomy_for_object_type( 'post_tag', 'job' );

		/* Taxonomy for request: request categories */
		register_taxonomy( 'request_cat', 'request', array( 'hierarchical' => true, 'label' => __( 'Request Categories', 'wpjobster' ) ) );

		/* Taxonomy for request: tags */
		register_taxonomy_for_object_type( 'post_tag', 'request' );

		/* Taxonomy for news: news categories */
		register_taxonomy( 'news_cat', 'news', array( 'hierarchical' => true, 'label' => __( 'News Categories', 'wpjobster' ) ) );

		/* Taxonomy for news: tags */
		register_taxonomy_for_object_type( 'post_tag', 'news' );

		/* Add support for job post type */
		add_post_type_support( 'job', 'author' );
	}
}
