<?php

// skip wp_redirect() if currently editing the page with a known page builder
add_filter( 'wp_redirect', 'wpj_redirect_pagebuilder_filter', 10, 2 );
function wpj_redirect_pagebuilder_filter( $location, $status ) {
	// check first if admin is logged in
	if ( ( function_exists( 'is_user_logged_in' ) && is_user_logged_in() )
		&& ( function_exists( 'current_user_can' ) && current_user_can( 'manage_options' ) )
	) {
		// wpj_is_pagebuilder_editor() may be undefined on early hooks, check directly
		global $vc_is_inline;
		$vc_inline = ( function_exists( 'vc_is_inline' ) && vc_is_inline() ) ? true : false;
		if ( $vc_inline
			|| isset( $_GET['brizy-edit'] )
			|| isset( $_GET['brizy-edit-iframe'] )
		) {
			$location = '';
		}
	}

	return $location;
}


// Homepage switch while logged in
add_filter( 'pre_option_page_on_front', 'page_on_front_logged_in' );
function page_on_front_logged_in( $id ) {
	$homepage_logged_in = apply_filters( 'wpj_main_page_url_user_filter', get_option( 'main_page_url_user' ) );

	// wpj_is_pagebuilder_editor() may be undefined on early hooks, check directly
	global $vc_is_inline;
	$vc_inline = ( function_exists( 'vc_is_inline' ) && vc_is_inline() ) ? true : false;
	if ( $vc_inline
		|| isset( $_GET['brizy-edit'] )
		|| isset( $_GET['brizy-edit-iframe'] )
	) {
		$wpj_is_pagebuilder_editor =  true;
	} else {
		$wpj_is_pagebuilder_editor = false;
	}

	if ( is_user_logged_in()
		&& $homepage_logged_in
		&& ! is_admin()                          // not admin dashboard
		&& ! function_exists( 'member_home' )    // not already redirecting in older acc seg
		&& ! $wpj_is_pagebuilder_editor          // not page builder
	) {
		return $homepage_logged_in;
	}

	return $id;
}

// Register redirect
if ( ! empty( $_POST['wp-submit'] ) ) {
	add_action( 'user_register', 'auto_login_new_user', 11 );
}
function auto_login_new_user( $user_id ) {
	wp_set_current_user( $user_id );
	wp_set_auth_cookie( $user_id, false, is_ssl() );

	$redirect = get_option( 'wpjobster_register_redirection_page' );
	if ( $redirect >= 1 ) {
		$redirect_to = get_permalink( $redirect );
	} else {
		$redirect_to = home_url();
	}

	wp_redirect( $redirect_to ); exit;
}

// Login redirect
add_filter( 'login_redirect','wpjobster_login_redirect', 999 );
function wpjobster_login_redirect( $redirect_to, $request = '', $user = null ) {
	if ( isset($_REQUEST['redirect_to'] ) ) {
		$redirect_to = $_REQUEST['redirect_to'];
	} else {
		$redirect_to = home_url();
	}

	return $redirect_to;
}

// Password reset redirect
add_action( 'password_reset', 'wpjobster_lost_password_reset_redirect', 10, 2 );
function wpjobster_lost_password_reset_redirect( $user, $new_pass ) {
	wp_set_password( $new_pass, $user->ID );
	wp_redirect( wp_login_url() ); exit;
}

add_filter( 'template_redirect', 'wpjobster_template_redirect' );
function wpjobster_template_redirect() {

	// Global Vars
	global $wp_query, $wp_rewrite, $post, $wp;

	// Current page or post ID
	$my_pid = isset( $post->ID ) ? $post->ID : '';

	// Redirect to public homepage if not logged in
	$homepage = get_option( 'page_on_front' );
	$homepage_logged_in = get_option( 'main_page_url_user' );
	if ( $my_pid
		&& $my_pid != $homepage // avoid redirect loop
		&& $my_pid == $homepage_logged_in
		&& ! is_user_logged_in()
	) {
		if ( wp_redirect( home_url() ) ) { exit; }
	}

	// Get WPJ page IDs
	$wpjobster_post_new_page_id                 = get_option( 'wpjobster_post_new_page_id' );
	$wpjobster_post_new_request_page_id         = get_option( 'wpjobster_new_request_page_id' );
	$wpjobster_my_account_page_id               = get_option( 'wpjobster_my_account_page_id' );
	$wpjobster_my_account_shopping_page_id      = get_option( 'wpjobster_my_account_shopping_page_id' );
	$wpjobster_my_account_sales_page_id         = get_option( 'wpjobster_my_account_sales_page_id' );
	$wpjobster_my_account_personal_info_page_id = get_option( 'wpjobster_my_account_personal_info_page_id' );
	$wpjobster_my_account_payments_page_id      = get_option( 'wpjobster_my_account_payments_page_id' );
	$wpjobster_my_favorites_page_id             = get_option( 'wpjobster_my_favorites_page_id' );
	$wpjobster_my_account_priv_mess_page_id     = get_option( 'wpjobster_my_account_priv_mess_page_id' );
	$wpjobster_my_account_reviews_page_id       = get_option( 'wpjobster_my_account_reviews_page_id' );
	$wpjobster_account_verification_page_id	    = get_option( 'wpjobster_account_verification_page_id' );

	// Get user type( buyer or seller )
	$user_type = '';
	if ( is_user_logged_in() ) {
		global $current_user;
		$current_user = wp_get_current_user();
		$uid = $current_user->ID;

		$user_type = get_user_meta( $uid, 'wpjobster_user_type', true );
	}

	// Pages that are allowed if phone number or email is still not verified
	$admin_custom_allowed_pages = get_option( 'wpjobster_locked_allowed_pages' );
	if ( $user_type == "seller" ) {
		$allowed_pages_id = array( $wpjobster_my_account_page_id, $wpjobster_my_account_personal_info_page_id );
	} else {
		$allowed_pages_id = array( $wpjobster_my_account_shopping_page_id, $wpjobster_my_account_personal_info_page_id, $wpjobster_my_account_sales_page_id, $wpjobster_account_verification_page_id );
	}
	if ( is_array( $admin_custom_allowed_pages ) && $admin_custom_allowed_pages ) {
		$allowed_pages_id = array_merge( $allowed_pages_id, $admin_custom_allowed_pages );
		$allowed_pages_id = array_unique( $allowed_pages_id );
	}

	// checking current page is not sending verification code
	if ( ! ( isset( $_GET['jb_action'] ) && $_GET['jb_action'] == 'verify_email' )
		&& ! ( isset( $_GET['jb_action'] ) && $_GET['jb_action'] == 'verify_phone' )
	) {
		// Lock to allowed_pages until phone number is verified
		if ( is_user_logged_in() ) {
			global $current_user;
			$current_user = wp_get_current_user();
			$uid = $current_user->ID;
			$user_cell_number = get_user_meta( $uid, "cell_number" );

			$is_verify_number = get_option( 'wpjobster_verify_phone_numbers' );
			if ( $is_verify_number=='yes'
				&& get_user_meta( $uid, 'uz_phone_verification', true ) != 1
				&& get_option( 'wpjobster_lock_verify_phone_numbers' ) == 'yes'
				&& ! in_array( $my_pid, $allowed_pages_id )
			) {
				if ( $user_type == "seller" ) {
					$redirect_url = get_permalink( $wpjobster_my_account_page_id );
				} else {
					$redirect_url = get_permalink( $wpjobster_my_account_shopping_page_id );
				}
			}
		}

		// Lock to allowed_pages until email is verified
		if ( is_user_logged_in() ) {
			$is_email_address = get_option( 'wpjobster_lock_verify_email_address' );
			if ( $is_email_address == 'yes'
				&& get_option( 'wpjobster_verify_email' ) != 'no'
				&& get_user_meta( $uid, 'uz_email_verification', true ) != 1
				&& ! in_array( $my_pid, $allowed_pages_id )
			) {
				if ( $user_type == "seller" ) {
					$redirect_url = get_permalink( $wpjobster_my_account_page_id );
				} else {
					$redirect_url = get_permalink( $wpjobster_my_account_shopping_page_id );
				}
			}
		}
	}

	$redirect_uri = isset( $redirect_url ) ? $redirect_url : false;
	$redirect_uri = apply_filters( 'wpj_theme_redirects_filter', $redirect_uri );

	if ( $redirect_uri ) {
		if ( wp_redirect( $redirect_uri ) ) { exit; }
	}

	// Go to login page if the user isn't logged in
	$post_parent = isset( $post->post_parent ) ? $post->post_parent : '';
	if ( $my_pid != ''
		&& ( $my_pid == $wpjobster_my_account_page_id
		|| $post_parent == $wpjobster_my_account_page_id
		|| $my_pid == $wpjobster_my_account_priv_mess_page_id
		|| $my_pid == $wpjobster_my_account_reviews_page_id
		|| $my_pid == $wpjobster_my_account_sales_page_id
		|| $my_pid == $wpjobster_my_account_shopping_page_id
		|| $my_pid == $wpjobster_my_account_personal_info_page_id
		|| $my_pid == $wpjobster_my_account_payments_page_id
		|| $my_pid == $wpjobster_my_favorites_page_id ) ) {

			if ( ! is_user_logged_in() ) {
				if ( wp_redirect( wp_login_url( get_current_page_url() ) ) ) { exit; }
			}
	}

	//--> START redirect by jb_action param
	$jb_action = wpjobster_get_jb_action();

	if ( $jb_action == "edit_job" ) {
		if ( wp_redirect(
			add_query_arg( array(
				'jb_action' => 'job_edit',
				'jobid'     => isset( $_GET['jobid'] ) ? $_GET['jobid'] : $my_pid,
			), get_permalink( $wpjobster_post_new_page_id ) )
		) ) { exit; }
	}

	if ( $jb_action == "edit_request" ) {
		if ( wp_redirect(
			add_query_arg( array(
				'jb_action' => 'request_edit',
				'requestid' => isset( $_GET['request_id'] ) ? $_GET['request_id'] : $my_pid,
			), get_permalink( $wpjobster_post_new_request_page_id ) )
		) ) { exit; }
	}

	if ( $jb_action == "purchase_this" ) {
		get_template_part( 'template-parts/pages/payments/page', 'payment-purchase-this' );
		die();
	}

	if ( $jb_action == "loader_page" ) {
		get_template_part( 'template-parts/pages/payments/page', 'payment-loader' );
		die();
	}

	if ( $jb_action == "chat_box" ) {
		$orderid = isset( $_GET['oid'] ) ? $_GET['oid'] : '';
		$order_exist = wpjobster_get_order( $orderid );
		if ( $order_exist ) {
			get_template_part( 'template-parts/pages/payments/page', 'payment-chat-box' );
		} else {
			if ( wp_redirect( get_site_url() ) ) { exit; }
		}
		die();
	}

	if ( $jb_action == "mark_delivered" ) {
		wpj_mark_delivered();
		die();
	}

	if ( $jb_action == "mark_completed" ) {
		wpj_mark_completed();
		die();
	}

	if ( $jb_action == "show_bank_details" ) {
		get_template_part( 'template-parts/pages/payments/page', 'payment-bank-details' );
		die();
	}

	if ( $jb_action == "verify_email" ) {
		get_template_part( 'template-parts/pages/user/page', 'user-email' );
		die();
	}

	if ( $jb_action == "verify_phone" ) {
		get_template_part( 'template-parts/pages/user/page', 'user-phone' );
		die();
	}

	if ( $jb_action == "resend_withdrawal_mail" ) {
		wpj_confirm_withdrawal_email( $_GET['uid'], $_GET['key'] );
		die();
	}

	if ( $jb_action == 'feature_job' ) {
		get_template_part( 'template-parts/pages/job/page', 'job-feature' );
		die();
	}

	if ( $jb_action == 'badges' ) {
		get_template_part( 'template-parts/pages/user/page', 'user-badges' );
		die();
	}
	//<-- END redirect by jb_action param

	//--> START payment to gateways
	if ( ! empty( $_GET['pay_for_item'] ) ) {
		$sk = $_GET['pay_for_item'];

		$action = "payment";

		$payment_type = isset( $_REQUEST['payment_type'] ) ? $_REQUEST['payment_type'] : 'job_purchase';

		/* Redirect by payment type */
		$payment_type_arr = array( 'feature', 'custom_extra', 'subscription', 'topup', 'job_purchase', 'tips' );
		foreach ( $payment_type_arr as $pt ) {
			if ( $payment_type == $pt ) {
				$curr_pt = $pt == 'feature' ? 'featured' : $pt;
				$curr_pt = $pt == 'topup' ? 'credit' : $curr_pt;

				include_once( get_template_directory() . '/lib/gateways/common.php');

				$process_action = '';
				$response_action = '';

				if ( $_GET['pay_for_item'] == 'credits' ) {
					$response_action = $process_action = 'show_credit_form';
				}

				if ( $_GET['pay_for_item'] == 'cod' ) {
					$response_action = $process_action = 'show_cod_form';
				}

				$wpjobster_payment_gateways = get_wpjobster_payment_gateways();
				foreach ( $wpjobster_payment_gateways as $order_index => $gateway ) {
					if ( $sk == $gateway['unique_id'] && isset( $gateway['action'] ) ) {
						$process_action = $gateway['action'];
					}
				}

				if ( $process_action != '' ) {
					include_once( get_template_directory() . '/lib/gateways/user_' . $curr_pt . '.php' );
				} else {
					include_once( get_template_directory() . '/lib/gateways/' . $sk . '.php' );
				} die();
			}
		}

		die();
	}
	//<-- END payment to gateways

	//--> START payment response from gateways
	if ( isset( $_REQUEST['custom'] ) ) {
		$payment = wpj_get_payment( array(
			'id' => $_REQUEST['custom'],
		) );
		$payment_type = $payment->payment_type;
	} else {
		$payment_type = isset( $_REQUEST['payment_type'] ) ? $_REQUEST['payment_type'] : '';
	}

	if ( ! empty( $_GET['payment_response'] ) ) {
		$sk = $_GET['payment_response'];

		$action = "process_payment";

		/* Redirect by payment type */
		$payment_type_arr = array( 'feature', 'custom_extra', 'subscription', 'topup', 'job_purchase', 'tips' );
		foreach ( $payment_type_arr as $pt ) {
			if ( $payment_type == $pt ) {
				$curr_pt = $pt == 'feature' ? 'featured' : $pt;
				$curr_pt = $pt == 'topup' ? 'credit' : $curr_pt;

				include_once( get_template_directory() . '/lib/gateways/common.php');

				$response_action = '';

				$wpjobster_payment_gateways = get_wpjobster_payment_gateways();
				foreach( $wpjobster_payment_gateways as $order_index => $gateway ) {
					$res_str = $gateway['unique_id'] . "_response";
					if ( ( $sk == $res_str || $sk ==  $gateway['unique_id'] ) && isset( $gateway['action'] ) ) {
						$process_action = $gateway['response_action'];
					}
				}

				if ( $process_action != '' ) {
					include_once( get_template_directory() . '/lib/gateways/user_' . $curr_pt . '.php' );
				} die();
			}
		}

		$no_gateway_defined = false;
		if ( $payment_type ) {
			foreach ( $payment_type_arr as $pt ) {
				if ( ! in_array( $payment_type, $pt ) ) {
					$no_gateway_defined = true;
				}
			}
		} else {
			$no_gateway_defined = true;
		}

		if ( $no_gateway_defined ) {
			include_once ( get_template_directory() . '/lib/gateways/common.php');

			$response_action = '';

			$wpjobster_payment_gateways = get_wpjobster_payment_gateways();
			foreach ( $wpjobster_payment_gateways as $order_index => $gateway ) {
				$res_str = $gateway['unique_id'] . "_response";
				if ( ( $sk == $res_str || $sk ==  $gateway['unique_id'] ) && isset( $gateway['response_action'] ) ) {
					$response_action = $gateway['response_action'];
				}
			}

			if ( $response_action != '' ) {

				$process_action = $response_action;

				$wcommon = wpjobster_all_common_payment_type_classes( $payment_type, $sk, true );

				do_action( $process_action, $payment_type, $wcommon );

			} else {

				if ( get_option( "wpjobster_{$sk}_developed_in_theme" ) == "yes" ) {
					include get_template_directory() . "/lib/gateways/wpjobster_{$sk}.php";
				} else {
					$plugin_path = WP_PLUGIN_DIR;
					include $plugin_path . "/wpjobster-{$sk}/wpjobster-{$sk}.php";
				}

			}
		}
	}
	// <-- END payment response from gateways

	//--> START payout response from gateways
	if ( ! empty( $_GET['payout_response'] ) ) {
		include_once get_template_directory() . '/vendor/PayPal-PHP-SDK/vendor/paypal/rest-api-sdk-php/wpj/payment.php';
	}
	//<-- END payout response from gateways

	// check if logged in when access the post new page
	if ( $my_pid == $wpjobster_post_new_page_id ) {

		if ( ! is_user_logged_in() ) {
			if ( wp_redirect( wp_login_url( get_permalink() ) ) ) { exit; }
		}

		global $current_user;
		$current_user = wp_get_current_user();

		$set_ad = ! isset( $_GET['jobid'] ) ? 1 : 0;
		if ( $set_ad == 1 ) {
			$pid = wpjobster_get_auto_draft( $current_user->ID, 'job' );

			update_post_meta( $pid, 'home_featured_now', "z" );
			update_post_meta( $pid, 'category_featured_now', "z" );
			update_post_meta( $pid, 'subcategory_featured_now', "z" );

			if ( wp_redirect( wpjobster_post_new_with_pid_stuff_thg( $pid ) ) ) { exit; }
		}
	}

	// check if logged in when accessing the my account page
	if ( $my_pid == $wpjobster_my_account_page_id ) {
		if ( ! is_user_logged_in() ) {
			if ( wp_redirect( wp_login_url( get_permalink() ) ) ) { exit; }
		}
	}

}
