<?php
// Helper Functions
add_action( 'admin_enqueue_scripts', 'wpjobster_add_common_scripts', 9 );
add_action( 'wp_enqueue_scripts', 'wpjobster_add_common_scripts', 9 );
function wpjobster_add_common_scripts() {
	// Google Maps
	if ( get_option( 'wpjobster_location_api_provider' ) == ''
		|| get_option( 'wpjobster_location_api_provider' ) == 'google' ) {
		$maps_key_url = get_option( 'wpjobster_google_maps_api_key' ) ? 'key=' . get_option( 'wpjobster_google_maps_api_key' ) . '&' : '';
		wp_enqueue_script( 'maps-api', 'https://maps.googleapis.com/maps/api/js?' . $maps_key_url . 'v=3.exp&libraries=places', array( 'jquery' ), false, true );
	}

	// Common
	wp_enqueue_script( 'wpj-hooks-scripts', get_template_directory_uri() . '/assets/js/common/hooks.js', array( 'jquery' ), wpjobster_VERSION, false );
	wp_enqueue_script( 'wpj-common-scripts', get_template_directory_uri() . '/assets/js/common/helpers.js', array( 'jquery' ), wpjobster_VERSION, false );
	wp_enqueue_script( 'wpj-moment-scripts', get_template_directory_uri() . '/assets/js/common/moment.js', array( 'jquery' ), wpjobster_VERSION, false );

	wpj_include_assets( get_template_directory() . '/assets/js/common', get_template_directory_uri() . '/assets/js/common', 'js', array( 'hooks', 'helpers', 'moment' ), false );

	wpj_include_assets( get_template_directory() . '/assets/css/vendor/common', get_template_directory_uri() . '/assets/css/vendor/common', 'css' );

	// No-defer
	wp_enqueue_script( 'wpj-no-defer-scripts', get_template_directory_uri() . '/assets/min/js/no-defer.min.js', array( 'jquery' ), wpjobster_VERSION, false );
}

// Front Scripts & Styles
add_action( 'wp_enqueue_scripts', 'wpjobster_add_theme_styles', 10 );
function wpjobster_add_theme_styles() {
	// jQuery libraries
	wp_enqueue_script( 'jquery-effects-slide' );
	wp_enqueue_script( 'jquery-touch-punch' );
	wp_enqueue_script( 'jquery-ui-autocomplete' );
	wp_enqueue_script( 'jquery-ui-slider' );
	wp_enqueue_script( 'jquery-ui-sortable' );

	// Semantic UI
	wpjobster_add_semantic_scripts( 'front' );

	// Vendor
	wp_enqueue_style( 'wpj-front-vendor-styles', get_template_directory_uri() . '/assets/min/css/front.vendor.min.css', array(), wpjobster_VERSION, 'all' );
	wp_enqueue_script( 'wpj-front-vendor-scripts', get_template_directory_uri() . '/assets/min/js/front.vendor.min.js', array( 'jquery' ), wpjobster_VERSION, true );

	// WPJ
	wp_enqueue_style( 'wpj-reset-styles', get_template_directory_uri() . '/assets/css/front/reset.css', array(), wpjobster_VERSION, 'all' );

	// Include all js files from assets js front folder
	wpj_include_assets( get_template_directory() . '/assets/js/front', get_template_directory_uri() . '/assets/js/front', 'js', array(), true );
}

// Front Main CSS
add_action( 'wp_enqueue_scripts', 'wpjobster_add_theme_styles_last', 11 );
function wpjobster_add_theme_styles_last() {

	// Style
	if ( is_rtl() ) {
		wp_enqueue_style( 'main-stylesheet', get_template_directory_uri() . '/assets/css/front-rtl/style-autogenerated.css', array(), wpjobster_VERSION );
		wp_enqueue_style( 'main-stylesheet-extra', get_template_directory_uri() . '/assets/css/front-rtl/style-extra.css', array(), wpjobster_VERSION );
	} else {
		wp_enqueue_style( 'main-stylesheet', get_template_directory_uri() . '/assets/css/front/style.css', array(), wpjobster_VERSION );
	}

	// Others
	if ( is_rtl() ) {
		wpj_include_assets( get_template_directory() . '/assets/css/front-rtl', get_template_directory_uri() . '/assets/css/front-rtl', 'css', array( 'responsive-autogenerated', 'responsive', 'style-autogenerated', 'style-extra', 'wysiwyg-rtl' ) );
	} else {
		wpj_include_assets( get_template_directory() . '/assets/css/front', get_template_directory_uri() . '/assets/css/front', 'css', array( 'reset', 'style', 'responsive' ) );
	}

	// Resopnsive
	if ( wpjobster_is_responsive() ) {
		wp_enqueue_style( 'responsive-main-stylesheet', get_template_directory_uri() . '/assets/css/front/responsive.css', array(), wpjobster_VERSION );
	}
}

add_action( 'wp_head', 'wpjobster_add_theme_responsive_styles', 99 );
function wpjobster_add_theme_responsive_styles() {
	if ( is_rtl() ) {
		wp_enqueue_style( 'rtl-responsive-main-stylesheet', get_template_directory_uri() . '/assets/css/front-rtl/responsive-autogenerated.css', array(), wpjobster_VERSION );
		wp_enqueue_style( 'rtl-responsive-main-stylesheet', get_template_directory_uri() . '/assets/css/front-rtl/responsive.css', array(), wpjobster_VERSION );
	}
}

// Admin Scripts & Styles
add_action( 'admin_enqueue_scripts', 'wpjobster_load_admin_scripts' );
function wpjobster_load_admin_scripts( $hook ) {
	// jQuery libraries
	wp_enqueue_script( "jquery-ui-widget" );
	wp_enqueue_script( "jquery-ui-mouse" );
	wp_enqueue_script( "jquery-ui-tabs" );
	wp_enqueue_script( "jquery-ui-datepicker" );
	wp_enqueue_script( "jquery-ui-sortable" );

	// Vendor
	wp_enqueue_style( 'wpj-admin-vendor-styles', get_template_directory_uri() . '/assets/min/css/admin.vendor.min.css', array(), wpjobster_VERSION, 'all' );
	wp_enqueue_script( 'wpj-admin-vendor-scripts', get_template_directory_uri() . '/assets/min/js/admin.vendor.min.js', array(), wpjobster_VERSION, true );

	// WPJ
	wpj_include_assets( get_template_directory() . '/assets/css/admin', get_template_directory_uri() . '/assets/css/admin', 'css' );
	wpj_include_assets( get_template_directory() . '/assets/js/admin', get_template_directory_uri() . '/assets/js/admin', 'js', array(), true );
}

function wpj_include_assets( $path = '', $uri = '', $type = 'css', $exclude_array = [], $in_footer = false ) {
	$files_arr = wpj_get_folder_files( $path );
	$folder_name = pathinfo( $path, PATHINFO_FILENAME );

	if ( $files_arr ) {
		foreach ( $files_arr as $key => $file ) {
			$name     = pathinfo( $file, PATHINFO_FILENAME );
			$ext      = pathinfo( $file, PATHINFO_EXTENSION );

			if ( $name && $ext ) {
				if ( $type == 'js' && $ext == 'js' ) {
					wp_enqueue_script( 'wpj-' . $folder_name . '-' . $name . '-scripts', $uri . '/' . $name . '.js', array( 'jquery', 'underscore' ), wpjobster_VERSION, $in_footer );
				} elseif ( $type == 'css' && $ext == 'css' ) {
					if ( ! in_array( $name, $exclude_array ) ) {
						wp_enqueue_style( 'wpj-' . $folder_name . '-' . $name . '-stylesheet', $uri . '/' . $name . '.css', array(), wpjobster_VERSION );
					}
				}
			}
		}
	}
}
