<?php
if ( defined( 'WPJ_ASSETS_DEBUG' ) && WPJ_ASSETS_DEBUG == true ) {
	include_once get_template_directory() . '/includes/theme-setup/scripts-and-styles-dev.php';
} else {
	include_once get_template_directory() . '/includes/theme-setup/scripts-and-styles-live.php';
}

add_action( 'admin_head', 'wpjobster_load_admin_semantic_scripts' );
function wpjobster_load_admin_semantic_scripts( $hook ) {
	// Semantic UI
	wpjobster_add_semantic_scripts( 'admin' );
}

// Semantic UI
function wpjobster_add_semantic_scripts( $type = 'front' ) {
	if ( $type == 'admin' ) {

		wp_enqueue_style( 'semantic-ui-icon', get_template_directory_uri() . '/vendor/semantic-ui-admin/icon.min.css', array(), '2.4.1' );
		wp_enqueue_style( 'semantic-ui-accordion-style', get_template_directory_uri() . '/vendor/semantic-ui-admin/accordion.min.css', array(), '2.4.1' );
		wp_enqueue_script( 'semantic-ui-accordion-script', get_template_directory_uri() . '/vendor/semantic-ui-admin/accordion.min.js', array( 'jquery' ), '2.4.1' );

	} else {

		$upload_dir    = wp_upload_dir();
		$semantic_path = $upload_dir['basedir'] . '/wpjobster/semantic.css';
		$semantic_dir  = $upload_dir['baseurl'] . '/wpjobster/semantic.css';
		if ( file_exists( $semantic_path ) ) {
			wp_enqueue_style( 'semantic-ui-css', $semantic_dir, array(), get_option( 'wpj_last_css_compiled' ) );
		} else {
			wp_enqueue_style( 'semantic-ui-css', get_template_directory_uri() . '/vendor/semantic-ui/dist/semantic.min.css', array(), '2.4.1' );
		}
		if ( is_rtl() ) {
			wp_enqueue_style( 'semantic-ui-css-rtl', get_template_directory_uri() . '/vendor/semantic-ui/dist/semantic.rtl.autogenerated.css', array(), '2.4.1' );
		}
		wp_enqueue_script( 'semantic-ui-js', get_template_directory_uri() . '/vendor/semantic-ui/dist/semantic.min.js', array( 'jquery' ), '2.4.1', true );

	}
}

// HTML5 File Upload
add_action( 'admin_enqueue_scripts', 'wpjobster_add_html5fileupload_scripts' );
add_action( 'wp_enqueue_scripts', 'wpjobster_add_html5fileupload_scripts' );
function wpjobster_add_html5fileupload_scripts() {
	$current_screen = is_admin() ? get_current_screen() : '';

	if ( get_option( 'wpjobster_preferred_image_uploader' ) == 'html5fileupload'
		&& (
			is_page( get_option( 'wpjobster_post_new_page_id' ) )
			|| is_page( get_option( 'wpjobster_user_profile_page_id' ) )
			|| is_page( get_option( 'wpjobster_my_account_personal_info_page_id' ) )
			|| ( is_admin() && $current_screen->base == 'post' && $current_screen->post_type == 'job' )
		)
	) {
		wp_enqueue_script( 'html5fileupload-js', get_template_directory_uri() . '/vendor/html5fileupload/html5fileupload.min.js', array( 'jquery' ), '1.3' );
		wp_enqueue_style( 'html5fileupload-css', get_template_directory_uri() . '/vendor/html5fileupload/html5fileupload.min.css' );
	}
}

// Dropzone File Upload
add_action( 'admin_enqueue_scripts', 'wpjobster_add_dropzone_scripts', 8 );
add_action( 'wp_enqueue_scripts', 'wpjobster_add_dropzone_scripts', 8 );
function wpjobster_add_dropzone_scripts() {
	$current_screen = is_admin() ? get_current_screen() : '';

	if ( get_option( 'wpjobster_preferred_image_uploader' ) == 'dropzone'
		&& (
			is_page( get_option( 'wpjobster_post_new_page_id' ) )
			|| is_page( get_option( 'wpjobster_user_profile_page_id' ) )
			|| ( is_admin() && $current_screen->base == 'post' && $current_screen->post_type == 'job' )
		)
	) {
		wp_enqueue_script( 'dropzonejs', get_template_directory_uri() . '/vendor/dropzone/min/dropzone.min.js', array( 'jquery' ), '4.3' );
		wp_add_inline_script( 'dropzonejs', 'Dropzone.autoDiscover = false' );
		wp_enqueue_style( 'dropzonecss', get_template_directory_uri() . '/vendor/dropzone/min/dropzone.min.css' );
	}
}

// Delete type attribute from scripts and styles
add_filter( 'style_loader_tag', 'wpjobster_remove_type_attr_from_script_and_style', 10, 2 );
add_filter( 'script_loader_tag', 'wpjobster_remove_type_attr_from_script_and_style', 10, 2 );
function wpjobster_remove_type_attr_from_script_and_style( $tag, $handle ) {
	return preg_replace( "/type=['\"]text\/(javascript|css)['\"]/", '', $tag );
}

// Defer Scripts
add_filter( 'clean_url', 'wpj_defer_parsing_of_js', 11, 1 );
function wpj_defer_parsing_of_js( $url ) {

	if ( get_theme_mod( 'enable_js_defer' ) == 'yes' ) {
		$exclude_files = apply_filters( 'wpj_js_exclude_defer_filter', array(
			'jquery.js',
			'jquery.min.js',
			'i18n.min.js',
			'hooks.min.js',
			'dropzone.min.js',
			'tinymce.min.js',
			'no-defer.min.js'
		) );

		$apostrophe_files = apply_filters( 'wpj_js_defer_apostrophe_filter', array(
			'wp-polyfill-fetch.min.js',
			'wp-polyfill-node-contains.min.js',
			'wp-polyfill-formdata.min.js',
			'wp-polyfill-element-closest.min.js',
			'wp-polyfill-dom-rect.min.js',
			'wp-polyfill-object-fit.min.js',
			'wp-polyfill-url.min.js'
		) );

		if ( ! is_admin() ) {

			if ( false === strpos( $url, '.js' ) ) { return $url; }

			if ( $exclude_files ) {
				foreach ( $exclude_files as $file ) {
					if ( strpos( $url, $file ) ) { return $url; }
				}
			}

			if ( $apostrophe_files ) {
				foreach ( $apostrophe_files as $file ) {
					if ( strpos( $url, $file ) ) { return '$url" defer="defer'; }
				}
			}

		} else { return $url; }

		return "$url' defer='defer";
	}

	return $url;
}

// Defer Styles
add_filter( 'style_loader_tag', 'wpj_defer_parsing_of_css', 10, 4 );
function wpj_defer_parsing_of_css( $html, $handle, $href, $media ) {
	if ( get_theme_mod( 'enable_css_preload' ) == 'yes' ) {
		if ( is_admin() ) return $html;

		$exclude_files = apply_filters( 'wpj_css_exclude_preloader_filter', array( 'front.min.css', 'front.vendor.min.css', 'preview.css', 'semantic.css', 'semantic.min.css' ) );

		if ( isset( $_SERVER[ 'HTTP_USER_AGENT' ] ) ) {
			$agent = $_SERVER[ 'HTTP_USER_AGENT' ];
			if ( strlen( strstr( $agent, 'Firefox' ) ) > 0 ) {
				$exclude_files[] = 'rs6.css';
				$exclude_files[] = 'dropzone.css';
				$exclude_files[] = 'dropzone.min.css';
			}
		}

		if ( $exclude_files ) {
			foreach ( $exclude_files as $file ) {
				if ( strpos( $html, $file ) ) { return $html; }
			}
		}

		$html  = '<link rel="preload" href="' . $href . '" as="style" onload="this.onload=null;this.rel=\'stylesheet\'" />';
		$html .= '<noscript><link rel="stylesheet" href="' . $href . '"></noscript>';

		return $html;
	}

	return $html;
}