<?php
add_filter( 'wpj_wrapper_class_filter', 'wpj_add_chat_class_to_wrapper' );
function wpj_add_chat_class_to_wrapper( $classes ) {
	$sidebar_status = isset( $_COOKIE['sidebar'] ) ? $_COOKIE['sidebar'] : 'maximized';
	if ( $sidebar_status == 'minimized' ) {
		return get_option( 'wpjobster_chat_enable' ) == 'yes' && is_user_logged_in() ? $classes . ' is-chat-active is-chat-minimized' : $classes;
	}
	return get_option( 'wpjobster_chat_enable' ) == 'yes' && is_user_logged_in() ? $classes . ' is-chat-active is-chat-maximized' : $classes;
}

function wpj_init_chat_system() {

	// User private messages link
	$using_perm = wpjobster_using_permalinks();
	if ( $using_perm ) {
		$privurl_m = get_permalink( get_option( 'wpjobster_my_account_priv_mess_page_id' ) ) . "?";
	} else {
		$privurl_m = get_bloginfo( 'url' ) . "/?page_id=" . get_option( 'wpjobster_my_account_priv_mess_page_id' ) . "&";
	}

	// Create users array
	$users = array();

	$users_list = wpj_chat_get_users_list();

	if ( $users_list ) {
		foreach ( $users_list as $user_id ) {
			if ( $user_id != get_current_user_id() ) {
				$user_arr = get_userdata( $user_id );

				if ( $user_arr->last_user_login ) {
					$time_elapsed    = time() - $user_arr->last_user_login;
					$time_difference = $time_elapsed / 60;
					$time_difference = (int)$time_difference;
				} else {
					$time_difference = '';
					$time_elapsed    = '';
				}

				$users[$user_arr->ID] = array(
					'ID'              => $user_arr->ID,
					'user_login'      => wpj_get_user_display_type( $user_arr->ID ),
					'user_nicename'   => $user_arr->user_nicename,
					'time_elapsed'    => $time_elapsed,
					'time_difference' => $time_difference,
					'unread_messages' => wpjobster_get_unread_number_messages_from_user( $user_arr->ID ),
					'privurl_m'       => $privurl_m
				);
			}
		}
	}

	// Online users count
	$user_on_cnt = 0;
	if ( $users ) {
		foreach ( $users as $user ) {
			if ( $user['time_elapsed'] && $user['time_elapsed'] <= 359 ) {
				$user_on_cnt++;
			}
		}
	}

	// Sidebar icon
	$icon = get_theme_mod( 'chat_sidebar_icon_name' ) != '' ? get_theme_mod( 'chat_sidebar_icon_name' ) : 'comments';

	// Incluide HTML
	$sidebar_status = isset( $_COOKIE['sidebar'] ) ? $_COOKIE['sidebar'] : 'maximized';
	wpj_chat_display_sidebar_content( $users, $sidebar_status, $user_on_cnt, $icon );
}

function wpj_chat_get_users_list() {
	global $wpdb;

	$current_user_id = get_current_user_id();

	// All users
	$all_users_arr = array();

	$user_table      = defined( 'CUSTOM_USER_TABLE' ) ? CUSTOM_USER_TABLE : $wpdb->prefix . 'users';
	$user_meta_table = defined( 'CUSTOM_USER_META_TABLE' ) ? CUSTOM_USER_META_TABLE : $wpdb->prefix . 'usermeta';

	$all_users_sql = $wpdb->get_results( "
		SELECT *
		FROM {$user_table} u, {$user_meta_table} um
		WHERE u.ID = um.user_id
			AND um.meta_key = 'last_user_login'
		ORDER BY um.meta_value DESC
		LIMIT 50
	" );
	if ( $all_users_sql ) {
		foreach ( $all_users_sql as $key => $user ) {
			$user_arr = get_userdata( $user->ID );
			if ( $user_arr ) {
				$is_seller = apply_filters( 'display_or_hide_section_filter', true, $user->ID );
				if ( $is_seller ) {
					if ( isset( $user_arr->last_user_login ) ) {
						$all_users_arr[$user_arr->ID] = $user_arr->last_user_login;
					} else {
						$all_users_arr[$user_arr->ID] = $user_arr->ID;
					}
				}
			}
		}
	}

	arsort( $all_users_arr ); // sort the array by last login

	$all_users = array_keys( $all_users_arr );

	// Tangential users
	$tangential_users_sql = $wpdb->get_results( "
		SELECT orders.uid as user FROM {$wpdb->prefix}job_orders orders INNER JOIN {$wpdb->prefix}posts posts ON posts.iD = orders.pid WHERE posts.post_author = {$current_user_id} GROUP BY orders.uid

		UNION ALL

		SELECT posts.post_author as user FROM {$wpdb->prefix}posts posts INNER JOIN {$wpdb->prefix}job_orders orders ON posts.ID = orders.pid WHERE orders.uid = {$current_user_id} GROUP BY posts.post_author

		UNION ALL

		SELECT initiator as user FROM {$wpdb->prefix}job_pm WHERE user = {$current_user_id} GROUP BY initiator

		UNION ALL

		SELECT user as user FROM {$wpdb->prefix}job_pm WHERE initiator = {$current_user_id} GROUP BY user
	" );

	$tangential_users_arr = array();
	if ( $tangential_users_sql ) {
		foreach ( $tangential_users_sql as $key => $user ) {
			$user_arr = get_userdata( $user->user );
			if ( $user_arr ) {
				if ( isset( $user_arr->last_user_login ) ) {
					$tangential_users_arr[$user_arr->ID] = $user_arr->last_user_login;
				} else {
					$tangential_users_arr[$user_arr->ID] = $user_arr->ID;
				}
			}
		}
	}

	arsort( $tangential_users_arr ); // sort the array by last login

	$tangential_users = array_keys( $tangential_users_arr );

	// Return
	if ( get_theme_mod( 'all_users_to_sidebar', true ) != '' ) {
		$ret_array = array_merge( $tangential_users, $all_users );
	} else {
		$ret_array = $tangential_users;
	}

	return array_unique( $ret_array );
}

function wpj_chat_get_user_info( $user_id ) {
	// User data array
	$user_arr = get_userdata( $user_id );

	// User private messages link
	$using_perm = wpjobster_using_permalinks();
	if ( $using_perm ) {
		$privurl_m = get_permalink( get_option( 'wpjobster_my_account_priv_mess_page_id' ) ) . "?";
	} else {
		$privurl_m = get_bloginfo( 'url' ) . "/?page_id=" . get_option( 'wpjobster_my_account_priv_mess_page_id' ) . "&";
	}

	// User last seen
	$time_elapsed    = time() - ($user_arr->last_user_login ?: 60000);
	$time_difference = $time_elapsed / 60;
	$time_difference = (int)$time_difference;

	// User status
	if ( $time_difference <= 5 ) {
		$status_class = "online";
	} else {
		$status_class = "offline";
	}

	// User messages
	global $wpdb;

	$sender_id = get_current_user_id();
	$receiver_id = $user_arr->ID;

	$result = $wpdb->get_results( "
		SELECT * FROM (
			SELECT * FROM {$wpdb->prefix}job_pm
			WHERE ( user = '{$receiver_id}' AND initiator = '{$sender_id}' AND show_to_source = '1' )
				OR ( initiator = '{$receiver_id}' and user = '{$sender_id}' AND show_to_destination = '1' )
			ORDER BY datemade DESC LIMIT 10 ) AS t1
		ORDER BY datemade ASC
	" );

	return array(
		'ID'               => $user_arr->ID,
		'name'             => wpj_get_user_display_type( $user_arr->ID ),
		'user_nicename'    => $user_arr->user_nicename,
		'status_class'     => $status_class,
		'privurl_m'        => $privurl_m,
		'messages_content' => $result,
		'box_position'     => is_rtl() ? 'left' : 'right'
	);
}

function wpj_chat_get_pm_info( $row ) {
	if ( $row ) {
		$is_sender = get_current_user_id() == $row->initiator ? true : false;

		// mark message as read
		if ( ! $is_sender ) {
			wpj_read_private_message( $row );
		}

		return array(
			'is_sender'    => $is_sender,
			'message_date' => wpj_chat_get_message_date( $row ),
			'message'      => wpj_apply_filter_to_string( stripslashes( $row->content ), false, 'privatemessages' )
		);
	}

	return false;
}

function wpj_chat_get_message_date( $row ) {
	$begin_of_day = strtotime( 'midnight', time() );
	$end_of_day   = strtotime( 'tomorrow', $begin_of_day ) - 1;

	$begin_of_week = strtotime( 'last Monday', time() );
	$end_of_week   = strtotime( 'next Sunday', time() ) + 86400;

	if ( $row->datemade ) {
		if ( $row->datemade > $begin_of_day && $row->datemade < $end_of_day ) {
			return wpj_date( get_option( 'time_format' ), $row->datemade );
		} elseif ( $row->datemade > $begin_of_week && $row->datemade < $end_of_week ) {
			return wpj_date( 'l, ' . get_option( 'time_format' ), $row->datemade );
		} else {
			return wpj_date( get_option( 'date_format' ), $row->datemade );
		}
	}

	return false;
}
function wpj_chat_get_custom_offer_info( $row ) {
	$sender_id    = $row->initiator;
	$sender_arr   = get_userdata( $sender_id );

	$receiver_id  = $row->user;
	$receiver_arr = get_userdata( $receiver_id );

	$using_perm = wpjobster_using_permalinks();
	if ( $using_perm ) {
		$privurl_m = get_permalink( get_option( 'wpjobster_my_account_priv_mess_page_id' ) ) . "?";
	} else {
		$privurl_m = get_bloginfo( 'url' ) . "/?page_id=" . get_option( 'wpjobster_my_account_priv_mess_page_id' ) . "&";
	}

	if ( $row->custom_offer == -1 ) {
		if ( get_current_user_id() == $row->initiator ) {
			return '<a href="' . $privurl_m . 'username=' . $receiver_arr->user_nicename . '">' . sprintf( __( "You requested a custom offer from %s", "wpjobster" ), wpj_get_user_display_type( $receiver_arr->ID ) ) . '</a>';
		} elseif ( get_current_user_id() == $row->user ) {
			return '<a href="' . $privurl_m . 'username=' . $sender_arr->user_nicename . '">' . sprintf( __( "%s sent you a custom offer request", "wpjobster" ), wpj_get_user_display_type( $sender_arr->ID ) ) . '</a>';
		}
	} elseif ( $row->custom_offer > 0 ) {
		if ( get_current_user_id() == $row->initiator ) {
			return '<a href="' . $privurl_m . 'username=' . $receiver_arr->user_nicename . '">' . sprintf( __( "You sent a custom price offer to %s", "wpjobster" ), wpj_get_user_display_type( $receiver_arr->ID ) ) . '</a>';
		} elseif ( get_current_user_id() == $row->user ) {
			return '<a href="' . $privurl_m . 'username=' . $sender_arr->user_nicename . '">' . sprintf( __( "%s sent you a custom price offer", "wpjobster" ), wpj_get_user_display_type( $sender_arr->ID ) ) . '</a>';
		}
	}

	return false;
}

function wpj_chat_get_custom_offer_response( $row ) {

	if ( $row ) {
		if ( get_post_meta( $row->custom_offer, "offer_accepted", true ) == 1 ) { return __( "Accepted", "wpjobster" ); }
		elseif ( get_post_meta( $row->custom_offer, "offer_declined", true ) == 1 ) { return __( "Declined", "wpjobster" ); }
		elseif ( get_post_meta( $row->custom_offer, "offer_withdrawn", true ) == 1 ) { return __( "Withdrawn", "wpjobster" ); }
		elseif ( get_post_meta( $row->custom_offer, "offer_expired", true ) == 1 ) { return __( "Expired", "wpjobster" ); }
	}

	return false;
}
