<?php include_once 'wpjobster_common_payment.php';

class WPJ_Common_Subscription extends WPJ_Common_Payment{

	public function __construct( $payment_gateway = '', $uid = 0 ) {
		parent::__construct( $payment_gateway );

		global $wpdb;
		$this->_wpdb = $wpdb;

		$this->_current_user    = $uid ? get_userdata( $uid ) : wp_get_current_user();
		$this->_currency        = wpjobster_get_currency();
		$this->_payment_gateway = $payment_gateway;

		add_action( "wpjobster_subscription_payment_success", array( $this, "payment_success" ), 10, 4 );
		add_action( "wpjobster_new_subscription_payment_success", array( $this, "payment_process" ), 10, 4 );
		add_action( "wpjobster_subscription_payment_failed", array( $this, "payment_failed" ), 10, 4 );
		add_action( "wpjobster_subscription_payment_other", array( $this, "payment_other" ), 10, 5 );

		$this->subscription_eligibility_enabled = get_option( 'wpjobster_subscription_eligibility_enabled' );

		$this->subscription_duration = array(
			"weekly",
			"monthly",
			"quarterly",
			"yearly",
			"lifetime"
		);

		$this->subscription_levels = array(
			"level0" => sprintf( __( "Level %d", "wpjobster" ), 0 ),
			"level1" => sprintf( __( "Level %d", "wpjobster" ), 1 ),
			"level2" => sprintf( __( "Level %d", "wpjobster" ), 2 ),
			"level3" => sprintf( __( "Level %d", "wpjobster" ), 3 )
		);

		$this->errors = array(
			"not_enough_balance"     => __( "You do not have enough balance to purchase this subscription.", "wpjobster" ),
			"no_subscription_levels" => __( "Suscription levels not defined", "wpjobster" ),
			"not_eligible"           => __( "You are not eligible for this level", "wpjobster" ),
			"cancelled"              => __( "You cancelled this subscription.", "wpjobster" ),
			"no_plan_selected"       => __( "Please select a plan.", "wpjobster" ),
		);

		$this->messages = array(
			"balance_down_subscription"        => __( "Thank you for subscribing with us! We have sent you a confirmation email.", "wpjobster" ),
			"balance_down_subscription_change" => __( "You have successfully changed your subscription! We have sent you a confirmation email.", "wpjobster" ),
			"subscription_schedule"            => __( "You have successfully scheduled your subscription. We have sent you a confirmation email.", "wpjobster" ),
			"success"                          => __( "Thank you for subscribing with us! If the subscription is not active, please refresh the page in a few minutes.", "wpjobster" )
		);
	}

	public function payment_other( $order_id, $gateway_slug, $payment_details = '', $payment_response = '', $payment_status = 'processing' ) {
		$this->update_subscription_order_status( $order_id, $payment_status, 'inactive', $payment_details, $payment_response );

		$subscription_order = $this->get_subscription_order_by_id( $order_id );

		$user_id = $subscription_order->user_id;

		$this->process_cancellation( $user_id );
	}

	public function payment_failed( $order_id, $gateway_slug, $payment_details = '', $payment_response = '' ) {
		$this->update_subscription_order_status( $order_id, 'cancelled', 'inactive', $payment_details, $payment_response );

		$subscription_order = $this->get_subscription_order_by_id( $order_id );

		$user_id = $subscription_order->user_id;

		$this->process_cancellation( $user_id );
	}

	public function payment_process( $order_id, $payment_gateway_slug, $payment_details, $response ) {
		$payment_response          = is_array( $response ) ? json_encode( $response ) : $response;
		$payment_response_original = json_encode( $_REQUEST );

		$subscription_order = $this->get_subscription_order_by_id( $order_id );

		$plan    = $subscription_order->plan;
		$user_id = $subscription_order->user_id;

		$level_arr = explode( '-', $subscription_order->level );
		$level     = isset( $level_arr[0] ) && $level_arr[0] ? $level_arr[0] : '';
		$usr_type  = isset( $level_arr[1] ) && $level_arr[1] ? $level_arr[1] : '';

		$register_sub = $plan . "-" . $level . "-" . $usr_type;

		$this->do_subscription( $register_sub, $user_id, $payment_gateway_slug );

		$subs    = explode(' ', $payment_details);
		$cust_id = $subs ? $subs[0] : 0;

		$profile_id = isset( $_POST['subscr_id'] ) && $_POST['subscr_id'] ? $_POST['subscr_id'] : $cust_id;

		$this->update_subscription_order_status( $order_id, 'Completed', 'active', $payment_details, $payment_response, $payment_response_original, $profile_id );
		$this->update_subscription_payment_received( $order_id, 'Completed', $payment_details, $payment_response );

		do_action( 'wpjobster_new_subscription_payment_completed', $order_id );
	}

	public function payment_success( $order_id, $payment_gateway_slug, $payment_details, $response ) {
		$payment_response = is_array( $response ) ? json_encode( $response ) : $response;

		if ( ! isset( $_POST['payment_status'] ) ) {
			$_POST['payment_status'] = "Completed";
		}

		$this->update_subscription_payment_received( $order_id, $_POST['payment_status'], $payment_details, $payment_response );

		$this->update_subscription_order_status( $order_id, '', '', $payment_details, '', '', '' );

		do_action( 'wpjobster_subscription_payment_completed', $order_id );
	}

	public function do_subscription( $register_sub = '', $uid = '', $payment_method ) {
		if ( $register_sub ) {
			$subscription_name = $register_sub;
			$uid               = $uid;
		} else {
			$subscription_name = $_GET['sub_id'];
			$uid               = $this->_current_user->ID;
		}

		$nm = explode( "-", $subscription_name );

		$sub_type  = $nm[0];
		$sub_level = $nm[1];

		// Error - not eligible for selected subscription
		if ( get_option( 'wpjobster_subscription_eligibility_enabled' ) != 'no' ) {
			$sub_eligibility = get_option( 'wpjobster_subscription_eligibility_amount_' . $sub_level );
			if ( wpjobster_formats_special( get_user_meta( $uid, 'user_total_earnings', true ), 2 ) < wpjobster_formats_special( $sub_eligibility, 2 ) ) {
				return array( 'error' => 'not_eligible' );
			}
		}

		$this->current_subscription = $this->get_current_subscription( $uid );

		if ( is_object( $this->current_subscription) ){ // vars for subscription upgrade
			$is_subscribed = 1;

			$where = array( "user_id" => $uid );

			$last_sub_level  = $this->current_subscription->subscription_level;
			$last_sub_plan   = $this->current_subscription->subscription_type;
			$last_sub_amount = get_option( 'wpjobster_subscription_' . $last_sub_plan . '_amount_' . $last_sub_level );

			$subscription_type = $this->current_subscription->subscription_type;

			$sub_field  = 'wpjobster_subscription_' . $nm[0] . '_amount_' . $nm[1];
			$sub_amount = get_option( 'wpjobster_subscription_' . $nm[0] . '_amount_' . $nm[1] );
			$new_amount = get_option( 'wpjobster_subscription_' . $subscription_type . '_amount_' . $nm[1] );

			$payable_amount = $sub_amount - $last_sub_amount;

			$start_date = time();

		} else { // vars for new subscription
			$is_subscribed = 0;

			$where = "";

			$sub_field  = 'wpjobster_subscription_' . $nm[0] . '_amount_' . $nm[1];
			$sub_amount = get_option( 'wpjobster_subscription_' . $nm[0] . '_amount_' . $nm[1] );

			$payable_amount = $sub_amount;

			$next_billing_date = $this->get_next_billing_date( $sub_type );

			$start_date = time();
		}

		if ( is_numeric( $payable_amount ) ) {

			$prices = $this->calculate_tax_and_fees( $sub_amount );

			$subscription_order= array(
				'user_id'              => $uid,
				'subscription_amount'  => $sub_amount,
				'payment_status'       => 'completed',
				'subscription_status'  => 'active',
				'payment_gateway_name' => $payment_method,
				'payable_amount'       => $payable_amount,
				'currency'             => $this->_currency,
				'plan'                 => $sub_type,
				'level'                => $sub_level,
				'tax'                  => $prices['tax'],
				'tax_orignal'          => $prices['tax_orignal'],
				'fees'                 => $prices['buyer_processing_fees'],
				'total_amount_orignal' => $prices['total_amount_orignal'],
				'fees_orignal'         => $prices['buyer_processing_fees_orignal']
			);

			$schedule_only = isset( $_REQUEST['schedule_only'] ) ? 1 : 0;

			if ( $payment_method == "credits" ) { // subscription with ACCOUNT BALANCE

				$cr = wpjobster_get_credits($uid);

				if ( $cr >= $payable_amount ) {

					if ( $schedule_only == 0 ) { // shedule
						wpjobster_update_credits( $uid, $cr - $payable_amount );
						do_action( 'before_save_subscription', $nm );
					}

					if ( $is_subscribed == 0 && $schedule_only == 0 ) { // new subscriber

						$order_id = $this->insert_subscription_order( $subscription_order );

						$this->update_subscription_order_status( $order_id, 'Completed', 'active', $order_id, '', json_encode( $subscription_order ), $uid );
						$this->insert_subscription_payment_received( $order_id, $payment_method, 'Completed', $order_id, 'New subscription' );
						$this->update_subscription_payment_received( $order_id, 'Completed', 'New Subscription', json_encode( $subscription_order ) );

					} elseif ( $is_subscribed != 0 && $schedule_only == 0 ) { // upgrate subscriber

						$current_subs = $this->get_subscription_order_by_user_id( $uid );
						if ( $current_subs ) {
							$order_id = $current_subs->id;
							$this->update_subscription_order_status( $order_id, 'cancelled', 'inactive', $order_id, '', 'Subscription cancelled', $uid );
						}

						$order_id = $this->insert_subscription_order( $subscription_order );

						$this->update_subscription_order_status( $order_id, 'Completed', 'active', $order_id, '', json_encode( $subscription_order ), $uid );
						$this->insert_subscription_payment_received( $order_id, $payment_method, 'Completed', $order_id, 'Subscription upgrated' );
						$this->update_subscription_payment_received( $order_id, 'Completed', 'Subscription upgrated', json_encode( $subscription_order ) );

					}

				} else { return array( "error" => 'not_enough_balance' ); }
			} else { do_action( 'before_save_subscription', $nm ); }

			$user_data = get_userdata( $uid );

			if ( $schedule_only == '1' && is_array( $where ) ) { // Subscription Schedule

				$subscription_data = array(
					"next_subscription_level"  => $sub_level,
					"next_subscription_type"   => $sub_type,
					"next_subscription_amount" => $sub_amount
				);
				$this->_wpdb->update( $this->_wpdb->prefix . 'job_subscriptions', $subscription_data, $where );

				$email_reason = 'subscription_schedule';

				do_action( 'before_save_subscription', $nm );

			} elseif ( $is_subscribed == 0 ) { // New Subscription

				$subscription_data = array(
					"subscription_level"       => $sub_level,
					"subscription_type"        => $sub_type,
					"sub_start_date"           => $start_date,
					"subscription_amount"      => $sub_amount,
					"user_id"                  => $uid,
					"next_billing_date"        => $next_billing_date,
					"subscription_status"      => 'active',
					"next_subscription_level"  => $sub_level,
					"next_subscription_type"   => $sub_type,
					"next_subscription_amount" => $sub_amount
				);

				// Activate subscription
				$this->_wpdb->insert( $this->_wpdb->prefix . 'job_subscriptions', $subscription_data );

				// Add to history log
				$reason       = __( "Payment for subscription", "wpjobster" );
				$details      = $nm[0] . "_" . $nm[1] . "_new";
				$cur_value    = wpjobster_formats_special_exchange( $payable_amount, '1', $this->_currency );
				$payed_amount = $this->_currency . '|' . $cur_value;

				wpjobster_add_history_log( '0', $reason, $payable_amount, $uid, '', '',11 , $details, $payed_amount );

				// Send email
				$email_reason = 'balance_down_subscription';

				wpj_notify_user_translated( 'admin_new_subscription', 'admin', array(
					'##amount_updated##'              => $payed_amount,
					'##username##'                    => wpj_get_user_display_type( $user_data->ID ),
					'##current_subscription_level##'  => wpjobster_translate_string( $sub_level ),
					'##current_subscription_period##' => wpjobster_translate_string( $sub_type ),
					'##current_subscription_amount##' => $sub_amount,
					"##next_subscription_level##"     => wpjobster_translate_string( $sub_level ),
					"##next_subscription_type##"      => wpjobster_translate_string( $sub_type ),
					"##next_subscription_amount##"    => $sub_amount,
					"##next_billing_date##"           => $next_billing_date
				) );

			} else { // Upgrade subscription

				$subscription_data = array(
					"subscription_level"       => $sub_level,
					"subscription_type"        => $sub_type,
					"subscription_status"      => 'active',
					"subscription_amount"      => $new_amount,
					"next_subscription_level"  => $sub_level,
					"next_subscription_type"   => $sub_type,
					"next_subscription_amount" => $sub_amount,
					"next_billing_date"        => $this->get_next_billing_date( $sub_type )
				);

				$this->_wpdb->update( $this->_wpdb->prefix . 'job_subscriptions', $subscription_data, $where );

				// Add to history log
				$reason       = __( "Payment for changing subscription", "wpjobster" );
				$details      = $nm[0] . "_" . $nm[1] . "_change";
				$cur_value    = wpjobster_formats_special_exchange( $payable_amount, '1', $this->_currency );
				$payed_amount = $this->_currency . '|' . $cur_value;

				wpjobster_add_history_log( '0', $reason, $payable_amount, $uid, '', '', 11 , $details, $payed_amount );

				// Send email
				$email_reason = 'balance_down_subscription_change';

				wpj_notify_user_translated( 'admin_upgrade_subscription', 'admin', array(
					'##username##'                    => wpj_get_user_display_type( $user_data->ID ),
					'##current_subscription_level##'  => wpjobster_translate_string( $sub_level ),
					'##current_subscription_period##' => wpjobster_translate_string( $sub_type ),
					'##current_subscription_amount##' => $new_amount,
					"##next_subscription_amount##"    => $sub_amount,
					"##next_subscription_level##"     => wpjobster_translate_string( $sub_level ),
					"##next_billing_date##"           => $this->get_next_billing_date( $sub_type ),
					'##amount_updated##'              => $payed_amount
				) );
			}

			$this->send_subscription_email( $email_reason, $uid, $payable_amount );

			do_user_level_extras_check( $uid );
			do_user_level_extras_price_check( $uid );
			do_user_level_job_price_check( $uid );

			return $email_reason;
		}
	}

	public function process_cancellation( $uid = '' ) {
		$uid = $uid ? $uid : get_current_user_id();
		$user_data = get_userdata( $uid );

		do_user_level_extras_check( $uid );
		do_user_level_extras_price_check( $uid );
		do_user_level_job_price_check( $uid );

		do_action( 'cancel_subscription', $uid );

		$subscription_order = $this->get_subscription_order_by_user_id( $uid );

		if ( isset( $subscription_order ) && $subscription_order ) {
			$profile_id                     = $subscription_order->profile_id;
			$order_id                       = $subscription_order->id;
			$payment_gateway_transaction_id = $subscription_order->payment_gateway_transaction_id;

			$subs = explode( ' ', $payment_gateway_transaction_id );
			if ( $subs ) {
				$cust_id = isset( $subs[0] ) ? $subs[0] : 0;
				$sub_id  = isset( $subs[1] ) ? $subs[1] : 0;
			}

			do_action( 'cancel_subscription_gateway', $subscription_order );

			$this->update_subscription_order_status( $order_id, 'cancelled', 'inactive', $payment_gateway_transaction_id, 'Subscription cancelled.', '', '' );
		}

		// Send email
		$reason = 'subscription_cancel';
		$this->send_subscription_email( $reason, $uid );

		$current_subscription = $this->get_current_subscription( $uid );

		$array_to_send = array(
			'##username##'                    => wpj_get_user_display_type( $user_data->ID ),
			'##amount_updated##'              => $current_subscription->subscription_amount,
			'##current_subscription_level##'  => wpjobster_translate_string( $current_subscription->subscription_level ),
			'##current_subscription_period##' => wpjobster_translate_string( $current_subscription->subscription_type ),
			'##current_subscription_amount##' => $current_subscription->subscription_amount,
			'##next_billing_date##'           => $current_subscription->next_billing_date,
			'##next_subscription_level##'     => wpjobster_translate_string( $current_subscription->next_subscription_level ),
			'##next_subscription_type##'      => wpjobster_translate_string( $current_subscription->next_subscription_type ),
			'##next_subscription_amount##'    => $current_subscription->next_subscription_amount
		);

		wpj_notify_user_translated( 'admin_cancel_subscription', 'admin', $array_to_send );

		$this->remove_subscription( $uid );
	}

	public function check_scheduled_subscription() {
		$subscriptions = $this->get_active_subscription();

		if ( is_array( $subscriptions ) ) {
			foreach ( $subscriptions as $subscription ) {
				$email_reason = 'balance_down_subscription';

				$uid = $subscription->user_id;

				$sub_level = $subscription->next_subscription_level;
				$sub_type  = $subscription->next_subscription_type;

				$sub_id         = 'wpjobster_subscription_' . $sub_type . '_amount_' . $sub_level;
				$sub_amount     = get_option( $sub_id );
				$payable_amount = wpjobster_formats_special( $sub_amount, 2 );

				$where = array( "user_id" => $uid );

				$cr = wpjobster_get_credits( $uid );
				if ( $cr >= $payable_amount && $payable_amount >=1 ) {

					$prices = $this->calculate_tax_and_fees( $payable_amount );

					$subscription_order = array(
						'user_id'              => $uid,
						'subscription_amount'  => $payable_amount,
						'payment_status'       => 'completed',
						'subscription_status'  => 'active',
						'payment_gateway_name' => $this->_payment_gateway,
						'payable_amount'       => $prices['payable_amount'],
						'currency'             => $this->_currency,
						'plan'                 => $sub_type,
						'level'                => $sub_level,
						'tax'                  => $prices['tax'],
						'tax_orignal'          => $prices['tax_orignal'],
						'fees'                 => $prices['buyer_processing_fees'],
						'total_amount_orignal' => $prices['total_amount_orignal'],
						'fees_orignal'         => $prices['buyer_processing_fees_orignal']
					);

					$order_id = $this->insert_subscription_order( $subscription_order );

					$this->update_subscription_order_status( $order_id, 'completed', 'active', $order_id, '', json_encode( $subscription_order ), $uid );
					$this->insert_subscription_payment_received( $order_id, $this->_payment_gateway, 'Completed', $order_id, 'Schedule subscription' );
					$this->update_subscription_payment_received( $order_id, 'completed', 'Schedule Subscription', json_encode( $subscription_order ) );

					wpjobster_update_credits( $uid, $cr - $payable_amount );

					$reason = __( "Payment for subscription renewal", "wpjobster" );
					$details = $sub_type . "_" . $sub_level . "_" . "renew";

					wpjobster_add_history_log( '0', $reason, $payable_amount, $uid, '', '', 11, $details );

					$subscription_data = array(
						"subscription_level"  => $sub_level,
						"subscription_type"   => $sub_type,
						"subscription_amount" => $payable_amount,
						"next_billing_date"   => $this->get_next_billing_date( $sub_type )
					);

					$this->_wpdb->update( $this->_wpdb->prefix . 'job_subscriptions', $subscription_data, $where );

					delete_user_meta( $uid, "wpjobster_subscription_prior_email_notification_sent" );

					$this->send_subscription_email( $email_reason, $uid, $payable_amount );

				} else {

					$array_to_send = array(
						'##amount_updated##'               => $payable_amount,
						'##current_subscription_level##'   => wpjobster_translate_string( $subscription->subscription_level ),
						'##current_subscription_period##'  => wpjobster_translate_string( $subscription->subscription_type ),
						'##current_subscription_amount##'  => $subscription->subscription_amount,
						'##next_billing_date##'            => $subscription->next_billing_date,
						'##next_subscription_level##'      => wpjobster_translate_string( $subscription->next_subscription_level ),
						'##next_subscription_type##'       => wpjobster_translate_string( $subscription->next_subscription_type ),
						'##next_subscription_amount##'     => $subscription->next_subscription_amount
					);

					wpj_notify_user_translated( 'subscription_cancel_lowbalance', $uid, $array_to_send );

					$this->remove_subscription( $uid );
				}

				do_user_level_extras_check( $uid );
				do_user_level_extras_price_check( $uid );
				do_user_level_job_price_check( $uid );

			}
		}
	}

	public function insert_subscription_order( $subscription_order = array() ) {
		if ( ! isset( $subscription_order['payment_gateway_name'] ) || $subscription_order['payment_gateway_name'] == '' ) {
			$subscription_order['payment_gateway_name'] = $this->_payment_gateway;
		}

		$tm = time();

		$sql = "
			INSERT INTO {$this->_wpdb->prefix}job_subscription_orders
			SET
				user_id              = '{$subscription_order['user_id']}',
				amount               = '{$subscription_order['subscription_amount']}',
				payment_status       = '{$subscription_order['payment_status']}',
				subscription_status  = '{$subscription_order['subscription_status']}',
				addon_date           = '{$tm}',
				mc_currency          = '{$subscription_order['currency']}',
				plan                 = '{$subscription_order['plan']}',
				level                = '{$subscription_order['level']}',
				payment_gateway_name = '{$subscription_order['payment_gateway_name']}',
				payable_amount       = '{$subscription_order['payable_amount']}',
				tax                  = '{$subscription_order['tax']}'
		";

		$insert_result = $this->_wpdb->query( $sql );

		$order_id = $this->_wpdb->insert_id;

		return $order_id;
	}

	public function insert_subscription_payment_received( $order_id, $payment_gateway_slug = '', $payment_status = 'Completed', $payment_details = '', $response = '' ) {
		$payment['payment_status']   = $payment_status;
		$payment['payment_gateway']  = $payment_gateway_slug;
		$payment['payment_response'] = $response;
		$payment['payment_details']  = $payment_details;
		$payment['payment_type']     = 'subscription';
		$payment['payment_type_id']  = $order_id;
		$payment['currency']         = wpjobster_get_currency_classic();

		$current_subs = $this->get_subscription_order_by_id( $order_id );
		$amount       = $current_subs->payable_amount;
		$datemate     = $current_subs->addon_date;

		$payment['amount']                 = $amount;
		$payment['tax']                    = 0;
		$payment['fees']                   = 0;
		$payment['final_amount']           = $amount;
		$payment['final_amount_exchanged'] = $amount;
		$payment['final_amount_currency']  = $this->_currency;
		$payment['datemade']               = $datemate;
		$payment['created_on']             = wpj_date( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), $datemate );
		$payment['payment_made_on']        = time();

		$this->insert_payment( $payment );
	}

	public function update_subscription_payment_received( $order_id, $payment_status = 'Completed', $payment_details = '', $response = '' ) {
		$payment['order_id']         = $order_id;
		$payment['status']           = $payment_status;
		$payment['payment_type']     = 'subscription';
		$payment['payment_response'] = $response;
		$payment['payment_details']  = $payment_details;

		$this->update_payment( $payment );
	}

	public function update_subscription_order_status( $order_id, $payment_status, $subscription_status, $transaction_id = 0, $payment_response = '', $payment_response_original = '', $profile_id = '', $sub_sts = '' ) {

		$tm = time();

		$sql = "UPDATE {$this->_wpdb->prefix}job_subscription_orders SET payment_date = '{$tm}'";

		if ( $subscription_status != '' )
			$sql .= ", subscription_status = '$subscription_status'";
		if ( $payment_status != '' )
			$sql .= ", payment_status='$payment_status'";
		if ( $transaction_id != '' )
			$sql .= ", payment_gateway_transaction_id='$transaction_id'";
		if ( $payment_response_original != '')
			$sql .= ", payment_response='" . $payment_response_original . "'";
		if ( $profile_id != '' )
			$sql .=", profile_id='" . $profile_id . "'";

		$sql .= "WHERE id='$order_id'";

		if ( $sub_sts != '' )
			$sql .= " AND subscription_status='active'";

		$update_result = $this->_wpdb->query( $sql );
	}

	public function get_current_subscription( $user_id ) {

		$current_subscription = $this->_wpdb->get_row( "SELECT * FROM {$this->_wpdb->prefix}job_subscriptions WHERE user_id = {$user_id}" );

		if ( is_object( $current_subscription ) ) {
			$current_subscription->next_billing_date = wpj_date( get_option( 'date_format' ), $current_subscription->next_billing_date );
			$current_subscription->sub_start_date    = wpj_date( get_option( 'date_format' ), $current_subscription->sub_start_date );
		}

		return $current_subscription;
	}

	public function get_active_subscription() {
		return $this->_wpdb->get_results( "SELECT * FROM {$this->_wpdb->prefix}job_subscriptions WHERE next_billing_date <= '" . time() . "' AND next_billing_date != '0000-00-00' AND next_billing_date != '' AND next_billing_date != 0" );
	}

	public function get_subscription_order_by_id( $order_id = 0 ) {
		$select_package = "SELECT * FROM {$this->_wpdb->prefix}job_subscription_orders WHERE id = {$order_id}";
		$r = $this->_wpdb->get_results( $select_package );
		return isset( $r['0'] ) ? $r['0'] : 0;
	}

	public function get_subscription_order_by_user_id( $user_id = '' ) {
		$select_package = "SELECT * FROM {$this->_wpdb->prefix}job_subscription_orders WHERE user_id = {$user_id} AND subscription_status != 'inactive'";
		$r = $this->_wpdb->get_results( $select_package );
		return isset( $r['0'] ) ? $r['0'] : 0;
	}

	public function get_subscription_levels() {

		if ( empty( $this->subscription_levels ) ) { $this->show_error( "no_subscription_levels" ); }

		$this->current_subscription = $this->get_current_subscription($this->_current_user->ID);

		foreach ( $this->subscription_levels as $key => $value ) {
			$this->subscription_arr[$key]['weekly']          = get_option( 'wpjobster_subscription_weekly_amount_' . $key );
			$this->subscription_arr[$key]['monthly']         = get_option( 'wpjobster_subscription_monthly_amount_' . $key );
			$this->subscription_arr[$key]['quarterly']       = get_option( 'wpjobster_subscription_quarterly_amount_' . $key );
			$this->subscription_arr[$key]['yearly']          = get_option( 'wpjobster_subscription_yearly_amount_' . $key );
			$this->subscription_arr[$key]['lifetime']        = get_option( 'wpjobster_subscription_lifetime_amount_' . $key );
			$this->subscription_arr[$key]['eligility']       = get_option( 'wpjobster_subscription_eligibility_amount_' . $key );
			$this->subscription_arr[$key]['fees']            = get_option( 'wpjobster_subscription_fees_' . $key );
			$this->subscription_arr[$key]['profile_label']   = get_option( 'wpjobster_subscription_profile_label_' . $key );
			$this->subscription_arr[$key]['icon_url']        = get_option( 'wpjobster_subscription_icon_url_' . $key );
			$this->subscription_arr[$key]['noof_extras']     = get_option( 'wpjobster_subscription_noof_extras_' . $key );
			$this->subscription_arr[$key]['noof_efd']        = get_option( 'wpjobster_subscription_fast_del_multiples_' . $key );
			$this->subscription_arr[$key]['noof_ar']         = get_option( 'wpjobster_subscription_add_rev_multiples_' . $key );
			$this->subscription_arr[$key]['noof_job_m']      = get_option( 'wpjobster_subscription_job_multiples_' . $key );
			$this->subscription_arr[$key]['noof_extra_m']    = get_option( 'wpjobster_subscription_extra_multiples_' . $key );
			$this->subscription_arr[$key]['noof_video_m']    = get_option( 'wpjobster_subscription_video_multiples_' . $key );
			$this->subscription_arr[$key]['min_ce_price']    = get_option( 'wpjobster_subscription_min_customextrasamount_' . $key );
			$this->subscription_arr[$key]['max_ce_price']    = get_option( 'wpjobster_subscription_max_customextrasamount_' . $key );
			$this->subscription_arr[$key]['min_extra_price'] = get_option( 'wpjobster_subscription_min_extra_price_' . $key );
			$this->subscription_arr[$key]['max_extra_price'] = get_option( 'wpjobster_subscription_max_extra_price_' . $key );
			$this->subscription_arr[$key]['min_job_price']   = get_option( 'wpjobster_subscription_min_job_price_' . $key );
			$this->subscription_arr[$key]['max_job_price']   = get_option( 'wpjobster_subscription_max_job_price_' . $key );
			$this->subscription_arr[$key]['job_packages']    = get_option( 'wpjobster_subscription_packages_' . $key );
			$this->subscription_arr[$key]['tips']            = get_option( 'wpjobster_subscription_tips_' . $key );

			$param1 = $this;
			do_action( 'add_item_in_array', $param1, $key );
		}
	}

	public function remove_subscription( $uid ) {
		$this->current_subscription = $this->get_current_subscription( $uid );

		$this->_wpdb->delete( $this->_wpdb->prefix . "job_subscriptions", array( "id" => $this->current_subscription->id ) );

		wp_redirect( get_permalink( get_option( 'wpjobster_subscriptions_page_id' ) ) );
	}

	public function get_next_billing_date( $sub_type ) {
		$start_date = date( 'Y-m-d' );
		$start_date_obj = new DateTime( $start_date );

		if ( $sub_type == 'weekly' ) { $interval = new DateInterval( 'P7D' ); }
		if ( $sub_type == 'monthly' ) { $interval = new DateInterval( 'P1M' ); }
		if ( $sub_type == 'quarterly' ) { $interval = new DateInterval( 'P3M' ); }
		if ( $sub_type == 'yearly' ) { $interval = new DateInterval( 'P12M' ); }

		if ( $sub_type == 'lifetime' ) {
			$next_billing_date = 0;
		} else {
			$start_date_obj->add( $interval );
			$next_billing_date = strtotime( $start_date_obj->format( 'Y-m-d' ) );
		}

		return $next_billing_date;
	}

	public function calculate_tax_and_fees( $amount ) {
		$_subscription_amount          = $amount;
		$buyer_processing_fees_orignal = wpjobster_get_site_processing_fee( $_subscription_amount, 0, 0);
		$tax_orignal                   = wpjobster_get_site_tax( $_subscription_amount, 0, 0, $buyer_processing_fees_orignal );
		$total_amount_orignal          = $_subscription_amount + $tax_orignal + $buyer_processing_fees_orignal;

		$_tax                  = wpjobster_formats_special_exchange( $tax_orignal, '1', $this->_currency );
		$buyer_processing_fees = wpjobster_formats_special_exchange( $buyer_processing_fees_orignal, '1', $this->_currency );
		$total                 = wpjobster_formats_special_exchange( $_subscription_amount, '1', $this->_currency );
		$_payable_amount       = $total + $buyer_processing_fees + $_tax;

		$data = array(
			'buyer_processing_fees_orignal' => $buyer_processing_fees_orignal,
			'tax_orignal'                   => $tax_orignal,
			'total_amount_orignal'          => $total_amount_orignal,
			'tax'                           => $_tax,
			'buyer_processing_fees'         => $buyer_processing_fees,
			'payable_amount'                => $_payable_amount
		);

		return $data;
	}

	public function send_subscription_renewal_reminder(){
		$subscriptions = $this->get_active_subscription();

		if ( is_array( $subscriptions ) ) {
			foreach ( $subscriptions as $subscription ) {

				$no_of_days_prior    = get_option( 'wpjobster_subscription_prior_notification' );
				$one_days_seconds    = 60 * 60 * 24;
				$total_seconds_prior = $no_of_days_prior * $one_days_seconds;

				$next_billing_date = $subscription->next_billing_date;
				$uid = $subscription->user_id;
				$wpjobster_subscription_prior_email_notification_sent = get_user_meta( $uid, "wpjobster_subscription_prior_email_notification_sent", true );

				if ( $total_seconds_prior + time() > $subscription->next_billing_date && $wpjobster_subscription_prior_email_notification_sent != '1' ) {

					update_user_meta( $uid, "wpjobster_subscription_prior_email_notification_sent", "1" );

					$array_to_send = array(
						'##amount_updated##'               => $subscription->subscription_amount,
						'##current_subscription_level##'   => wpjobster_translate_string( $subscription->subscription_level ),
						'##current_subscription_period##'  => wpjobster_translate_string( $subscription->subscription_type ),
						'##current_subscription_amount##'  => $subscription->subscription_amount,
						'##next_billing_date##'            => $subscription->next_billing_date,
						'##next_subscription_level##'      => wpjobster_translate_string( $subscription->next_subscription_level ),
						'##next_subscription_type##'       => wpjobster_translate_string( $subscription->next_subscription_type ),
						'##next_subscription_amount##'     => $subscription->next_subscription_amount,
						'##no_of_days_subscription_left##' => $no_of_days_prior
					);

					wpj_notify_user_translated( 'wpjobster_subscription_prior_notification', $uid, $array_to_send );
				}
			}
		}
	}

	public function send_payment_details( $payment_method = '', $jb_action = '' ) {
		$uid = $this->_current_user->ID;

		$nm = explode( "-", $_GET['sub_id'] );

		$sub_type     = isset( $nm[0] ) ? $nm[0] : '';
		$sub_level    = isset( $nm[1] ) ? $nm[1] : '';
		$sub_usr_type = isset( $nm[2] ) ? $nm[2] : '';

		$sub_amount = get_option( 'wpjobster_subscription_' . $nm[0] . '_amount_' . $nm[1] );

		if ( $jb_action == 'change_subscription' ) {
			$this->current_subscription = $this->get_current_subscription($uid);
			$last_sub_level             = $this->current_subscription->subscription_level;
			$last_sub_plan              = $this->current_subscription->subscription_type;
			$last_sub_amount            = get_option( 'wpjobster_subscription_' . $last_sub_plan . '_amount_' . $last_sub_level );
			$sub_amount                 = $sub_amount - $last_sub_amount;

			if ( $payment_method == "credits" ) {
				wpjobster_update_credits( $uid, wpjobster_get_credits( $uid ) + $nm[2] );
			}
		}

		if ( is_numeric( $sub_amount ) ) {

			$wpjobster_subscriptions_page_id = get_option( 'wpjobster_subscriptions_page_id' );
			$subscription_page_post          = get_post( $wpjobster_subscriptions_page_id );
			$subscription_page_post_name     = $subscription_page_post->post_name;

			if ( strpos( $_SERVER['HTTP_REFERER'], $subscription_page_post_name ) ) { ?>

				<script>
					window.addEventListener( 'load', function() {
						take_to_gateway_subscription(
							'<?php echo $this->_payment_gateway; ?>',
							'<?php echo get_option( 'wpjobster_' . $this->_payment_gateway . '_enablepopup' ); ?>',
							'<?php echo $uid; ?>',
							'<?php echo $sub_amount; ?>',
							'<?php echo $sub_type; ?>',
							'<?php echo $sub_level; ?>',
							'<?php echo $sub_usr_type; ?>'
						);
					});
				</script>

			<?php }

		}
	}

	// send email to users when admin changes amount in the price settings
	public function send_update_email_subscription( $period_level_id ) {
		$nm = explode( "_", $period_level_id );

		$sub_type  = $nm[0];
		$sub_level = $nm[1];

		$subscriptions = $this->_wpdb->get_results( "
			SELECT * FROM {$this->_wpdb->prefix}job_subscriptions
			WHERE
				( subscription_level = '{$sub_level}' AND subscription_type = '{$sub_type}' )
				OR ( next_subscription_level = '{$sub_level}' AND next_subscription_type = '{$sub_type}' )
		" );

		if ( is_array( $subscriptions ) ) {
			foreach ( $subscriptions as $subscription ) {
				$new_amount = get_option( 'wpjobster_subscription_' . $sub_type . '_amount_' . $sub_level );

				wpj_notify_user_translated( 'price_update_subscription', $subscription->user_id, array( '##subscription_url##' => wpj_get_subscription_link(), '##amount_updated##' => $new_amount ), '', 'email' );
			}

			echo json_encode( array( 'msg' => 'done' ) );
		} else {
			echo json_encode( array( 'msg1' => 'done' ) );
		}
	}

	public function send_subscription_email( $email_reason, $uid, $payable_amount = 0 ) {
		$user_data = get_userdata( $uid );
		$current_subscription = $this->get_current_subscription( $uid );

		$array_to_send = array(
			'##username##'                    => wpj_get_user_display_type( $user_data->ID ),
			'##amount_updated##'              => $payable_amount,
			'##current_subscription_level##'  => wpjobster_translate_string( $current_subscription->subscription_level ),
			'##current_subscription_period##' => wpjobster_translate_string( $current_subscription->subscription_type ),
			'##current_subscription_amount##' => $current_subscription->subscription_amount,
			'##next_billing_date##'           => $current_subscription->next_billing_date,
			'##next_subscription_level##'     => wpjobster_translate_string( $current_subscription->next_subscription_level ),
			'##next_subscription_type##'      => wpjobster_translate_string( $current_subscription->next_subscription_type ),
			'##next_subscription_amount##'    => $current_subscription->next_subscription_amount
		);

		wpj_notify_user_translated( $email_reason, $uid, $array_to_send );
	}

	public function chose_subscriptions(){
		$levels = $this->get_subscription_levels();

		$is_subscribed = '0';
		if ( is_object( $this->current_subscription ) ) {
			$is_subscribed  = '1';
			$current_level  = $this->current_subscription->subscription_level;
			$current_type   = $this->current_subscription->subscription_type;
			$current_amount = $this->current_subscription->subscription_amount;
		} ?>

		<div id="content-full-ov">

			<?php include_once get_template_directory() . '/template-parts/pages/subscriptions/subscription_top.php';

			$sub_action = isset( $_GET['sub_action'] ) ?$_GET['sub_action'] : 'default';

			if ( $is_subscribed == '1' ) {

				if ( $sub_action == 'cancel' ) {
					include_once get_template_directory() . '/template-parts/pages/subscriptions/subscription_cancel.php';
				} elseif ( $sub_action == 'schedule' ) {
					$schedule_only = 1;
					$subscr_action = 'schedule_upgrade_subscription';
				} elseif ( $sub_action == 'change' ) {
					$subscr_action = 'upgrade_subscription';
				} else {
					include_once get_template_directory() . '/template-parts/pages/subscriptions/subscription_details.php';
				}

			} else { // if already subscription

				$schedule_only = $sub_action == 'schedule' ? 1 : 0;
				$subscr_action = 'new_subscription';
			}

			if ( isset( $subscr_action ) ) { include_once get_template_directory() . '/template-parts/pages/subscriptions/subscription_form.php'; } ?>

		</div>

	<?php }

	public function show_messages( $error = 1, $msg = '' ) {
		if ( $error == '1' ) {
			return '<div class="ui negative message">' . $this->errors[$msg] . '</div>';
		} else {
			return '<div class="ui positive message">' . $this->messages[$msg] . '</div>';
		}
	}

}
