<?php

include_once 'wpjobster_common_payment.php';

class WPJ_Common_Tips extends WPJ_Common_Payment{
	public $_currency, $_current_user, $_wpdb, $_order_id, $_tips_id, $_myaccount_lnk, $_payable_amount, $_payment_gateway, $_payment_type;

	public function payment_process( $order_id, $payment_gateway_slug, $payment_details, $response, $redirect = 'yes' ) {
		$tips_order = $this->get_tips_order_by_id( $order_id );
		if ( is_array( $response ) ) {
			$payment_response = json_encode( $response );
		} else {
			$payment_response = $response;
		}

		$pmt_row = $this->get_order_by_type_and_id( $order_id, 'tips' );
		if ( $pmt_row ) {
			$response_array['total'] = $pmt_row->final_amount;
		} else {
			$response_array['total'] = $tips_order->payable_amount;
		}

		$response_array['mc_gross']    = $tips_order->payable_amount;
		$response_array['order_id']    = $tips_order->order_id;
		$response_array['tips_id']     = $tips_order->tips_id;
		$response_array['mc_currency'] = $tips_order->currency;
		$response_array['uid']         = $tips_order->user_id;
		$payment_details               = ! empty( $payment_details ) ? $payment_details : $tips_order->payment_gateway_transaction_id;
		$payment_response              = ! empty( $payment_response ) ? $payment_response : $tips_order->payment_response;

		$this->complete_tips_process( $response_array );
		$this->update_tips_order_status( $order_id, 'completed', $payment_details, $payment_response );
		if ( $redirect=='yes' ) {
			$this->goto_order_page( $payment_gateway_slug, $response_array );
		}
	}

	public function payment_failed( $order_id, $gateway_slug, $payment_details = '', $payment_response = '', $redirect = 'yes' ) {
		$tips_order       = $this->get_tips_order_by_id( $order_id );
		$payment_details  = ! empty( $payment_details ) ? $payment_details : $tips_order->payment_gateway_transaction_id;
		$payment_response = ! empty( $payment_response ) ? $payment_response : $tips_order->payment_response;
		$this->update_tips_order_status( $order_id, 'cancelled', $payment_details, $payment_response );

		$order          = wpjobster_get_order( $tips_order->order_id );
		$tips           = json_decode( $order->tips );
		$tip            = $tips[$tips_order->tips_id];
		$tip->paid      = false;
		$tip->cancelled = true;

		wpjobster_update_order_meta( $tips_order->order_id, 'tips', json_encode( $tips ) );

		$datemade = current_time( 'timestamp', 1 );

		$g1 = "INSERT INTO {$this->_wpdb->prefix}job_chatbox (datemade, uid, oid, content) VALUES( '{$datemade}', '-38', '{$tips_order->order_id}', '{$tips_order->tips_id}')";
		$this->_wpdb->get_results( $g1 );

		wpj_notify_user_translated( 'cancel_tips', $order->uid, array( '##transaction_page_link##' => wpj_get_order_link( $order_id ) ) );

		if ( $redirect == 'yes' ) {
			$this->goto_order_fail_page( $tips_order );
		}
	}

	public function __construct( $payment_gateway = '' ) {
		parent::__construct( $payment_gateway );
		global $wp_query, $wpdb, $current_user;

		$this->_payment_type    = 'tips';
		$this->_payment_gateway = $payment_gateway;
		$this->_current_user    = wp_get_current_user();
		$this->_wpdb            = $wpdb;

		add_action( "wpjobster_tips_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_tips_payment_failed", array( $this, "payment_failed" ), 10, 5 );

		$this->_currency = wpjobster_get_currency();

		$this->_myaccount_lnk = wpj_get_my_account_link();

		if ( isset( $_GET['oid'] ) && isset( $_GET['tips'] ) ) {
			$this->_order_id = isset( $_GET['oid'] ) ? $_GET['oid'] : '0';
			$this->_tips_id  = isset( $_GET['tips'] ) ? $_GET['tips'] : false;
			$ord             = wpjobster_get_order( $this->_order_id );
			$tips            = json_decode( $ord->tips );
			if ( ! $this->_tips_id ) $this->_tips_id = 0;
			$total = $tips[$this->_tips_id]->amount;
			$wpjobster_enable_site_tax   = get_option( 'wpjobster_enable_site_tax' );
			$this->_wpjobster_tax_percent = 0;
			if ( $wpjobster_enable_site_tax == 'yes' ) {
				$master_total                 = 0;
				$country_code                 = user( $this->_current_user->ID, 'country_code' );
				$this->_wpjobster_tax_percent = wpjobster_get_tax( $country_code );
			}
			$this->_tips_amount    = $total;
			$total                 = wpjobster_formats_special_exchange( $total, '1', $this->_currency );
			$total                 = wpjobster_formats_special( $total, 2 );
			$this->_tax            = wpjobster_formats_special( $total * $this->_wpjobster_tax_percent/100, 2 );
			$this->_payable_amount = $total + $this->_tax;
		}

		add_filter( "wpjobster_insert_tips_order", array( $this, 'insert_tips_order' ), 10, 2 );
	}

	function insert_tips_order( $tips_order = array() ) {
		if ( empty( $tips_order ) ) {
			$tips_order = array(
				'order_id'             => $this->_order_id,
				'tips_id'              => $this->_tips_id,
				'user_id'              => $this->_current_user->ID,
				'tips_amount'          => $this->_tips_amount,
				'payment_status'       => 'pending',
				'payment_gateway_name' => $this->payment_gateway,
				'tax'                  => $this->_tax,
				'payable_amount'       => $this->_payable_amount,
				'currency'             => $this->_currency
			);
			if ( $tips_order['order_id'] == '' || $tips_order['tips_id'] == '' ) {
				return 0;
			}
		}
		if ( $tips_order['payment_status'] == 0 || $tips_order['paid'] == 0 ) {
			$tips_order['payment_status'] = 'pending';
		}

		if ( ! isset( $tips_order['payment_gateway_name'] ) || $tips_order['payment_gateway_name'] == '' ) {
			$tips_order['payment_gateway_name'] = $this->_payment_gateway;
		}

		$tm = time();
		$sql = "
			INSERT INTO {$this->_wpdb->prefix}job_tips_orders
			SET order_id             = {$tips_order['order_id']},
				tips_id              = {$tips_order['tips_id']},
				user_id              = {$tips_order['user_id']},
				tips_amount          = {$tips_order['tips_amount']},
				payable_amount       = {$tips_order['payable_amount']},
				added_on             = {$tm},
				payment_status       = '{$tips_order["payment_status"]}',
				currency             = '{$tips_order["currency"]}',
				tax                  = '{$tips_order["tax"]}',
				payment_gateway_name = '{$tips_order["payment_gateway_name"]}'
		";
		$insert_result = $this->_wpdb->query( $sql );

		$order_id = $this->_wpdb->insert_id;

		$payment_info['payment_status']  = 'pending';
		$payment_info['payment_gateway'] = $tips_order['payment_gateway_name'];
		$payment_info['payment_type']    = $this->_payment_type;
		$payment_info['payment_type_id'] = $order_id;
		$payment_info['fees']            = $tips_order['fees_orignal'];
		$payment_info['amount']          = $tips_order['tips_amount'];
		$payment_info['tax']             = $tips_order['tax_orignal'];
		$payment_info['currency']        = wpjobster_get_currency_classic();
		$payment_info['final_amount']           = $tips_order['total_amount_orignal'];
		$payment_info['final_amount_exchanged'] = $tips_order['payable_amount'];
		$payment_info['final_amount_currency']  = $tips_order['currency'];

		$this->insert_payment( $payment_info );

		return $order_id ;
	}

	function update_tips_order_status( $order_id, $status,$transaction_id=0, $payment_response='' ) {
		$tm = time();
		$sql = "
			UPDATE {$this->_wpdb->prefix}job_tips_orders
			SET payment_status                 = '{$status}',
				paid_on                        = '{$tm}',
				payment_gateway_transaction_id = '{$transaction_id}',
				payment_response               = '{$payment_response}'
			WHERE id={$order_id}";
		$update_result = $this->_wpdb->query( $sql );

		$payment['order_id']         = $order_id;
		$payment['status']           = $status;
		$payment['payment_type']     = 'tips';
		$payment['payment_response'] = $payment_response;
		$payment['payment_details']  = $transaction_id;

		$this->update_payment( $payment );
	}

	function complete_tips_process( $response_array = array() ) {
		$payed_amt = $response_array['mc_currency'] . "|" . $response_array['mc_gross'];
		if ( $response_array['order_id'] != false && $response_array['tips_id'] != null ) {
			$ord       = wpjobster_get_order( $response_array['order_id'] );
			$tips      = json_decode( $ord->tips );
			$tip       = $tips[$response_array['tips_id']];
			$tip->paid = true;

			$buyer_processing_fees_orignal = wpjobster_get_site_processing_fee( $tip->amount, 0, 0);
			$tax_orignal = wpjobster_get_site_tax($tip->amount,0,0,$buyer_processing_fees_orignal);

			$tax = wpjobster_formats_special_exchange( $tax_orignal, '1', $response_array['mc_currency'] );
			$buyer_processing_fees = wpjobster_formats_special_exchange( $buyer_processing_fees_orignal, '1', $response_array['mc_currency'] );

			if ( $buyer_processing_fees_orignal )
				$tip->processing_fees = $buyer_processing_fees_orignal;
			if ( $tax_orignal )
				$tip->tax = $tax_orignal;
			$tip->paid = true;

			wpjobster_update_order_meta( $response_array['order_id'], 'tips', json_encode( $tips ) );

			notify_after_tips_pay( $response_array['order_id'], $response_array['uid'],  $response_array['total'], $response_array['mc_currency'], $response_array['tips_id'] );

			$datemade = current_time( 'timestamp', 1 );

			$g1 = "INSERT INTO {$this->_wpdb->prefix}job_chatbox (datemade, uid, oid, content) VALUES( {$datemade}, '-37', '" . $response_array['order_id'] . "', '" . $response_array['tips_id'] . "')";
			$this->_wpdb->get_results( $g1 );

			$this_notification = $this->_wpdb->insert_id;
			wpj_update_user_notifications( wpj_get_seller_id( $ord ), 'notifications', +1, $this_notification );
		}

		return true;

	}

	function goto_order_fail_page( $response_array ) {
		if ( strpos( $_SERVER['HTTP_REFERER'], 'page=order-stats' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) ) {
			wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail" );
		} else {
			wp_redirect( get_bloginfo( 'url' ) . "/?jb_action=chat_box&oid=" . $response_array->order_id . "&status=fail" );
		}

		exit;
	}

	function get_main_order_id_from_orderid( $order_id ) {
		$sql = "SELECT order_id FROM {$this->_wpdb->prefix}job_tips_orders WHERE id={$order_id}";
		$select_result = $this->_wpdb->get_results($sql);
		$select_row = $select_result[0];

		return $select_row->order_id;
	}

	function get_tips_order_by_id( $order_id=0 ) {
		$query = "SELECT * FROM {$this->_wpdb->prefix}job_tips_orders WHERE id={$order_id}";
		$r = $this->_wpdb->get_results( $query );

		return isset( $r['0'] ) ? $r['0'] : 0;
	}

	function goto_order_page( $gateway, $response_array ) {
		do_action( 'wpjobster_tips_payment_completed', $gateway, $response_array );

		if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=order-stats' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) ) {
			wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=tabs8" );
		} else {
			wp_redirect( get_bloginfo( 'url' ) . "/?jb_action=chat_box&oid=" . $response_array['order_id'] );
		}

		die();
	}

	function get_tips_orders_pagination( $gateway = '', $limit = array(), $order_by = 'id', $order = 'desc' ) {
		if ( $gateway != '' ) {
			$where = " and payment_gateway_name='{$gateway}' ";
		} else {
			$where = '';
		}

		if ( ! empty( $limit ) && $limit[0] >= 0 && $limit[1] > 0 ) {
			$limit = "limit {$limit['0']},{$limit['1']}";
		} else {
			$limit = "";
		}

		$order_str = " order by $order_by " . $order;

		$query = "SELECT * FROM {$this->_wpdb->prefix}job_tips_orders WHERE 1 {$where} {$order_str} {$limit}";
		$r = $this->_wpdb->get_results( $query );

		return isset( $r['0'] ) ? $r : 0;
	}
}
