<?php
// exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

class Image_Watermark_WPJ_Extension extends Image_Watermark_Settings {

	public function __construct() {
		add_action( 'admin_init', array( $this, 'register_settings' ), 11 );
		add_action( 'wpjobster_new_admin_options_menu', array( $this, 'options_page' ), 6 );
		add_action( 'wpjobster_new_admin_options_top_menu', array( $this, 'options_bar_page' ), 6 );
		add_action( 'wp_loaded', array( $this, 'load_image_sizes' ) );
		add_action( 'wp_loaded', array( $this, 'load_image_categories' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
	}

	public function load_image_categories() {
		$this->image_categories = array(
			'job_images'           => __( 'Job images', 'image-watermark' ),
			'job_cover_images'     => __( 'Job cover', 'image-watermark' ),
			'job_instant_delivery' => __( 'Job instant delivery', 'image-watermark' ),
			'job_preview'          => __( 'Job preview', 'image-watermark' ),
			'job_work_samples'     => __( 'Job work samples', 'image-watermark' ),
			'chat_box_messages'    => __( 'Chatbox messages', 'image-watermark' ),
			'private_messages'     => __( 'Private messages', 'image-watermark' ),
			'custom_offer_request' => __( 'Custom offer request', 'image-watermark' ),
			'new_request'          => __( 'Requests', 'image-watermark' ),
			'user_cover'           => __( 'User cover', 'image-watermark' ),
			'user_avatar'          => __( 'User avatar', 'image-watermark' ),
			'user_portofolio'      => __( 'User portofolio', 'image-watermark' ),
		);
	}

	public function admin_enqueue_scripts() {
		wp_enqueue_style( 'wpj-iw-theme-style', IMAGE_WATERMARK_URL . 'wpj/style.css', array(), '1.6.5' );
		wp_enqueue_script( 'wpj-iw-theme-scrpt', IMAGE_WATERMARK_URL . 'wpj/script.js', array( 'jquery' ), '1.6.5' );
	}

	public function options_page() {
		add_submenu_page(
			"PT1_admin_mnu",
			__( 'Image Watermark Options', 'image-watermark' ),
			wpjobster_disp_spcl_cst_pic( 'setup_icon.png' ) . __( 'Watermark', 'image-watermark' ),
			'manage_options',
			'watermark-options',
			array ( $this, 'options_page_output' )
		);
	}

	public function options_bar_page( $wp_admin_bar ) {
		$wp_admin_bar->add_node( array(
			'id'     => 'watermark-options',
			'parent' => 'PT1_admin_mnu',
			'title'  => __( 'Watermark', 'image-watermark' ),
			'href'   => get_admin_url() . 'admin.php?page=watermark-options',
			'meta'   => array(
				'title' => __( 'Watermark', 'image-watermark' )
			),
		));
	}

	public function options_page_output() {

		if ( ! current_user_can( 'manage_options' ) )
			return; ?>

		<div class="wrap image-watermark-wrapper">
			<h2 class="wpj-admin-title"><?php echo __( 'Jobster - Image Watermark', 'image-watermark' ); ?></h2>

			<?php settings_errors( 'iw_settings_errors' ); ?>

			<div id="usual2" class="usual">
				<form action="options.php" method="post">

					<input type="hidden" name="_wp_http_referer" value="<?php echo admin_url( 'admin.php?page=watermark-options&active_tab=watermark-general' ); ?>" />

					<?php $sections = array(
						'general'    => __( 'General settings', 'image-watermark' ),
						'position'   => __( 'Watermark position', 'image-watermark' ),
						'image'      => __( 'Watermark image', 'image-watermark' ),
						'protection' => __( 'Image protection', 'image-watermark' ),
						'backup'     => __( 'Image backup', 'image-watermark' )
					); ?>

					<ul>
						<?php foreach ( $sections as $key => $section ) { ?>
							<li class="wpj-js-iw-tab"><a href="#watermark-<?php echo $key; ?>"><?php echo $section; ?></a></li>
						<?php } ?>
					</ul>

					<?php foreach ( $sections as $key => $section ) { ?>

						<div id="watermark-<?php echo $key; ?>">

							<?php settings_fields( 'image_watermark_options' ); ?>

							<input type="hidden" name="_wp_http_referer" value="<?php echo admin_url( 'admin.php?page=watermark-options&active_tab=watermark-' . $key ); ?>" />

							<table width="100%" class="wpj-admin-table">
								<tr>
									<td colspan="2"><h2><?php echo $section; ?></h2></td>
								</tr>

								<?php do_settings_fields( 'image_watermark_options', 'image_watermark_' . $key ); ?>

								<tr>
									<th></th>
									<td>
										<?php submit_button( '', 'primary', 'save_image_watermark_options', false ); ?>
										&nbsp;
										<?php submit_button( __( 'Reset to defaults', 'image-watermark' ), 'secondary', 'reset_image_watermark_options', false ); ?>
									</td>
								</tr>
							</table>

						</div>

					<?php } ?>

				</form>

			</div>

			<div class="clear"></div>
		</div>

	<?php }

	public function validate_options( $input ) {
		if ( ! current_user_can( 'manage_options' ) )
			return $input;

		if ( isset( $_POST['save_image_watermark_options'] ) ) {
			$input['watermark_image']['plugin_off'] = isset( $_POST['iw_options']['watermark_image']['plugin_off'] ) ? ((bool) $_POST['iw_options']['watermark_image']['plugin_off'] == 1 ? true : false) : Image_Watermark()->defaults['options']['watermark_image']['plugin_off'];
			$input['watermark_image']['manual_watermarking'] = isset( $_POST['iw_options']['watermark_image']['manual_watermarking'] ) ? ((bool) $_POST['iw_options']['watermark_image']['manual_watermarking'] == 1 ? true : false) : Image_Watermark()->defaults['options']['watermark_image']['manual_watermarking'];

			// sizes
			$watermark_on = array();

			foreach ( $this->image_sizes as $key => $size ) {
				$watermark_on[$size] = 1;
			}

			$input['watermark_on'] = $watermark_on;

			// categories
			$watermark_cat_on = array();

			if ( isset( $_POST['iw_options']['watermark_cat_on'] ) && is_array( $_POST['iw_options']['watermark_cat_on'] ) ) {
				foreach ( $this->image_categories as $key => $category ) {
					if ( in_array( $key, array_keys( $_POST['iw_options']['watermark_cat_on'] ) ) ) {
						$watermark_cat_on[$key] = 1;
					}
				}
			}

			$input['watermark_cat_on'] = $watermark_cat_on;

			// post type
			$input['watermark_cpt_on'] = Image_Watermark()->defaults['options']['watermark_cpt_on'];

			if ( isset( $_POST['iw_options']['watermark_cpt_on'] ) && in_array( esc_attr( $_POST['iw_options']['watermark_cpt_on'] ), array( 'everywhere', 'specific' ) ) ) {
				if ( $_POST['iw_options']['watermark_cpt_on'] === 'specific' ) {
					if ( isset( $_POST['iw_options']['watermark_cpt_on_type'] ) ) {
						$tmp = array();

						foreach ( $this->get_post_types() as $cpt ) {
							if ( in_array( $cpt, array_keys( $_POST['iw_options']['watermark_cpt_on_type'] ) ) ) {
								$tmp[$cpt] = 1;
							}
						}

						if ( count( $tmp ) > 0 ) {
							$input['watermark_cpt_on'] = $tmp;
						}
					}
				}
			}

			// extension
			$input['watermark_image']['extension'] = isset( $_POST['iw_options']['watermark_image']['extension'], Image_Watermark()->extensions[$_POST['iw_options']['watermark_image']['extension']] ) ? $_POST['iw_options']['watermark_image']['extension'] : Image_Watermark()->defaults['options']['watermark_image']['extension'];

			$input['watermark_image']['frontend_active'] = true;
			$input['watermark_image']['deactivation_delete'] = isset( $_POST['iw_options']['watermark_image']['deactivation_delete'] ) ? ((bool) $_POST['iw_options']['watermark_image']['deactivation_delete'] == 1 ? true : false) : Image_Watermark()->defaults['options']['watermark_image']['deactivation_delete'];


			$positions = array();

			foreach ( $this->watermark_positions['y'] as $position_y ) {
				foreach ( $this->watermark_positions['x'] as $position_x ) {
					$positions[] = $position_y . '_' . $position_x;
				}
			}
			$input['watermark_image']['position'] = isset( $_POST['iw_options']['watermark_image']['position'] ) && in_array( esc_attr( $_POST['iw_options']['watermark_image']['position'] ), $positions ) ? esc_attr( $_POST['iw_options']['watermark_image']['position'] ) : Image_Watermark()->defaults['options']['watermark_image']['position'];

			$input['watermark_image']['offset_unit'] = isset( $_POST['iw_options']['watermark_image']['offset_unit'] ) && in_array( $_POST['iw_options']['watermark_image']['offset_unit'], array( 'pixels', 'percentages' ), true ) ? $_POST['iw_options']['watermark_image']['offset_unit'] : Image_Watermark()->defaults['options']['watermark_image']['offset_unit'];
			$input['watermark_image']['offset_width'] = isset( $_POST['iw_options']['watermark_image']['offset_width'] ) ? (int) $_POST['iw_options']['watermark_image']['offset_width'] : Image_Watermark()->defaults['options']['watermark_image']['offset_width'];
			$input['watermark_image']['offset_height'] = isset( $_POST['iw_options']['watermark_image']['offset_height'] ) ? (int) $_POST['iw_options']['watermark_image']['offset_height'] : Image_Watermark()->defaults['options']['watermark_image']['offset_height'];
			$input['watermark_image']['url'] = isset( $_POST['iw_options']['watermark_image']['url'] ) ? (int) $_POST['iw_options']['watermark_image']['url'] : Image_Watermark()->defaults['options']['watermark_image']['url'];
			$input['watermark_image']['watermark_size_type'] = isset( $_POST['iw_options']['watermark_image']['watermark_size_type'] ) ? (int) $_POST['iw_options']['watermark_image']['watermark_size_type'] : Image_Watermark()->defaults['options']['watermark_image']['watermark_size_type'];
			$input['watermark_image']['absolute_width'] = isset( $_POST['iw_options']['watermark_image']['absolute_width'] ) ? (int) $_POST['iw_options']['watermark_image']['absolute_width'] : Image_Watermark()->defaults['options']['watermark_image']['absolute_width'];
			$input['watermark_image']['absolute_height'] = isset( $_POST['iw_options']['watermark_image']['absolute_height'] ) ? (int) $_POST['iw_options']['watermark_image']['absolute_height'] : Image_Watermark()->defaults['options']['watermark_image']['absolute_height'];
			$input['watermark_image']['width'] = isset( $_POST['iw_options']['watermark_image']['width'] ) ? (int) $_POST['iw_options']['watermark_image']['width'] : Image_Watermark()->defaults['options']['watermark_image']['width'];
			$input['watermark_image']['transparent'] = isset( $_POST['iw_options']['watermark_image']['transparent'] ) ? (int) $_POST['iw_options']['watermark_image']['transparent'] : Image_Watermark()->defaults['options']['watermark_image']['transparent'];
			$input['watermark_image']['quality'] = isset( $_POST['iw_options']['watermark_image']['quality'] ) ? (int) $_POST['iw_options']['watermark_image']['quality'] : Image_Watermark()->defaults['options']['watermark_image']['quality'];
			$input['watermark_image']['jpeg_format'] = isset( $_POST['iw_options']['watermark_image']['jpeg_format'] ) && in_array( esc_attr( $_POST['iw_options']['watermark_image']['jpeg_format'] ), array( 'baseline', 'progressive' ) ) ? esc_attr( $_POST['iw_options']['watermark_image']['jpeg_format'] ) : Image_Watermark()->defaults['options']['watermark_image']['jpeg_format'];

			$input['image_protection']['rightclick'] = isset( $_POST['iw_options']['image_protection']['rightclick'] ) ? ((bool) $_POST['iw_options']['image_protection']['rightclick'] == 1 ? true : false) : Image_Watermark()->defaults['options']['image_protection']['rightclick'];
			$input['image_protection']['draganddrop'] = isset( $_POST['iw_options']['image_protection']['draganddrop'] ) ? ((bool) $_POST['iw_options']['image_protection']['draganddrop'] == 1 ? true : false) : Image_Watermark()->defaults['options']['image_protection']['draganddrop'];
			$input['image_protection']['forlogged'] = isset( $_POST['iw_options']['image_protection']['forlogged'] ) ? ((bool) $_POST['iw_options']['image_protection']['forlogged'] == 1 ? true : false) : Image_Watermark()->defaults['options']['image_protection']['forlogged'];

			$input['backup']['backup_image'] = isset( $_POST['iw_options']['backup']['backup_image'] );
			$input['backup']['backup_quality'] = isset( $_POST['iw_options']['backup']['backup_quality'] ) ? (int) $_POST['iw_options']['backup']['backup_quality'] : Image_Watermark()->defaults['options']['backup']['backup_quality'];

			add_settings_error( 'iw_settings_errors', 'iw_settings_saved', __( 'Settings saved.', 'image-watermark' ), 'updated' );
		} elseif ( isset( $_POST['reset_image_watermark_options'] ) ) {

			$input = Image_Watermark()->defaults['options'];

			add_settings_error( 'iw_settings_errors', 'iw_settings_reset', __( 'Settings restored to defaults.', 'image-watermark' ), 'updated' );
		}

		if ( $input['watermark_image']['plugin_off'] != 0 || $input['watermark_image']['manual_watermarking'] != 0 ) {
			if ( empty( $input['watermark_image']['url'] ) )
				add_settings_error( 'iw_settings_errors', 'iw_image_not_set', __( 'Watermark will not be applied when watermark image is not set.', 'image-watermark' ), 'error' );

			if ( empty( $input['watermark_cat_on'] ) )
				add_settings_error( 'iw_settings_errors', 'iw_sizes_not_set', __( 'Watermark will not be applied when no image category is selected.', 'image-watermark' ), 'error' );
		}

		return $input;
	}

	public function iw_enable_for() { ?>

		<fieldset id="iw_enable_for">
			<div id="thumbnail-select">

				<?php foreach ( $this->image_categories as $key => $image_category ) { ?>
					<input name="iw_options[watermark_cat_on][<?php echo $key; ?>]" type="checkbox" id="<?php echo $key; ?>" value="1" <?php echo ( in_array( $key, array_keys( Image_Watermark()->options['watermark_cat_on'] ) ) ? ' checked="checked"' : '' ); ?> />

					<label for="<?php echo $key; ?>"><?php echo $image_category; ?></label>

					<br>
				<?php } ?>

			</div>
		</fieldset>

	<?php }

	public function iw_frontend_watermarking() {

		if ( Image_Watermark()->options['watermark_image']['plugin_off'] == 1 || Image_Watermark()->options['watermark_image']['manual_watermarking'] == 1 ) {
			_e( 'Yes', 'image-watermark' );
		} else {
			_e( 'No', 'image-watermark' );
		}
	}

}
