<?php
/*
	Plugin Name: WPJobster PayPal
	Plugin URL: http://wpjobster.com/
	Description: WPJobster PayPal Payment System.
	Version: 1.0.0
	Author: WPJobster
	Author URI: http://wpjobster.com/
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once( plugin_dir_path( __FILE__ ) . 'lib/paypal.class.php' );

if ( ! class_exists( "WPJobster_PayPal_Loader" ) ) {

	class WPJobster_PayPal_Loader {

		private static $instance;

		public $_paypal_url, $_jb_action, $_oid, $_unique_id;

		var $enable_log;

		public static function get_instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		public function __construct( $gateway = 'paypal' ) {

			$this->priority   = 100;
			$this->_unique_id = 'paypal';

			add_action( 'after_setup_theme', array( $this, 'init_gateways' ), 0 );

			add_action( 'wpjobster_taketo_' . $this->_unique_id . '_gateway', array( $this, 'taketogateway_function' ), 10, 2 );
			add_action( 'wpjobster_processafter_' . $this->_unique_id . '_gateway', array( $this, 'processgateway_function' ), 10, 2 );

			add_filter( 'wpjobster_take_allowed_currency_' . $this->_unique_id, array( $this, 'get_gateway_currency' ) );

			add_action( 'cancel_subscription_gateway', array( $this, 'change_subscription_status' ), 10, 1 );

			if ( isset( $_POST[ 'wpjobster_save_' . $this->_unique_id ] ) ) {
				add_action( 'wpjobster_payment_methods_action', array( $this, 'save_gateway' ), 11 );
			}

			$this->site_url = get_bloginfo( 'url' );

			$this->key = md5( date( "Y-m-d:" ) . rand() );

			// write IPN debug log in a text file
			$this->enable_log = false;

			$this->p = new paypal_class;
		}

		function get_gateway_currency( $currency ) {
			// if the gateway requires a specific currency you can declare it there
			// currency conversions are done automatically

			$currency = wpjobster_get_currency();

			$accepted_paypal_currencies = array( 'AUD', 'BRL', 'CAD', 'CZK', 'DKK', 'EUR', 'HKD', 'HUF', 'INR', 'ILS', 'JPY', 'MYR', 'MXN', 'TWD', 'NZD', 'NOK', 'PHP', 'PLN', 'GBP', 'RUB', 'SGD', 'SEK', 'CHF', 'THB', 'USD' );

			// if currency not supported
			if ( ! in_array( $currency, $accepted_paypal_currencies ) ) {

				// fallback
				$currency = 'USD';

				// try other site currencies
				global $wpjobster_currencies_array;
				foreach ( $wpjobster_currencies_array as $wpjobster_currency ) {
					if ( in_array( $wpjobster_currency, $accepted_paypal_currencies ) ) {
						$currency = $wpjobster_currency;
						break;
					}
				}
			}

			return $currency;
		}

		public function init_gateways() {
			add_filter( 'wpjobster_payment_gateways', array( $this, 'add_gateways' ) );
		}

		public function add_gateways( $methods ) {
			if ( get_option( 'wpjobster_paypal_email' ) ) {
				$methods[$this->priority] = array(
					'label'           => __( 'PayPal', 'wpjobster' ),
					'unique_id'       => $this->_unique_id,
					'action'          => 'wpjobster_taketo_' . $this->_unique_id . '_gateway', // action called when user request to send payment to gateway
					'response_action' => 'wpjobster_processafter_' . $this->_unique_id . '_gateway', //action called when any response comes from gateway after payment
				);
			} else {
				$methods[$this->priority] = array(
					'label'         => __( 'PayPal', 'wpjobster' ),
					'unique_id'     => $this->_unique_id,
					'no_pay_button' => true
				);
			}
			add_action( 'wpjobster_show_paymentgateway_forms', array( $this, 'show_gateways' ), $this->priority, 3 );

			return $methods;
		}

		public function save_gateway() {
			if ( isset( $_POST[ 'wpjobster_save_' . $this->_unique_id ] ) ) {
				update_option('wpjobster_paypal_enable'        , trim($_POST['wpjobster_paypal_enable']));
				update_option('wpjobster_paypal_email'         , trim($_POST['wpjobster_paypal_email']));
				update_option('wpjobster_paypal_enable_sdbx'   , trim($_POST['wpjobster_paypal_enable_sdbx']));
				update_option('wpjobster_paypal_button_caption', trim($_POST['wpjobster_paypal_button_caption']));

				if ( wpj_get_payment_types() ) {
					foreach ( wpj_get_payment_types() as $payment_type_enable_key => $payment_type_enable ) {
						if ( isset( $_POST['wpjobster_paypal_enable_' . $payment_type_enable_key] ) )
							update_option( 'wpjobster_paypal_enable_' . $payment_type_enable_key, trim( $_POST['wpjobster_paypal_enable_' . $payment_type_enable_key] ) );
					}
				}

				update_option( 'wpjobster_paypal_enable_secure', trim( $_POST['wpjobster_paypal_enable_secure'] ) );
				update_option( 'wpjobster_paypal_success_page' , trim( $_POST['wpjobster_paypal_success_page'] ) );
				update_option( 'wpjobster_paypal_failure_page' , trim( $_POST['wpjobster_paypal_failure_page'] ) );

				update_option( 'wpjobster_theme_appid'         , trim( $_POST['wpjobster_theme_appid'] ) );
				update_option( 'wpjobster_theme_appsecret'     , trim( $_POST['wpjobster_theme_appsecret'] ) );

				update_option( 'wpjobster_theme_apiusername'   , trim( $_POST['wpjobster_theme_apiusername'] ) );
				update_option( 'wpjobster_theme_apipassword'   , trim( $_POST['wpjobster_theme_apipassword'] ) );
				update_option( 'wpjobster_theme_apisignature'  , trim( $_POST['wpjobster_theme_apisignature'] ) );

				echo '<div class="updated fade"><p>' . __( 'Settings saved!', 'wpjobster' ) . '</p></div>';
			}
		}

		function show_gateways( $wpjobster_payment_gateways, $arr, $arr_pages ) {
			$tab_id = get_tab_id( $wpjobster_payment_gateways ); ?>

			<div id="tabs<?php echo $tab_id?>">
				<form method="post" action="<?php bloginfo( 'url' ); ?>/wp-admin/admin.php?page=payment-methods&active_tab=tabs<?php echo $tab_id;?>">
					<table width="100%" class="wpj-admin-table">
						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td width="200"><?php _e('Enable:','wpjobster'); ?></td>
							<td><?php echo wpjobster_get_option_drop_down( $arr, 'wpjobster_paypal_enable', 'no' ); ?></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(__('Enable testing mode', 'wpjobster')); ?></td>
							<td width="200"><?php _e('Enable Sandbox:','wpjobster'); ?></td>
							<td><?php echo wpjobster_get_option_drop_down($arr, 'wpjobster_paypal_enable_sdbx'); ?></td>
						</tr>

						<?php foreach ( wpj_get_payment_types() as $key => $payment_type ) { ?>

							<tr>
								<td valign="top" width="22"><?php wpjobster_theme_bullet( $payment_type['hint_label'] ); ?></td>
								<td width="200"><?php echo $payment_type['enable_label']; ?></td>
								<td><?php echo wpjobster_get_option_drop_down( $arr, 'wpjobster_paypal_enable_' . $key ); ?></td>
							</tr>

						<?php } ?>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(__('Set it to yes only if you know what it means and you have the SSL API certificates from PayPal on your server!', 'wpjobster')); ?></td>
							<td width="200"><?php _e('Certificate installed on the server:','wpjobster'); ?></td>
							<td><?php echo wpjobster_get_option_drop_down($arr, 'wpjobster_paypal_enable_secure'); ?> <?php _e('(In most of the cases it should be set to No)', 'wpjobster') ?></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td ><?php _e('PayPal Email Address:','wpjobster'); ?></td>
							<td><input type="text" size="45" name="wpjobster_paypal_email" value="<?php echo apply_filters( 'wpj_sensitive_info_email', get_option('wpjobster_paypal_email') ); ?>"/></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet("Put the Paypal Button caption you want user to see on purchase page "); ?></td>
							<td><?php _e('Paypal Button caption:','wpjobster'); ?></td>
							<td><input type="text" size="45" name="wpjobster_paypal_button_caption" value="<?php echo get_option('wpjobster_paypal_button_caption'); ?>"/></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet("Please select a page to show when paypal payment successful."); ?></td>
							<td><?php _e('Transaction success page:','wpjobster'); ?></td>
							<td><?php echo wpjobster_get_option_drop_down($arr_pages, 'wpjobster_paypal_success_page','', ' class="" '); ?></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('Transaction failure page:','wpjobster'); ?></td>
							<td><?php echo wpjobster_get_option_drop_down($arr_pages, 'wpjobster_paypal_failure_page','', ' class="" '); ?> </td>
						</tr>

						<tr>
							<td></td>
							<td><h2><?php _e("Automatic Withdrawals", "wpjobster"); ?></h2></td>
							<td></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('PayPal Client ID:','wpjobster'); ?></td>
							<td><input type="text" name="wpjobster_theme_appid" value="<?php echo apply_filters( 'wpj_sensitive_info_credentials', get_option('wpjobster_theme_appid') ); ?>" size="55" /> </td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('PayPal Secret:','wpjobster'); ?></td>
							<td>
								<input type="password" name="wpjobster_theme_appsecret" value="<?php echo apply_filters( 'wpj_sensitive_info_credentials', get_option('wpjobster_theme_appsecret') ); ?>" size="55" />
								<a class="cursor-pointer" id="show-withdrawal-info"><?php _e( 'Show info', 'wpjobster' ); ?></a>
							</td>
						</tr>

						<tr class="withdrawal-credentials-info" style="display: none;">
							<td></td>
							<td></td>
							<td>
								<p><?php _e( 'To get your withdrawal credentials, follow these steps:', 'wpjobster' ); ?></p>
								<p><?php _e( '1. Login to your paypal account', 'wpjobster' ); ?></p>
								<p><?php echo sprintf( __( '2. Go to %s', 'wpjobster' ), '<a target="_blank" href="https://developer.paypal.com/developer/applications">https://developer.paypal.com/developer/applications</a>' ); ?></p>
								<p><?php echo __( '3. Select Live or Sandbox', 'wpjobster' ); ?></p>
								<p><?php echo __( '4. Click "Create app"', 'wpjobster' ); ?></p>
								<p><img src="<?php echo get_template_directory_uri() . '/assets/images/admin/create_paypal_app_button.PNG'; ?>" width="900" height="487"></p>
								<p><?php echo __( '5. Fill the "App Name" input', 'wpjobster' ); ?></p>
								<p><?php echo __( '6. Select an account', 'wpjobster' ); ?></p>
								<p><?php echo __( '7. Click "Create app"', 'wpjobster' ); ?></p>
								<p><img src="<?php echo get_template_directory_uri() . '/assets/images/admin/create_paypal_app_details.PNG'; ?>" width="900" height="605"></p>
								<p><?php echo __( '8. Click "Show" secret field and copy your credentials to the above fields', 'wpjobster' ); ?></p>
								<p><img src="<?php echo get_template_directory_uri() . '/assets/images/admin/view_paypal_withdrawal_credentials.PNG'; ?>" width="900" height="485"></p>
							</td>
						</tr>

						<tr>
							<td></td>
							<td><h2><?php _e("Subscriptions", "wpjobster"); ?></h2></td>
							<td></td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('Paypal API Username:','wpjobster'); ?></td>
							<td><input type="text" name="wpjobster_theme_apiusername" value="<?php echo apply_filters( 'wpj_sensitive_info_credentials', get_option('wpjobster_theme_apiusername') ); ?>" size="55" /> </td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('Paypal API Password:','wpjobster'); ?></td>
							<td><input type="password" name="wpjobster_theme_apipassword" value="<?php echo apply_filters( 'wpj_sensitive_info_credentials', get_option('wpjobster_theme_apipassword') ); ?>" size="55" /> </td>
						</tr>

						<tr>
							<td valign="top" width="22"><?php wpjobster_theme_bullet(); ?></td>
							<td><?php _e('Paypal API Signature:','wpjobster'); ?></td>
							<td>
								<input type="text" name="wpjobster_theme_apisignature" value="<?php echo apply_filters( 'wpj_sensitive_info_credentials', get_option('wpjobster_theme_apisignature') ); ?>" size="55" />
								<a class="cursor-pointer" id="show-subscription-info"><?php _e( 'Show info', 'wpjobster' ); ?></a>
							</td>
						</tr>

						<tr class="subscription-credentials-info" style="display: none;">
							<td></td>
							<td></td>
							<td>
								<p><?php _e( 'To get your subscription credentials, follow these steps:', 'wpjobster' ); ?></p>
								<p><?php _e( '1. Login to your paypal account', 'wpjobster' ); ?></p>
								<p><?php echo sprintf( __( '2. Go to %s', 'wpjobster' ), '<a target="_blank" href="https://www.paypal.com/businessprofile/mytools/apiaccess/firstparty/signature">https://www.paypal.com/businessprofile/mytools/apiaccess/firstparty/signature</a>' ); ?></p>
								<p><?php echo __( '3. Check "Request an API signature" and click "Agree and Submit"', 'wpjobster' ); ?></p>
								<p><img src="<?php echo get_template_directory_uri() . '/assets/images/admin/request_paypal_api_signature.png'; ?>" width="900" height="383"></p>
								<p><?php echo __( '4. Click "Show" for each field and click "Done" after you copy your credentials to the above fields', 'wpjobster' ); ?></p>
								<p><img src="<?php echo get_template_directory_uri() . '/assets/images/admin/view_paypal_subscription_credentials.PNG'; ?>" width="900" height="360"></p>
							</td>
						</tr>

						<tr>
							<td></td>
							<td></td>
							<td><input type="submit" name="wpjobster_save_paypal" value="<?php _e( 'Save Options', 'wpjobster' ); ?>"/></td>
						</tr>

					</table>
				</form>
			</div>

		<?php }

		public function taketogateway_function( $payment_type, $common_details ) {

			// Normal Purchase Vars
			$order_id = isset( $common_details['order_id'] ) ? $common_details['order_id'] : '';
			$pid      = isset( $common_details['pid'] ) ? $common_details['pid'] : '';

			$currency_code                  = $common_details['selected'];
			$wpjobster_final_payable_amount = $common_details['wpjobster_final_payable_amount'];

			// Recurring Purchase Vars
			$cycle     = isset( $common_details['cycle'] )     ? $common_details['cycle'] : '';
			$period    = isset( $common_details['period'] )    ? $common_details['period'] : '';
			$sub_type  = isset( $common_details['sub_type'] )  ? $common_details['sub_type'] : '';
			$sub_level = isset( $common_details['sub_level'] ) ? $common_details['sub_level'] : '';

			// Set Product Title
			if ( $this->is_subscription_payment( $payment_type, $sub_type ) == 'recurring' ) {
				$title = strtoupper( $sub_type . ' Plan' );
			} else {
				$title = isset( $common_details['title'] ) ? $common_details['title'] : '-';
			}

			// Filter PayPal Job Title
			if ( $payment_type == 'job_purchase' ) {
				$title = apply_filters( 'wpj_paypal_order_job_title', $title, $order_id );
			}

			// Get Order ID
			$payment = wpj_get_payment( array(
				'payment_type'    => $payment_type,
				'payment_type_id' => $order_id,
			) );

			// Redirection Pages
			$notify_page  = get_bloginfo( 'url' ) . '/?payment_response=paypal&oid=' . $order_id . '&wpj_payment_id=' . $payment->id;
			$success_page = get_bloginfo( 'url' ) . '/?jb_action=loader_page&oid=' . $order_id . '&wpj_payment_id=' . $payment->id;
			$cancel_page  = get_bloginfo( 'url' ) . '/?payment_response=paypal&payment_type=' . $payment_type . '&action=cancel&order_id=' . $order_id . '&jobid=' . $pid . '&wpj_payment_id=' . $payment->id;

			if ( $this->is_subscription_payment( $payment_type, $sub_type ) ) {
				$notify_page = get_bloginfo( 'url' ) . '/?payment_response=paypal&payment_type=' . $payment_type . '&oid=' . $order_id . '&sub_type=' . $common_details['sub_type'];
			}

			$this->business = get_option( 'wpjobster_paypal_email' );
			if ( empty( $this->business ) ) {
				echo __( "ERROR: please input your paypal address in backend", 'wpjobster' ); exit;
			}

			// Send Data to PayPal
			$this->p->add_field( 'business'     , $this->business );
			$this->p->add_field( 'currency_code', $currency_code );
			$this->p->add_field( 'return'       , $success_page );
			$this->p->add_field( 'cancel_return', $cancel_page );
			$this->p->add_field( 'notify_url'   , $notify_page );
			$this->p->add_field( 'item_name'    , $title ) ;
			$this->p->add_field( 'item_number'  , $pid );
			$this->p->add_field( 'charset'      , get_bloginfo( 'charset' ) );
			$this->p->add_field( 'amount'       , $wpjobster_final_payable_amount );
			$this->p->add_field( 'custom'       , $payment->id );
			$this->p->add_field( 'key'          , $this->key );

			// Send Subscription Data to PayPal
			if ( $this->is_subscription_payment( $payment_type, $sub_type ) == 'recurring' ) {
				$this->p->add_field( 'cmd'    , '_xclick-subscriptions' );
				$this->p->add_field( 'no_note', 1 );
				$this->p->add_field( 'src'    , 1 );
				$this->p->add_field( 'a3'     , $wpjobster_final_payable_amount );
				$this->p->add_field( 'p3'     , $period );
				$this->p->add_field( 't3'     , $cycle );
				$this->p->add_field( 'bn'     , 'PP-SubscriptionsBF:btn_subscribeCC_LG.gif:NonHostedGuest' );
			}

			$this->p->submit_paypal_post();
		}

		public function processgateway_function( $payment_type, $details ) {

			$this->debug_log( 'IPN Start' );

			if ( $payment_type == '' ) {
				if ( isset( $_POST['custom'] ) ) {
					$pid          = $_POST['item_number'];
					$payment      = wpj_get_payment( array( 'id' => $_POST['custom'] ) );
					$order_id     = $payment->payment_type_id;
					$payment_type = $payment->payment_type;
				} else {
					$item_number     = $_POST['item_number'];
					$item_number_arr = explode( "|", $item_number );
					$pid             = $item_number_arr['0'];
					$payment_type    = $item_number_arr['1'];
				}
			}

			$payment_response = json_encode( $_REQUEST );
			$response_decoded = json_decode( $payment_response );

			if ( ! isset( $order_id ) ) {
				$order_id = isset( $_GET['order_id'] ) ? $_GET['order_id'] : "Unknown Order";
			}
			$transaction_id = isset( $_POST['txn_id'] ) ? $_POST['txn_id'] : "No ID";
			$payment_status = isset( $_POST['payment_status'] ) ? $_POST['payment_status'] : "No status";

			$payment['order_id']         = $order_id;
			$payment['payment_type']     = $payment_type;
			$payment['transaction_id']   = $transaction_id;
			$payment['payment_response'] = $payment_response;
			$payment['payment_status']   = $payment_status;
			$payment['gateway']          = $this->_unique_id;

			do_action( "wpjobster_store_payment_gateway_log", $payment );

			if ( ! empty( $response_decoded->custom ) ) {
				$payment      = wpj_get_payment( array( 'id' => $response_decoded->custom ) );
				$payment_type = $payment->payment_type;
			}

			if ( ! empty( $response_decoded->payment_type ) && $response_decoded->payment_type == 'subscription' ) {
				$amount = ! empty( $response_decoded->mc_amount3 ) ? $response_decoded->mc_amount3 : '';
				$date   = ! empty( $response_decoded->subscr_date ) ? $response_decoded->subscr_date : time();
			} else {
				$amount = ! empty( $response_decoded->mc_gross ) ? $response_decoded->mc_gross : '';
				$date   = ! empty( $response_decoded->payment_date ) ? $response_decoded->payment_date : time();
			}

			// Webhooks
			if ( isset( $response_decoded->ipn_track_id ) ) {

				global $wpdb;
				$results = $wpdb->get_results( "SELECT webhook_id FROM {$wpdb->prefix}job_webhooks WHERE webhook_id = '{$response_decoded->ipn_track_id}';" );

				if ( ! $results ) {

					wpj_save_webhook( array(
						'webhook_id'      => ! empty ( $response_decoded->ipn_track_id ) ? $response_decoded->ipn_track_id : '',
						'payment_id'      => ! empty ( $response_decoded->custom ) ? $response_decoded->custom : $_REQUEST['wpj_payment_id'],
						'status'          => $payment_status,
						'type'            => ! empty ( $response_decoded->payment_type ) ? $response_decoded->payment_type : '',
						'description'     => ! empty ( $response_decoded->item_name ) ? $response_decoded->item_name : '',
						'amount'          => $amount,
						'amount_currency' => ! empty ( $response_decoded->mc_currency ) ? $response_decoded->mc_currency : '',
						'fees'            => ! empty ( $response_decoded->mc_fee ) ? $response_decoded->mc_fee : '',
						'fees_currency'   => ! empty ( $response_decoded->mc_currency ) ? $response_decoded->mc_currency : '',
						'create_time'     => strtotime( $date ),
						'response'        => $payment_response,
						'payment_type'    => $payment_type,
						'order_id'        => ! empty ( $response_decoded->oid ) ? $response_decoded->oid : $order_id
					) );

				}

			}

			if ( isset( $_GET['action'] ) && $_GET['action'] == 'cancel' ) {

				$payment = wpj_get_payment( array( 'id' => $_REQUEST['wpj_payment_id'] ) );

				if ( ! $payment || $payment->payment_status != 'completed' ) {

					if ( wpj_get_buyer_by_payment_type( $order_id, $payment_type ) == get_current_user_id() ) {
						$payment_details = __( 'Buyer clicked cancel', 'wpjobster' );
						$this->debug_log( 'cancelled' );
						$this->cancel( $payment_type, $order_id, $payment_details, $payment_response );
					} else {
						wp_redirect( get_bloginfo( 'url' ) ); exit;
					}

				} else {

					$wpjobster_failure_page_id = get_option( "wpjobster_{$this->_unique_id}_failure_page" );
					if ( $wpjobster_failure_page_id != '' && $wpjobster_failure_page_id != '0' ) {
						wp_redirect( get_permalink( $wpjobster_failure_page_id ) );
					} else {
						wp_redirect( get_bloginfo( 'url' ) . '/?jb_action=chat_box&oid=' . $order_id );
					}

				}

			} elseif ( isset( $_POST['txn_id'] ) && isset( $_POST['payment_status'] ) && isset( $_POST['custom'] ) ) {

				// job purchase, featured job, subscription lifetime, topup, custom extra, tips
				$payment        = wpj_get_payment( array( 'id' => $_POST['custom'] ) );
				$order_id       = $payment->payment_type_id;
				$payment_type   = $payment->payment_type;

				$payment_status = $_POST['payment_status'];
				$transaction_id = $_POST['txn_id'];
				$txn_type       = $_POST['txn_type'];

				// only consider requests from PayPal
				if ( $this->p->validate_ipn() ) {
					if ( $this->validate_transaction( $payment ) ) {

						if ( strtolower( $payment_status ) == 'completed' ) {
							$payment_details = sprintf( __( 'PayPal Transaction ID: %s', 'wpjobster' ), $transaction_id );

							$this->debug_log( 'success' );
							$this->success( $payment_type, $order_id, $payment_details, $payment_response );

						} elseif ( strtolower( $payment_status ) == 'pending' ) {
							if ( isset( $_POST['pending_reason'] ) ) {
								$payment_details = sprintf( __( 'Payment not cleared yet, may need manual action through PayPal. Pending reason: %s', 'wpjobster' ), $_POST['pending_reason'] );
							} else {
								$payment_details = sprintf( __( 'Unknown pending reason. PayPal Transaction ID: %s', 'wpjobster' ), $transaction_id );
							}

							$this->debug_log( 'processing' );
							$this->other( $payment_type, $order_id, $payment_details, $payment_response, 'processing' );

						} else {
							$payment_details = sprintf( __( 'Unrecognized payment status. PayPal Transaction ID: %s', 'wpjobster' ), $transaction_id );

							$this->debug_log( 'failed | ' . $payment_status );
							$this->failed( $payment_type, $order_id, $payment_details, $payment_response );
						}

					} else {
						$payment_details = sprintf( __( 'Payment failed. Recipient, currency or amount check failed. PayPal Transaction ID: %s', 'wpjobster' ), $transaction_id );
						$this->failed( $payment_type, $order_id, $payment_details, $payment_response );
					}
				}

			} elseif ( isset( $_POST['txn_type'] ) && isset( $_POST['subscr_id'] ) && isset( $_POST['custom'] ) ) {

				// subscription recurring
				$payment        = wpj_get_payment( array( 'id' => $_POST['custom'] ) );
				$order_id       = $payment->payment_type_id;
				$payment_type   = $payment->payment_type;

				$payment_status = isset( $_POST['payment_status'] ) ? $_POST['payment_status'] : 'pending';
				$transaction_id = $_POST['subscr_id'];
				$txn_type       = $_POST['txn_type'];

				// only consider requests from PayPal
				if ( $this->p->validate_ipn() ) {
					if ( $this->is_subscription_payment( $payment_type, $_REQUEST['sub_type'] ) == 'recurring' ) {
						if ( $txn_type == 'subscr_signup' ) {

							// create - this doesn't charge money
							// transaction id needed for further processing
							$payment_details = $transaction_id;

							$this->debug_log( 'new subscription success' );
							do_action( "wpjobster_new_" . $payment_type . "_payment_success", $order_id, $this->_unique_id, $payment_details, $payment_response );

						} elseif ( $txn_type == 'subscr_cancel' || $txn_type == 'subscr_failed' ) {

							// failed
							$payment_details = $transaction_id; // transaction id needed for further processing

							$this->debug_log( 'new subscription cancelled' );
							$this->failed( $payment_type, $order_id, $payment_details, $payment_response );

						} elseif ( $txn_type == 'subscr_payment' ) {

							// pay - this charges money for the already created subscription
							if ( $this->validate_transaction( $payment ) ) {

								// transaction id needed for further processing
								$payment_details = $transaction_id;

								$this->debug_log( 'subscription success' );
								do_action( "wpjobster_" . $payment_type . "_payment_success", $order_id, $this->_unique_id, $payment_details, $payment_response );

							} else {
								$payment_details = sprintf( __( 'Payment failed. Recipient, currency or amount check failed. PayPal Transaction ID: %s', 'wpjobster' ), $transaction_id );
								$this->failed( $payment_type, $order_id, $payment_details, $payment_response );
							}

						} else {

							// processing
							$payment_details = "Your payment is under process and transaction id is " . $transaction_id ." and payment_status is $payment_status ";

							$this->debug_log( 'subscription processing' );
							$this->other( $payment_type, $order_id, $payment_details, $payment_response, 'processing' );
						}
					}
				}

			}

			$this->debug_log( "IPN End \n" );
		}

		public function validate_transaction( $payment ) {

			$this->debug_log( 'validating' );

			$final_amount   = $_POST['mc_gross'];
			$currency_code  = $_POST['mc_currency'];

			$business_email = isset( $_POST['business'] ) && is_email( $_POST['business'] ) ? trim( $_POST['business'] ) : trim( $_POST['receiver_email'] );

			// verify payment recipient
			if ( strcasecmp( $business_email, trim( get_option( 'wpjobster_paypal_email' ) ) ) != 0 ) {
				$this->debug_log( 'email error | ' . $business_email . ' | ' . get_option( 'wpjobster_paypal_email' ) );
				return false;
			}

			// verify payment currency
			if ( strtoupper( $currency_code ) != strtoupper( $payment->final_amount_currency ) ) {
				$this->debug_log( 'currency error | ' . $currency_code . ' | ' . $payment->final_amount_currency );
				return false;
			}

			// verify payment amount
			if ( number_format( (float) $final_amount, 2 ) < number_format( (float) $payment->final_amount_exchanged, 2 ) ) {
				$this->debug_log( 'amount error | ' . $final_amount . ' | ' . $payment->final_amount_exchanged );
				return false;
			}

			$this->debug_log( 'validated!' );

			return true;
		}

		public function success( $payment_type, $order_id, $payment_details, $payment_response ) {
			if ( $payment_type == 'subscription' && ( isset( $_GET['sub_type'] ) && $_GET['sub_type'] == 'lifetime' ) ) {
				// this is one time payment, even if it is for subscription
				do_action( "wpjobster_new_" . $payment_type . "_payment_success", $order_id, $this->_unique_id, $payment_details, $payment_response );
			}
			do_action( "wpjobster_" . $payment_type . "_payment_success", $order_id, $this->_unique_id, $payment_details, $payment_response );
		}

		public function cancel( $payment_type, $order_id, $payment_details, $payment_response ) {
			do_action( "wpjobster_" . $payment_type . "_payment_failed", $order_id, $this->_unique_id, $payment_details, $payment_response );
		}

		public function failed( $payment_type, $order_id, $payment_details, $payment_response ) {
			do_action( "wpjobster_" . $payment_type . "_payment_failed", $order_id, $this->_unique_id, $payment_details, $payment_response );
		}

		public function other( $payment_type, $order_id, $payment_details, $payment_response, $payment_status = 'processing' ) {
			do_action( "wpjobster_" . $payment_type . "_payment_other", $order_id, $this->_unique_id, $payment_details, $payment_response, $payment_status );
		}

		public function debug_log( $text ) {
			if ( ! $this->enable_log ) return;

			if ( isset( $_POST['custom'] ) ) { $text = $_POST['custom'] . ' | ' . $text; }

			$fp = fopen( '.wpj_paypal.log', 'a' );
			fwrite( $fp, $text . "\n" );
			fclose( $fp );
		}

		public function is_subscription_payment( $payment_type, $sub_type ) {
			if ( $payment_type == 'subscription' && $sub_type == 'lifetime' ) {
				return 'lifetime';
			} elseif ( $payment_type == 'subscription' && $sub_type != 'lifetime' ) {
				return 'recurring';
			} else {
				return false;
			}
		}

		public function change_subscription_status( $subscription_order ) {

			$payment_gateway = $subscription_order->payment_gateway_name;
			$profile_id = $subscription_order->profile_id;
			$action = 'Cancel';

			if ( $payment_gateway == 'paypal' ) {

				$sdb        = get_option( 'wpjobster_paypal_enable_sdbx' );
				$paypal_url = 'https://api-3t.paypal.com/nvp';
				if ( $sdb == "yes" ) $paypal_url = 'https://api-3t.sandbox.paypal.com/nvp';

				$api_request = 'USER=' . urlencode( get_option( 'wpjobster_theme_apiusername' ) )
							.  '&PWD=' . urlencode( get_option( 'wpjobster_theme_apipassword' ) )
							.  '&SIGNATURE=' . urlencode( get_option( 'wpjobster_theme_apisignature' ) )
							.  '&VERSION=76.0'
							.  '&METHOD=ManageRecurringPaymentsProfileStatus'
							.  '&PROFILEID=' . urlencode( $profile_id )
							.  '&ACTION=' . urlencode( $action )
							.  '&NOTE=' . urlencode( 'Profile cancelled at store' );

				$ch = curl_init();
				curl_setopt( $ch, CURLOPT_URL, $paypal_url );
				curl_setopt( $ch, CURLOPT_VERBOSE, 1 );

				curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
				curl_setopt( $ch, CURLOPT_POST, 1 );

				// Set the API parameters for this transaction
				curl_setopt( $ch, CURLOPT_POSTFIELDS, $api_request );

				// Request response from PayPal
				$response = curl_exec( $ch );

				// If no response was received from PayPal there is no point parsing the response
				if ( ! $response )
					die( 'Calling PayPal to change_subscription_status failed: ' . curl_error( $ch ) . '(' . curl_errno( $ch ) . ')' );

				curl_close( $ch );

				parse_str( $response, $parsed_response );

				return $parsed_response;

			}
		}

	} // END CLASS

	$GLOBALS['WPJobster_PayPal_Loader'] = WPJobster_PayPal_Loader::get_instance();

} // END IF CLASS EXIST
