<?php /*** FRONT FUNCTIONS - CHATBOX ***/

/* Change seller_confirmation value before insert the order to database */
add_filter( 'wpj_seller_confirmation_value_filter', 'wpj_sor_change_seller_confirmation_value' );
function wpj_sor_change_seller_confirmation_value( $value ) {
	if ( get_option( 'wpjobster_seller_order_rejection_enable' ) == 'yes' ) {
		return 0;
	}

	return $value;
}

/* Change 'waiting for seller to deliver' message */
add_filter( 'wpj_seller_deliver_msg_filter', 'wpj_sor_buyer_waiting_message', 10, 2 );
function wpj_sor_buyer_waiting_message( $message, $oid ) {

	if ( get_option( 'wpjobster_seller_order_rejection_enable' ) == 'yes' ) {

		if ( wpj_sor_get_order_status( $oid ) == '0' ) {

			$message = __( 'This order is pending until seller confirms it. Seller is given up to 24h to confirm and accept this order, otherwise the order will be automatically cancelled by the system, and you will be refunded.', 'wpjobster' );

		} elseif ( wpj_sor_get_order_status( $oid ) == '1' ) {

			$message = __( 'Order has been confirmed by the seller, and delivery timer has been activated.', 'wpjobster' );

		} else {

			$message = __( 'Order has been rejected by the seller and/or the seller did not confirm the order in the designated 24 hours window. This order has been cancelled, and the buyer has been refunded.', 'wpjobster' );

		}

	}

	return $message;
}

/* Show info text for seller */
add_action( 'wpj_before_mark_delivered_button', 'wpj_sor_seller_waiting_message', 10, 1 );
function wpj_sor_seller_waiting_message( $oid ) {
	if ( get_option( 'wpjobster_seller_order_rejection_enable' ) == 'yes' ) { ?>

		<!-- Show info message -->
		<div>
			<span class="ui huge disabled uppercase button waiting-seller-deliver seller-page">

				<?php if ( wpj_sor_get_order_status( $oid ) == '0' ) {

					$message = __( 'You have up to 24h to confirm and accept this order, otherwise the order will be automatically cancelled by the system, buyer will be refunded, and you will receive a negative feedback (incomplete order).', 'wpjobster' );

				} elseif ( wpj_sor_get_order_status( $oid ) == '1' ) {

					$message = __( 'Order has been confirmed by the seller, and delivery timer has been activated.', 'wpjobster' );

				} else {

					add_filter( 'wpj_mark_delivered_btn_filter', '__return_false' );

					$message = __( 'Order has been rejected by the seller and/or the seller did not confirm the order in the designated 24 hours window. This order has been cancelled, and the buyer has been refunded.', 'wpjobster' );

				}

				echo $message; ?>

			</span>
		</div>

		<?php if ( wpj_sor_get_order_status( $oid ) == '0' ) { ?>

			<!-- Hide mark as delivered button -->
			<?php add_filter( 'wpj_mark_delivered_btn_filter', '__return_false' ); ?>

			<!-- Show seller buttons -->
			<div class="cf pr">
				<a class="ui huge positive uppercase button accept_order submit-button" onclick="clickAndDisable( this );"><?php _e( 'Accept', 'wpjobster' ); ?></a> &nbsp;
				<a class="ui huge negative uppercase button deny_order submit-button" onclick="clickAndDisable( this );"><?php _e( 'Deny','wpjobster' ); ?></a>
			</div>

		<?php }

	}

}

/* Stop autodelivered for order */
add_filter( 'wpj_allow_order_auto_delivered_filter', 'wpj_sor_stop_autodelivered_for_order' );
function wpj_sor_stop_autodelivered_for_order() {
	if ( get_option( 'wpjobster_seller_order_rejection_enable' ) == 'yes' ) {
		return false;
	}

	return true;
}

/* Hide timer */
add_filter( 'wpj_show_order_timer_filter', 'wpj_sor_hide_timer_for_pending_confirmation_order', 10, 2 );
function wpj_sor_hide_timer_for_pending_confirmation_order( $received_value, $row ) {
	if ( get_option( 'wpjobster_seller_order_rejection_enable' ) == 'yes' && $row->seller_confirmation == '0' ) {
		return false;
	}

	return true;
}
