<?php

/**
 * Our abstract class for zM Ajax Login.
 *
 * This class is designed to reduce and factor out the shared details between our classes.
 * Thus allowing us to focus on as few concepts at a time.
 */
abstract Class AjaxLogin {

	public $scripts = array();

	/**
	 * WordPress hooks to be ran during init
	 */
	public function __construct(){

		add_action( 'wp_head', array( &$this, 'header' ) );

		add_action( 'wp_ajax_nopriv_validate_email', array( &$this, 'validate_email' ) );
		add_action( 'wp_ajax_validate_email', array( &$this, 'validate_email' ) );

		add_action( 'wp_ajax_nopriv_validate_email_exists', array( &$this, 'validate_email_exists' ) );
		add_action( 'wp_ajax_validate_email_exists', array( &$this, 'validate_email_exists' ) );

		add_action( 'wp_ajax_nopriv_validate_phone_number', array( &$this, 'validate_phone_number' ) );
		add_action( 'wp_ajax_validate_phone_number', array( &$this, 'validate_phone_number' ) );

		add_action( 'wp_ajax_nopriv_validate_user_type', array (&$this, 'validate_user_type') );
		add_action( 'wp_ajax_validate_user_type', array( &$this, 'validate_user_type' ) );

		add_action( 'wp_ajax_nopriv_validate_phone_exists', array( &$this, 'validate_phone_exists' ) );
		add_action( 'wp_ajax_validate_phone_exists', array( &$this, 'validate_phone_exists' ) );

		add_action( 'wp_ajax_nopriv_validate_user_agree_tos_privacy', array( &$this, 'validate_user_agree_tos_privacy' ) );
		add_action( 'wp_ajax_validate_user_agree_tos_privacy', array( &$this, 'validate_user_agree_tos_privacy' ) );

		add_action( 'wp_ajax_nopriv_validate_reCaptcha', array( &$this, 'validate_reCaptcha' ) );
		add_action( 'wp_ajax_validate_reCaptcha', array( &$this, 'validate_reCaptcha' ) );

		add_action( 'wp_ajax_nopriv_validate_username', array( &$this, 'validate_username' ) );
		add_action( 'wp_ajax_validate_username', array( &$this, 'validate_username' ) );

		add_action( 'wp_ajax_nopriv_load_template', array( &$this, 'load_template' ) );
		add_action( 'wp_ajax_load_template', array( &$this, 'load_template' ) );
	}


	/**
	 * Any additional code to be ran during wp_head
	 *
	 * Prints the ajaxurl in the html header.
	 * Prints the meta tags template.
	 */
	public function header(){
		load_template( plugin_dir_path( dirname( __FILE__ ) ) . "views/meta-tags.php" );
	}


	/**
	 * Build the settings array
	 *
	 * @todo use add_settings_field()
	 */
	public function get_settings(){
		$settings['advanced_usage'] = array(
				array(
					'key' => 'ajax_login_register_advanced_usage_login',
					'label' => __('Login Handle','wpjobster'),
					'type' => 'text',
					'description' => sprintf('%s <code>%s</code>', __('Type the class name or ID of the element you want to launch the dialog box when clicked, example','wpjobster'), '.login-link')
					),
				array(
					'key' => 'ajax_login_register_advanced_usage_register',
					'label' => __('Register Handle','wpjobster'),
					'type' => 'text',
					'description' => sprintf('%s <code>%s</code>',__('Type the class name or ID of the element you want to launch the dialog box when clicked, example','wpjobster'), '.register-link')
					),
				array(
					'key' => 'ajax_login_register_advanced_usage_forgot',
					'label' => __('Forgot Handle','wpjobster'),
					'type' => 'text',
					'description' => sprintf('%s <code>%s</code>',__('Type the class name or ID of the element you want to launch the dialog box when clicked, example','wpjobster'), '.forgot-password-handle')
					),
				array(
					'key' => 'ajax_login_register_additional_styling',
					'label' => __('Additional Styling','wpjobster'),
					'type' => 'textarea',
					'description' => __('Type your custom CSS styles that are applied to the dialog boxes.','wpjobster')
					),
				array(
					'key' => 'ajax_login_register_redirect',
					'label' => __('Redirect After Login URL','wpjobster'),
					'type' => 'text',
					'description' => sprintf( '%s <code>%s</code>', __('Enter the URL or slug you want users redirected to after login, example: ','wpjobster'), 'http://example.com/, /dashboard/, /wp-admin/' )
					),
				array(
					'key' => 'ajax_login_register_default_style',
					'label' => __('Form Layout','wpjobster'),
					'type' => 'text',
					'description' => ''
					)
				);

		$settings['general'] = array(
				array(
					'key' => 'ajax_login_register_keep_me_logged_in',
					'label' => __('Disable "keep me logged in"', 'wpjobster'),
					'description' => __('Use this option to disable the check box shown to keep users logged in.','wpjobster')
				),
				array(
					'key' => 'ajax_login_register_phone_number',
					'label' => __('Enable Phone Number','wpjobster'),
					'description' => __('Display the Phone Number input on the register form.','wpjobster')
				)
			);

		return $settings;
	}


	/**
	 * Generates the needed markup for a given form field.
	 *
	 * @param $type string text, textarea
	 * @param $key string used for the form field "name" and "id"
	 * @param $extras array containing the following keys: 'class','attributes'
	 * @todo use add_settings_field()
	 */
	public function build_input( $type=null, $key=null, $extras=null ){

		switch( $type ){
			case 'textarea':
				$field = '<textarea name="' . $key . '" id="' . $key . '" rows="10" cols="80" class="code">' . wp_kses( get_option( $key ),'' ) . '</textarea>';
				break;

			case 'text':
				$field = '<input type="text" name="' . $key . '" id="' . $key . '" class="regular-text" value="' . esc_attr( get_option( $key ) ) . '" />';
				break;

			case 'select':
				$field = 'select here';
				break;
		}
		return $field;
	}


	/**
	 * Check if an email is "valid" using PHPs filter_var & WordPress
	 * email_exists();
	 *
	 * @param $email (string) Emailt to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_email( $email=null, $is_ajax=true ) {

		$email = is_null( $email ) ? $email : $_POST['email'];

		if ( ! filter_var( $email, FILTER_VALIDATE_EMAIL ) ) {
			$msg = $this->status('email_invalid');
		} else if ( email_exists( $email ) ){
			$msg = $this->status('email_in_use');
		} else {
			$msg = $this->status('email_valid');
		}

		if ( $is_ajax ){
			print json_encode( $msg );
			die();
		} else {
			return $msg;
		}
	}


	/**
	 * Check if an email is "valid" using PHPs filter_var & WordPress
	 * email_exists();
	 *
	 * @param $email (string) Emailt to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_email_exists( $email=null, $is_ajax=true ) {

		$email = is_null( $email ) ? $email : $_POST['email'];

		if ( ! filter_var( $email, FILTER_VALIDATE_EMAIL ) ) {
			$msg = $this->status('email_invalid');
		} else if ( ! email_exists( $email ) ){
			$msg = $this->status('email_not_in_use');
		} else {
			$msg = $this->status('email_valid');
		}

		if ( $is_ajax ){
			print json_encode( $msg );
			die();
		} else {
			return $msg;
		}
	}

		/**
	 * Check if a phone is "not blank" using PHPs filter_var & WordPress
	 *
	 * @param $phone (string) Phone to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_phone_number( $phone=null, $is_ajax=true ) {
		if ( get_option('wpjobster_enable_phone_number') == 'yes' ) {
			if( get_option('wpjobster_phone_number_mandatory') == 'yes' ) {
				if ( $_POST['cell_number'] == '' ) {
					$msg = $this->status('phone_empty');
				} else {
					$msg = $this->status('phone_valid');
				}
			} else {
				$msg = $this->status('phone_valid');
			}
		} else {
			$msg = $this->status('phone_valid');
		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}

	/**
	 * Check if a user type is "not blank" using PHPs filter_var & WordPress
	 *
	 * @param $user_type (string) User Type to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_user_type( $user_type=null, $is_ajax=true ) {

		$wpj_as_display_on_register = get_option( 'wpj_as_display_on_register' );
		$wpj_as_default_user_type   = get_option( 'wpj_as_default_user_type' );
		$wpj_as_user_type_mandatory = get_option( 'wpj_as_user_type_mandatory' );

		if ( is_plugin_active( 'wpjobster-account-segregation/wpjobster-account-segregation.php' ) ) {
			if ( $wpj_as_display_on_register == "yes" && $wpj_as_default_user_type == '' && $wpj_as_user_type_mandatory == "yes" ) {
				if ( empty( $_POST['wpjobster_user_type'] ) ) {
					$msg = $this->status( 'user_type_empty' );
				} else {
					$msg = $this->status( 'user_type_not_empty' );
				}
			} else {
				$msg = $this->status( 'user_type_not_empty' );
			}
		} else {
			$msg = $this->status( 'user_type_not_empty' );
		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}

	/**
	 * Check if a phone is "valid" using PHPs filter_var & WordPress
	 *
	 * @param $phone (string) Phone to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_phone_exists( $phone=null, $is_ajax=true ) {

		$post_phone = ( isset( $_POST['cell_number'] ) ? $_POST['cell_number'] : '' );
		$phone = $phone ? $phone : $post_phone;

		if ( $phone ) {
			if (strpos($phone, '+') === false) {
				$phone = "+".trim($phone);
			}else{
				$phone = trim($phone);
			}
		}

		if ( get_option('wpjobster_enable_phone_number') == 'yes' && $phone ) {
			global $wpdb;

			$user_meta_table = defined( 'CUSTOM_USER_META_TABLE' ) ? CUSTOM_USER_META_TABLE : $wpdb->prefix . 'usermeta';

			$sql = "SELECT * FROM {$user_meta_table} WHERE meta_key = 'cell_number' AND meta_value = '{$phone}'";
			$results = $wpdb->get_results( $sql );
			if ( $results ) {
				$msg = $this->status('phone_exists');
			}else{
				$msg = $this->status('phone_valid');
			}
		} else {
			$msg = $this->status('phone_valid');
		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}

	/**
	 * Check if a user agreed to Terms of Service and Privacy Policy if needed
	 *
	 * @param $agreed (string) User Type to be validated
	 * @param $is_ajax (bool)
	 * @todo check ajax refer
	 */
	public function validate_user_agree_tos_privacy( $agreed=null, $is_ajax=true ) {
		if ( get_option( 'wpjobster_register_tos_and_privacy' ) == 'checkbox'
			&& ! isset( $_POST['wpj_agree_tos_privacy'] ) ) {
			$msg = $this->status( 'tos_not_agreed' );
		} else {
			$msg = $this->status( 'tos_agreed' );
		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}

	public function validate_reCaptcha( $captcha=null, $is_ajax=true ) {
		$post_g_captcha = ( isset( $_POST['g-recaptcha-response'] ) ? $_POST['g-recaptcha-response'] : '' );
		$g_captcha = $captcha ? $captcha : $post_g_captcha;

		$parameters = array(
			'secret'   => get_option( 'wpjobster_recaptcha_api_secret' ),
			'response' => $g_captcha
		);
		$url = 'https://www.google.com/recaptcha/api/siteverify?' . http_build_query($parameters);

		$response = wpj_recaptcha_open_url( $url );
		$json_response = json_decode( $response, true );

		if ( $json_response['success'] == false ) {
			$msg = $this->status('captcha_invalid');
		} else {
			$msg = $this->status('captcha_valid');
		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}

	public function validate_2fa( $two_fa = null, $is_ajax = true ) {
		$two_fa_code = ( isset( $_POST['2fa_code'] ) ? $_POST['2fa_code'] : '' );
		$two_fa      = $two_fa ? $two_fa : $two_fa_code;

		include_once get_template_directory() . '/vendor/google-authenticator/FixedBitNotation.php';
		include_once get_template_directory() . '/vendor/google-authenticator/GoogleAuthenticatorInterface.php';
		include_once get_template_directory() . '/vendor/google-authenticator/GoogleAuthenticator.php';
		include_once get_template_directory() . '/vendor/google-authenticator/GoogleQrUrl.php';
		include_once get_template_directory() . '/vendor/google-authenticator/RuntimeException.php';

		$g = new \Sonata\GoogleAuthenticator\GoogleAuthenticator();

		$secret = isset( $_COOKIE['wpj_2fa_code'] ) ? $_COOKIE['wpj_2fa_code'] : '';

		if ( $g->checkCode( $secret, $two_fa ) ) {
			$msg = $this->status( '2fa_valid' );

		} else {
			$msg = $this->status( '2fa_invalid' );

		}

		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}


	/**
	 * Process request to pass variables into WordPress' validate_username();
	 *
	 * @uses validate_username()
	 * @param $username (string)
	 * @param $is_ajax (bool) Process as an AJAX request or not.
	 */
	public function validate_username( $username=null, $is_ajax=true ) {

		$username = empty( $_POST['login'] ) ? esc_attr( $username ) : $_POST['login'];

		if ( validate_username( $username ) ) {
			$user_id = username_exists( $username );
			if ( $user_id ){
				$msg = $this->status('username_exists');
			} else {
				$msg = $this->status('valid_username');
			}
		} else {
			$msg = $this->status('invalid_username');
		}



		if ( $is_ajax ){
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}


	/**
	 * Load the login form via an AJAX request.
	 *
	 * @package AJAX
	 */
	public function load_template(){
		check_ajax_referer( $_POST['referer'], 'security', false );
		load_template( plugin_dir_path( dirname( __FILE__ ) ) . "views/" . $_POST['template'] . '.php' );
		die();
	}


	/**
	 * Validation status responses
	 */
	static function status( $key=null, $value=null ){

		$status = array(
			'valid_username' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'username_exists' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Username already exists', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'invalid_username' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Invalid username', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'unknown_username' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Unknown username. Check again or try your email address.', 'wpjobster' )  : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'phone_empty' => array(
				'description' => __('Please enter phone number', 'wpjobster'),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'phone_exists' => array(
				'description' => __('Phone number already exists', 'wpjobster'),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'phone_valid' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'user_type_empty' => array(
				'description' => __('Please select user type', 'wpjobster'),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'tos_not_agreed' => array(
				'description' => __('Terms of Service and Privacy Policy agreement is required', 'wpjobster'),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'tos_agreed' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'user_type_not_empty' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'captcha_invalid' => array(
				'description' => __('Please verify the captcha!', 'wpjobster'),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'captcha_valid' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'2fa_invalid' => array(
				'description' => __( 'The 2fa verification code is invalid!!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'2fa_valid' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'incorrect_password' => array(
				'description' => __( 'Wrong Password', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'passwords_do_not_match' => array(
				'description' => __('Passwords do not match.','wpjobster'),
				'cssClass' =>'error-container',
				'code' => 'error'
			),
			'email_valid' => array(
				'description' => null,
				'cssClass' => 'noon',
				'code' => 'success'
			),
			'email_invalid' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Invalid Email', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'unknown_email' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Unknown email address. Check again or try your username.', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'email_in_use' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Email already in use', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'email_not_in_use' => array(
				'description' => get_option( 'wpjobster_enable_login_hints' ) != 'no' ? __( 'Email not in use', 'wpjobster' ) : __( 'The login data entered is incorrect!', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			),
			'success_login' => array(
				'description' => __( 'Success! One moment while we log you in...', 'wpjobster' ),
				'cssClass' => 'success-container',
				'code' => 'success_login'
			),
			'success_registration' => array(
				'description' => __( 'Success! One moment while we log you in...', 'wpjobster' ),
				'cssClass' => 'noon',
				'code' => 'success_registration'
			),
			'success_reset' => array(
				'description' => __( 'Success! Please check your email for more instructions...', 'wpjobster' ),
				'cssClass' => 'success-container',
				'code' => 'success_reset'
			),
			'something_wrong' => array(
				'description' => __( 'Something went wrong... Please try again.', 'wpjobster' ),
				'cssClass' => 'error-container',
				'code' => 'error'
			)
		);

		$status = apply_filters( 'ajax_login_register_status_codes', $status );

		if ( empty( $value ) ){
			return $status[ $key ];
		} else {
			return $status[ $key ][ $value ];
		}
	}
}
