<?php

/**
 * This is file is responsible for custom logic needed by all templates. NO
 * admin code should be placed in this file.
 */
Class ajax_login_register_Forgot Extends AjaxLogin {

	/**
	 * Run the following methods when this class is loaded
	 */
	public function __construct(){
		add_action( 'init', array( &$this, 'init' ) );
		add_action( 'wp_footer', array( &$this, 'footer' ) );
		parent::__construct();
	}


	/**
	 * During WordPress' init load various methods.
	 */
	public function init(){
		add_action( 'wp_ajax_nopriv_forgot_submit', array( &$this,'forgot_submit' ) );
		add_action( 'wp_ajax_forgot_submit', array( &$this,'forgot_submit' ) );

		add_shortcode( 'ajax_forgot', array( &$this, 'forgot_shortcode' ) );
	}


	/**
	 * Any additional code to be ran during wp_footer
	 *
	 * If the user is not logged in we display the hidden jQuery UI dialog containers
	 */
	public function footer(){
		load_template( plugin_dir_path( dirname( __FILE__ ) ) . 'views/forgot-dialog.php' );
	}


	/**
	 * Registers a new user, checks if the user email or name is
	 * already in use.
	 *
	 * @uses check_ajax_referer() http://codex.wordpress.org/Function_Reference/check_ajax_referer
	 * @uses get_user_by_email() http://codex.wordpress.org/Function_Reference/get_user_by_email
	 * @uses get_user_by() http://codex.wordpress.org/Function_Reference/get_user_by
	 * @uses wp_create_user() http://codex.wordpress.org/Function_Reference/wp_create_user
	 *
	 * @param $login
	 * @param $password
	 * @param $email
	 * @param $is_ajax
	 */
	public function forgot_submit( $email=null, $is_ajax=true ) {

		if ( $is_ajax ) check_ajax_referer('forgot_submit','security');

		$user = array(

			'email'    => empty( $_POST['email'] ) ? $email : sanitize_text_field( $_POST['email'] )
		);

		$valid['email'] = $this->validate_email( $user['email'], false );
		$user_id = null;
		$user_exists = false;

		if ( email_exists( $user['email'] ) ) {
			global $wpdb;

			$user_exists = true;
			$user = get_user_by( 'email', $user['email'] );

			$user_login = $user->user_login;
			$user_email = $user->user_email;


			/*
			 * Generating Random password using wordpress readymade function
			 */
			$key = get_password_reset_key($user);

			$password_reset_link = apply_filters( 'wpj_reset_password_link_filter', wp_login_url() . "?action=rp&key={$key}&login=" . rawurlencode( $user->user_login ), $key, $user->user_login );

			$msg = $this->status('success_reset'); // success

			$uz_email_user_forgot_password_enable = get_option("uz_email_user_forgot_password_enable");
			if( $uz_email_user_forgot_password_enable == 'no' ) {
				//create email message
				$message = __('Someone has requested a password reset for the following account:', 'wpjobster') . "\r\n\r\n";
				$message .= sprintf(__('Site Name: %s', 'wpjobster'), get_bloginfo( 'name' )) . "\r\n\r\n";
				$message .= sprintf(__('Username: %s', 'wpjobster'), $user_login) . "\r\n\r\n";
				$message .= __('If this was a mistake, just ignore this email and nothing will happen.', 'wpjobster') . "\r\n\r\n";
				$message .= __('To reset your password, visit the following address:', 'wpjobster') . "\r\n\r\n";
				$message .= get_option('siteurl') . "/wp-login.php?action=rp&key={$key}&login=" . rawurlencode($user_login) . "\r\n";
				//send email meassage
				if (FALSE == wp_mail($user_email, sprintf(__('[%s] Password Reset', 'wpjobster'), get_option('blogname')), $message)) {

				}
			} else {
				wpj_notify_user_translated( 'user_forgot_password', $user->ID, array( '##password_reset_link##' => $password_reset_link, '##receiver_email##' => $user_email ), '', 'email' );
			}

			$uz_sms_user_forgot_password_enable = get_option("uz_sms_user_forgot_password_enable");
			if ( $uz_sms_user_forgot_password_enable == 'yes' ) {
				wpj_notify_user_translated( 'user_forgot_password', $user->ID, array( '##password_reset_link##' => $password_reset_link, '##receiver_email##' => $user_email ), '', 'sms' );
			}


		} else {
			$msg = $this->status('email_not_in_use');
		}

		if ( $is_ajax ) {
			wp_send_json( $msg );
		} else {
			return $msg;
		}
	}


	/**
	 * Load the login shortcode
	 */
	public function forgot_shortcode(){
		ob_start();
		load_template( plugin_dir_path( dirname( __FILE__ ) ) . 'views/forgot-form.php' );
		return ob_get_clean();
	}

}
new ajax_login_register_Forgot;
