//----------------------------------------
// Initialize calendar fields
//----------------------------------------
( function ( $ ) {
	$.fn.wpjcalendar = function( page, date_type, time_format ) {
		var today = new Date();

		if ( ! date_type ) { date_type = 'date'; }
		if ( ! time_format ) { time_format = 'false'; }

		var inp_val_ts    = $( this ).find( "input" ).val();
		var inp_val_ts_js = inp_val_ts * 1000;

		var new_date = getSafeDateFormat( inp_val_ts_js, date_type );
		if ( inp_val_ts ) {
			$( this ).find( "input" ).val( new_date );
		}

		var inp_name = $( this ).find( "input" ).attr( 'name' );
		$( this ).find( "input" ).attr( 'name', inp_name + '-old' );

		var new_input = $( '<input type="hidden" name="' + inp_name + '" value="' + inp_val_ts + '" />' );
		new_input.insertAfter( $( this ) );

		var min_date = page == 'vacation' ? new Date( today.getFullYear(), today.getMonth(), today.getDate() ) : null;

		$( this ).calendar({
			type           : date_type,
			ampm           : time_format == 'true' ? true : false,
			firstDayOfWeek : parseInt( wpj_vars.starting_day ),
			minDate        : min_date,
			popupOptions   : {
				position   : 'top left',
				lastResort : 'bottom left'
			},
			text           : {
				days       : [
					wpj_vars.days.sun,
					wpj_vars.days.mon,
					wpj_vars.days.tue,
					wpj_vars.days.wed,
					wpj_vars.days.thu,
					wpj_vars.days.fri,
					wpj_vars.days.sat
				],
				months     : [
					wpj_vars.months.jan,
					wpj_vars.months.feb,
					wpj_vars.months.mar,
					wpj_vars.months.apr,
					wpj_vars.months.may,
					wpj_vars.months.jun,
					wpj_vars.months.jul,
					wpj_vars.months.aug,
					wpj_vars.months.sep,
					wpj_vars.months.oct,
					wpj_vars.months.nov,
					wpj_vars.months.dec
				],
				monthsShort: [
					wpj_vars.monthsShort.jan,
					wpj_vars.monthsShort.feb,
					wpj_vars.monthsShort.mar,
					wpj_vars.monthsShort.apr,
					wpj_vars.monthsShort.may,
					wpj_vars.monthsShort.jun,
					wpj_vars.monthsShort.jul,
					wpj_vars.monthsShort.aug,
					wpj_vars.monthsShort.sep,
					wpj_vars.monthsShort.oct,
					wpj_vars.monthsShort.nov,
					wpj_vars.monthsShort.dec
				],
				today      : wpj_vars.today,
				now        : wpj_vars.now,
				am         : wpj_vars.am,
				pm         : wpj_vars.pm
			},
			monthFirst: false,
			onChange: function( date, text, mode ) {
				var timestamp = '';

				if ( date ) {
					timestamp = Math.floor( date.getTime() / 1000 );
				}
				$( this ).find( 'input' ).attr( 'data-timestamp', timestamp );

				$( this ).next( 'input[type=hidden]' ).attr( 'data-timestamp', timestamp );
				$( this ).next( 'input[type=hidden]' ).val( timestamp );
			}
		});

		new_input.attr( 'data-timestamp', inp_val_ts );

		if ( inp_val_ts ) {
			new_input.val( inp_val_ts );
		}

		return this;
	}

	$.fn.wpjCalendarInit = function() {
		if ( $( '.js-calendar' ).length ) {
			jQuery( '.js-calendar' ).each( function() {
				var datetype_attr   = $( this ).attr( 'data-datetype' );
				var datepage_attr   = $( this ).attr( 'data-page' );
				var timeformat_attr = $( this ).attr( 'data-timeformat' );

				if ( typeof datetype_attr !== typeof undefined && datetype_attr !== false ) {
					$( this ).wpjcalendar( datepage_attr, datetype_attr, timeformat_attr );
				} else {
					$( this ).wpjcalendar();
				}
			});
		}
	}

	$.fn.wpjCalendarInit();
} ( jQuery ) );

//----------------------------------------
// Initialize tag fields
//----------------------------------------
( function ( $ ) {
	$.fn.wpjTagsInit = function() {
		if ( $( '.js-tags' ).length ) {
			jQuery( '.js-tags' ).each( function() {
				$( this ).tagsInput({
					'defaultText':'',
					'height': 'auto',
					'width' : '100%'
				});
			});
		}
	}

	$.fn.wpjTagsInit();
} ( jQuery ) );

//----------------------------------------
// Initialize location autocomplete fields
//----------------------------------------
( function ( $ ) {
	// Google Places API
	$.fn.wpjMapsInit = function() {
		if ( typeof google !== 'undefined' ) {
			if ( jQuery( '.js-location-autocomplete' ).length ) {
				jQuery( '.js-location-autocomplete' ).each( function() {
					var location_input = jQuery( this );
					if ( ! location_input.is( 'input' ) ) {
						location_input = location_input.find( 'input' );
					}

					var maps_return = wpj_vars.locations_types[0] ? wpj_vars.locations_types[0] : '(cities)';

					var options = {
						componentRestrictions: {country: wpj_vars.locations_country},
						types: [maps_return],
						language: [wpj_vars.language_attr]
					}

					if ( wpj_vars.location_fields ) {
						options['fields'] = JSON.parse( wpj_vars.location_fields );
					}

					var autocomplete = new google.maps.places.Autocomplete( location_input[0], options );

					google.maps.event.addListener( autocomplete, 'place_changed', function() {
						var place = autocomplete.getPlace();
						if ( place.geometry ) {
							location_input.next( 'input' ).val( place.geometry.location.lat() );
							location_input.next( 'input' ).next( 'input' ).val( place.geometry.location.lng() );
						}
					});
				});
			}
		}
	}

	// TomTom Search API
	$.fn.wpjTomTomInit = function() {
		if ( jQuery( '.js-location-autocomplete' ).length ) {
			jQuery( '.js-location-autocomplete' ).each( function() {
				var this_ui_input = jQuery( this );
				this_ui_input.search({
					apiSettings: {
						onResponse: function(tomtomResponse) {
							var response = { results: [] };
							// translate TomTom API response to work with search
							$.each(tomtomResponse.results, function(index, item) {
								response.results.push({
									title : item.address.freeformAddress,
									lat   : item.position.lat,
									lng   : item.position.lon
								})
							});
							return response;
						},
						url: 'https://api.tomtom.com/search/2/search/{query}.json?countrySet=' + encodeURI( wpj_vars.locations_country.join() ) + '&key=' + wpj_vars.tomtom_api_key
					},
					fields: {
						results : 'results',
						title   : 'title',
						description: false,
						url     : false
					},
					minCharacters : 2,
					showNoResults: false,
					onSelect: function(result, response) {
						jQuery( this_ui_input.find( 'input' )[1] ).val( result.lat );
						jQuery( this_ui_input.find( 'input' )[2] ).val( result.lng );
					}
				});
			});
		}
	}

	// Init
	if ( wpj_vars.locations_api === '' || wpj_vars.locations_api === 'google'
		&& typeof google !== 'undefined' ) {
		google.maps.event.addDomListener( window, 'load', $.fn.wpjMapsInit );
	} else if ( wpj_vars.locations_api === 'tomtom' ) {
		jQuery( document ).ready( function() { $.fn.wpjTomTomInit(); } );
	}
} ( jQuery ) );

//----------------------------------------
// Initialize reCAPTCHA Responsive
//----------------------------------------
( function ( $ ) {
	$.fn.wpjResizeReCaptcha = function() {
		if ( $( '.g-recaptcha-class' ).length ) {
			var width;
			$( '.g-recaptcha-class' ).each( function() {
				if ( ! width ) {
					width = $( this ).parent().width();
				}
				if ( width ) {
					var scale = width / 302;
					$( this ).css( 'transform', 'scale(' + scale + ')' );
					$( this ).css( '-webkit-transform', 'scale(' + scale + ')' );
					$( this ).css( 'transform-origin', '0 0' );
					$( this ).css( '-webkit-transform-origin', '0 0' );
				}
			});
		}
	}

	$( window ).on( 'load resize', function() {
		$.fn.wpjResizeReCaptcha();
	});
} ( jQuery ) );

//----------------------------------------
// Initialize tooltip fields
//----------------------------------------
( function( $ ) {
	$.fn.wpjTooltip = function() {
		$( this ).each( function() {
			var handler_id     = $( this ).attr( 'data-handler-id' );
			var this_handler   = $( this );
			var other_handlers = $( '.js-tooltip-handler:not([data-handler-id="' + handler_id + '"])' );

			var ui_popup       = $( '[data-tooltip-id="' + handler_id + '"]' );

			if ( ui_popup.text().length > 0 ) {
				this_handler.popup({
					target      : this_handler,
					on          : 'manual',
					popup       : ui_popup,
					position    : "right center",
					lastResort  : "right center",
					transition  : 'fade down',
					distanceAway: 0,
					offset      : 0,
					hoverable   : false, // creates issues
					exclusive   : false, // creates issues
					inline      : true,
					preserve    : true,
				});

				this_handler.hover( function() {
					other_handlers.popup( 'hide' );
					this_handler.popup( 'show' );
				});
			} else {
				this_handler.removeClass( 'js-tooltip-handler' );
				ui_popup.removeClass( 'ui popup' );
				ui_popup.hide();
			}
		});
	}

	$( '.js-tooltip-handler' ).wpjTooltip();
} ( jQuery ) );

//----------------------------------------
// Initialize Semantic UI fields
//----------------------------------------
( function( $ ) {
	$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	$( '.ui.dropdown.full-text-search' ).dropdown( { fullTextSearch: true, message: { noResults: wpj_vars.nothing_found } } );
	$( '.ui.menu .item' ).tab();
	$( '.ui.accordion' ).accordion();
	$( '.ui.checkbox' ).checkbox();
} ( jQuery ) );

jQuery( document ).ready( function( $ ) {

	//----------------------------------------
	// Initialize Semantic UI dropdown upward
	//----------------------------------------
	window.onload = function() {
		$( '.ui.dropdown.upward' ).each( function() {
			$( this ).dropdown({ direction: 'upward', fullTextSearch: true, message: { noResults: wpj_vars.nothing_found } });
		});
	}

	//----------------------------------------
	// Initialize Semantic UI clearable input
	//----------------------------------------
	$( '.ui.input.clearable' ).each( function() {
		var $clearable = $( this );
		$clearable.append( '<i class="icon clear link hidden"></i>' );

		var $input = $clearable.find( 'input' );
		var $icon = $clearable.find( 'i.clear.icon' );

		if ( $input.val() ) {
			$icon.removeClass( 'hidden' );
			$clearable.addClass( 'icon' );
		} else {
			$icon.addClass( 'hidden' );
			$clearable.removeClass( 'icon' );
		}

		$input.on( 'change paste keyup', function() {
			if ( $input.val() ) {
				$icon.removeClass( 'hidden' );
				$clearable.addClass( 'icon' );
			} else {
				$icon.addClass( 'hidden' );
				$clearable.removeClass( 'icon' );
			}
		});

		$icon.click( function( e ) {
			$input.val( '' );
			$icon.addClass( 'hidden' );
			$clearable.removeClass( 'icon' );
			e.stopPropagation();
		});
	});

	//------------------------------------------
	// Initialize Semantic UI clearable dropdown
	//------------------------------------------
	$( '.ui.dropdown.clearable' ).each( function() {
		if ( $( this ).dropdown( 'get value' ) ) {
			$( this ).find( '.dropdown.icon' ).removeClass( 'dropdown' ).addClass( 'x' ).addClass( 'clear-dropdown' );
		} else {
			$( this ).removeClass( 'clear-dropdown' ).removeClass( 'x' ).addClass( 'dropdown' );
		}

		$( this ).on( 'change', function() {
			$( this ).find( '.dropdown.icon' ).removeClass( 'dropdown' ).addClass( 'x' ).addClass( 'clear-dropdown' );
		});

		$( document ).on( 'click', '.clear-dropdown', function() {
			$( this ).parents( '.clearable' ).dropdown( 'clear' );
			$( this ).removeClass( 'clear-dropdown' ).removeClass( 'x' ).addClass( 'dropdown' );
		});
	});
});

//----------------------------------------
// Initialize autohide keyboard iOS
//----------------------------------------
( function( $ ) {
	jQuery( '.autohide-keyboard' ).form({
		on: 'blur',
		keyboardShortcuts: false
	});
} ( jQuery ) );

//----------------------------------------
// Initialize button to dropdown on mobile
//----------------------------------------
( function( $ ) {
	$( ".js-buttons-to-dropdown" ).each( function() {
		var $cnt = $( this );

		var selected_val = false;

		$( "<select />" ).appendTo( $cnt );
		$cnt.find( "a" ).each( function() {
			var $el = $( this );

			if ( $el.hasClass( 'active' ) == true ) {
				selected_val = $el.index();
			}

			$( "<option />", {
				"value": $el.attr( "href" ),
				"text" : $el.text()
			}).appendTo( $cnt.find( "select" ) );
		});

		if ( selected_val ) {
			$cnt.find( "select" ).find( "option" ).eq( selected_val - 1 ).prop( 'selected', true );
		}

		$cnt.find( "select" ).change( function() {
			window.parent.postMessage( {data: {
				isExternal    : false,
				isTargetBlank : false,
				currentUrl    : window.location.href,
				nextUrl       : $( this ).find( "option:selected" ).val()
			}}, "*" );
			window.location = $( this ).find( "option:selected" ).val();
		});

		$cnt.find( "select" ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	});
} ( jQuery ) );

//----------------------------------------
// Initialize tab to dropdown on mobile
//----------------------------------------
( function( $ ) {
	$( ".js-tab-to-dropdown" ).each( function() {
		var $cnt = $( this );

		var selected_val = false;

		$( "<select />" ).appendTo( $cnt );
		$cnt.find( "div.item.force-white-btn" ).each( function() {
			var $el = $( this );

			if ( $el.hasClass( 'active' ) == true ) {
				selected_val = $el.index();
			}

			$( "<option />", {
				"value"   : $el.attr( "data-tab" ),
				"text"    : $el.text(),
			}).appendTo( $cnt.find( "select" ) );
		});

		if ( selected_val ) {
			$cnt.find( "select" ).find( "option" ).eq( selected_val - 1 ).prop( 'selected', true );
		}

		$cnt.find( "select" ).change( function() {
			var active_tab = $( '.item.force-white-btn.active' ).attr( 'data-tab' );
			$( 'div[data-tab="' + active_tab + '"]' ).removeClass( 'active' );
			$( 'div[data-tab="' + $( this ).find( "option:selected" ).val() + '"]' ).addClass( 'active' );
		});

		$cnt.find( "select" ).addClass( 'fluid' );
		$cnt.find( "select" ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
	});
} ( jQuery ) );

//----------------------------------------
// Initialize toggle arrow
//----------------------------------------
( function( $ ) {
	$( ".js-toggle-arrow" ).each( function() {
		var $cnt = $( this );

		// iOS workaround for on click event
		$cnt.css( 'cursor', 'pointer' );

		// Add ui grid on parent element
		$cnt.addClass( 'ui grid js-toggle-wrapper' );

		// Move existing title inside a 'column' div
		$cnt.find( ':header' ).wrap('<div class="fourteen wide column dynamically dynamically-title"></div>');

		// Append a new column for icon
		$cnt.append( '<div class="two wide column dynamically dynamically-icon"><i class="js-toggle-angle-icon toggle-angle-icon toggle-angle-icon-up icon"></i></div>' );

	});

	// Click on arrow
	$( document ).on( 'click', '.js-toggle-arrow', function() {
		if ( $( this ).find( '.dynamically-icon' ).is( ':visible' ) ) {
			var $cnt = $( this ).find( '.js-toggle-angle-icon' );

			if ( $( this ).find( '.js-toggle-angle-icon' ).hasClass( 'toggle-angle-icon-up' ) ) {
				$cnt.removeClass( 'toggle-angle-icon-up' ).addClass( 'toggle-angle-icon-down' );
				$cnt.parents( '.ui.grid.js-toggle-wrapper' ).nextAll().slideUp( "slow" );
			} else {
				$cnt.removeClass( 'toggle-angle-icon-down' ).addClass( 'toggle-angle-icon-up' );
				$cnt.parents( '.ui.grid.js-toggle-wrapper' ).nextAll().slideDown( "slow" );
			}
		}
	});

	// Hide content on ready
	if ( isMobile() ) {
		$( ".js-toggle-arrow" ).each( function() {
			$( this ).trigger( 'click' );
		});
	}
} ( jQuery ) );

//----------------------------------------
// Initialize number format
//----------------------------------------
jQuery( window ).ready( function( $ ) {
	Number.prototype.formatMoney = function( c, d, t ) {
		var n = Math.round( this * 100 ) / 100,
		c = isNaN( c = Math.abs( c ) ) ? 2 : c,
		d = d == undefined ? "." : d,
		t = t == undefined ? "," : t,
		s = n < 0 ? "-" : "",
		i = parseInt( n = Math.abs( +n || 0 ).toFixed( c ) ) + "",
		j = ( j = i.length ) > 3 ? j % 3 : 0;
		return s + ( j ? i.substr( 0, j ) + t : "" ) + i.substr( j ).replace( /(\d{3})(?=\d)/g, "$1" + t ) + ( c ? d + Math.abs( n - i ).toFixed( c ).slice( 2 ) : "" );
	};
});

//----------------------------------------
// Initialize args for wysiwyg textarea
//----------------------------------------
function wpj_js_description_args_allowed( max_chr_description, post_status, rejected_description, pck_index, identifier_id ) {
	if ( ! identifier_id ) { var identifier_id = 'job_description'; }

	var wysihtml5ParserRules = {
		classes: "any",
		classes_blacklist: {
			"Apple-interchange-newline": 1,
			"MsoNormal": 1,
			"MsoPlainText": 1
		},
		tags: {
			strong : { rename_tag: "b" },
			b      : {},
			i      : {},
			em     : { rename_tag: "i" },
			u      : {},
			br     : {},
			p      : {},
			span   : 1,
			div    : 1,
			ul     : {},
			ol     : {},
			li     : {},
			comment: { remove: 1 },
			style  : { remove: 1 },
		}
	};

	if ( typeof pck_index !== 'undefined' && pck_index ) {
		var input_id = 'package_description_' + pck_index;
		var input_id_toolbar = 'package_description_' + pck_index + '_toolbar';
	} else {
		var input_id = identifier_id;
		var input_id_toolbar = identifier_id + '_toolbar';
	}

	if ( jQuery( 'body' ).hasClass( "rtl" ) ) {
		var stylesheets = [wpj_vars.theme_path + '/assets/css/front-rtl/wysiwyg-rtl.css'];
	} else {
		var stylesheets = [wpj_vars.theme_path + '/assets/css/vendor/front/wysiwyg.css'];
	}

	var editor = new wysihtml5.Editor( input_id, {
		toolbar    : input_id_toolbar,
		autoLink   : false,
		parserRules: wysihtml5ParserRules,
		stylesheets: stylesheets
	});

	editor.on( "load", function() {

		if ( typeof pck_index === 'undefined' || ! pck_index  ) {
			var $iframe = jQuery( this.composer.iframe );
			var $body   = jQuery( this.composer.element );
			var $html   = $body.parent();

			$body.css( { 'min-height': '100px', 'overflow': 'hidden', 'height': 'auto' } );
			$html.css( { 'height': 'auto', } );

			jQuery( '<link rel="stylesheet" href="' + wpj_vars.blog_url + '?action=kirki-styles">' ).appendTo( $html.children( 'head' ) );

			var scrollHeightInit = $body[0].scrollHeight;
			var bodyHeightInit   = $body.height();
			var heightInit       = Math.min( scrollHeightInit, bodyHeightInit );
			$iframe.height( heightInit );

			$body.bind( 'keypress keyup keydown paste change focus blur', function( e ) {
				var scrollHeight = $body[0].scrollHeight;
				var bodyHeight   = $body.height();
				var height       = Math.min( scrollHeight, bodyHeight );
				$iframe.height( height );
			});
		}

		add_input_length_listener( editor, jQuery( "#" + input_id ).siblings( ".char-count" ), max_chr_description, "html" );

		jQuery( '#' + identifier_id ).parents( '#job_description_field' ).removeClass( 'error' );
		if ( post_status == 'pending' && typeof rejected_description !== 'undefined' && rejected_description == 1 ) {
			jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).addClass( "visible" );
		}

		if ( jQuery( 'body' ).hasClass( 'wpj-is-ios' ) ) {
			if ( jQuery( '#' + input_id + '_iosblurfix' ).length == 0 ) {
				// create fake input to help with blur
				jQuery( '#' + input_id ).after( '<input id="' + input_id + '_iosblurfix" type="text" disabled="disabled" style="width: 0; height: 0; padding: 1px; border: 0; position: absolute; opacity: 0;">' );
			}

			jQuery( document ).mouseup( function( e ) {
				// if the target of the click isn't the container nor a descendant of the container
				if ( ! jQuery( '#' + input_id ).is( e.target )
					&& jQuery( '#' + input_id ).has( e.target ).length === 0
					&& ( e.target.tagName.toUpperCase() !== 'INPUT' )
					&& ( e.target.tagName.toUpperCase() !== 'TEXTAREA' )
				) {
					jQuery( '#' + input_id + '_iosblurfix' ).removeAttr( "disabled" ).focus().blur().attr( "disabled", "disabled" );
				}
			});
		}
	})
	.on( "focus", function() {
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).addClass( "visible" );
		jQuery( '#' + identifier_id ).parents( ".post-new-job-wrapper-x" ).eq( 0 ).addClass( 'has-focus' );
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( 'iframe' ).addClass( 'focus' );
		jQuery( '#' + identifier_id ).parents( "#job_description_field" ).removeClass( 'error' );
	})
	.on( "blur", function() {
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( '.hidden-tooltip' ).removeClass( "visible" );
		jQuery( '#' + identifier_id ).parents( ".post-new-job-wrapper-x" ).eq( 0 ).removeClass( 'has-focus' );
		jQuery( '#' + identifier_id ).parents( ".input-block" ).eq( 0 ).find( 'iframe' ).removeClass( 'focus' );
	})

	editor.observe( "load", function() {

	});
}

jQuery( document ).ready( function( $ ) {

	//-----------------------------------
	// Initialize modal open
	//-----------------------------------
	$( '.button-modal-open' ).click( function( e ) {
		e.preventDefault();

		var modal_class = $( this ).next( '.ui.modal' ).attr( 'class' );
		if ( modal_class ) {
			var classes = modal_class.split( ' ' );

			var class_list = "";
			for ( var i = 0; i < classes.length; i++ ) {
				if ( classes[i].length > 0 ) {
					class_list += "." + classes[i];
				}
			}

			localStorage.setItem( 'modal_name', class_list );
		} else {
			class_list = localStorage.getItem( 'modal_name' );
		}

		$( class_list )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	//-----------------------------------
	// Initialize form submit
	//-----------------------------------
	$( "[data-submit]" ).click( function() {
		var ob = $( this ).parents( "form" );

		if ( $( this ).data( "submit" ) ) { ob = $( $( this ).data( "submit" ) ); }

		ob.submit();

		return false;
	});

	//-----------------------------------
	// Initialize range slider
	//-----------------------------------
	var slider_default = $( "#slider-range-min" ).data( "value" );

	if ( 'undefined' == typeof slider_default ) slider_default = wpj_vars.max_default_days;

	$( "#slider-range-min" ).slider({
		range: "min",
		value: slider_default,
		min  : 1,
		max  : wpj_vars.max_default_days,
		slide: function( event, ui ) {
			$( "#amount" ).val( ui.value );

			jQuery.ajax({
				type    : 'POST',
				url     : wpj_vars.ajaxurl,
				data    : {
					action : 'day_translation',
					value  : ui.value
				},
				success : function( data ) {
					$( "#amount-label" ).html( data );
				}
			});
		}
	});

	$( "#amount" ).val( $( "#slider-range-min" ).slider( "value" ) );

});

function wpj_audio_js_player_init( id, url, filename ) {
	jQuery( "#jquery_jplayer_" + id ).jPlayer({
		ready: function() {
			jQuery( this ).jPlayer( "setMedia", {
				title:filename,
				mp3: url,
				wav: url
			});
		},
		play: function() { // to avoid multiple jPlayers playing together.
			jQuery( this ).jPlayer( "pauseOthers" );
		},
		swfPath            : "../../js",
		supplied           : "mp3, wav",
		cssSelectorAncestor: "#jp_container_" + id,
		wmode              : "window",
		globalVolume       : true,
		useStateClassSkin  : true,
		autoBlur           : false,
		smoothPlayBar      : true,
		keyEnabled         : true
	});
}

jQuery( document ).ready( function( $ ) {

	// Downlad Attachment With Token
	$( document ).on( 'click', "a[href*='secure_download']", function( e ) {
		var url = ( $( this ).attr( 'href' ) );
		var auth_token = getParameterFromGivenURL( url, 'auth_token' );
		var secure_download = getParameterFromGivenURL( url, 'secure_download' );

		if ( secure_download ) {
			$.ajax({
				type: "POST",
				url: wpj_vars.ajaxurl,
				data: {
					action: 'wpjobster_save_auth_token_transient',
					secure_download: secure_download,
					auth_token: auth_token,
				},
				success: function( msg ) {}
			});
		}
	});

	// International Phone
	var user_country = $( ".cell_number" ).attr( 'data-country' );
	if ( user_country )
		user_country = user_country.toLowerCase();
	else
		user_country = 'us';

	var default_country = $( ".cell_number" ).attr( 'data-default-country' );
	if ( default_country )
		default_country = default_country.toLowerCase();
	else
		default_country = 'us';

	var only_countries = $( ".cell_number" ).attr( 'data-only-countries' );
	if ( only_countries ) {
		only_countries = only_countries.toLowerCase().split(',');
		// prevent undefined errors
		if ( jQuery.inArray( user_country, only_countries ) === -1 ) {
			user_country = '';
		}
		if ( jQuery.inArray( default_country, only_countries ) === -1 ) {
			default_country = '';
		}
	} else {
		only_countries = [];
	}

	$( ".cell_number" ).intlTelInput({
		nationalMode      : false,
		initialCountry    : default_country,
		preferredCountries: [ user_country ],
		onlyCountries     : only_countries
	});

	if ( $( 'body' ).hasClass( "rtl" ) ) {
		$( ".cell_number" ).parent().addClass( "iti-rtl" );
	}

	// Login / Register Fields
	$( "#login form p label" ).contents().filter( function() {
		if ( this.type == 'checkbox' ) {
			$( this ).parent().addClass( 'ui checkbox' );
		}
		return ( this.nodeType === 3 );
	}).wrap( '<span class="box"></span>' );

	$( "#loginform" ).prepend( "<h2 style='text-align:center;'>" + wpj_vars.login + "</h2>" );
	$( "#registerform" ).prepend( "<h2 style='text-align:center;'>" + wpj_vars.register + "</h2>" );
	$( "#registerform" ).addClass('ui form');

	$( "#lostpasswordform" ).prepend( "<h2 style='text-align:center;'>" + wpj_vars.forgot + "</h2>" );
	$( "#resetpassform" ).prepend( "<h2 style='text-align:center;'>" + wpj_vars.reset + "</h2>" );

	$( "#user_login" ).attr( "placeholder", wpj_vars.user_name );
	$( "#loginform #user_login" ).attr( "placeholder", wpj_vars.user_email );
	$( "#lostpasswordform #user_login" ).attr( "placeholder", wpj_vars.user_email );
	$( "#lostpasswordform #wp-submit" ).attr( "value", wpj_vars.reset );
	$( "#loginform #wp-submit" ).attr( "value", wpj_vars.login );

	$( "#user_email" ).attr( "placeholder", wpj_vars.email );
	$( "#user_pass" ).attr( "placeholder", wpj_vars.password );
	$( "#cell_number" ).attr( "placeholder", wpj_vars.phone_number );
	$( "#user_company" ).attr( "placeholder", wpj_vars.company );
	$( "#user_password" ).attr( "placeholder", wpj_vars.password );
	$( "#user_confirm_password" ).attr( "placeholder", wpj_vars.confirm_password );

	$( '#login > h1' ).remove();
	$( '#login > #backtoblog' ).remove();
	$( '#login > #nav' ).remove();
	$( '#login .forgetmenot' ).remove();
	$( '#login #reg_passmail' ).remove();

	$( '#divider_login_outer' ).appendTo( '#login form' );

});

// Change layout
jQuery( function( $ ) {
	$( '.layout_jobs' ).on( 'click', function() {

		// Simulate resize to set the correct width for sliders
		var event = document.createEvent( 'HTMLEvents' );
		event.initEvent( 'resize', true, false );
		document.dispatchEvent( event );

		var job_style = $( this ).data( "value" );
		if ( job_style == 'grid' ) {
			$( '.wpj-load-more-target' ).removeClass( 'list-grid' );
			$( this ).parent().removeClass( 'list-grid' );
		}
		if ( job_style == 'list' ) {
			$( '.wpj-load-more-target' ).addClass( 'list-grid' );
			$( this ).parent().addClass( 'list-grid' );
		}

		// Change video card height
		$( '.owl-video-wrapper' ).each( function() {
			var wrapper_height = $( this ).height();
			$( this ).find( 'iframe' ).attr( 'height', wrapper_height );
		});

		if ( $.cookie( 'cards-layout' ) != 'list' ) {
			$.cookie( 'cards-layout', 'list', { expires: 7, path: '/' } );
		} else {
			$.cookie( 'cards-layout', 'grid', { expires: 7, path: '/' } );
		}

	});
});

// Style recommended for you - label
jQuery( document ).ready( function( $ ) {
	var $title = $( '.layout_jobs' ).parents( '.brz-wrapper' ).prev( '.brz-wrapper' ).find( 'p' );
	if ( $title.length ) {
		var title_offset = $( '.layout_jobs' ).offset().top - $title.offset().top;

		// selector can be wrong, check if it really overlaps
		if ( -50 < title_offset && title_offset < 50 ) {
			if ( $( 'body' ).hasClass( "rtl" ) ) {
				$title.css({
					'margin-left': '70px',
					'text-overflow': 'ellipsis',
					'white-space': 'nowrap',
					'overflow': 'hidden',
					'direction': 'ltr'
				});
			} else {
				$title.css({
					'margin-right': '70px',
					'text-overflow': 'ellipsis',
					'white-space': 'nowrap',
					'overflow': 'hidden'
				});
			}
		}
	}
});

// Cards lazy loading images
function wpj_enable_lazy_loading() {

	jQuery.fn.echoLazyLoadInit = function() {
		if ( jQuery.isFunction( echo.init ) ) {
			echo.init({
				offset  : 100,
				throttle: 250,
				unload  : false,
				callback: function ( element, op ) {
					jQuery( element ).addClass( 'echo-lazy-loaded' );
				}
			});
		}
	}

	jQuery.fn.echoLazyLoadRender = function() {
		if ( jQuery.isFunction( echo.render ) ) {
			echo.render({
				offset  : 100,
				throttle: 250,
				unload  : false,
				callback: function ( element, op ) {
					setTimeout( function() {
						jQuery( element ).addClass( 'echo-lazy-loaded' );
					}, 1000 );
				}
			});
		}
	}

	jQuery( document ).ready( function() {
		jQuery.fn.echoLazyLoadInit();
	});

}

// General OWL Carousel
function wpj_initialize_wpj_carousel( is_rtl ) {
	jQuery( '.wpj-carousel' ).owlCarousel({
		rtl            : is_rtl,
		loop           : false,
		margin         : 14,
		nav            : true,
		dots           : false,
		navText        : ['',''],
		lazyLoad       : true,
		video          : true,
		URLhashListener: true,
		startPosition  : 'URLHash',
		responsive     : {
			0:{
				items:1
			}
		},
		onTranslated : function( e ) {
			var current = e.item.index;
			var this_item = jQuery( e.target ).find( '.owl-item' ).eq( current );
			this_item.find( '.owl-video-wrapper' ).find( 'iframe' ).siblings( '.owl-video-play-icon' ).remove();
		},
		onInitialized : function( e ) {
			jQuery( '.wpj-card-style-3' ).find( '.card-image-clipper' ).remove();
		}
	});
}

jQuery( window ).ready( function( $ ) {

	var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;

	// News Carousel
	$( '.news-carousel' ).owlCarousel({
		rtl       : is_rtl,
		loop      : false,
		margin    : 14,
		nav       : true,
		dots      : false,
		navText   : ['<','>'],
		lazyLoad  : true,
		responsive: {
			0:{
				items: Hooks.apply_filters( 'wpj_news_items_mobile_filter', 1 )
			},
			480:{
				items: Hooks.apply_filters( 'wpj_news_items_filter', 2 )
			}
		}
	});

	// Job Carousel - Slider
	$( '.js-jobs-carousel' ).owlCarousel({
		rtl       : is_rtl,
		loop      : false,
		margin    : 16,
		nav       : true,
		lazyLoad  : true,
		dots      : false,
		navText   : ["<i class='icon angle left'>", "<i class='icon angle right'>"],
		navClass  : ["nav-prev", "nav-next"],
		responsive: {
			0: {
				items: Hooks.apply_filters( 'wpj_job_slider_items_mobile_filter', 1 )
			},
			480:{
				items: Hooks.apply_filters( 'wpj_job_slider_items_480_filter', 2 )
			},
			767: {
				items: Hooks.apply_filters( 'wpj_job_slider_items_767_filter', 3 )
			},
			1200: {
				items: Hooks.apply_filters( 'wpj_job_slider_items_1200_filter', 4 )
			}
		}
	});

	// Job Carousel - Slider - Lazy Load
	$( '.nav-next, .nav-prev' ).click( function() {
		if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
			jQuery.fn.echoLazyLoadRender();
		}
	});

	// Job Carousel - Single
	if ( ! $( '.js-jobs-carousel' )[0] ) { wpj_initialize_wpj_carousel( is_rtl ); }

});

jQuery( document ).ready( function( $ ) {

	var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;

	//--> START User Portfolio Slider
	$( '.js-profile-portfolio-carousel' ).owlCarousel({
		rtl       : is_rtl,
		loop      : false,
		margin    : 16,
		nav       : true,
		dots      : false,
		lazyLoad  : true,
		navText   : ["<i class='icon angle left'>", "<i class='icon angle right'>"],
		navClass  : ["nav-prev", "nav-next"],
		responsive: {
			0: {
				items: 1
			},
			767: {
				items: 3
			},
			1200: {
				items: 3
			}
		}
	});

	// Go to job link when card is video and the play button is not pressed
	$( document ).on( 'click', '.owl-video-wrapper', function( e ) {

		if ( $( this ).closest( '.wpj-card-style-3' ).length > 0 ) {

			if ( e.target !== e.currentTarget ) return false;

			var card_link = $( this ).parents( '.image' ).siblings( '.cards-title' ).find( '.list-header' ).attr( 'href' );

			if ( card_link ) {
				window.location.href = card_link;
			}

		}

	});
});
//<-- END User Portfolio Slider

jQuery( document ).ready( function( $ ) {

	if ( wpj_vars.chat_enabled == 'yes' && wpj_vars.is_user_logged_in == true ) {

		var active_popups = []; // this array contains the open message boxes

/*** TOGGLE SIDEBAR ****/
		$( document ).on( 'click', '.chat-sidebar-anchor', function() {

			var sidebar_wrapper = $( this ).parents( '.chat-sidebar-container' ).find( '.chat-sidebar-wrapper' );

			// set cookie
			var sidebar_status = wpj_chat_set_box_status_cookie( sidebar_wrapper );

			if ( sidebar_status == 'minimized' ) {

				if ( $( this ).find( 'div:visible' ).attr( 'class' ) == 'chat-sidebar-anchor-icon' ) {

					sidebar_wrapper.hide( "slide", { direction: wpj_vars.h_margin_name }, 300 );

					wpj_chat_animate_element( 'hide' );

					$( '.is-chat-active' ).removeClass( 'full-sidebar' );

				} else if ( $( this ).find( 'div:visible' ).attr( 'class' ) == 'chat-sidebar-anchor-text' ) {

					sidebar_wrapper.slideToggle( 300 );
					$( '.chat-sidebar-anchor-icon' ).removeAttr( 'style' );

				}

				$( '.is-chat-active' ).addClass( 'is-chat-minimized' );
				$( '.is-chat-active' ).removeClass( 'is-chat-maximized' );

			} else {

				if ( $( this ).find( 'div:visible' ).attr( 'class' ) == 'chat-sidebar-anchor-icon' ) {

					sidebar_wrapper.show( "slide", { direction: wpj_vars.h_margin_name }, 300 );

					wpj_chat_animate_element( 'show' );

					$( '.is-chat-active' ).addClass( 'full-sidebar' );

				} else if ( $( this ).find( 'div:visible' ).attr( 'class' ) == 'chat-sidebar-anchor-text' ) {

					sidebar_wrapper.slideToggle( 300 );
					$( '.chat-sidebar-anchor-icon' ).removeAttr( 'style' );

				}

				$( '.is-chat-active' ).addClass( 'is-chat-maximized' );
				$( '.is-chat-active' ).removeClass( 'is-chat-minimized' );

				if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
					jQuery.fn.echoLazyLoadRender();
				}
			}
		});
/*** END TOGGLE SIDEBAR ****/

/*** ARCHIVE CONVERSATION ****/
		$( document ).on( 'click', '.archive-conversation', function( event ) {
			event.preventDefault();

			var box_id = $( this ).parents( '.chat-sidebar-user-box' ).attr( "data-box-id" )
			jQuery( '[rel="' + box_id + '"]' ).find( '.message-box-close' ).trigger( 'click' );

			var url = $( this ).attr( 'href' );
			var current_user = $( this ).parents( ".chat-sidebar-user-box" );

			$.ajax({
				url       : url,
				type      : "POST",
				data      : { action_button: "1" },
				success   : function( data ) {
					$( current_user ).hide( 400 );
				}
			});
		});
/*** END ARCHIVE CONVERSATION ****/

/*** OPEN BOX ***/
		$( document ).on( 'click', '.chat-sidebar-user-box', function( event ) {
			// skip action archive icon is clicked
			if ( $( event.target ).hasClass( 'archive-conversation' ) || $( event.target ).parent().hasClass( 'archive-conversation' ) ) {
				return false;
			}

			// get current user data
			var box_id = $( this ).attr( "data-box-id" ); // box id
			var this_box = jQuery( '[rel="' + box_id + '"]' ); // box id element

			// show user to sidebar if is archived
			if ( $( '.chat-sidebar-user-box[data-box-id="' + box_id + '"]' ).is( ':hidden' ) ) {
				$( '.chat-sidebar-user-box[data-box-id="' + box_id + '"]' ).show();
				wpj_unarchive_pm_conversation( $( this ).find( '.user-name' ).attr( 'data-nicename' ) );
			}

			// the number of boxes that fit in the screen
			var total_popups = wpj_chat_calculate_popup_no();

			// get only the last total_popups elements from array,
			var screen_popups = active_popups.slice( - total_popups );

			// delete span for unread messages
			$( this ).find( '.msg-unread-count' ).remove();

			// box is already on the first screen
			if ( $.inArray( box_id, screen_popups ) != -1 ) {

				if ( this_box.find( '.message-box-wrapper' ).hasClass( 'minimized' ) ) { // box is minimized
					this_box.find( '.message-box-head' ).trigger( 'click' ); //maximize the box
				} else { // box is maximized
					this_box.find( '.message-box-wrapper' ).addClass( 'has-focus' ); // add class for focus
					this_box.find( '.message-box-input-content' ).focus(); // set focus on the current box
				}

			} else {

				// if box already opened but is hidden,
				// remove from the current position,
				// to be inserted to the first position
				if ( $.inArray( box_id, active_popups ) != -1 ) {
					active_popups.splice( $.inArray( box_id, active_popups ), 1 );
					this_box.remove();
				}

				// add the new box to active popups
				active_popups.push( box_id );

				// MINIMIZE STORED BOXES
				// minimize the boxes when loading the page
				// if they have been minimized on a previous page
				box_status = 'maximized';
				if ( event.originalEvent === undefined ) { // is triggered
					var stored_popups_minimized = wpj_chat_get_stored_active_boxes( 'minimized_popups' );
					if ( jQuery.inArray( box_id, stored_popups_minimized ) != -1 ) {
						box_status = 'minimized'; // minimize the box
					}
				}

				$( '.pusher' ).append( wpj_chat_get_box_content_ajax( box_id, box_status ) );

				// initialize emoji
				if ( wpj_vars.chat_emoji_enabled != 'no' ) { wpj_chat_emoji_init( '[rel="' + box_id + '"] .message-box-input-content.' + box_id ); }

				// initialize quick response
				jQuery( '.ui.dropdown.quick-response-dropdown' ).dropdown( {
					fullTextSearch: true,
					message: { noResults: wpj_vars.nothing_found },
					onChange: function ( value, text, selected_item ) {
						var $this = $( this );
						wpj_insert_quick_response_to_textarea( selected_item, $this );
					}
				} );

				// recalculate the position of the boxes
				wpj_chat_display_boxes( active_popups, 'open_popup' );
			}

			// save active boxes to be loaded to other pages
			wpj_chat_store_active_boxes( active_popups.slice( - total_popups ), 'active_popups' );
		});
/*** END OPEN BOX ***/

/*** MINIMIZE/MAXIMIZE BOX ****/
		$( document ).on( 'click', '.message-box-head', function() {
			var $this = $( this ); // this box

			// maximize
			if ( $( this ).parents( '.message-box-wrapper' ).hasClass( 'minimized' ) ) {
				// add class for focus
				$( this ).parents( '.message-box-wrapper' ).removeClass( 'minimized' ).addClass( 'has-focus' );

				// slide and animate
				$( this ).parents( '.message-box-wrapper' ).find( '.message-box-body' ).slideToggle( 300 );
				$( this ).parents( '.message-box-wrapper' ).animate( { width: '+=80px' }, 300 );

				// set focus on the current box
				$( this ).parents( '.message-box-wrapper' ).find( '.message-box-input-content' ).focus();

				// add extra right space
				wpj_chat_change_boxes_margin( $this, 'extend', 80 );

				// save active boxes to be loaded to other pages
				wpj_chat_store_active_boxes( $( this ).parents( '.message-box-container' ).attr( "rel" ), 'removed' );

			} else { // minimize

				// slide and animate
				$( this ).parents( '.message-box-wrapper' ).find( '.message-box-body' ).slideToggle( 300, function() {
					// remove focus class
					$( this ).parents( '.message-box-wrapper' ).addClass( 'minimized' ).removeClass( 'has-focus' );
				});
				$( this ).parents( '.message-box-wrapper' ).animate( { width: '-=80px' }, 300 );

				// remove extra right space
				wpj_chat_change_boxes_margin( $this, 'reduce', 80 );

				// save active boxes to be loaded to other pages
				wpj_chat_store_active_boxes( $( this ).parents( '.message-box-container' ).attr( "rel" ), 'minimized' );
			}

			// remove class unread
			$( this ).parents( '.message-box-wrapper' ).removeClass( 'unread' );

			return false;
		});
/*** END MINIMIZE/MAXIMIZE BOX ****/

/*** CLOSE BOX ***/
		$( document ).on( 'click', '.message-box-close', function( e ) {
			e.preventDefault();
			e.stopPropagation();

			// remove from array
			var box_id = $( this ).parents( '.message-box-container' ).attr( "rel" );
			active_popups.splice( $.inArray( box_id, active_popups ), 1 );

			// remove from front
			$( this ).parents( '.message-box-container' ).remove();

			// recalculate the position of the boxes
			wpj_chat_display_boxes( active_popups, 'close_popup' );

			// the number of boxes that fit in the screen
			var total_popups = wpj_chat_calculate_popup_no();

			// get only the last total_popups elements from array,
			var screen_popups = active_popups.slice( - total_popups );

			// update stored active boxes
			wpj_chat_store_active_boxes( screen_popups, 'active' );
			wpj_chat_store_active_boxes( box_id, 'removed' );
		});
/*** END CLOSE BOX ***/

/*** ENTER - SEND MESSAGE ***/
		$( document ).on( 'blur keypress keyup paste input', '.message-box-container #message_box_input_content, .message-box-container .emojionearea', function( e ) {

			if ( wpj_vars.chat_emoji_enabled != 'no' && $( this ).is( '#message_box_input_content' ) )
				return false;

			if ( wpj_vars.chat_emoji_enabled != 'no' ) {

				// get message
				var msg_orig = msg = $( this ).siblings( '#message_box_input_content' ).data( 'emojioneArea' ).getText();

			} else {

				// get message
				var msg_orig = $( this ).text();

				// get message with line breaks
				var msg = $( this ).text().replace( /</g, '&lt;' ).replace( />/g,'&gt;' ).replace( /\n/g, '<br/>' );

			}

			// get box id
			var box_id = $( this ).parents( '.message-box-container' ).attr( "rel" );

			// get date now
			var date = new Date();

			// get am/pm
			var ampm = date.getHours() >= 12 ? wpj_vars.pm : wpj_vars.am;

			// stops enter action
			// if the attachments were not fully loaded
			var attachments_complete = true;
			if ( $( this ).parents( '.message-box-footer' ).siblings( '.message-box-body' ).find( '.uploadifive-queue-item' )[0] ) {
				$( this ).parents( '.message-box-footer' ).siblings( '.message-box-body' ).find( '.uploadifive-queue-item' ).each( function() {
					if ( $( this ).hasClass( 'complete' ) ) {
						attachments_complete = true;
					} else {
						attachments_complete = false;
					}
				});
			}

			// if the key is enter and shift is not press
			// shift + enter for new line
			if ( e.keyCode == 13 && ! e.shiftKey && attachments_complete ) {

				if ( wpj_vars.chat_emoji_enabled != 'no' ) {
					var message_length = get_input_length_emoji( msg );
				} else {
					var message_length = get_input_length( $( this ), 'html' );
				}

				// if message is not empty
				if ( msg.trim().length != 0 && message_length >= parseInt( wpj_vars.characters_pm_min ) && message_length <= parseInt( wpj_vars.characters_pm_max ) ) {

					// filter the message
					msg = wpj_chat_filter_message( msg );

					// insert the attachments to the box
					var attachments = '';
					var attachments_post = jQuery( 'input[name="hidden_files_chat_attachments_' + box_id + '"]' ).val();

					if ( attachments_post ) {

						var pm_files_array = attachments_post.split( "," );

						if ( pm_files_array ) {
							attachments = '<div class="pm-attachments">';

								for ( var i = 0; i < pm_files_array.length; i++ ) {
									attachments = attachments + '\
										<div class="div_div2" id="image_ss' + pm_files_array[i] + '">\
											<div class="pm-attachment-rtl">\
												<a class="download-req" target="_blank" href="' + wpj_vars.blog_url + '/?secure_download=' + pm_files_array[i] + '" download="">' + jQuery( '.uploadifive-queue-item[data-fileid=' + pm_files_array[i] + ']' ).find( '.filename' ).text() + '</a>\
											</div>\
										</div>\
									';
								}

							attachments = attachments + '</div>';
						}
					}

					// insert the message to the box
					$( '\
						<div class="multiple-messages-wrapper">\
							<div class="message-wrapper sent">\
								<div class="message-text-content" data-inverted="" data-tooltip="' + date.getHours() + ':' + date.getMinutes() + ' ' + ampm.toLowerCase() + '" data-position="top right">\
									<div class="message-send">' + msg + attachments + '</div>\
								</div>\
							</div>\
						</div>\
					' ).insertBefore( '[rel="' + box_id + '"] .message-box-push' );

					// insert custom offer to the message box
					// custom-offer.js -> request - line 92 - 115
					// custom-offer.js -> send - line 156 - 179

					// insert custom offer responses to the message box
					// chatbox.js -> line 216 - 226

					// insert to database
					jQuery.ajax({
						type: 'post',
						url : wpj_vars.ajaxurl,
						data: {
							action    : 'wpj_ajax_send_message_users',
							otheruid  : box_id,
							message   : msg_orig,
							upload    : jQuery( 'input[name="hidden_files_chat_attachments_' + box_id + '"]' ).val(),
							request_id: '',
							job_id    : '',
						},
						success: function( data ) {}
					});

					// clear attachments queue
					$( '#uploadifive-file_upload_chat_attachments_' + box_id + '-queue' ).empty();

					// clear attachments value
					$( "input[name=hidden_files_chat_attachments_" + box_id + "]" ).val( '' );

					// scroll to the last message
					$( this ).parents( '.message-box-wrapper' ).find( '.message-box-content' ).scrollTop( $( this ).parents( '.message-box-wrapper' ).find( '.message-box-content' )[0].scrollHeight );
				}

				// show placeholder
				$( this ).parents( '.message-box-footer' ).find( '.message-box-placeholder-container' ).show();

				// clear the box
				if ( wpj_vars.chat_emoji_enabled != 'no' ) {
					$( this ).siblings( '#message_box_input_content' ).data( 'emojioneArea' ).setText( '' );
				} else {
					$( this ).text( '' );
				}

				// clear 'no message' pusher div
				$( this ).parents( '.message-box-wrapper' ).find( '.message-box-push' ).text( '' );

				return false;

			} else { // click on the box input

				if ( $( this ).text() !== '' ) { // input has content
					// hide placeholder
					$( this ).parents( '.message-box-footer' ).find( '.message-box-placeholder-container' ).hide();
				} else { // input is empty
					// show placeholder
					$( this ).parents( '.message-box-footer' ).find( '.message-box-placeholder-container' ).show();
				}

				if ( e.keyCode == 13 && ! e.shiftKey ) {
					return false;
				}

			}

			if ( e.key === "Escape" ) {
				jQuery( '[rel="' + box_id + '"]' ).find( '.message-box-close' ).trigger( 'click' );
			}

		});
/*** END ENTER - SEND MESSAGE ***/

/*** LOAD MORE MESSAGES ***/
		$( '.pusher' ).on( 'mousewheel DOMMouseScroll scroll', '.message-box-content', function() {
			// if scroll is at the top of the box
			// load new messages
			if ( $( this ).scrollTop() == 0 ) {
				$( this ).find( '.chat-load-btn' ).show().trigger( 'click' );
			}
		});

		$( document ).on( 'click', '.chat-load-btn', function() {
			var $this = $( this );

			// current offset
			var page = Math.ceil( $( this ).parents( '.message-box-content' ).find( '.message-wrapper' ).length / 10 ) + 1;

			$.ajax({
				url  : wpj_vars.ajaxurl,
				type : 'post',
				data : {
					page: page,
					user_id: $this.parents( '.message-box-container' ).attr( "rel" ),
					action: 'more_messages'
				},
				beforeSend: function(){
					// show loader
					$this.show();
				},
				success: function( result ) {
					if ( result ) {
						// get current scroll position
						var current_scroll_position = $this.parents( '.message-box-content' ).offset().top;
						// insert new messages
						$( result ).insertAfter( $this.parents( '.message-box-ajax-trigger' ) );
						// move the scroll to its last position
						$this.parents( '.message-box-content' ).scrollTop( current_scroll_position );
					}

					// hide loader
					$this.hide();
				}
			});
		});
/*** END LOAD MORE MESSAGES ***/

/*** LINKS - BOX HEAD ***/
		$( document ).on( 'click', '.message-box-maximize, .message-box-logo-area, .message-box-user-info-title-container', function( e ) {
			// if box is not minimized
			if ( ! $( this ).parents( '.message-box-wrapper' ).hasClass( 'minimized' ) ) {
				// stop other action
				e.preventDefault();
				e.stopPropagation();

				// redirect to url
				window.location.href = $( this ).find( 'a' ).attr( 'href' );
			}
		});
/*** END LINKS - BOX HEAD ***/

/*** WINDOW RESIZE - SHOW/HIDE BOX ***/
		$( window ).on( 'load resize', function() {
			// call 'wpj_chat_display_boxes' function to show only last boxes
			wpj_chat_display_boxes( active_popups, 'resize_window' );

			// pusher full width if width < 1258
			if ( $( this ).width() < ( 1258 - 15 ) ) {
				$( '.pusher' ).css( 'padding-' + wpj_vars.h_margin_name, '0' );
				$( '.is-chat-active' ).removeClass( 'full-sidebar' );
			} else {
				$( '.pusher' ).removeAttr( 'style' );
				if ( $( '.chat-sidebar-wrapper' ).is( ':visible' ) ) {
					$( '.is-chat-active' ).addClass( 'full-sidebar' );
				}
			}
		});
/*** END WINDOW RESIZE - SHOW/HIDE BOX ***/

/*** BOX FOCUS ***/
		$( document ).on( 'click blur', '.message-box-container' , function( e ) {

			var selection = window.getSelection();

			if ( selection.toString().length === 0 ) {

				if ( e.type == 'click' ) {

					if ( ! $( this ).find( '.message-box-wrapper' ).hasClass( 'has-focus' ) ) {

						// hide placeholder
						$( this ).find( '.message-box-placeholder-container' ).hide();

						// add class for focus
						$( this ).find( '.message-box-wrapper' ).addClass( 'has-focus' );

						// set focus on the current box
						$( this ).find( '.message-box-input-content' ).focus();

						// remove unread class
						$( this ).find( '.message-box-wrapper' ).removeClass( 'unread' );

					}

				} else if ( e.type == 'focusout' ) {

					// remove focus class
					$( this ).find( '.message-box-wrapper' ).removeClass( 'has-focus' );

				}

			} else {

				// text selecting

			}

		});
/*** END BOX FOCUS ***/

/*** OPEN STORED BOXES ***/
		var stored_popups = wpj_chat_get_stored_active_boxes( 'active_popups' );
		if ( stored_popups ) {
			stored_popups.forEach( function( box_id ) {
				// trigger click to open the boxes
				jQuery( '.chat-sidebar-user-box[data-box-id="' + box_id + '"]' ).trigger( 'click' );
			});
		}
/*** END OPEN STORED BOXES ***/

		/* Add space for search box */
		if ( $( '#wpadminbar' )[0] ) { $( '.chat-sidebar-users-list' ).css( 'height', 'calc(100% - 60px)' ); }

	}

});

/*** FUNCTIONS ***/
function wpj_chat_calculate_popup_no() {
	// get window width
	var width = window.innerWidth;

	if ( width < 540 ) { // hide boxes if windows width < 540
		total_popups = 0;
	} else { // calculate the number of boxes we can insert
		width = width - 200;
		total_popups = parseInt( width / 300 );
	}

	// return the number of boxes that fit in the screen
	return total_popups;
}

function wpj_chat_display_boxes( active_popups, action ) {
	// the number of boxes that fit in the screen
	var total_popups = wpj_chat_calculate_popup_no();

	// first right to be opened after sidebar
	var sidebar_width             = parseInt( jQuery( '.chat-sidebar-container' ).outerWidth() );
	var sidebar_margin_width      = parseInt( jQuery( '.chat-sidebar-container' ).css( wpj_vars.h_margin_name ) );
	var space_between_sidebar_box = 15;

	var right = sidebar_width + sidebar_margin_width + space_between_sidebar_box;
	if ( ! right ) { right = 220; }

	// get only the last total_popups elements from array,
	var screen_popups = active_popups.slice( - total_popups );

	for ( var i = 0; i < total_popups; i++ ) {
		if ( screen_popups[i] != undefined ) {

			// calculate the right for next element
			var new_right = jQuery( '[rel="' + screen_popups[i] + '"]' ).prev( '.message-box-container' ).find( '.message-box-wrapper' ).width();
			if ( new_right && i > 0 ) { right += ( new_right + space_between_sidebar_box ); }

			// set right css value
			jQuery( '[rel="' + screen_popups[i] + '"]' ).find( '.message-box-wrapper' ).css( wpj_vars.h_margin_name, right );

			// show the box
			jQuery( '[rel="' + screen_popups[i] + '"]' ).show();

			// set focus on the new box
			jQuery( '[rel="' + screen_popups[i] + '"]' ).find( '.message-box-input-content' ).focus();

			// scroll to the last message
			if ( jQuery( '[rel="' + screen_popups[i] + '"]' )[0] ) {
				jQuery( '[rel="' + screen_popups[i] + '"]' ).find( '.message-box-content' ).scrollTop( jQuery( '[rel="' + screen_popups[i] + '"]' ).find( '.message-box-content' )[0].scrollHeight );
			}

		}
	}

	if ( active_popups.length > total_popups ) {
		// get hidden boxes
		var hidden_popups = active_popups.slice( 0, - total_popups );

		// hide the rest of the boxes
		for ( var j = 0; j < hidden_popups.length; j++ ) {
			jQuery( '[rel="' + hidden_popups[j] + '"]' ).hide();
		}
	}
}

function wpj_chat_change_boxes_margin( this_elem, operation, value ) {
	this_elem.parents( '.message-box-container' ).nextAll( '.message-box-container' ).each( function() {
		// box id
		var box_id = jQuery( this ).attr( "rel" );

		// get right value of current box id
		var old_right = jQuery( '[rel="' + box_id + '"]' ).find( '.message-box-wrapper' ).css( wpj_vars.h_margin_name ).replace( /[^-\d\.]/g, '' );

		// calculate and chagne right value
		var new_right = operation == 'extend' ? parseInt( old_right ) + parseInt( value ) : parseInt( old_right ) - parseInt( value );

		// apply new right value to current box id
		jQuery( '[rel="' + box_id + '"]' ).find( '.message-box-wrapper' ).css( wpj_vars.h_margin_name, new_right );
	});
}

function wpj_chat_open_box( box_id ) {
	if (
		wpj_vars.chat_enabled == 'yes'
		&& wpj_vars.is_user_logged_in == true
		&& jQuery( window ).width() >= 768
		&& ! isMobile()
		&& wpj_vars.is_page_pm != 1
		&& wpj_vars.is_page_pm_single != 1
		&& jQuery( '.chat-sidebar-user-box[data-box-id="' + box_id + '"]' )[0]
	) {

		// Hide preview window
		jQuery( '.nh-messages-dropdown' ).hide();

		// Hide count box
		jQuery( '.nh-messages' ).find( '.unread-label' ).hide();

		// Open message box
		jQuery( '.chat-sidebar-user-box[data-box-id="' + box_id + '"]' ).trigger( 'click' );

		return false;

	}

	return true;
}

function wpj_chat_search_user_sidebar( element ) {
	// user to search
	var value = wpj_validate_input_content( jQuery( element ).val().toLowerCase() );

	jQuery( ".chat-sidebar-users-list > .chat-sidebar-user-box" ).each( function() {
		// if the wanted user existed, display it
		if ( jQuery( this ).find( '.user-name' ).text().toLowerCase().search( value ) > -1 ) {
			jQuery( this ).show();
		} else {
			jQuery( this ).hide();
		}
	});

	// show/hide "No user found" message
	if ( jQuery( ".chat-sidebar-users-list > .chat-sidebar-user-box" ).children( ':visible' ).length == 0 ) {
		jQuery( '.chat-sidebar-notifications' ).show();
	} else {
		jQuery( '.chat-sidebar-notifications' ).hide();
	}
}

function wpj_chat_filter_message( msg ) {
	ret = '';

	jQuery.ajax({
		url  : wpj_vars.ajaxurl,
		type : 'post',
		async: false,
		data : {
			message: msg,
			action: 'filter_message'
		},
		success: function( result ) {
			ret = result;
		}
	});

	// return filtered message
	return ret;
}

function wpj_chat_get_stored_active_boxes( item_name ) {
	if ( localStorage.getItem( item_name ) ) {

		// return stored active boxes
		return JSON.parse( localStorage.getItem( item_name ) );
	}

	return false;
}

function wpj_chat_store_active_boxes( popups, status ) {
	if ( status == 'minimized' || status == 'removed' ) {

		current_items = wpj_chat_get_stored_active_boxes( 'minimized_popups' );

		// remove the new box from minimized popups if exist
		if ( current_items ) {
			if ( jQuery.inArray( popups, current_items ) != -1 ) {
				current_items.splice( jQuery.inArray( popups, current_items ), 1 );
			}
		} else {
			current_items = [];
		}

		// add the new box to minimized popups
		if ( status == 'minimized' ) {
			current_items.push( popups );
		}

		// store minimized boxed
		localStorage.setItem( 'minimized_popups', JSON.stringify( current_items ) );

	} else {
		// remove old boxes
		localStorage.removeItem( 'active_popups' );

		// add the new boxes
		localStorage.setItem( 'active_popups', JSON.stringify( popups ) );
	}
}

function wpj_chat_get_box_content_ajax( box_id, box_status ) {
	var ret = '';

	jQuery.ajax({
		url : wpj_vars.ajaxurl,
		type: 'post',
		async: false,
		data: {
			action    : 'display_box_content',
			user_id   : box_id,
			box_status: box_status
		},
		success: function( result ) {
			ret = result;
		}
	});

	// return content
	return ret;
}

function wpj_chat_set_box_status_cookie( element ) {
	if ( element.is( ':hidden' ) ) {
		jQuery.cookie( 'sidebar', 'maximized', { expires: 7, path: '/' } );
		return 'maximized';
	} else {
		jQuery.cookie( 'sidebar', 'minimized', { expires: 7, path: '/' } );
		return 'minimized';
	}
}

function wpj_chat_animate_element( action ) {
	var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;

	if ( action == 'show' ) {

		if ( is_rtl == true ) {
			jQuery( '.chat-sidebar-anchor-icon' ).animate({ 'left' : '206px' }, 300 );
			jQuery( '.pusher' ).animate( { 'padding-left' : '200px' }, 300 );
		} else {
			jQuery( '.chat-sidebar-anchor-icon' ).animate({ 'right' : '206px' }, 300 );
			jQuery( '.pusher' ).animate( { 'padding-right' : '200px' }, 300 );
		}

	} else if ( action == 'hide' ) {

		if ( is_rtl == true ) {
			jQuery( '.chat-sidebar-anchor-icon' ).animate({ 'left' : '0' }, 300 );
			jQuery( '.pusher' ).animate( { 'padding-left' : '0' }, 300 );
		} else {
			jQuery( '.chat-sidebar-anchor-icon' ).animate({ 'right' : '0' }, 300 );
			jQuery( '.pusher' ).animate( { 'padding-right' : '0' }, 300 );
		}

	}
}
/*** END FUNCTIONS ***/

jQuery( window ).ready( function( $ ) {

	// Scroll to last message
	if ( $( ".chatbox_post" )[0] ) {
		$( 'html, body' ).animate({
			scrollTop: $( ".chatbox_post" ).last().offset().top - 89
		}, 1000 );
	}

	// Initialize fliptimer
	if ( wpj_vars.order_expected_delivery ) {
		$( '.flipTimer' ).flipTimer({
			direction: 'down',
			date: wpj_vars.order_expected_delivery,
		});
	}

});

jQuery( document ).ready( function( $ ) {

	function addLoadingClass( $this, container ) {
		container = typeof container !== 'undefined' ? container : '#all_chatbox_messages';

		jQuery( container + ' .button:not(.loading):not(.alwaysdisabled)' ).addClass( 'disabled' );
		$this.addClass( 'loading' ).addClass( 'disabled' );
	}

	function removeLoadingClass( $this, container ) {
		container = typeof container !== 'undefined' ? container : '#all_chatbox_messages';

		jQuery( container + ' .button:not(.loading):not(.alwaysdisabled)' ).removeClass( 'disabled' );
		$this.removeClass( 'loading' ).removeClass( 'disabled' );
	}

	function wpj_open_chatbox_modal( modal_class_name, ajax_action, content_class_name, data ) {
		jQuery( '.ui.modal.' + modal_class_name )
			.modal({
				onApprove: function() { return false; },
				onDeny: function() { return false; }
			})
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' )
			.modal( 'refresh' );

		if ( ! data ) {
			data = {
				action: ajax_action,
				oid : getUrlParameter( 'oid' )
			};
		}

		jQuery.ajax({
			type: 'post',
			url : wpj_vars.ajaxurl,
			data: data,
			success: function( data ) {
				jQuery( '.' + content_class_name ).html( data );
				jQuery( '.ui.modal.' + modal_class_name ).modal( 'refresh' );
				jQuery( '.ui.checkbox' ).checkbox();
			}
		});
	}

	// Chatbox Modals
	jQuery( document ).ajaxStop( function() {

		// Open resolution center modal
		$( '.open-modal-resolution-center' ).click( function( e ) {
			e.preventDefault();
			wpj_open_chatbox_modal( 'resolution-center', 'wpj_resolution_center_form', 'modal-content-resolution-center' );
		});

		// Open request modification modal
		$( '.open-modal-request-modifications' ).click( function( e ) {
			e.preventDefault();
			wpj_open_chatbox_modal( 'request-modification', 'wpj_request_modification_form_function', 'modal-content-request-modification' );
		});

		// Resolution center action
		$( '.btn-wpj-send-resolution-center-option' ).click( function( e ) {
			e.preventDefault();

			var selected_action = $( 'input[name="resolution_center_option"]:checked' ).val();
			if ( ! selected_action ) { selected_action = 'cancellation'; }

			jQuery( '.ui.modal.resolution-center' ).modal( 'hide' );

			if ( selected_action == 'cancellation' ) {
				wpj_open_chatbox_modal( 'request-mutual-cancellation', 'wpj_request_mutual_cancellation_form', 'modal-content-cancellation' );
			} else if ( selected_action == 'arbitration' ) {
				wpj_open_chatbox_modal( 'request-arbitration', 'wpj_request_arbitration_form', 'modal-content-arbitration' );
			} else if ( selected_action == 'extended_delivery_time' ) {
				wpj_open_chatbox_modal( 'request-extended-delivery-time', 'wpj_request_extended_delivery_time_form', 'modal-content-extended-delivery-time' );
			}
		});

		// Request mutual cancellation action
		$( '.btn-wpj-send-mutual-cancellation' ).click( function( e ) {
			e.preventDefault();

			var $this = $( this );
			addLoadingClass( $this );

			jQuery.ajax({
				type: 'post',
				url : wpj_vars.ajaxurl,
				data: $( '#wpj_send_mutual_cancellation' ).serialize(),
				success: function( data ) {
					removeLoadingClass( $this );

					jQuery( '.ui.modal.request-mutual-cancellation' ).modal( 'hide' );

					if ( wpj_vars.live_notify == 'yes' ) {
						initLiveNotifications();
					} else {
						location.reload();
					}
				}
			});
		});

		// Request arbitration action
		$( '.btn-wpj-send-arbitration' ).click( function( e ) {
			e.preventDefault();

			var $this = $( this );
			addLoadingClass( $this );

			jQuery.ajax({
				dataType: 'json',
				type    : 'POST',
				url     : wpj_vars.ajaxurl,
				data    : $( '#wpj_send_arbitration' ).serialize(),
				success: function( msg ) {
					removeLoadingClass( $this );

					if ( msg.err === 1 ) {
						$( ".arbitration-msg-target" ).html( '<div class="ui negative visible message"><p>' + msg.msg + '</p></div>' );
					} else {
						jQuery( '.ui.modal.request-arbitration' ).modal( 'hide' );

						if ( wpj_vars.live_notify == 'yes' ) {
							initLiveNotifications();
						} else {
							location.reload();
						}
					}
				}
			});
		});

		// Request extended delivery time
		$( '.btn-wpj-send-extended-delivery-time' ).click( function( e ) {
			e.preventDefault();

			var $this = $( this );
			addLoadingClass( $this );

			jQuery.ajax({
				type    : 'POST',
				url     : wpj_vars.ajaxurl,
				data    : $( '#wpj_send_extended_delivery_time' ).serialize(),
				success : function( data ) {
					removeLoadingClass( $this );

					jQuery( '.ui.modal.request-extended-delivery-time' ).modal( 'hide' );

					if ( wpj_vars.live_notify == 'yes' ) {
						initLiveNotifications();
					} else {
						location.reload();
					}
				}
			});
		});

		// Request modification action
		$( '.btn-wpj-send-request-modification' ).click( function( e ) {
			e.preventDefault();

			var $this = $( this );
			addLoadingClass( $this );

			jQuery.ajax({
				type: 'post',
				url : wpj_vars.ajaxurl,
				data: $( '#wpj_send_request_modification' ).serialize(),
				success: function( data ) {
					removeLoadingClass( $this );

					jQuery( '.ui.modal.request-modification' ).modal( 'hide' );

					if ( wpj_vars.live_notify == 'yes' ) {
						initLiveNotifications();
					} else {
						location.reload();
					}
				}
			});
		});
	});

	// Function for Buttons Action
	function transaction_action( url, data, $this ) {
		if ( ! url ) {
			url = wpj_vars.ajaxurl;
		}

		jQuery.ajax({
			type: "POST",
			url : url,
			data: data,
			success: function( msg ) {
				removeLoadingClass( $this );

				if ( wpj_vars.live_notify == 'yes' ) {
					initLiveNotifications();
				} else {
					location.reload();
				}
			}
		});

		return false;
	}

	// Ajax for ChatBox & Custom Offer Buttons
	var actions = [
		"mark_completed",
		"abort_arbitration",
		"abort_mutual_cancelation",
		"mark_delivered",
		"order_cancellation",
		"accept_cancellation",
		"deny_cancellation",
		"decline_custom_extra",
		"cancel_custom_extra",
		"mark_custom_extra_paid",
		"cancel_tips",
		"withdraw_custom_offer",
		"decline_custom_offer",
		"abort_extend_delivery",
		"accept_extend_delivery",
		"deny_extend_delivery"
	];
	actions.forEach( function( action ) {
		jQuery( document ).on( 'click', 'a.' + action, function() {

			var $this = $( this );
			addLoadingClass( $this );

			var data = '';
			if ( typeof oid !== 'undefined' ) {
				var data = "oid=" + oid;
			}

			var url = wpj_vars.ajaxurl;

			if ( action == 'accept_cancellation' || action == 'deny_cancellation' ) {
				var accept = action == 'accept_cancellation' ? 'yes' : 'no';
				data = { action: 'answer_mutual_cancellation', orderid: oid, accept: accept }
			} else if ( action == 'abort_mutual_cancelation' ) {
				data = { action: 'abort_mutual_cancelation', orderid: oid }
			} else if ( action == 'order_cancellation' ) {
				data = { action: 'cancel_expired_order', orderid: oid }
			} else if ( action == 'abort_extend_delivery' || action == 'accept_extend_delivery' || action == 'deny_extend_delivery' ) {
				data = { action: action, orderid: oid }
			} else if ( action == 'decline_custom_extra' || action == 'cancel_custom_extra' || action == 'mark_custom_extra_paid' || action == 'cancel_tips' ) {
				data = jQuery( jQuery( this ).parent().children( 'form' ) ).serialize();
			} else if ( action == 'decline_custom_offer' || action == 'withdraw_custom_offer' ) {

				// send notification to message box
				if ( jQuery( '.message-wrapper[data-pm-id="' + jQuery( this ).attr( 'data-id' ) + '"]' )[0] ) {
					var notification_message = action == 'decline_custom_offer' ? wpj_vars.declined : wpj_vars.withdrawn;
					jQuery( ".message-wrapper[data-pm-id='" + jQuery( this ).attr( 'data-id' ) + "'] .message-custom-offer" ).append( '<span class="ui mini right label custom-offer-response">' + notification_message + '</span>' );
				}

				// proposals
				if ( jQuery( '.proposals-status' )[0] ){
					var notification_message = action == 'decline_custom_offer' ? wpj_vars.offer_declined : wpj_vars.offer_withdrawn;
					jQuery( ".proposals-status[data-custom-offer='" + jQuery( this ).attr( 'data-id' ) + "']" ).html( '<span class="offer-red">' + notification_message + '</span>' );
				}

				data = jQuery( jQuery( this ).parent().children( 'form' ) ).serialize();

				jQuery( '#pm_' + jQuery( this ).attr( 'data-id' ) ).fadeOut( "normal", function() { jQuery( this ).remove(); });
			} else if ( action == 'abort_arbitration' ) {
				data = { action: 'abort_arbitration', oid: oid }
			} else {
				url = wpj_vars.blog_url + "/?jb_action=" + action + "&oid=" + oid;
			}

			transaction_action( url, data, $this );
		});
	});

	// Send message with ENTER key
	wpj_send_message_with_enter( '.send-message' );

	// Send message action
	$( '.send-message' ).click( function( e ) {
		e.preventDefault();

		var $this = $( this );

		if ( wpj_vars.transaction_emoji_enabled != 'no' ) {
			var message = wpj_validate_input_content( $( '.cmi-listen.message-field' ).data( 'emojioneArea' ).getText() );
		} else {
			var message = wpj_validate_input_content( $( '.cmi-listen.message-field' ).val() );
		}

		if ( wpj_vars.transaction_emoji_enabled != 'no' ) {
			var message_length = get_input_length_emoji( $( '.cmi-listen.message-field' ).data( 'emojioneArea' ).getText() );
		} else {
			var message_length = get_input_length( $( '.cmi-listen.message-field' ) );
		}

		if ( message == "" ) {

			$( '.wrapper-pm-errors' ).hide().html( '<div class="ui small error message"> ' + wpj_vars.msg_err + ' </div>' ).fadeIn( 600 );

		} else if ( message_length < parseInt( wpj_vars.characters_pm_min ) ) {

			$( '.wrapper-pm-errors' ).hide().html( '<div class="ui small error message"> ' + wpj_vars.pm_min_content + ' </div>' ).fadeIn( 600 );

		} else if ( message_length > parseInt( wpj_vars.characters_pm_max ) ) {

			$( '.wrapper-pm-errors' ).hide().html( '<div class="ui small error message"> ' + wpj_vars.pm_max_content + ' </div>' ).fadeIn( 600 );

		} else {

			var data = $( '#chatbox_message_form' ).serialize();

			if ( wpj_vars.transaction_emoji_enabled != 'no' ) {
				var element  = data.split( "&" );
				var new_data = "";

				for ( i = 0; i < element.length; i++ ) {
					if ( 'messaje' == element[i].split( "=" )[0] ) {
						new_data += 'messaje' + "=" + message + "&";

					} else {
						new_data += element[i] + "&";

					}
				}
				data = new_data;
			}

			addLoadingClass( $this, '#chat_box_message_form' );
			$( this ).attr( "disabled", "disabled" );

			$.ajax({
				type: "POST",
				url : wpj_vars.ajaxurl,
				data: data,
				success: function( msg ) {
					$( '.wrapper-pm-errors' ).fadeOut( 600 );

					$( '.chat_box_messages' ).val( '' );

					if ( wpj_vars.transaction_emoji_enabled != 'no' ) {
						$( '.emojionearea-editor' ).text( '' );
						$( '.emojionearea-editor' ).focus();
					}

					$( '#uploadifive-file_upload_chat_box_attachments-queue' ).empty();

					if ( wpj_vars.live_notify == 'yes' ) {
						initLiveNotifications();
					} else {
						location.reload();
					}

					removeLoadingClass( $this, '#chat_box_message_form' );
					setTimeout( 'jQuery(".send-message").removeAttr("disabled")', 500 );
				}
			});

		}

	});

	// Open tips modal
	$( document ).on( 'click', '.open-modal-tips-chatbox', function( event ) {
		event.preventDefault();
		var data = { action: 'tips_form', oid: getUrlParameter( 'oid' ), user: $( this ).attr( 'data-user' ), tips: $( this ).attr( 'data-tips' ) }
		wpj_open_chatbox_modal( 'add-tips', 'tips_form', 'modal-content-add-tips', data );
	});

	// Tips action
	$( document ).on( 'submit', '.tips_form', function( event ) {
		event.preventDefault();

		$( '.tips_form .button').addClass( 'loading' );
		$( '.tips_form .button').addClass( 'disabled' );

		var $this = $( this );

		$.ajax({
			data    : "action=tips_submit&" + $this.serialize(),
			dataType: "json",
			type    : "POST",
			url     : wpj_vars.ajaxurl,
			success: function( msg ) {
				$( '.tips_form .button' ).removeClass( 'loading' );
				$( '.tips_form .button' ).removeClass( 'disabled' );

				jQuery( '.tips-status-container', $this ).addClass( msg.cssClass );
				jQuery( '.tips-msg-target', $this ).fadeIn().html( msg.description );
				jQuery( '.tips-status-container', $this ).show();

				if ( msg['code'] == 'success' ) {
					$( '.ui.modal.add-tips' ).modal( 'hide' );
					window.location.replace( wpj_vars.blog_url + "/?jb_action=purchase_this&oid=" + msg['oid'] + "&tips=" + msg['tips_id'] );

					var form_content = '\
						<form id="accept_tips" method="post" name="purchase_tips' + msg['tips_id'] + '" action="' + wpj_vars.blog_url + "/?jb_action=purchase_this&oid=" + msg['oid'] + "&tips=" + msg['tips_id'] + '" style="display: none;">\
							<input type="hidden" name="purchaseformvalidation" value="ok" />\
						</form>\
					';
					$( form_content ).insertAfter( $( '#all_chatbox_messages' ) );
					$( "form[name='purchase_tips" + msg['tips_id'] + "']" ).submit();
				}
			}
		});
	});

	// Cancel modal button
	$( document ).on( 'click', '.ui.cancel.button', function() {
		$( this ).parents( '.ui.modal' ).modal( 'hide' );
	});

	// Cool message input( chatbox & pm )
	$( ".cmi-listen" ).focus( function() {
		$( this ).parents( ".cool-message-input" ).addClass( "focus" );
	}).blur( function() {
		$( this ).parents( ".cool-message-input" ).removeClass( "focus" );
	});

	// Pay custom extra
	$( document ).on( 'click', '[data-submit]', function() {
		var ob = $( this ).parents( "form" );

		if ( $( this ).data( "submit" ) ) {
			ob = $( $( this ).data( "submit" ) );
		}

		ob.submit();

		return false;
	});

	// User rating
	$( document ).off( 'click', '.submit-user-rating' ).on( 'click', '.submit-user-rating', function( e ) {

		var $this = $( this );
		var id = jQuery( this ).attr( 'rel' );

		if ( ! jQuery( "#reason-" + id ).val() && jQuery( "#reason-" + id ).val().length < wpj_vars.characters_feedback_min ) {

			$( '.error-wrapper' ).removeClass( 'hidden' ).html( '<i class="close icon"></i><div class="header">' + wpj_vars.feedback_min + '</div><p>' + wpj_vars.feedback_min_desc + '</p></div>' );

			return false;

		} else if ( jQuery( "#reason-" + id ).val() && jQuery( "#reason-" + id ).val().length > wpj_vars.characters_feedback_max ) {

			$( '.error-wrapper' ).removeClass( 'hidden' ).html( '<i class="close icon"></i><div class="header">' + wpj_vars.feedback_max + '</div><p>' + wpj_vars.feedback_max_desc + '</p></div>' );

			return false;

		} else if ( ! $( "input[name=stars]:checked", "#rating-" + id ).val() ) {

			$( '.error-wrapper' ).removeClass( 'hidden' ).html( '<i class="close icon"></i><div class="header">' + wpj_vars.err + '</div><p>' + wpj_vars.feedback_stars + '</p></div>' );

			return false;

		} else {

			jQuery( ".error-wrapper" ).addClass( 'hidden' );

		}

		jQuery.ajax({
			type   : "POST",
			url    : wpj_vars.ajaxurl,
			data   : {
				action    : 'wpj_save_user_rating',
				ids       : id,
				uprating  : $( "input[name=stars]:checked", "#rating-" + id ).val(),
				reason    : encodeURIComponent( wpj_validate_input_content( jQuery( "#reason-" + id ).val() ) ),
				buyer     : typeof buyer !== 'undefined' ? buyer : '',
				orderid   : typeof oid !== 'undefined' ? oid : '',
				pid       : typeof pid !== 'undefined' ? pid : '',
				user_type : jQuery( this ).attr( 'data-user' ),
				sample    : jQuery( this ).attr( 'data-sample' )
			},

			beforeSend: function() {
				addLoadingClass( $this, '#chat_box_review_form' );
			},

			success: function( msg ) {

				jQuery( "#chat_box_message_form" ).hide( 'slow' );

				jQuery( "#post-" + id ).hide( 'slow' );

				jQuery( ".error-wrapper" ).addClass( 'hidden' );

				if ( wpj_vars.live_notify == 'yes' ) {
					initLiveNotifications();
				} else {
					location.reload();
				}
			},

			complete: function() {
				removeLoadingClass( $this, '#chat_box_review_form' );
			}
		});

		return false;
	});


	// Work Samples Init
	wpj_initialize_work_sample();


	// Work Samples Select
	$( document ).on( 'click', '.js-select-work-sample', function() {

		var $allSamples = $( this ).closest( '.js-review-form' ).find( '.js-select-work-sample' );
		var $submitButton = $( this ).closest( '.js-review-form' ).find( '.submit-user-rating' );

		if ( $( this ).hasClass( 'selected' ) ) {

			$allSamples.removeClass( 'selected' );
			$submitButton.attr( 'data-sample', '' );

		} else {

			$allSamples.removeClass( 'selected' );
			$( this ).addClass( 'selected' );
			$submitButton.attr( 'data-sample', $( this ).attr( 'data-id' ) );
		}
	});

});


// Work Samples Init
function wpj_initialize_work_sample() {
	jQuery( '.js-review-form' ).each(function() {

		var $firstSample = jQuery( this ).find( '.js-select-work-sample' ).first();
		var $submitButton = jQuery( this ).find( '.submit-user-rating' );

		$firstSample.addClass( 'selected' );
		$submitButton.attr( 'data-sample', $firstSample.attr( 'data-id' ) );
	});
}

// Charscounter
( function( $ ) {
	$.fn.counted = function( options ) {
		var settings = {
			count: 300
		};
		options = $.extend( settings, options || {} );
		return this.each( function() {
			var $this = $( this );
			var counter = $( '<span class="charscounter" />' ).html( options.count ).insertAfter( $this );
			function wpjobster_count_and_insert( $this ) {
				var count = options.count - $this.val().length;
				if ( count >= 0 ) {
					counter.html( count );
				} else {
					$this.val( $this.val().substr( 0, options.count ) );
					counter.html( 0 );
				}
			}
			$this.on( "ready change paste keyup blur", function( e ) {
				wpjobster_count_and_insert( $this );
			});
			$this.ready( function() {
				wpjobster_count_and_insert( $this );
			});
		});
	};
})( jQuery );

// Input char counter functions
function get_input_length( element, type ) {
	var $ = jQuery.noConflict();

	type = typeof type !== 'undefined' ? type : 'input';

	if ( type == 'html' ) {
		var contentdiv = $( "<div/>" ).html( ( element ).html() );
		var breakrows = $( contentdiv ).html().match( /(<((br)|(\/br)|(\/ br))>)/gi );
		var breakrows_count = breakrows ? breakrows.length : 0;

		var $elem_class = $( element ).attr( 'class' );
		if ( $elem_class.indexOf( "wysiwyg-description-textarea" ) >= 0 ) {
			var $placeholder = $( '.wysiwyg-description-textarea' ).attr( 'placeholder' );
			if ( $( contentdiv ).text() == $placeholder ) {
				return $( contentdiv ).val().length + breakrows_count;
			} else {
				return $( contentdiv ).text().length + breakrows_count;
			}
		}

		return $( contentdiv ).text().length + breakrows_count;
	} else {
		return $( "<div/>" ).html( ( element ).val() ).text().length;
	}
}

function get_input_length_emoji( str ) {
	var point;
	var index;

	var width = 0;
	var len   = 0;

	for ( index = 0; index < str.length; ) {
		point = str.codePointAt( index );
		width = 0;

		while ( point ) {
			width += 1;
			point = point >> 8;
		}

		index += Math.round( width / 2 );
		len   += 1;
	}

	var breakrows = str.match( /(<((br)|(\/br)|(\/ br))>)/gi );
	var breakrows_count = breakrows ? breakrows.length : 0;

	return len + breakrows_count;
}

function the_input_length( element, target, max_length, type ) {
	var $ = jQuery.noConflict();

	type = typeof type !== 'undefined' ? type : 'input';

	var target_cnt = target.find( 'em' ).eq( 0 );
	if ( target_cnt.length == 0 ) {
		var target_cnt = $( '<em/>' ).prependTo( target );
	}

	var input_length = get_input_length( element, type );
	target_cnt.html( input_length );

	if ( input_length > max_length ) {
		target.addClass( 'char-limit-exceeded' );
	} else {
		target.removeClass( 'char-limit-exceeded' );
	}
}

function add_input_length_listener( element, target, max_length, type ) {
	var $ = jQuery.noConflict();

	type = typeof type !== 'undefined' ? type : 'input';

	if ( type == 'html' ) {
		var editor = element;
		var element = $( editor.composer.element );

		the_input_length( element, target, max_length, type );
		editor.composer.element.addEventListener( "keyup", function() {
			the_input_length( element, target, max_length, type );
		});
	} else {
		the_input_length( element, target, max_length, type );
		element.keyup( function( e ) {
			the_input_length( element, target, max_length, type );
		});
	}
}

jQuery( document ).ready( function( $ ) {
	// change currency and keep the POST
	jQuery( "#my_select_purchase" ).change( function( e ) {
		jQuery( '#big-search' ).attr( 'name', '' );

		var vars = getUrlVars();
		var url  = window.location.pathname + '?' + vars + 'site_currency=' + jQuery( 'select[id="my_select_purchase"]' ).val();

		var extraitems = "";
		$.each( $( ".extra-item" ), function() {
			if ( wpj_vars.extra_prch_page == 'no' && ! wpj_vars.force_allow ) {
				extraitems += '<input type="hidden" name="extra' + $(this).data("extranr") + '" value="' + $(this).data("extraamount") + '" />';
			} else {
				var $chk = $( this ).parents( 'label' ).find( '.ui.checkbox' ).find( 'input' );
				if ( $chk.filter( ":checked" ).length > 0 ) {
					extraitems += '<input type="hidden" name="extra' + $( this ).data( "extranr" ) + '" value="' + $( this ).find( ".current_amount" ).val() + '" />';
				}
			}
		});

		if ( wpj_vars.extra_prch_page == 'no' && ! wpj_vars.force_allow ) {
			var mainitem = '<input type="hidden" name="main_value_inp" value="' + $( ".payment-main-item" ).data( "mainamount" ) + '" />';
		} else {
			var mainitem = '<input type="hidden" name="main_value_inp" value="' + $( ".main_value_inp" ).val() + '" />';
		}

		var form = $(
			'<form action="' + url + '" method="post">' +
				'<input type="hidden" name="purchaseformvalidation" value="ok" />' + mainitem + extraitems +
			'</form>'
		);
		$( 'body' ).append( form );

		form.submit();
	});

	// currency on mobile
	jQuery( ".ui.dropdown.currency .item, .currency-list-mobile li" ).click( function( e ) {
		var vars = getUrlVars();

		var addressbar = window.location.href;
		if ( addressbar.indexOf( '?' ) > -1 ) {
			window.location = window.location.pathname + '?' + vars + 'site_currency=' + jQuery( this ).data( "currencyval" );
		} else {
			window.location = window.location.pathname + '?' + 'site_currency=' + jQuery(this).data( "currencyval" );
		}
	});

});

jQuery( document ).ready( function( $ ) {

	// open modal
	$( document ).on( "click", ".open-custom-offer-modal", function( e ) {

		e.preventDefault();

		var pid         = $( this ).attr( 'data-pid' );
		var page        = $( '#custom-offer-wrapper' + pid ).attr( 'data-page' );
		var action_name = $( this ).is( '.request-custom-offer' ) ? 'custom_offers_request_form' : 'custom_offer_and_extra_send_form';

		$( '.custom-offer-container.' + pid )
			.modal({
				onApprove: function() { return false; },
				onDeny: function() { return false; }
			})
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' )
			.modal( 'refresh' );

		jQuery.ajax({

			type : 'POST',
			url  : wpj_vars.ajaxurl,
			data : {
				action: action_name,
				user  : $( '#custom-offer-wrapper' + pid ).attr( 'data-user' ),
				oid   : $( '#custom-offer-wrapper' + pid ).attr( 'data-oid' ),
				pid   : $( '#custom-offer-wrapper' + pid ).attr( 'data-pid' ),
				page  : $( '#custom-offer-wrapper' + pid ).attr( 'data-page' ),
				extra : $( '#custom-offer-wrapper' + pid ).attr( 'data-extra' ),
				error : $( this ).is( '.custom-offer-error' ) ? true : false
			},
			beforeSend: function() {
				$( '.ui.button.custom-offer-btn' ).addClass( 'loading' );
			},
			success: function( data ) {
				$( '.custom-offer-content.' + page + '.' + pid ).html( data );

				// Initialize map fields
				$.fn.wpjMapsInit();

				// Initialize calendar fields
				$.fn.wpjCalendarInit();

				// Initialize tag fields
				$.fn.wpjTagsInit();

				// Initialize dropdown fields
				$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );

				$( '.custom-offer-container.' + pid ).modal( 'refresh' );
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ui.button.custom-offer-btn' ).removeClass( 'loading' );
			}
		});

		return false;
	});

	// show error message
	window.custom_offers_show_message = function( form_obj, msg ) {
		jQuery( '.custom-offers-msg-target', form_obj ).addClass( msg.cssClass );
		jQuery( '.custom-offers-msg-target', form_obj ).fadeIn().html( msg.description );
	}

	// save request
	$( document ).on( 'submit', '.request_form', function( event ) {
		event.preventDefault();

		$( '.request_form .actions .button' ).addClass( 'loading disabled' );

		var $this = $( this );
		var pid = $( this ).parents( '.custom-offer-wrapper' ).attr( 'data-pid' );

		$.ajax({
			data     : "action=custom_offer_request_save&" + $this.serialize(),
			dataType : "json",
			type     : "POST",
			url      : wpj_vars.ajaxurl,
			success: function( data ) {
				custom_offers_show_message( $this, data.message );
				$( '.request_form .actions .button' ).removeClass( 'loading disabled' );

				if ( data.message['code'] == 'success' ) {
					$( '.ui.modal.custom-offer-container.' + pid ).modal( 'hide' );

					/*** For Chat ***/
					// clear 'no message' pusher div
					jQuery( '[rel="' + data.user + '"]' ).find( '.message-box-push' ).text( '' );

					// push custom offer to chat message box
					if ( $( '.message-box-push' )[0] ) {
						if ( data.custom_offer ) {
							$( '\
								<div class="multiple-messages-wrapper">\
									<div class="message-wrapper sent" data-pm-id="' + data.pm_id + '">\
										<div class="message-text-content custom-offer" data-inverted="" data-tooltip="' + data.message_date + '" data-position="top right">\
											<div class="message-send">\
												<div class="message-custom-offer">\
													<i class="tags icon"></i>' + data.custom_offer + '\
												</div>\
											</div>\
										</div>\
									</div>\
								</div>\
							' ).insertBefore( '[rel="' + data.user + '"] .message-box-push' );

							// scroll to the last message
							$( '[rel="' + data.user + '"]' ).find( '.message-box-content' ).scrollTop( $( '[rel="' + data.user + '"]' ).find( '.message-box-content' )[0].scrollHeight );
						}
					}
					/* END for Chat */

				} else if ( data.message['code'] == 'loggged_in_error' ) {
					$( '.request_form .actions .button' ).removeClass( 'loading' );
					$( '.request_form .actions .button' ).attr( 'disabled', 'disabled' );
				}
			}
		});
	});

	// save offer and extra
	$( document ).on( 'submit', '.offer_form', function( event ){
		event.preventDefault();

		$( '.offer_form .actions .button' ).addClass( 'loading disabled' );

		var $this = $( this );
		var pid   = $( this ).parents( '.custom-offer-wrapper' ).attr( 'data-pid' );
		var page  = $( this ).parents( '.custom-offer-wrapper' ).attr( 'data-page' );

		$.ajax({
			data     : "action=custom_offer_or_extra_save&" + $this.serialize(),
			dataType : 'json',
			type     : "POST",
			url      : wpj_vars.ajaxurl,
			success: function( data ) {
				custom_offers_show_message( $this, data.message );
				$( '.offer_form .actions .button' ).removeClass( 'loading disabled' );

				if ( data.message['code'] == 'success' ) {
					$( '.ui.modal.custom-offer-container.' + pid ).modal( 'hide' );

					// push custom offer to private message page
					if ( $( ".private-message-from-user" ).length && data.message_content ) {
						$( '.private-message-from-user' ).append( data.message_content );

						$( 'html, body' ).animate({
							scrollTop: $( ".pm-holder" ).last().offset().top - 94
						}, 1000);
					}

					/*** For Chat ***/
					// clear 'no message' pusher div
					jQuery( '[rel="' + data.user + '"]' ).find( '.message-box-push' ).text( '' );

					// push custom offer to chat message box
					if ( $( '.message-box-push' )[0] ) {
						if ( data.custom_offer ) {
							$( '\
								<div class="multiple-messages-wrapper">\
									<div class="message-wrapper sent" data-pm-id="' + data.pm_id + '">\
										<div class="message-text-content custom-offer" data-inverted="" data-tooltip="' + data.message_date + '" data-position="top right">\
											<div class="message-send">\
												<div class="message-custom-offer">\
													<i class="tags icon"></i>' + data.custom_offer + '\
												</div>\
											</div>\
										</div>\
									</div>\
								</div>\
							' ).insertBefore( '[rel="' + data.user + '"] .message-box-push' );

							// scroll to the last message
							$( '[rel="' + data.user + '"]' ).find( '.message-box-content' ).scrollTop( $( '[rel="' + data.user + '"]' ).find( '.message-box-content' )[0].scrollHeight );
						}
					}
					/* END for Chat */

					// refresh page
					if ( page == 'single_request' || wpj_vars.live_notify != 'yes' ) {
						location.reload();
					}
				}
			}
		});
	});

});

jQuery( document ).ready( function( $ ) {

	/* PM page */
	if ( wpj_vars.pm_emoji_enabled != 'no' ) {

		$( "#message-pm-user" ).emojioneArea({
			pickerPosition : "top",
			filtersPosition: "top",
			searchPosition : "top",
			tonesStyle     : "bullet"
		});

	}

	/* Transaction page */
	if ( wpj_vars.transaction_emoji_enabled != 'no' ) {

		$( ".chat_box_messages" ).emojioneArea({
			pickerPosition : "top",
			filtersPosition: "top",
			searchPosition : "top",
			tonesStyle     : "bullet"
		});

	}

	// initialize emoji
	if ( wpj_vars.chat_emoji_enabled != 'no' ) { wpj_chat_emoji_init(); }

});

/* Chat */
function wpj_chat_emoji_init( class_name ) {

	class_name = typeof class_name !== 'undefined' ? class_name : '.message-box-input-content';

	if ( wpj_vars.chat_emoji_enabled != 'no' ) {

		jQuery( class_name ).emojioneArea({
			pickerPosition : "top",
			filtersPosition: "top",
			searchPosition : "top",
			tonesStyle     : "bullet",
			placeholder    : wpj_vars.write_message,
		});

	}

	return false;
}
jQuery( document ).ready( function( $ ) {
	// scroll to top button
	$( window ).scroll( function() {
		if ( $( this ).scrollTop() > 100 ) {
			$( '.scrollToTop' ).fadeIn();
		} else {
			$( '.scrollToTop' ).fadeOut();
		}
	});

	// click event to scroll to top
	$( '.scrollToTop' ).click( function() {
		$( 'html, body' ).animate( {scrollTop : 0}, 800) ;
		return false;
	});

	// add stackable class on responsive columns
	$( window ).on( 'load resize', function() {
		if ( $( this ).width() < ( 767 - 15 ) ) {
			if ( ! $( '.footer-row-social-media' ).hasClass( 'doubling' ) ) {
				$( '.footer-row-social-media' ).addClass( 'doubling' );
			}
			if ( ! $( '.footer-row-social-media' ).hasClass( 'stackable' ) ) {
				$( '.footer-row-social-media' ).addClass( 'stackable' );
			}
		} else {
			$( '.footer-row-social-media' ).removeClass( 'doubling' ).removeClass( 'stackable' );
		}
	});
});
function take_to_gateway( gateway_name, enable_popup, payment_type ) {

	if ( payment_type == 'job_purchase' ) {
		take_to_gateway_job( gateway_name, enable_popup );
	} else if ( payment_type == 'featured' ) {
		take_to_gateway_feature( gateway_name, enable_popup );
	} else if ( payment_type == 'custom_extra' ) {
		take_to_gateway_custom_extra( gateway_name, enable_popup );
	} else if ( payment_type == 'tips' ) {
		take_to_gateway_tips( gateway_name, enable_popup );
	} else if ( payment_type == 'topup' ) {
		take_to_gateway_topup( gateway_name, enable_popup );
	} else if ( payment_type == 'badge' ) {
		take_to_gateway_badge( gateway_name, enable_popup );
	}

}

function take_to_gateway_job( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	var extra_params = {};
	$.map( jQuery( '#purchase-form' ).serializeArray(), function( n, i ) { extra_params[n['name']] = n['value']; } );

	var amount = $( '.main_value_inp' ).val();
	if ( ! amount ) { amount = 1; }

	var jobid = getUrlParameter( 'jobid' );

	var extras = '';
	var extras_amounts = '';

	// Extra Fast Delivery
	if ( $( '.chk_extrafast' ).parents( '.ui.checkbox' )[0] && $( '.chk_extrafast' ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
		var extra_fast_amount = $( '.hid_extrafast' ).val();
		if ( ! extra_fast_amount ) { extra_fast_amount = 1; }

		extras += 'f|';
		extras_amounts += extra_fast_amount + '|';
	}

	// Additional Revision
	if ( $( '.chk_extrarevision' ).parents( '.ui.checkbox' )[0] && $( '.chk_extrarevision' ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
		var extra_revision_amount = $( '.hid_extrarevision' ).val();
		if ( ! extra_revision_amount ) { extra_revision_amount = 1; }

		extras += 'r|';
		extras_amounts += extra_revision_amount + '|';
	}

	// Extras
	for ( var k = 1; k <= 10; k++ ) {
		if ( $( '.chk_extra' + k ).parents( '.ui.checkbox' )[0] && $( '.chk_extra' + k ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
			var extras_amnt = $( '.hid_extra' + k ).val();
			if ( ! extras_amnt ) { extras_amnt = 1; }

			extras         += k + '|';
			extras_amounts += extras_amnt + '|';
		}
	}

	// Checkout with extras as text
	if ( wpj_vars.extra_prch_page == 'no' && ! wpj_vars.force_allow ) {

		amount = $( '.payment-main-item' ).attr( 'data-mainamount' );
		if ( ! amount ) { amount = 1; }

		jQuery( '.extra-item' ).each( function() {

			var extra_name   = $( this ).attr( 'data-extranr' );
			var extra_amount = $( this ).attr( 'data-extraamount' );

			if ( ! extra_amount ) { extra_amount = 1; }

			if ( extra_name == 'fast' ) {
				extras += 'f|';
				extras_amounts += extra_amount + '|';
			} else if ( extra_name == 'revision' ) {
				extras += 'r|';
				extras_amounts += extra_amount + '|';
			} else if ( extra_name >= 1 && extra_name <= 10 ) {
				extras += extra_name + '|';
				extras_amounts += extra_amount + '|';
			}

		});

	}

	var total_amount = $( '.total' ).attr( 'data-total' );

	var base_url = wpj_vars.blog_url;
	base_url = base_url + '/?pay_for_item=' + gateway_name;
	base_url = base_url + '&jobid=' + jobid;
	base_url = base_url + '&amount=' + amount;
	base_url = base_url + '&extras=' + extras;
	base_url = base_url + '&extras_amounts=' + extras_amounts;

	jQuery.each( extra_params, function( param_name, param_value ) {
		base_url = base_url + '&' + param_name + '=' + param_value;
	});

	var data = {
		action        : 'wpjobster_check_payment_gateway_popup',
		jobid         : jobid,
		amount        : amount,
		extras        : extras,
		extras_amounts: extras_amounts,
		gateway       : gateway_name,
		total_amount  : total_amount,
	};

	jQuery.each( extra_params, function( param_name, param_value ) {
		data[[param_name]] = param_value;
	});

	if ( enable_popup === 'yes' ) {

		jQuery.ajax({
			method  : 'GET',
			url     : base_url,
			dataType: 'text',
			data    : data,
			success: function ( output ) {
				jQuery( '.payment-gateway-popup' ).html( output );
				Hooks.do_action( 'wpj_after_gateway_popup_load' );
			}
		});

		return false;

	} else {

		take_to_gateway_window_message( base_url, gateway_name );
		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

	}
}

function take_to_gateway_custom_extra( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	var oid = getUrlParameter( 'oid' );
	var custom_extra = getUrlParameter( 'custom_extra' );

	var amount = 1;

	var base_url = wpj_vars.blog_url;
	base_url = base_url + '/?pay_for_item=' + gateway_name;
	base_url = base_url + '&payment_type=custom_extra';
	base_url = base_url + '&oid=' + oid;
	base_url = base_url + '&amount=' + amount;
	base_url = base_url + '&custom_extra=' + custom_extra;

	if ( enable_popup === 'yes' ) {

		jQuery.ajax({
			type: "GET",
			url : base_url,
			dataType: 'text',
			data: {
				action      : 'wpjobster_check_payment_gateway_popup',
				payment_type: 'custom_extra',
				oid         : oid,
				amount      : amount,
				custom_extra: custom_extra,
				gateway     : gateway_name
			},
			success: function ( output ) {
				jQuery( ".payment-gateway-popup" ).html( output );
				Hooks.do_action( 'wpj_after_gateway_popup_load' );
			}
		});

		return false;

	} else {

		take_to_gateway_window_message( base_url, gateway_name );
		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

	}
}

function take_to_gateway_tips( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	var oid = getUrlParameter( 'oid' );
	var tips_id = getUrlParameter( 'tips' );

	var amount = 1;

	var base_url = wpj_vars.blog_url;
	base_url = base_url + '/?pay_for_item=' + gateway_name;
	base_url = base_url + '&payment_type=tips';
	base_url = base_url + '&oid=' + oid;
	base_url = base_url + '&amount=' + amount;
	base_url = base_url + '&tips=' + tips_id;

	if ( enable_popup === 'yes' ) {

		jQuery.ajax({
			type: "GET",
			url: base_url,
			dataType: 'text',
			data: {
				action       : 'wpjobster_check_payment_gateway_popup',
				payment_type : 'tips',
				oid          : oid,
				amount       : amount,
				tips         : tips_id,
				gateway      : gateway_name
			},
			success: function ( output ) {
				jQuery( ".payment-gateway-popup" ).html( output );
				Hooks.do_action( 'wpj_after_gateway_popup_load' );
			}
		});

		return false;

	} else {

		take_to_gateway_window_message( base_url, gateway_name );
		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

	}
}

function take_to_gateway_feature( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	var pid = $( 'input[name="jobid"]' ).val();

	var h_date_start = $( 'input[name="h_date_start"]' ).val();
	var c_date_start = $( 'input[name="c_date_start"]' ).val();
	var s_date_start = $( 'input[name="s_date_start"]' ).val();

	var current_feature_pages = '';
	jQuery( 'input:checked[name="feature_pages[]"]' ).each( function() {
		if ( jQuery( this ).val() == 'homepage' ) current_feature_pages += "h";
		else if ( jQuery( this ).val() == 'category' ) current_feature_pages += "c";
		else if ( jQuery( this ).val() == 'subcategory' ) current_feature_pages += "s";
	});

	if ( ! current_feature_pages ) {
		$( '.ui.message' ).removeClass( 'success' ).removeClass( 'hidden' ).addClass( 'negative' ).html( wpj_vars.featured_empty );

	} else if ( gateway_name == 'credits' && parseFloat( $( '#showtotal' ).attr( 'data-total' ) ) > parseFloat( wpj_vars.user_credits ) ) {
		$( '.ui.message' ).removeClass( 'success' ).removeClass( 'hidden' ).addClass( 'negative' ).html( wpj_vars.not_enough_credits );

	} else if (
		( wpj_vars.h_date_start != h_date_start && jQuery( '#homepage_featured_chk' ).is( ":checked" ) ) ||
		( wpj_vars.c_date_start != c_date_start && jQuery( '#category_featured_chk' ).is( ":checked" ) ) ||
		( wpj_vars.s_date_start != s_date_start && jQuery( '#subcategory_featured_chk' ).is( ":checked" ) )
	) {
		$( '.ui.message' ).removeClass( 'success' ).removeClass( 'hidden' ).addClass( 'negative' ).html( wpj_vars.featured_interval );

	} else {

		var base_url = wpj_vars.blog_url;
		base_url = base_url + '/?pay_for_item=' + gateway_name;
		base_url = base_url + '&payment_type=feature';
		base_url = base_url + '&jobid=' + pid;
		base_url = base_url + '&h_date_start=' + h_date_start;
		base_url = base_url + '&c_date_start=' + c_date_start;
		base_url = base_url + '&s_date_start=' + s_date_start;
		base_url = base_url + '&feature_pages=' + current_feature_pages;

		if ( enable_popup === 'yes' ) {

			jQuery.ajax({
				type: "GET",
				url: base_url,
				dataType: 'text',
				data: {
					action        : 'wpjobster_check_payment_gateway_popup',
					payment_type  : 'feature',
					jobid         : pid,
					h_date_start  : h_date_start,
					c_date_start  : c_date_start,
					s_date_start  : s_date_start,
					feature_pages : current_feature_pages,
					gateway       : gateway_name
				},
				success: function ( output ) {
					jQuery( '.payment-gateway-popup' ).html( output );
					Hooks.do_action( 'wpj_after_gateway_popup_load' );
				}
			});

			return false;

		} else {

			take_to_gateway_window_message( base_url, gateway_name );
			if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
				window.location = base_url;
			}

		}

	}
}

function take_to_gateway_topup( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	var package_id = jQuery( 'input[name=buy_credit_amount]:checked' ).val();

	var base_url = wpj_vars.blog_url;
	base_url = base_url + '/?pay_for_item=' + gateway_name;
	base_url = base_url + '&payment_type=' + 'topup';
	base_url = base_url + '&package_id=' + package_id;

	var data = {
		action        : 'wpjobster_check_payment_gateway_popup',
		package_id    : package_id,
		payment_type  : 'topup',
		gateway       : gateway_name,
	};

	if ( package_id >= '1' ) {

		if ( enable_popup === 'yes' ) {

			jQuery.ajax({
				method  : 'GET',
				url     : base_url,
				dataType: 'text',
				data    : data,
				success: function ( output ) {
					jQuery( '.payment-gateway-popup' ).html( output );
					Hooks.do_action( 'wpj_after_gateway_popup_load' );
				}
			});

			return false;

		} else {

			base_url = wpj_vars.blog_url + '/?pay_for_item=' + gateway_name + '&payment_type=topup&package_id=' + package_id;
			take_to_gateway_window_message( base_url, gateway_name );
			if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
				window.location.href = base_url;
			}

		}

	} else {
		$( '.error-wrapper' ).removeClass( 'hidden' ).html( '<i class="close icon"></i><div class="header">' + wpj_vars.err + '</div><p>' + wpj_vars.topup_package_empty + '</p>' );
	}
}

function take_to_gateway_topup_process( act, topup_oid, gateway_name, package_id ) {

	var $ = jQuery.noConflict();

	if ( act == 'process' ) {

		base_url = wpj_vars.blog_url + '/?pay_for_item=' + gateway_name + '&payment_type=topup&order_id=' + topup_oid + '&package_id=' + package_id + '&process_pending=1';

		take_to_gateway_window_message( base_url, gateway_name );

		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

		return;

	} else {

		jQuery.ajax({
			type : "POST",
			url  : wpj_vars.ajaxurl,
			data : {
				action          : 'cancel_topup_pending_order',
				order_id        : topup_oid,
				payment_gateway : gateway_name
			},
			success: function( msg ) {
				window.location.reload();
			}
		});

	}

}

function take_to_gateway_badge( gateway_name, enable_popup ) {

	var $ = jQuery.noConflict();

	if ( isNaN( $( '#showtotal' ).attr( 'data-total' ) ) || $( '#showtotal' ).attr( 'data-total' ) == 0 ) {
		$( '.ui.message' ).removeClass( 'success' ).removeClass( 'hidden' ).addClass( 'negative' ).html( wpj_vars.badge_empty );

	} else if ( parseFloat( $( '#showtotal' ).attr( 'data-total' ) ) > parseFloat( wpj_vars.user_credits ) ) {
		$( '.ui.message' ).removeClass( 'hidden' ).html( wpj_vars.not_enough_credits );

	} else {
		var badge = [];

		jQuery( 'input:checked[name="badges[]"]' ).each( function() {
			badge.push( $( this ).val() );
		});

		jQuery( 'input:checked[name="badges_bought[]"]' ).each( function() {
			badge.push( $( this ).val() );
		});

		badge.sort();

		$.ajax({
			url: wpj_vars.ajaxurl,
			type: 'POST',
			data: {
				action      : 'update_badge_user',
				uid         : wpj_vars.uid,
				badge       : badge,
				badges_price: $( '#showtotal' ).attr( 'data-total' )
			},
			success: function ( text ) {
				window.location = wpj_vars.my_account_url;
			}
		});

	}
}

function take_to_gateway_subscription( gateway_name, enable_popup, uid, sub_amount, sub_type, sub_level, sub_usr_type ) {

	var $ = jQuery.noConflict();

	base_url = wpj_vars.blog_url;
	base_url = base_url + '/?pay_for_item=' + gateway_name;
	base_url = base_url + '&payment_type='  + 'subscription';
	base_url = base_url + '&user_id='       + uid;
	base_url = base_url + '&sub_amount='    + sub_amount;
	base_url = base_url + '&sub_type='      + sub_type;
	base_url = base_url + '&sub_level='     + sub_level;
	base_url = base_url + '&sub_usr_type='  + sub_usr_type;

	if ( enable_popup === 'yes' ) {

		jQuery.ajax({
			type: "POST",
			url : wpj_vars.ajaxurl,
			data: {
				action      : 'wpjobster_check_payment_gateway_popup',
				user_id     : uid,
				payment_type: 'subscription',
				sub_amount  : sub_amount,
				sub_type    : sub_type,
				sub_level   : sub_level,
				sub_usr_type: sub_usr_type,
				gateway     : gateway_name
			},
			success: function ( output ) {
				jQuery( ".payment-gateway-popup" ).html( output );
				Hooks.do_action( 'wpj_after_gateway_popup_load' );
			}
		});

	} else {

		take_to_gateway_window_message( base_url, gateway_name );
		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

	}
}

function take_to_gateway_cancel_order( act, order_id, payment_gateway ) {

	var $ = jQuery.noConflict();

	if ( act == 'process' ) {

		base_url = wpj_vars.blog_url + '/?pay_for_item=' + payment_gateway + '&order_id=' + order_id + '&process_pending=1';

		take_to_gateway_window_message( base_url, payment_gateway );

		if ( ! ( typeof wpj_vars !== 'undefined' && wpj_vars.is_in_app == 'true' ) ) {
			window.location = base_url;
		}

		return;

	} else {

		jQuery.ajax({
			type   : "POST",
			url    : wpj_vars.ajaxurl,
			data   : "action=cancel_pending_order&process=" + act + "&order_id=" + order_id,
			success: function( msg ) {
				window.location.reload();
			}
		});

	}
}

function take_to_gateway_window_message( base_url, gateway ) {

	var $ = jQuery.noConflict();

	if ( gateway && gateway != 'credits' && gateway != 'cod' && gateway != 'banktransfer' ) {
		window.parent.postMessage( {data: {
			isExternal    : true,
			isTargetBlank : false,
			currentUrl    : window.location.href,
			externalUrl   : base_url
		}}, "*" );
	} else {
		window.parent.postMessage( {data: {
			isExternal    : false,
			isTargetBlank : false,
			currentUrl    : window.location.href,
			nextUrl       : base_url
		}}, "*" );

		window.location = base_url;
	}
}

// Prevent multiple clicks
jQuery( document ).ready( function( $ ) {
	$( '.payment-gateways .button' ).on( 'click', function( e ) {
		$( this ).parents( '.payment-gateways' ).find( '.button' ).addClass( 'disabled' );
	});
});

function wpj_cancel_featured_order( feature_oid, gateway ) {

	jQuery.ajax({
		type : "POST",
		url  : wpj_vars.ajaxurl,
		data : {
			action          : 'featured_order_cancel',
			order_id        : feature_oid,
			payment_gateway : gateway
		},
		success: function( msg ) {
			window.location.reload();
		}
	});
}
var graph_page = '';
if ( wpj_vars.is_page_my_account == 1 ) {
	graph_page = 'my_account';
} else if ( wpj_vars.is_page_my_sales == 1 ) {
	graph_page = 'sales';
} else if ( wpj_vars.is_page_my_shopping == 1 ) {
	graph_page = 'shopping';
}

function get_wpjobster_graph() {

	if ( graph_page && jQuery( ".chart-wrapper" )[0] ) {

		disp_type    = jQuery( "#disp_type" ).val();
		select_year  = jQuery( "#select_year select[name=select_year]" ).val();
		select_month = jQuery( "#select_month select[name=select_month]" ).val();

		jQuery.ajax({
			url: wpj_vars.ajaxurl,
			data: {
				'uid'         : wpj_vars.uid,
				'action'      : 'get_wpjobster_graph',
				'disp_type'   : disp_type,
				'select_year' : select_year,
				'select_month': select_month,
				'graph_page'  : graph_page

			},
			success:function( json_data ) {
				chart_data   = JSON.parse( json_data );
				chart_data2  = eval( chart_data['data_table'] );
				data         = google.visualization.arrayToDataTable( chart_data2 );

				drawChart();
			},
			error: function( errorThrown ) {}
		});

	}
}

if ( graph_page && jQuery( ".chart-wrapper" )[0] ) {
	jQuery( document ).ready( function( $ ) {

		$( ".graph-button" ).click( function() {

			$( "#disp_type" ).val( $( "input[name=disp_type]:checked" ).val() );

			if ( $( "#disp_type" ).val() == 'lastweek' || $( "#disp_type" ).val() == 'all' ) {
				$( "#form_graph" ).removeClass( "hidden" );
				$( "#form_graph" ).addClass( "hidden" );
				$( "#select_month" ).removeClass( "hidden" );
				$( "#select_month" ).addClass( "hidden" );
				get_wpjobster_graph();
			} else if ( $( "#disp_type" ).val() == 'month' ){
				$( "#form_graph" ).removeClass( "hidden" );
				$( "#select_month" ).removeClass( "hidden" );
			} else if ( $( "#disp_type" ).val() == 'year' ) {
				$( "#form_graph" ).removeClass( "hidden" );
				$( "#select_month" ).removeClass( "hidden" );
				$( "#select_month" ).addClass( "hidden" );
			}

		});

	});

	jQuery( document ).ready( function( $ ) {
		google.charts.load( 'current', {'packages' : ['corechart']} );
		google.charts.setOnLoadCallback( drawChart );
	});
}

function drawChart() {

	if ( wpj_vars.is_rtl == 'true' ) {
		vAxis_val = { minValue: 0, reverseAxis: true, legend: { position: "top" } };
	} else {
		vAxis_val = { minValue: 0 };
	}

	if ( graph_page && wpj_vars.data_table && jQuery( ".chart-wrapper" )[0] ) {

		if ( typeof data == 'undefined' ) {
			data_table = wpj_vars.data_table;
			data_table = data_table.replace( /'/g, '"' );
			data = google.visualization.arrayToDataTable( JSON.parse( data_table ) );
		}

		if ( graph_page == 'my_account' ) {
			var options = {
				hAxis: {
					titleTextStyle: {color: '#333'}
				},
				vAxis: vAxis_val,
				colors: ['#BEEC78', '#119EE2', '#FFBE00', '#65BEE9', '#83C124']
			};
		} else if ( graph_page == 'sales' ) {
			var options = {
				hAxis: {
					titleTextStyle: {color: '#333'}
				},
				vAxis: vAxis_val,
				colors: ['#BEEC78', '#FFBE00', '#65BEE9', '#83C124', '#83C124']
			};
		} else if ( graph_page == 'shopping' ) {
			var options = {
				hAxis: {
					titleTextStyle: {color: '#333'}
				},
				vAxis: vAxis_val,
				colors: ['#BEEC78', '#FFBE00', '#119EE2', '#83C124', '#83C124']
			};
		} else {
			var options = {
				hAxis: {
					titleTextStyle: {color: '#333'}
				},
				vAxis: vAxis_val,
				colors: ['#83C124', '#83C0D8', '#03C0D8', '#f3CaD8', '#8fCbD8']
			};
		}

		var chart = new google.visualization.AreaChart( document.getElementById( 'chart_div' ) );
		chart.draw( data, options );

	}
}
// fire on document ready
jQuery( document ).ready( function( $ ) {
	if ( wpj_vars.html5_geolocation == 'yes' ) {
		wpj_geolocation_autofill(); // try from cookies
		wpj_geolocation_get(); // fetch from browser + google places api
	}
});

// prompt browser html5 geolocation
function wpj_geolocation_get() {
	if ( navigator.geolocation ) {
		navigator.geolocation.getCurrentPosition( wpj_geolocation_success );
	}
}

// use google places api to fetch location name based on lat + lng
function wpj_geolocation_success( position ) {
	var lat = position.coords.latitude;
	var lng = position.coords.longitude;

	// check if input exists or cokie never set (so we limit requests)
	if ( ( jQuery( '.js-location-autocomplete' ).length
		|| jQuery.cookie( 'wpj_location' ) == undefined
		|| jQuery.cookie( 'wpj_lat' ) == undefined
		|| jQuery.cookie( 'wpj_lng' ) == undefined
	) ) {

		var city = '';
		var state = '';
		var country = '';
		var location = '';

		// Google Places API
		if ( wpj_vars.locations_api === '' || wpj_vars.locations_api === 'google'
			&& typeof google !== 'undefined'
		) {

		var geocoder = new google.maps.Geocoder();
		var latlng = new google.maps.LatLng(lat, lng);

		// perform an educated guess for city, state and country
		geocoder.geocode({'latLng': latlng}, function(results, status) {
			if ( status == google.maps.GeocoderStatus.OK ) {
				if ( results[1] ) {
					geocode_loop:
					for ( var i = 0; i < results[0].address_components.length; i++ ) {
						for ( var j = 0; j < results[0].address_components[i].types.length; j++ ) {

							// avoid multiple loops by checking all at once
							// do not overwrite
							if ( city == ''
								&& ( results[0].address_components[i].types[j] == "locality"
									|| results[0].address_components[i].types[j] == "administrative_area_level_2" ) ) {
								city = results[0].address_components[i].long_name;
							}

							if ( state == ''
								&& results[0].address_components[i].types[j] == "administrative_area_level_1" ) {
								state = results[0].address_components[i].long_name;
							}

							if ( country == ''
								&& results[0].address_components[i].types[j] == "country" ) {
								country = results[0].address_components[i].long_name;
							}

							// break loops when we have all data
							if ( city != '' && state != '' && country != '' ) {
								break geocode_loop;
							}
						}
					}

					location = city;
					location += ( state != '' ) ? ', ' + state : '';
					location += ( country != '' ) ? ', ' + country : '';

					// autofill input
					wpj_geolocation_autofill( location, lat, lng );
				}
			}
		});

		}

		// TomTom Search API
		else if ( wpj_vars.locations_api === 'tomtom' ) {
			jQuery.ajax({
				type: 'GET',
				url: 'https://api.tomtom.com/search/2/reverseGeocode/' + lat + ',' + lng + '.json?key=' + wpj_vars.tomtom_api_key,
				dataType: 'json',
				success: function( response ) {
					if ( response.addresses[0] ) {
						location = response.addresses[0].address.freeformAddress;
						wpj_geolocation_autofill( location, lat, lng );
					}
				},
				error: function( response ) {
					console.log( 'Error: ' + response );
				},
			});
		}
	}
}

// store cookies and autofill inputs
function wpj_geolocation_autofill( location, lat, lng ) {
	// autofill from cookies, if google places api doesn't work or is slow
	if ( location !== undefined
		&& lat !== undefined
		&& lng !== undefined
	) {
		jQuery.cookie( 'wpj_location', location, { expires: 7, path: '/' } );
		jQuery.cookie( 'wpj_lat', lat, { expires: 7, path: '/' } );
		jQuery.cookie( 'wpj_lng', lng, { expires: 7, path: '/' } );
	} else {
		location = jQuery.cookie( 'wpj_location' );
		lat = jQuery.cookie( 'wpj_lat' );
		lng = jQuery.cookie( 'wpj_lng' );
	}

	// autofill only if all values are populated and input exists
	if ( location != '' && lat != '' && lng != ''
		&& jQuery( '.js-location-autocomplete' ).length ) {
		jQuery( '.js-location-autocomplete' ).each( function() {

			// do not autofill if user edited/editing the field
			// do not autofill after first search query (already filled or emptied by the user)
			var location_input = jQuery( this );
			if ( ! location_input.is( 'input' ) ) {
				location_input = location_input.find( 'input' );
			}

			if ( ( getUrlParameter( 'location' ) === undefined
				&& getUrlParameter( 'latitude' ) === undefined
				&& getUrlParameter( 'longitude' ) === undefined )
				&& ( location_input.val() == '' || location_input.attr( 'data-autofilled' ) )
				&& ! location_input.is( ':focus' )
			) {
				// allow cookie based autofill to be overwritten by api
				location_input.attr( 'data-autofilled', 'true' );
				location_input.val( location ).trigger( 'change' );
				location_input.next( 'input' ).val( lat ).trigger( 'change' );
				location_input.next( 'input' ).next( 'input' ).val( lng ).trigger( 'change' );
			}

			// stop autofill if user edited
			location_input.focus( function() {
				location_input.removeAttr( 'data-autofilled' );
			});
		});
	}
}

//-> FUNCTIONS for validation type
function wpj_aoe_empty( name ) {
	var i = arguments.length > 1 && arguments[1] ? arguments[1] : '';

	var empty_ret = {
		type   : 'empty',
		prompt : wpj_vars[name + i],
	}

	return empty_ret;
}

function wpj_aoe_min_length( name ) {
	var min_no = arguments.length > 1 && arguments[1] ? arguments[1] : 0;
	var i      = arguments.length > 2 && arguments[2] ? arguments[2] : '';

	var min_length_ret = {
		type   : 'minLength[' + min_no + ']',
		prompt : wpj_vars[name + i],
	}

	return min_length_ret;
}

function wpj_aoe_max_length( name ) {
	var max_no = arguments.length > 1 && arguments[1] ? arguments[1] : 0;
	var i      = arguments.length > 2 && arguments[2] ? arguments[2] : '';
	var field  = arguments.length > 3 && arguments[3] ? arguments[3] : null;

	var fnc_type = field == 'job_description' ? 'maxLengthDesc[' + max_no + ']' : 'maxLength[' + max_no + ']';

	var max_length_ret = {
		type   : fnc_type,
		prompt : wpj_vars[name + i],
	}

	return max_length_ret;
}

function wpj_aoe_number( name ) {
	var i = arguments.length > 1 && arguments[1] ? arguments[1] : '';

	var number_ret = {
		type   : 'number',
		prompt : wpj_vars[name + i],
	}

	return number_ret;
}

function wpj_aoe_greater_than_or_equal( name ) {
	var min_no = arguments.length > 1 && arguments[1] ? arguments[1] : 0;
	var i      = arguments.length > 2 && arguments[2] ? arguments[2] : '';

	var greater_than_ret = {
		type   : 'greaterThan[' + min_no + ']',
		prompt : wpj_vars[name + i]
	}

	return greater_than_ret;
}

function wpj_aoe_less_than_or_equal( name ) {
	var max_no = arguments.length > 1 && arguments[1] ? arguments[1] : 0;
	var i      = arguments.length > 2 && arguments[2] ? arguments[2] : '';

	var less_than_ret = {
		type   : 'lessThan[' + max_no + ']',
		prompt : wpj_vars[name + i],
	}

	return less_than_ret;
}

function wpj_aoe_instant_file_upload() {
	var instant_file_upload_ret = {
		type   : 'instant_file_upload',
		prompt : wpj_vars.job_instant_file_blank,
	}

	return instant_file_upload_ret;
}

function wpj_aoe_audio_file_upload() {
	var audio_file_upload_ret = {
		type   : 'audio_file_upload',
		prompt : wpj_vars.job_audio_blank,
	}

	return audio_file_upload_ret;
}

function wpj_aoe_image_file_upload() {
	var image_file_upload_ret = {
		type   : 'image_file_upload',
		prompt : wpj_vars.job_image_blank,
	}

	return image_file_upload_ret;
}

function wpj_aoe_image_file_upload_error() {
	var image_file_upload_error_ret = {
		type   : 'image_file_upload_error',
		prompt : wpj_vars.job_image_error,
	}

	return image_file_upload_error_ret;
}

function wpj_aoe_faq() {
	var faq_ret = {
		type   : 'faq_validation',
		prompt : wpj_vars.job_faq_blank,
	}

	return faq_ret;
}

function wpj_aoe_video() {
	var video_ret = {
		type   : 'video_validation',
		prompt : wpj_vars.job_video_invalid,
	}

	return video_ret;
}

function wpj_aoe_i_agree() {
	var i_agree_ret = {
		type   : 'checked',
		prompt : wpj_vars.job_tos_uncheck,
	}

	return i_agree_ret;
}

//-> FUNCTION for max days validation
function wpj_aoe_max_days_validation( $this, fields_arr ) {
	if ( $this.val() == "instant" && jQuery( 'select[name="price_type"]' ).val() != 'package' ) {
		fields_arr.instant_delivery = {
			identifier : 'hidden_files_instant_job_attachments',
			rules: [ wpj_aoe_instant_file_upload() ]
		}
	} else {
		delete fields_arr.instant_delivery;
	}
	wpj_aoe_execute_form_validation( fields_arr );
}

//-> FUNCTION for extra fast delivery validation
function wpj_aoe_efd_validation( $this, fields_arr ) {
	if ( $this.prop( 'checked' ) && wpj_vars.max_days_enabled != 'no' ) {
		var amount_jobefdprice_min = wpj_vars.amount_jobextra_price_min;
		var amount_jobefdprice_max = wpj_vars.amount_jobextra_price_max;
		if ( amount_jobefdprice_max ) {
			var max_amount_efdprice_rule = wpj_aoe_less_than_or_equal( 'job_efd_price_max', amount_jobefdprice_max );
		} else {
			var max_amount_efdprice_rule = { type: 'noValidation' };
		}

		if ( jQuery( 'select[name="price_type"]' ).val() == 'package' ) {
			var pck_max_days_values = jQuery( "select[name='package_max_days[]']" ).map( function() { return jQuery( this ).val(); } ).get();
			var amount_jobefdmaxdays_min = Math.max.apply( Math, pck_max_days_values );
		} else {
			var amount_jobefdmaxdays_min = jQuery( '#max_days' ).val();
		}

		var max_days_fast_validation = jQuery( '#max_days_fast' ).val() != 'instant' ? wpj_aoe_less_than_or_equal( 'job_efd_max_days_max', amount_jobefdmaxdays_min ) : { type: 'noValidation' };

		fields_arr.efd_price = {
			identifier : 'extra_fast_price',
			rules: [
				wpj_aoe_empty( 'job_efd_price_blank' ),
				wpj_aoe_number( 'job_efd_price_numeric' ),
				wpj_aoe_greater_than_or_equal( 'job_efd_price_min', amount_jobefdprice_min ),
				max_amount_efdprice_rule
			]
		}

		fields_arr.efd_max_days = {
			identifier : 'max_days_fast',
			rules: [ wpj_aoe_empty( 'job_efd_max_days_blank' ), max_days_fast_validation ]
		}
	} else {
		delete fields_arr.efd_price;
		delete fields_arr.efd_max_days;

		$this.parents( '.field' ).siblings( '.two.fields' ).children( '.field' ).removeClass( 'error' );
	}
	wpj_aoe_execute_form_validation( fields_arr );
}

//-> FUNCTION for additional revision validation
function wpj_aoe_ar_validation( $this, fields_arr ) {
	if ( $this.prop( 'checked' ) ) {
		var amount_jobarprice_min = wpj_vars.amount_jobextra_price_min;
		var amount_jobarprice_max = wpj_vars.amount_jobextra_price_max;
		if ( amount_jobarprice_max ) {
			var max_amount_arprice_rule = wpj_aoe_less_than_or_equal( 'job_ar_price_max', amount_jobarprice_max );
		} else {
			var max_amount_arprice_rule = { type: 'noValidation' };
		}

		fields_arr.ar_price = {
			identifier : 'extra_revision_price',
			rules: [
				wpj_aoe_empty( 'job_ar_price_blank' ),
				wpj_aoe_number( 'job_ar_price_numeric' ),
				wpj_aoe_greater_than_or_equal( 'job_ar_price_min', amount_jobarprice_min ),
				max_amount_arprice_rule
			]
		}

		fields_arr.ar_max_days = {
			identifier : 'max_days_revision',
			rules: [ wpj_aoe_empty( 'job_ar_max_days_blank' ) ]
		}
	} else {
		delete fields_arr.ar_price;
		delete fields_arr.ar_max_days;

		$this.parents( '.field' ).siblings( '.three.fields' ).children( '.field' ).removeClass( 'error' );
	}
	wpj_aoe_execute_form_validation( fields_arr );
}

//-> FUNCTION for extra validation
function wpj_aoe_extra_validation( $this, fields_arr, i, cond ) {
	var amount_jobextraprice_min = wpj_vars.amount_jobextra_price_min;
	var amount_jobextraprice_max = wpj_vars.amount_jobextra_price_max;
	if ( amount_jobextraprice_max ) {
		var max_amount_extraprice_rule = wpj_aoe_less_than_or_equal( 'job_extra_price_max', amount_jobextraprice_max );
	} else {
		var max_amount_extraprice_rule = { type: 'noValidation' };
	}

	var characters_jobextra_description_min = wpj_vars.characters_extradesc_min;
	var characters_jobextra_description_max = wpj_vars.characters_extradesc_max;

	if ( cond ) {
		fields_arr['job_extra_description' + i] = {
			identifier : 'extra' + i + '_content',
			rules: [
				wpj_aoe_empty( 'job_extra_desc_blank', i ),
				wpj_aoe_min_length( 'job_extra_desc_min', characters_jobextra_description_min ),
				wpj_aoe_max_length( 'job_extra_desc_max', characters_jobextra_description_max )
			],
		}

		fields_arr['job_extra_price' + i] = {
			identifier : 'extra' + i + '_price',
			rules: [
				wpj_aoe_empty( 'job_extra_price_blank', i ),
				wpj_aoe_number( 'job_extra_price_numeric' ),
				wpj_aoe_greater_than_or_equal( 'job_extra_price_min', amount_jobextraprice_min ),
				max_amount_extraprice_rule
			]
		}

		fields_arr['job_extra_max_days' + i] = {
			identifier : 'max_days_' + i,
			rules: [ wpj_aoe_empty( 'job_extra_max_days_blank', i ) ]
		}
	} else {
		delete fields_arr['job_extra_description' + i];
		delete fields_arr['job_extra_price' + i];
		delete fields_arr['job_extra_max_days' + i];

		$this.siblings( '.three.fields' ).children( '.field' ).removeClass( 'error' );
		$this.siblings( '.extra_description' ).removeClass( 'error' );
	}
}

//-> FUNCTION for packages validation
function wpj_aoe_packages_validation( $this ,fields_arr ) {
	if ( $this.val() == 'package' ) {

		delete fields_arr.price;
		delete fields_arr.max_days;

		for ( var i = 0; i < 3; i++ ) {
			var min_pck_title = wpj_vars.characters_job_package_title_min;
			var max_pck_title = wpj_vars.characters_job_package_title_max;
			fields_arr['package_name' + i] = {
				identifier : 'package_name' + i,
				rules: [
					wpj_aoe_empty( 'job_pck_name_blank', i + 1 ),
					wpj_aoe_min_length( 'job_pck_name_min', min_pck_title, i + 1 ),
					wpj_aoe_max_length( 'job_pck_name_max', max_pck_title, i + 1 )
				]
			}

			var min_pck_description = wpj_vars.characters_job_package_description_min;
			var max_pck_description = wpj_vars.characters_job_package_description_max;
			fields_arr['package_description' + i] = {
				identifier : 'package_description' + i,
				rules: [
					wpj_aoe_empty( 'job_pck_description_blank', i + 1 ),
					wpj_aoe_min_length( 'job_pck_description_min', min_pck_description, i + 1 ),
					wpj_aoe_max_length( 'job_pck_description_max', max_pck_description, i + 1 )
				]
			}

			var min_pck_price = wpj_vars.amount_job_pacakger_price_min;
			var max_pck_price = wpj_vars.amount_job_pacakger_price_max;
			if ( max_pck_price ) {
				max_pck_price_rule = wpj_aoe_less_than_or_equal( 'job_pck_price_max', max_pck_price, i + 1 );
			} else {
				max_pck_price_rule = { type: 'noValidation' };
			}

			fields_arr['package_price' + i] = {
				identifier : 'package_price' + i,
				rules: [
					wpj_aoe_empty( 'job_pck_price_blank', i + 1 ),
					wpj_aoe_number( 'job_pck_price_numeric', i + 1 ),
					wpj_aoe_greater_than_or_equal( 'job_pck_price_min', min_pck_price, i + 1 ),
					max_pck_price_rule
				]
			}
		}

		wpj_aoe_max_days_validation( jQuery( 'select[name="price_type"]' ), fields_arr );

	} else {

		for ( var i = 0; i < 3; i++ ) {
			delete fields_arr['package_name' + i];
			delete fields_arr['package_description' + i];
			delete fields_arr['package_price' + i];
		}

		var amount_jobprice_min = wpj_vars.amount_jobprice_min;
		var amount_jobprice_max = wpj_vars.amount_jobprice_max;
		if ( amount_jobprice_max ) {
			var max_amount_jobprice_rule = wpj_aoe_less_than_or_equal( 'job_price_max', amount_jobprice_max );
		} else {
			var max_amount_jobprice_rule = { type: 'noValidation' };
		}
		fields_arr.price = {
			identifier : 'job_cost',
			rules: [
				wpj_aoe_empty( 'job_price_blank' ),
				wpj_aoe_number( 'job_price_numeric' ),
				wpj_aoe_greater_than_or_equal( 'job_price_min', amount_jobprice_min ),
				max_amount_jobprice_rule
			]
		}

		fields_arr.max_days = {
			identifier : 'max_days',
			rules: [ wpj_aoe_empty( 'job_max_days_blank' ) ]
		}

		wpj_aoe_max_days_validation( jQuery( '#max_days' ), fields_arr );
		jQuery( '#max_days' ).change( function() {
			wpj_aoe_max_days_validation( jQuery( this ), fields_arr );
		});
	}
	wpj_aoe_execute_form_validation( fields_arr );
}

//-> MAIN FUNCTION that contain the fields and the events
function wpj_aoe_validate_form() {

	var job_title_min                 = wpj_vars.characters_job_title_min;
	var job_title_max                 = wpj_vars.characters_job_title_max;
	var characters_jobdescription_min = wpj_vars.characters_job_desc_min;
	var characters_jobdescription_max = wpj_vars.characters_job_desc_max;
	var characters_jobinstr_min       = wpj_vars.characters_job_instr_min;
	var characters_jobinstr_max       = wpj_vars.characters_job_instr_max;
	var wpjobster_shipping_enable     = wpj_vars.op_enable_shipping;
	var wpjobster_image_mandatory     = wpj_vars.op_mandatory_job_image;
	var wpjobster_audio_mandatory     = wpj_vars.op_mandatory_job_audio;
	var wpjobster_audio_enable        = wpj_vars.op_enable_audio;
	var wpjobster_tos_type            = wpj_vars.op_enable_tos;

	if ( localStorage.getItem( 'validate_subcat' ) == 'no' ) {
		var sub_cat_rule = { type: 'noValidation' };
	} else {
		var sub_cat_rule = wpj_aoe_empty( 'job_subcategory_blank' );
	}

	var fields_arr = {};

	fields_arr.title = {
		identifier: 'job_title',
		rules: [ wpj_aoe_empty( 'job_title_blank' ), wpj_aoe_min_length( 'job_title_min', job_title_min ), wpj_aoe_max_length( 'job_title_max', job_title_max ) ],
	}

	fields_arr.category = {
		identifier: 'job_cat',
		rules: [ wpj_aoe_empty( 'job_category_blank' ) ]
	}

	fields_arr.subcategory = {
		identifier: 'subcat',
		rules: [ sub_cat_rule ]
	}

	fields_arr.description = {
		identifier: 'job_description',
		rules: [ wpj_aoe_empty( 'job_description_blank' ), wpj_aoe_min_length( 'job_description_min', characters_jobdescription_min ), wpj_aoe_max_length( 'job_description_max', characters_jobdescription_max, null, 'job_description' ) ],
	}

	if ( jQuery( 'textarea[name="instruction_box"]' ).attr( 'data-required' ) == 'true' ) {
		fields_arr.buyer_instruction = {
			identifier: 'instruction_box',
			rules: [ wpj_aoe_empty( 'job_instructions_blank' ), wpj_aoe_min_length( 'job_instructions_min', characters_jobinstr_min ), wpj_aoe_max_length( 'job_instructions_max', characters_jobinstr_max ) ],
		}
	}

	if ( jQuery( '.faq-question' ).attr( 'data-required' ) == 'true' ) {
		fields_arr.faq = {
			identifier: 'faq_question[]',
			rules: [ wpj_aoe_faq() ],
		}
	}

	if ( wpjobster_shipping_enable == 'yes' ) {
		fields_arr.shipping = {
			identifier: 'job_shipping',
			rules: [ wpj_aoe_number( 'job_shipping_numeric' ), ]
		}
	}

	wpj_aoe_packages_validation( jQuery( 'select[name="price_type"]' ), fields_arr );
	jQuery( document ).on( "change", 'select[name="price_type"]', function() {
		wpj_aoe_packages_validation( jQuery( this ), fields_arr );
	});

	if ( wpjobster_image_mandatory == 'yes' ) {
		fields_arr.image = {
			identifier: 'images_order',
			rules: [ wpj_aoe_image_file_upload(), wpj_aoe_image_file_upload_error() ]
		}
	}

	fields_arr.video = {
		identifier: 'video_link[]',
		rules: [ wpj_aoe_video() ]
	}

	if ( wpjobster_audio_mandatory == 'yes' && wpjobster_audio_enable == 'yes' ) {
		fields_arr.audio = {
			identifier: 'audio_file_upload',
			rules: [ wpj_aoe_audio_file_upload() ]
		}
	}

	wpj_aoe_efd_validation( jQuery( '#enable_extra_fast' ), fields_arr );
	jQuery( '#enable_extra_fast, #max_days_fast, #max_days' ).change( function() {
		wpj_aoe_efd_validation( jQuery( '#enable_extra_fast' ), fields_arr );
	});

	wpj_aoe_ar_validation( jQuery( '#enable_extra_revision' ), fields_arr );
	jQuery( '#enable_extra_revision' ).change( function() {
		wpj_aoe_ar_validation( jQuery( this ), fields_arr );
	});

	jQuery( document ).on( "change", ".extra_enable", function() {
		$id_arr = jQuery( this ).find( 'input:checkbox' ).attr( 'id' ).split( '_' );
		wpj_aoe_extra_validation( jQuery( this ), fields_arr, parseInt( $id_arr[2] ), jQuery( this ).find( 'input:checkbox' ).prop( 'checked' ) );
		wpj_aoe_execute_form_validation( fields_arr );
	});

	for ( var i = 1; i <= 10; i++ ) {
		wpj_aoe_extra_validation( jQuery( '#enable_extra_' + i ), fields_arr, i, jQuery( '#enable_extra_' + i ).prop( 'checked' ) );
	}

	if ( wpjobster_tos_type != 'disabled' ) {
		fields_arr.terms = {
			identifier: 'i_agree',
			rules: [ wpj_aoe_i_agree() ]
		}
	}

	Hooks.do_action( 'wpj_before_execute_job_form_validation', fields_arr );

	// On LOAD //
	wpj_aoe_execute_form_validation( fields_arr );
}

//-> Execute the FORM
function wpj_aoe_execute_form_validation( fields_arr ) {

	fields_arr = Hooks.apply_filters( 'wpj_fields_validation_filter', fields_arr, 'job' );

	jQuery( '#add-edit-job-form' ).form({
		on: 'blur',
		keyboardShortcuts: false,
		fields: fields_arr,
	});
}

jQuery( document ).ready( function( $ ) {

	//-> FUNCTION for validations
	$.fn.form.settings.rules.maxLengthDesc = function ( inputValue, validationValue ) {
		if ( jQuery( ".char-count" ).length ) {
			inputValue = jQuery( "#job_description_field .char-count" ).children( "em" ).html();
		} else if ( jQuery( "#chars_counter" ).length ) {
			inputValue = jQuery( "#job_description_field #chars_counter" ).html();
		} else {
			inputValue = jQuery( "#job_description_field .charscounter" ).html();
		}
		return parseFloat( inputValue ) <= parseFloat( validationValue );
	}
	$.fn.form.settings.rules.greaterThan = function ( inputValue, validationValue ) {
		return parseFloat( inputValue ) >= parseFloat( validationValue );
	}
	$.fn.form.settings.rules.lessThan = function ( inputValue, validationValue ) {
		return parseFloat( inputValue ) <= parseFloat( validationValue );
	}
	$.fn.form.settings.rules.noValidation = function () {
		return true;
	}
	$.fn.form.settings.rules.instant_file_upload = function () {
		var validation_complete = true;

		if ( jQuery( "#job_instant_delivery_field .pm-attachments" ).length ) {
			if ( jQuery( "#job_instant_delivery_field .pm-attachments" ).text().length <= 0 ) {
				if ( jQuery( "#uploadifive-file_upload_instant_job_attachments-queue" ).html().length <= 0 ) {
					validation_complete = false;
				} else {
					validation_complete = true;
				}
			} else {
				validation_complete = true;
			}
		} else if ( jQuery( "#uploadifive-file_upload_instant_job_attachments-queue" ).html().length <= 0 ) {
			validation_complete = false;
		} else {
			validation_complete = true;
		}

		if ( validation_complete ) {
			return true;
		} else {
			return false;
		}
	}
	$.fn.form.settings.rules.audio_file_upload = function () {
		if ( jQuery( ".audio_uploaded" ).length ) {
			return true;
		} else {
			return false;
		}
	}
	$.fn.form.settings.rules.image_file_upload = function () {
		if ( jQuery( "#dropzone-jobimages" ).find( '.dz-complete' ).length || $.trim( jQuery( '#thumbnails' ).html() ).length ) {
			return true;
		} else {
			return false;
		}
	}
	$.fn.form.settings.rules.image_file_upload_error = function () {
		if ( jQuery( "#dropzone-jobimages" ).find( '.dz-error' ).length ) {
			return false;
		} else {
			return true;
		}
	}
	$.fn.form.settings.rules.video_validation = function () {
		var is_ok = true;
		jQuery( ".video-link" ).each( function() {
			if ( jQuery( this ).val() != '' && validateVideoUrl( jQuery( this ).val() ) === false ) {
				is_ok = false
			}
		});

		return is_ok;
	}
	$.fn.form.settings.rules.faq_validation = function () {
		var is_ok = true;
		jQuery( ".faq-question" ).each( function() {
			if ( ! jQuery( this ).val() ) {
				is_ok = false
			}
		});

		jQuery( ".faq-answer" ).each( function() {
			if ( ! jQuery( this ).val() ) {
				is_ok = false
			}
		});

		return is_ok;
	}

	//-> RUN Form validate
	wpj_aoe_validate_form();

});
//------------------------------------------
// Job Activate / Deactivate / Delete Modals
//------------------------------------------
jQuery( function( $ ) {

	function wpj_change_job_section( my_id, status ) {

		// Increment and decrement jobs count tab
		var current_tab = '';
		if ( status == 'inactive' ) { current_tab = 'active';
			jQuery( '.ticket-count-active' ).text( parseInt( jQuery( '.ticket-count-active' ).text() ) - 1 );
			jQuery( '.ticket-count-inactive' ).text( parseInt( jQuery( '.ticket-count-inactive' ).text() ) + 1 );
		} else if ( status == 'active' ) { current_tab = 'inactive';
			jQuery( '.ticket-count-active' ).text( parseInt( jQuery( '.ticket-count-active' ).text() ) + 1 );
			jQuery( '.ticket-count-inactive' ).text( parseInt( jQuery( '.ticket-count-inactive' ).text() ) - 1 );
		}

		// Show table header if initially no jobs
		if ( $( '.no-jobs-message' )[0] ) {
			$( '.no-jobs-message' ).remove();
			jQuery( 'div.box_content[data-tab="' + status + '"]' ).find( '.wpj-grid-table' ).show();
		}

		// Move job to correct tab
		jQuery( '.background-delete-' + my_id ).detach().prependTo( jQuery( 'div.box_content[data-tab="' + status + '"]' ).find( '#job_listings' ) );

		// Change active tab
		jQuery( '.item.force-white-btn[data-tab="' + status + '"]' ).trigger( 'click' );

		// Add no jobs text if no more jobs
		var no_jobs = current_tab == 'inactive' ? wpj_vars.no_inactive_jobs : wpj_vars.no_active_jobs;
		if ( ! jQuery.trim( jQuery( 'div.box_content[data-tab="' + current_tab + '"]' ).find( '#job_listings' ).text() ) ) {
			jQuery( 'div.box_content[data-tab="' + current_tab + '"]' ).find( '.wpj-grid-table' ).hide();
			jQuery( 'div.box_content[data-tab="' + current_tab + '"]' ).find( '#job_listings' ).parents( '.box_content' ).append( '<span class="no-jobs-message">' + no_jobs + '</span>' );
		}
	}

	$( document ).on( 'click', '.open-delete-job', function() {
		$( '.job-title-modal' ).html( wpj_validate_input_content( $( this ).attr( 'data-title-delete' ) ) );

		$( '.ajax_delete_job' ).attr( 'data-id', $( this ).attr( 'data-id' ) );

		$( '.ui.modal.delete-job' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_delete_job', function( event ) {
		event.preventDefault();

		var my_id = $( this ).attr( 'data-id' );

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action     : 'wpj_ajax_delete_job',
				var_post_id: my_id
			},
			beforeSend: function() {
				$( '.ajax_delete_job' ).addClass( 'loading' );
			},
			success: function( response ) {
				if ( response == 'success' ) {

					// Remove current job
					$( '.background-delete-' + my_id ).css( 'background', '#DF3F3F' );
					$( '.background-delete-' + my_id ).slideUp( 'normal', function() {

						$( this ).remove();

						// Close modal
						$( '.ui.modal.delete-job' ).modal( 'hide' );

						// Name of active tab
						var active_tab = jQuery( '.item.force-white-btn.active' ).attr( 'data-tab' );

						// Decrement jobs count tab
						var active_elem = jQuery( 'div.item.force-white-btn[data-tab="' + active_tab + '"]' );
						active_elem.find( 'span' ).text( parseInt( active_elem.find( 'span' ).text() ) - 1 );

						// Add no jobs text if no more jobs
						if ( ! jQuery.trim( jQuery( 'div.box_content[data-tab="' + active_tab + '"]' ).find( '#job_listings' ).text() ) ) {
							jQuery( 'div.box_content[data-tab="' + active_tab + '"]' ).find( '.wpj-grid-table' ).hide();
							jQuery( 'div.box_content[data-tab="' + active_tab + '"]' ).append( '<span class="no-jobs-message">' + wpj_vars['no_' + active_tab + '_jobs'] + '</span>' );
						}
					});

				} else if ( response == 'not_your_post' ) {
					$( '.content.delete-job' ).text( 'This is not your post.' );
				} else if ( response == 'not_logged_in' ) {
					$( '.content.delete-job' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_delete_job' ).removeClass( 'loading' );
			}
		});

		return false;

	});

	$( document ).on( 'click', '.open-deactivate-job', function() {
		$( '.ajax_deactivate_job' ).attr( 'data-id', $( this ).attr( 'data-id' ) );

		$( '.job-title-modal' ).html( wpj_validate_input_content( $( this ).attr( 'data-title' ) ) );

		$( '.ui.modal.deactivate-job' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_deactivate_job', function( event ) {

		event.preventDefault();

		var my_id = $( this ).attr( 'data-id' );

		jQuery.ajax({
			type: 'post',
			url : wpj_vars.ajaxurl,
			data: {
				action      : 'wpj_ajax_deactivate_job',
				var_post_id : my_id
			},
			beforeSend: function() {
				$( '.ajax_deactivate_job' ).addClass( 'loading' );
			},
			success: function( response ) {
				if ( response == 'success' ) {
					$( '.background-delete-' + my_id + ' .open-deactivate-job' ).html( wpj_vars.activate );
					$( '.background-delete-' + my_id + ' .open-deactivate-job' ).addClass( 'open-activate-job' ).removeClass( 'open-deactivate-job' );
					$( '.background-delete-' + my_id + ' .my-account-job-status .oe-green' ).addClass( 'oe-yellow' ).removeClass( 'oe-green' );
					$( '.background-delete-' + my_id + ' .my-account-job-status .oe-yellow' ).html( wpj_vars.paused );

					$( '.ui.modal.deactivate-job' ).modal( 'hide' );

					wpj_change_job_section( my_id, 'inactive' );

				} else if ( response == 'not_your_post' ) {
					$( '.content.deactivate-job' ).text( 'This is not your post.' );
				} else if ( response == 'not_logged_in' ) {
					$( '.content.deactivate-job' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_deactivate_job' ).removeClass( 'loading' );
			}
		});

		return false;
	});

	$( document ).on( 'click', '.open-activate-job', function() {
		$( '.ajax_activate_job' ).attr( 'data-id', $( this ).attr( 'data-id' ) );

		$( '.job-title-modal' ).html( wpj_validate_input_content( $( this ).attr( 'data-title' ) ) );

		$( '.ui.modal.activate-job' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_activate_job', function( event ) {
		var my_id = $( this ).attr( 'data-id' );

		event.preventDefault();

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action      : 'wpj_ajax_activate_job',
				var_post_id : my_id
			},
			beforeSend: function() {
				$( '.ajax_activate_job' ).addClass( 'loading' );
			},
			success: function( response ) {

				if ( response == 'success' ) {
					$( '.background-delete-' + my_id + ' .open-activate-job' ).html( wpj_vars.deactivate );
					$( '.background-delete-' + my_id + ' .open-activate-job' ).addClass( 'open-deactivate-job' ).removeClass( 'open-activate-job' );
					$( '.background-delete-' + my_id + ' .my-account-job-status .oe-yellow' ).addClass( 'oe-green' ).removeClass( 'oe-yellow' );
					$( '.background-delete-' + my_id + ' .my-account-job-status .oe-green' ).html( wpj_vars.published );

					$( '.ui.modal.activate-job' ).modal( 'hide' );

					wpj_change_job_section( my_id, 'active' );

				} else if ( response == 'not_your_post' ) {
					$( '.content.activate-job' ).text( 'This is not your post.' );
				} else if ( response == 'no_credits' ) {
					$( '.content.activate-job' ).text( wpj_vars.no_credits );
				} else if ( response == 'not_logged_in' ) {
					$( '.content.activate-job' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_activate_job' ).removeClass( 'loading' );
			}
		});

		return false;
	});

	$( document ).on( 'click', '.js-activate-all-jobs-link', function( event ) {
		$( '.ui.modal.js-activate-all-jobs-modal' ).modal( 'setting', 'transition', 'fly down' ).modal( 'show' );
	});

	$( document ).on( 'click', '.js-activate-all-jobs-action', function( event ) {
		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : { action : 'activate_all_jobs', reason: 'by_user' },
			success: function( response ) { window.location.href = wpj_vars.my_account_url + 'active'; }
		});
	});

	$( document ).on( 'click', '.js-deactivate-all-jobs-link', function( event ) {
		$( '.ui.modal.js-deactivate-all-jobs-modal' ).modal( 'setting', 'transition', 'fly down' ).modal( 'show' );
	});

	$( document ).on( 'click', '.js-deactivate-all-jobs-action', function( event ) {
		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : { action : 'deactivate_all_jobs', reason: 'by_user' },
			success: function( response ) { window.location.href = wpj_vars.my_account_url + 'inactive'; }
		});
	});

	$( document ).on( 'click', '.js-delete-all-jobs-link', function( event ) {
		$( '.ui.modal.js-delete-all-jobs-modal' ).modal( 'setting', 'transition', 'fly down' ).modal( 'show' );
	});

	$( document ).on( 'click', '.js-delete-all-jobs-action', function( event ) {
		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : { action : 'delete_all_jobs' },
			success: function( response ) { window.location.href = wpj_vars.my_account_url; }
		});
	});

});

//---------------------------------------
// Job - Read More Description
//---------------------------------------
jQuery( function( $ ) {
	$( 'a.read-more-desc' ).click( function ( e ) {
		e.preventDefault();

		if ( $( this ).parents( '.post-job-description' ).find( '.job-excerpt' ).is( ':visible' ) ) {
			$( this ).text( wpj_vars.read_less );

			$( this ).parents( '.post-job-description' ).find( '.job-excerpt' ).hide();
			$( this ).parents( '.post-job-description' ).find( '.job-post' ).show();
		} else {
			$( this ).text( wpj_vars.read_more );

			$( this ).parents( '.post-job-description' ).find( '.job-post' ).hide();
			$( this ).parents( '.post-job-description' ).find( '.job-excerpt' ).show();
		}
	});
});

//---------------------------------------
// Job - Show/Hide Let's Meet
//---------------------------------------
jQuery( function( $ ) {
	function wpj_show_lets_meet_inputs() {
		$( '#location-input' ).show();
		$( '#distance-input' ).show();
		$( '#map-checkbox' ).show();
	}

	function wpj_hide_lets_meet_inputs() {
		$( '#location-input' ).hide();
		$( '#distance-input' ).hide();
		$( '#map-checkbox' ).hide();
	}

	// on load
	if ( $( '#lets_meet' ).is( ':checked' ) ) {
		wpj_show_lets_meet_inputs();
	} else {
		wpj_hide_lets_meet_inputs();
	}

	// on change
	$( '#lets_meet' ).change( function() {
		if ( this.checked ) {
			wpj_show_lets_meet_inputs();
		} else {
			wpj_hide_lets_meet_inputs();
		}
	});
});

//---------------------------------------
// Job - Show/Hide Max Days Instant
//---------------------------------------
jQuery( function( $ ) {
	jQuery( "#max_days" ).change( function() {
		if ( jQuery( "#max_days" ).val() == 'instant' ) {
			$( "#job_instant_delivery_field" ).removeClass( 'hidden' );
		} else {
			$( "#job_instant_delivery_field" ).addClass( 'hidden' );
		}
	});
});

//---------------------------------------
// Job - Video poster
//---------------------------------------
function wpj_display_video_poster() {
	if ( jQuery( '.owl-video-tn' ).length >= 1 ) {
		jQuery( '.owl-video-tn' ).each( function() {
			var img_url = jQuery( this ).attr( 'srctype' );

			var el = jQuery( this ).parents( '.owl-video-wrapper' );
			el.css( 'opacity', 1 );
			el.css( 'background-image', 'url(' + img_url + ')' );
			el.css( 'background-repeat', 'no-repeat' );
			el.css( 'background-position', 'center' );
			el.css( 'background-size', 'cover' );
		});
	}
}
jQuery( window ).on( 'load', function() {
	wpj_display_video_poster();
});

jQuery( document ).ready( function( $ ) {

	//---------------------------------------
	// Job - Map
	//---------------------------------------
	if ( jQuery( "#job_address" )[0] ) {
		jQuery( "#job_address" ).each( function() {

			var src = "https://maps.google.com/maps?&amp;q=" + encodeURIComponent( jQuery( this ).text() ) + "&amp;output=embed";
			var embed ="<iframe class='job_google_map' frameborder='0' scrolling='no' marginheight='0' marginwidth='0' src='" + src + "'></iframe>";

			jQuery( '#job_map' ).html( embed );

		});
	}

	//---------------------------------------
	// Job - Social Media - Scroll Bottom
	//---------------------------------------
	if ( jQuery( '.social-icons-floating' )[0] ) {

		var topValue = parseFloat( jQuery( '.social-icons-floating' ).css( 'top' ) );

		var bottomValue = $( '.footer-wrapper' ).outerHeight() + 50;

		$( document ).scroll( function() {
			if ( $( '.social-icons-floating' ).offset().top + $( '.social-icons-floating' ).height() >= $( '.footer-wrapper' ).offset().top - 50 ) {
				jQuery( '.social-icons-floating' ).stop().animate({ bottom : bottomValue }, 200 );
				jQuery( '.social-icons-floating' ).css({ 'top' : 'auto' });
			} else {
				jQuery( '.social-icons-floating' ).stop().animate({ top : topValue }, 200 );
				jQuery( '.social-icons-floating' ).css({ 'bottom' : 'auto' });
			}
		});
	}


	//---------------------------------------
	// Job - Chart Graph
	//---------------------------------------
	$( '.graph-link' ).click( function() {
		if ( $( this ).hasClass( 'open' ) ) {

			$( this ).removeClass( 'open' );

			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item:last-child' ).addClass( 'item-no-top-border-mobile' );
			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item:not(.item-no-top-border-mobile)' ).addClass( 'mobile-hidden' );
			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item' ).addClass( 'padding5horizontal' );

			$( '#chart-div-container' ).slideUp( 400 );
			$( '#chart_div' ).slideUp( 400 );

		} else {

			$( this ).addClass( 'open' );

			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item:not(.item-no-top-border-mobile)' ).removeClass( 'mobile-hidden' );
			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item.item-no-top-border-mobile' ).removeClass( 'item-no-top-border-mobile' );
			$( this ).parents( '.wrapper-graph-dropdown' ).siblings( '.wpj-stats-segment' ).find( '.item' ).removeClass( 'padding5horizontal' );

			$( '#chart-div-container' ).slideDown( 400 );
			$( '#chart_div' ).slideDown( 400 );

			setTimeout( function() {
				if ( typeof drawChart === "function" ) {
					drawChart();
				}
			}, 500 );

		}

		$( this ).find( 'i' ).toggleClass( 'down' ).toggleClass( 'up' );
	});

	//---------------------------------------
	// Job - Subcategories
	//---------------------------------------
	$( '#job_cat' ).on( 'change rightnow', function( e ) {
		if ( $( this ).val() ) {
			$.post( wpj_vars.blog_url + "/?get_subcats_for_me=1", { queryString: $( this ).val(), term_val_type: 'id' }, function( data ) {

				if ( data && data.match( /option/g ).length > 2 ) {
					$( '#job_subcategory_field' ).show();
					localStorage.setItem( 'validate_subcat', 'yes' );

					if ( e.type == 'change' ) {
						$( '#sub_cats' ).html( data );
					}

					$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
				} else {
					$( '#job_subcategory_field' ).hide();
					localStorage.setItem( 'validate_subcat', 'no' );
				}

				if ( $( '#sub_cats' ).attr( 'data-required' ) != 'true' ) {
					localStorage.setItem( 'validate_subcat', 'no' );
				}

				wpj_aoe_validate_form();

			});
		} else {
			$( '#job_subcategory_field' ).hide();
		}
	}).triggerHandler( 'rightnow' );

	//---------------------------------------
	// Job - Audio
	//---------------------------------------
	if ( typeof wpj_audio_js_player_init === 'function' && wpj_vars.attachments_audio ) {
		$.each( JSON.parse( wpj_vars.attachments_audio ), function( key, value ) {
			wpj_audio_js_player_init( value['attachment_id'], value['url'], value['filename'] );
		});
	}

});

//---------------------------------------
// Job - Description
//---------------------------------------
jQuery( window ).on( 'load', function() {
	if ( jQuery( '#job_description_ifr' )[0] ) {
		// load
		var job_description_lenght = get_input_length( jQuery( '#job_description_ifr' ).contents().find( 'body' ), 'html' );
		jQuery( '#chars_counter' ).text( job_description_lenght );

		// keyup
		jQuery( '#job_description_ifr' ).contents().find( 'body' ).keyup( function( e ) {
			job_description_lenght = get_input_length( jQuery( '#job_description_ifr' ).contents().find( 'body' ), 'html' );
			jQuery( '#chars_counter' ).text( job_description_lenght );
		});

		// rejected class
		if ( jQuery( 'textarea[name="job_description"]' ).hasClass( 'rejected-input' ) ) {
			jQuery( '#job_description_ifr' ).parents( '#wp-job_description-wrap' ).addClass( 'rejected-input' );
		}
	}
});
function addNotify( type, msgs, cls ) {
	var html = '';

	if ( isNumeric( msgs ) && msgs > 0 ) {
		if ( msgs > 99 ) { msgs = 99; }

		html = '<div class="unread-label digits"><span class="messages_count">' + msgs + '</span></div>';

	}
	jQuery( "." + cls + " .nh-link" ).each( function() {
		jQuery( this ).html( html );
	});

	jQuery( "." + cls + ".label" ).each( function() {
		if ( ( msgs ) > 0 ) {
			jQuery( this ).show();
		} else {
			jQuery( this ).hide();
		}
		jQuery( this ).html( msgs );
	});
}

/* PM - New message on archive page */
function addMessageOnArchive() {
	jQuery.extend( jQuery.expr[":"], {
		"containsIN": function( elem, i, match, array ) {
			return ( elem.textContent || elem.innerText || "" ).toLowerCase().indexOf( ( match[3] || "" ).toLowerCase() ) >= 0;
		}
	});

	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: {
			action: 'show_new_messages_for_archive',
		},
		success: function( data ) {
			if ( data ) {
				// If exist, remove "No messages" string
				if ( jQuery( "#user_messages > #no_messages" ).length > 0 ) {
					jQuery( "#user_messages > #no_messages" ).remove();
				}

				// Create an array of users - initators for new messages
				// to use username as class, to remove current holder and append a new one
				var users = [];
				jQuery( data ).find( '.link-to-pm' ).each( function() {
					var current_user = jQuery( this ).attr( 'data-user-id' );
					if ( users.indexOf( current_user ) === -1 ) {
						users.push( current_user );
					}
				});

				// Remove old message holder if exist
				users.forEach( function( element ) {
					jQuery( '.js-tpm-holder.js-' + element ).remove();
				});

				// Insert new message
				jQuery( "#user_messages" ).prepend( data );

				jQuery( '.ui.dropdown' ).dropdown();
			}
		}
	});

}

/* PM - New pessage on conversation page */
function addMessageContent() {
	var msg_username = jQuery( '#pm_current_read_user_id' ).val();

	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: {
			action: 'show_new_messages',
			msg_username: msg_username
		},
		success: function( data ) {
			if ( data != '' ) {
				jQuery( '.error-no-messages' ).remove();
			}

			var div_exist = jQuery( data ).filter( '.js-pm-holder' ).attr( "id" );
			if ( jQuery( ".js-pm-holder#" + div_exist ).length != 0 ) {
				jQuery( ".js-pm-holder#" + div_exist ).fadeOut( "normal", function() {
					jQuery( this ).remove();
				});
			}

			jQuery( '.private-message-from-user' ).append( data );

			jQuery( '.ui.dropdown' ).dropdown();
		}
	});
}

/* CHATBOX - Page notifications */
function addMessageChatBox() {
	var oid = getUrlParameter( 'oid' );

	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: {
			action   : 'notifications_for_chatbox',
			oid      : oid,
			jb_action: getUrlParameter( 'jb_action' )
		},
		success: function( data ) {
			var buyer_rating  = wpj_validate_input_content( jQuery( '.buyer_rating' ).val() );
			var seller_rating = wpj_validate_input_content( jQuery( '.seller_rating' ).val() );
			var rating_stars  = jQuery( 'input[name=stars]:checked', '.rating' ).val();

			var is_buyer_rating_focused  = jQuery( '.buyer_rating' ).is( ':focus' ) ? true : false;
			var is_seller_rating_focused = jQuery( '.seller_rating' ).is( ':focus' ) ? true : false;

			jQuery( '#all_chatbox_messages' ).html( data );

		// Initialize fliptimer
			if ( wpj_vars.order_expected_delivery ) {
				jQuery( '.flipTimer' ).flipTimer({
					direction: 'down',
					date: wpj_vars.order_expected_delivery,
				});
			}

			if ( is_buyer_rating_focused === true ) {
				jQuery('.buyer_rating').focus();
			};
			jQuery( '.buyer_rating' ).val( buyer_rating );

			if ( is_seller_rating_focused === true ) {
				jQuery('.seller_rating').focus();
			};
			jQuery( '.seller_rating' ).val( seller_rating );

			jQuery( 'input[name=stars]:checked', '.rating' ).val( rating_stars );
			jQuery( 'input[name=stars]' ).filter( '[value=' + rating_stars + ']' ).prop( 'checked', true );
		}
	});
}

/* CHATBOX - Page messages */
function addMessageFormChatBox() {
	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: {
			action   : 'messages_for_chatbox',
			oid      : getUrlParameter( 'oid' ),
			jb_action: getUrlParameter( 'jb_action' )
		},
		success: function( data ) {
			var obj = JSON.parse( data );

			var sts1payment = jQuery( '#payment_status' ).html();
			var sts2payment = obj['payment_status'];

			var sts1order = jQuery( '#order_status' ).html();
			var sts2order = obj['order_status'];

			var sts1timeup = jQuery( '#times_up' ).html();
			var sts2timeup = obj['times_up'];

			var sts1order_cancellation = jQuery( '#order_cancellation' ).html();
			var sts2order_cancellation = obj['order_cancellation'];

			var sts1arbitration = jQuery( '#arbitration' ).html();
			var sts2arbitration = obj['arbitration'];

			var sts1review = jQuery( '#buyer_given_feedback' ).html();
			var sts2review = obj['buyer_given_feedback'];

			if (
				( sts1payment            != '' && sts1payment            != sts2payment ) ||
				( sts1order              != '' && sts1order              != sts2order )   ||
				( sts1timeup             != '' && sts1timeup             != sts2timeup )  ||
				( sts1order_cancellation != '' && sts1order_cancellation != sts2order_cancellation ) ||
				( sts1arbitration        != '' && sts1arbitration        != sts2arbitration ) ||
				( sts1review             != '' && sts1review             != sts2review )
			){
				jQuery( '#chat_box_message_form' ).html( obj['content'] );

				jQuery( '#chat_box_review_form' ).html( obj['review'] );
				var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;
				wpj_initialize_wpj_carousel( is_rtl );
				wpj_initialize_work_sample();
			}

			jQuery( '#payment_status' ).html( obj['payment_status'] );
			jQuery( '#order_status' ).html( obj['order_status'] );
			jQuery( '#times_up' ).html( obj['times_up'] );
			jQuery( '#order_cancellation' ).html( obj['order_cancellation'] );
			jQuery( '#arbitration' ).html( obj['arbitration'] );
			jQuery( '#buyer_given_feedback' ).html( obj['buyer_given_feedback'] );
		}
	});
}

/* CHAT - Open message box when new message */
function addNewMessage() {
	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: {
			action: 'new_message_for_user',
		},
		success: function( data ) {
			if ( data ) {
				var obj = JSON.parse( data );
				jQuery.each( obj, function( id, response ) {
					if ( ! jQuery( '[rel="' + response + '"]' )[0] && ! jQuery( '.pm-nav-btn' )[0] ) {
						// Open message box
						wpj_chat_open_box( response );

						// Audio notification
						wpj_play_sound(
							wpj_vars.theme_path + "/assets/audio/new_message.ogg",
							wpj_vars.theme_path + "/assets/audio/new_message.mp3",
							wpj_vars.theme_path + "/assets/audio/new_message.m4a"
						);
					}

					addMessageToBox( response );
				});
			}
		}
	});
}

/* CHAT - Insert message to message box */
function addMessageToBox( user_id ) {

	var $this = jQuery( '[rel="' + user_id + '"]' );
	if ( $this.length ) {
		jQuery.ajax({
			type: "POST",
			url : wpj_vars.ajaxurl,
			data: {
				action   : 'show_new_message_content',
				sender_id: user_id
			},
			success: function( msg ) {

				obj = JSON.parse( msg );
				jQuery.each( obj, function( id, response ) {
					if ( response['content'] || response['custom_offer'] ) {
						// clear 'no message text';
						$this.find( '.message-box-push' ).text( '' );

						// add class unread
						if ( ! $this.find( '.message-box-wrapper' ).hasClass( 'has-focus' ) ) {
							$this.find( '.message-box-wrapper' ).addClass( 'unread' );
						}

						// insert the new message
						var date         = new Date();
						var ampm         = date.getHours() >= 12 ? wpj_vars.pm : wpj_vars.am;
						var status_class = $this.find( '.message-box-user-status online' ).hasClass( 'offline' ) ? 'offline' : 'online';
						var avatar       = $this.find( '.message-box-logo-container' ).find( 'img' ).attr( 'src' );
						var user_link    = $this.find( '.message-box-user-info-title-container' ).find( 'a' ).attr( 'href' );
						var name         = $this.find( '.message-box-user-info-title' ).text();

						if ( response['custom_offer'] != '' ) {
							// add custom offer message
							var message_content = '\
								<div class="message-custom-offer">\
									<i class="tags icon"></i>' + response['custom_offer'] + '\
								</div>\
							';
							var custom_class = ' custom-offer';
						} else {
							var message_content = response['content'] + response['attachments'];
							var custom_class = '';
						}

						// insert the message only if is not already inserted
						if ( ! jQuery( ".message-wrapper[data-pm-id='" + response['id'] + "']" )[0] ) {
							var message_received = '\
								<div class="multiple-messages-wrapper">\
									<div class="message-wrapper received" data-pm-id="' + response['id'] + '">\
										\
										<div aria-hidden="true" class="message-box-logo-area" data-inverted="" data-tooltip="' + name + ' - ' + date.getHours() + ':' + date.getMinutes() + ' ' + ampm.toLowerCase() + '" data-position="top left">\
											<a class="left" tabindex="-1" href="' + user_link + '">\
												<div class="message-box-logo-container">\
													<img src="' + avatar + '" width="28" height="28" alt="" />\
												</div>\
											</a>\
											<div class="message-box-user-status ' + status_class + '"></div>\
										</div>\
										\
										<div class="message-text-content ' + custom_class + '">\
											<div class="message-received">'
												+ message_content +
											'</div>\
										</div>\
										\
									</div>\
								</div>\
							';

							jQuery( message_received ).insertBefore( '[rel="' + user_id + '"] .message-box-push' );

							// scroll to the last message
							$this.find( '.message-box-content' ).scrollTop( $this.find( '.message-box-content' )[0].scrollHeight );
						}

					} else if ( response['custom_offer_response'] ) {

						// send custom offer response to message box
						if ( jQuery( '.message-wrapper[data-pm-id="' + response['response_id'] + '"]' )[0] ) {
							if ( ! jQuery( '.message-wrapper[data-pm-id="' + response['response_id'] + '"]' ).find( '.custom-offer-response' )[0] ) {
								jQuery( ".message-wrapper[data-pm-id='" + response['response_id'] + "'] .message-custom-offer" ).append( '<span class="ui mini right label custom-offer-response">' + response['custom_offer_response'] + '</span>' );
							}
						}
					}
				});

			}
		});
	}
}

// declare initLiveNotifications timeout handle in global scope
// in order to clear it when the function is called repeatedly
// and prevent flooding
var ilnTimeoutHandle;

function initLiveNotifications( previous ) {
	clearTimeout( ilnTimeoutHandle );

	var previous = typeof previous !== 'undefined' ? previous : [];
	jQuery.ajax({
		type: "POST",
		url : wpj_vars.light_ajax_url,
		data: {
			action: 'check_live_notifications'
		},
		success: function( data ) {
			addNotify( "new", data.notifications, "nh-notifications" );
			addNotify( "new", data.messages, "nh-messages" );
			window.parent.postMessage( {data: data}, "*" );


			if ( isNumeric( data.messages ) && data.messages > 0
			&& data.messages_time > previous.messages_time ) {
				/* PM */
				if ( wpj_vars.is_page_pm == 1 ) {
					addMessageOnArchive();
				}

				else if ( wpj_vars.is_page_pm_single == 1 ) {
					addMessageOnArchive();
					addMessageContent();
				}

				/* CHAT */
				else if ( wpj_vars.chat_enabled == 'yes' && wpj_vars.is_user_logged_in == true ) {
					addNewMessage();
				}
			}

			/* CHATBOX */
			if ( wpj_vars.is_page_chatbox == 1 ) {
				addMessageChatBox();
				addMessageFormChatBox();
			}

			if ( data.enabled == 'yes' ) {

				// check previous request
				var timeout = data.timeout;
				if ( previous.timeout > data.timeout ) {
					if ( previous.timeout <= data.max_timeout ) {
						timeout = previous.timeout;
					} else {
						timeout = data.max_timeout;
					}
				}

				// add delay or reset for the next one
				if ( data.notifications == previous.notifications
					&& data.messages == previous.messages ) {
					data.timeout += timeout;
				} else {
					timeout = data.timeout;
				}

				clearTimeout( ilnTimeoutHandle );
				ilnTimeoutHandle = setTimeout(
					function() {
						initLiveNotifications( data );
					},
					timeout
				);
			}
		},
		error: function( XMLHttpRequest, textStatus, errorThrown ) {
			clearTimeout( ilnTimeoutHandle );
			ilnTimeoutHandle = setTimeout(
				function() {
					initLiveNotifications();
				},
				32000
			);
		}
	});
};

jQuery( document ).ready( function() {
	if ( wpj_vars.live_notifications_enabled ) {
		initLiveNotifications();
	}
});

jQuery( document ).ready( function( $ ) {

	if ( ( '.load-more-button.wpj-load-more' )[0] ) {
		if ( $( '.load-more-button.wpj-load-more' ).parent().parent().is( '#content-full' ) ) {
			$( '.load-more-button.wpj-load-more' ).parent().wrap( '<div class="mb150"></div>' );
		} else {
			if ( $( '.load-more-button.wpj-load-more' ).parent().siblings().hasClass( 'grid-switch-absolute' ) ) {
				$( '.load-more-button.wpj-load-more' ).parent().parent().addClass( 'mb75' );
			} else {
				$( '.load-more-button.wpj-load-more' ).parent().parent().addClass( 'mb150' );
			}
		}

		$( '.load-more-button.wpj-load-more' ).parent().addClass( 'pr' );
		$( '.load-more-button.wpj-load-more' ).show();
	}

	// Load more general function
	$( '.wpj-load-more' ).unbind().click( function( event ) {
		var button        = this;
		var max_num_pages = Number( $( button ).attr( 'data-max' ) );
		var action        = $( button ).attr( 'data-action' );
		var page          = Number( $( button ).attr( 'data-page' ) );
		if ( isNaN( page ) ) {
			page = 2;
		}

		var initial       = Number( $( button ).attr( 'data-initial' ) );
		var clicks        = Number( $( button ).attr( 'data-clicks' ) );
		var query_type    = $( button ).attr( 'data-querytype' );
		var query_page    = $( button ).attr( 'data-page' );
		var query_status  = $( button ).attr( 'data-querystatus' );
		var function_name = $( button ).attr( 'data-functionname' );

		var args_encoded  = $( button ).attr( 'data-class-args' );
		if ( args_encoded ) {
			args_encoded = JSON.parse( args_encoded );
		}

		$( button ).addClass( 'loading' );
		$( button ).attr( 'data-page', page + 1 );
		$( button ).attr( 'data-initial', initial + 1 );

		var data = {
			'action'         : action,
			'page'           : page,
			'initial'        : initial,
			'query_type'     : query_type,
			'query_page'     : query_page,
			'query_status'   : query_status,
			'function_name'  : function_name,
			'args_encoded'   : args_encoded
		};

		$.post( wpj_vars.ajaxurl + ( wpj_vars.url_params ? '?' + wpj_vars.url_params : '' ), data, function( response ) {

			$( response ).hide().appendTo( $( button ).siblings( ".wpj-load-more-target" ) ).slideDown( 400 );

			var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;

			wpj_initialize_wpj_carousel( is_rtl );
			wpj_display_video_poster();

			$( button ).removeClass( 'loading' );

			if ( response === '' || initial == clicks ) {
				$( button ).slideUp( 400 );
				$( button ).parents( '.mb75' ).removeClass( 'mb75' );
				$( button ).parents( '.mb150' ).removeClass( 'mb150' );
			}

			if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
				jQuery.fn.echoLazyLoadRender();
			}
		});
	});

	// Load more feedback function
	jQuery( "#load-more-feedback" ).click( function() {
		var current = jQuery( "#load-more-feedback" ).attr( "data-rel" );
		var uid     = jQuery( "#uid" ).val();

		var pid     = jQuery("#pid").val();
		if ( pid == 'undefined' ) {
			pid = '';
		}

		var total_per_load = jQuery( "#total_per_load" ).val();
		var action = "show_more_feedbacks_user";

		var version = '';
		if ( $( this ).data( "version" ) ) {
			version = $( this ).data( "version" );
		}

		jQuery( "#load-more-feedback" ).addClass( "loading" );

		jQuery.ajax({
			type    : "POST",
			url     : wpj_vars.ajaxurl,
			dataType: 'json',
			data    : {
				current       : current,
				uid           : uid,
				pid           : pid,
				total_per_load: total_per_load,
				action        : action,
				version       : version
			},
			success: function ( data ) {
				if ( data.ok == '1' ) {
					jQuery( "#all-feedback-box" ).append( data.html );

				} else if ( typeof data.error != 'undefined' ) {
					alert( data.error );
				}

				jQuery( "#load-more-feedback" ).removeClass( "loading" );

				if ( data.current == '0' ) {
					jQuery( "#load-more-feedback" ).hide( 'slow' );
				} else {
					jQuery( "#load-more-feedback" ).attr( "data-rel", data.current );
				}
			}
		});

	});

	// Load more general categories on taxonomy and search pages
	jQuery( function( $ ) {
		$( "form .filter-box" ).click( function() {
			$( ".filter-container .js-group-filters" ).toggleClass( "collapse-filters" );
		});
	});

	jQuery( function( $ ) {
		$( ".js-more-elements" ).click( function() {
			if ( $( ".show-categories" ).is( ':hidden' ) ) {
				$( ".show-categories" ).slideDown( 500 );
			} else {
				$( ".show-categories" ).slideUp( 500 );
			}

			$( ".js-more-elements .angle" ).toggleClass( "arrow-up" );
		});
	});

	// Load moare private messages
	$( ".pm-ajax-trigger" ).click( function() {
		var at = Math.ceil( $( '.js-pm-holder' ).length / 10 ) + 1;

		$.ajax({
			type : "POST",
			url  : wpj_vars.ajaxurl,
			data : {
				pg              : at,
				current_user_id : $( this ).attr( 'data-uid' ),
				other_user_id   : $( this ).attr( 'data-otherid' ),
				action          : 'load_more_messages'
			},
			beforeSend: function() {
				$( '.pm-ajax-trigger' ).addClass( 'loading' );
			},
			success: function( data ) {
				$( '.pm-ajax-trigger' ).removeClass( 'loading' );

				var obj = JSON.parse( data );

				$( '.pm-list-ajax' ).slideDown( 400 ).prepend( obj['messages'] );

				if ( obj['messages_cnt'] < 10 ) {
					jQuery( ".pm-ajax-trigger-container" ).slideUp( 400 );
				}

				$( '.ui.dropdown' ).dropdown();
			}
		});
	});

	// Load more notifications
	$( '#more_notifications_handler' ).on( 'click', function( event ) {
		event.preventDefault();

		var notifications_handler = $( "#more_notifications_handler" );
		var notifications_target  = $( "#more_notifications_target" );

		var more_text             = notifications_handler.data( 'more-text' );
		var loading_text          = notifications_handler.data( 'loading-text' );

		var limit                 = notifications_handler.data( 'limit' );
		var offset                = notifications_handler.data( 'offset' );

		$.ajax({
			type: "POST",
			url: wpj_vars.ajaxurl,
			data: {
				action : 'wpjobster_ajax_notifications',
				limit  : limit,
				offset : offset,
				is_ajax: true,
			},
			beforeSend : function () {
				notifications_handler.attr( 'disabled', true );
				notifications_handler.addClass( 'loading' ).html( loading_text );

				notifications_handler.data( 'offset', offset + limit );
			},
			success: function( data ) {

				var notifications = $.parseJSON( data );
				if ( notifications.count > 0 ) {

					$( notifications.content ).hide().appendTo( notifications_target ).slideDown( 400 );

					notifications_handler.removeClass( 'loading' ).html( more_text );

					if ( notifications.count < limit ) {
						notifications_handler.slideUp( 400 );
					}

				} else {
					notifications_handler.hide();
				}
			},
			error: function( jqXHR, textStatus, errorThrown ) {
				notifications_handler.html( jqXHR + " :: " + textStatus + " :: " + errorThrown );
			}
		});
	});

});

jQuery( document ).ready( function( $ ) {

	/* JOB AUDIO - UPLOADIFIVE */
	if ( wpj_vars.is_user_logged_in == true && $( '#audio_file_upload' )[0] ) {

		var i = 0;
		var n = jQuery( "#thumbnails_audio .div_div" ).length;

		for ( x = n; x < wpj_vars.max_audio_uploads; x++ ) {
			jQuery( "#thumbnails_audio" ).append( '<div class="div_div_input_audio not_sortable"></div>' );
		};

		jQuery( document ).on( 'click', '.div_div_input_audio', ( function() {
			if ( ! jQuery( this ).hasClass( "div_div_inactive_audio" ) ) {
				jQuery( "#uploadifive-audio_file_upload input:last" ).click();

				i = i + 1;
				jQuery( this ).addClass( "clicked_" + i );

			}
		}));

		jQuery( "#audio_file_upload" ).uploadifive({
			'auto'         : true,
			'multi'        : false,
			'uploadScript' : wpj_vars.theme_path + '/lib/uploadifive/uploady_audio.php',
			'fileTypeExts' : '*.mp3;*.wav;',
			'formData'     : { 'ID': wpj_vars.pid, 'author': wpj_vars.uid },
			'fileType'     : 'audio/mp3,audio/wav',
			'fileSizeLimit': wpj_vars.max_audio_filesize * 1024,
			'onProgress' : function() {
				jQuery( ".clicked_" + i ).addClass( 'uploading' );
				jQuery( ".div_div_input_audio" ).not( ".div_div_active" ).addClass( "div_div_inactive_audio" );
			},
			'onError' : function( data ) {

				if ( data == "FILE_SIZE_LIMIT_EXCEEDED" ) {
					alert( wpj_vars.audio_filesize_msg );

				} else if ( data == "FORBIDDEN_FILE_TYPE" ) {
					alert( wpj_vars.audio_filetype_msg );

				} else {
					alert( data );

				}
				jQuery( ".div_div_input_audio" ).removeClass( 'uploading' ).removeClass( 'div_div_inactive_audio' );

			},
			'onUploadComplete' : function( file, data, response ) {
				var bar = data.split( "|" );

				if ( bar[0] == "ok" ) {

					var html_content = '\
						<div class="div_div audio_uploaded" id="image_ss' + bar[2] + '" audio_id="' + bar[2] + '" >\
							<p>' + bar[1] + ' </p>\
							<a href="javascript: void(0)" onclick="delete_this_file('+ bar[2] +', \'\', \'\', \'\', \'audio\')" class="delete-this"></a>\
						</div>\
					';
					jQuery( ".clicked_" + i ).replaceWith( html_content );

				} else if ( bar[0] == "extension" ) {

					alert( wpj_vars.audio_filetype_msg );

				}

				jQuery( ".clicked_" + i ).removeClass( 'uploading' );
				jQuery( ".div_div_input_audio" ).removeClass( 'uploading' ).removeClass( 'div_div_inactive_audio' );
			}

		});

	}

	/* JOB COVER - HTML5 FILE UPLOAD */
	if ( wpj_vars.is_user_logged_in == true ) {

		if ( wpj_vars.preferred_image_uploader == 'html5fileupload' && $( '.html5fileupload.cover-image' )[0] ) {

			$.html5fileupload.defaults = {
				showErrors      : true,
				url             : null,
				downloadUrl     : null,
				removeUrl       : null,
				removeDone      : false,
				removeDoneDelay : 1200,
				file            : null,
				edit            : true,
				randomName      : false,
				randomNameLength: 8,
				form            : false,
				data            : { ID: wpj_vars.pid, author: wpj_vars.uid },
				ajax            : true,
				ajaxType        : 'POST',
				ajaxDataType    : 'json',
				ajaxHeaders     : {},
				multiple        : false,
				validExtensions : null,
				validMime       : null,
				labelInvalid    : null,
				autostart       : false,
				minFilesize     : 0,
				maxFilesize     : 2048000,
				labelMinFilesize: null,
				labelMaxFilesize: null,
				regexp          : /^[^\\/:\*\?"<>\|]+$/,
			}

			$( '.html5fileupload.cover-image' ).html5fileupload({
				onAfterStartSuccess: function( response ) {

					if ( response.error == '' ) {
						var html_content = '\
							<div class="div_div cover_div_div" id="image_ss' + response.attach_id + '" image_id="' + response.attach_id + '">\
								<img class="image_class" src="' + response.go + '" />\
								<a href="javascript: void(0)" onclick="delete_this_file(' + response.attach_id + ', \'\', \'\', wpj_vars.pid, \'cover\')" class="delete-this"></a>\
							</div>\
						';
						$( '#cover-image' ).html( html_content );

					} else {
						alert( response.error );

					}

				}
			});

		}

	}

	/* JOB IMAGE - HTML5 FILE UPLOAD */
	if ( wpj_vars.is_user_logged_in == true ) {

		if ( wpj_vars.preferred_image_uploader == 'html5fileupload' && $( '.html5fileupload.demo_multi' )[0] ) {

			$.html5fileupload.defaults = {
				showErrors      : true,
				url             : null,
				downloadUrl     : null,
				removeUrl       : null,
				removeDone      : false,
				removeDoneDelay : 1200,
				file            : null,
				edit            : true,
				randomName      : false,
				randomNameLength: 8,
				form            : false,
				data            : { ID: wpj_vars.pid, author: wpj_vars.uid },
				ajax            : true,
				ajaxType        : 'POST',
				ajaxDataType    : 'json',
				ajaxHeaders     : {},
				multiple        : false,
				validExtensions : null,
				validMime       : null,
				labelInvalid    : null,
				autostart       : false,
				minFilesize     : 0,
				maxFilesize     : 2048000,
				labelMinFilesize: null,
				labelMaxFilesize: null,
				regexp          : /^[^\\/:\*\?"<>\|]+$/,
			}

			$( '.html5fileupload.demo_multi' ).html5fileupload({
				onAfterStartSuccess: function( response ) {
					if ( response.error == '' ) {
						var html_content = '\
							<div class="div_div" id="image_ss' + response.attach_id + '" image_id="' + response.attach_id + '">\
								<img width="90" class="image_class" height="90" src="' + response.go + '" />\
								<a href="javascript: void(0)" onclick="delete_this_file(' + response.attach_id + ', \'\', \'\', \'\', \'image-html5\')" class="delete-this"></a>\
							</div>\
						';
						$( '#thumbnails' ).append( html_content );

					} else {
						alert( response.error );

					}
				}
			});

		}

	}

	/* USER COVER - UPLOADIFIVE */
	if ( wpj_vars.is_user_logged_in == true && $( '#file_upload_banner' )[0] ) {

		var i = 0;
		jQuery( document ).on( 'click', '.banner_input', ( function() {

			if ( ! jQuery( this ).hasClass( "avatar_input_inactive" ) ) {

				jQuery( "#uploadifive-file_upload_banner input:last" ).click();
				i = i + 1;
				jQuery( this ).addClass( "clicked_" + i );

			}

		}));

		/* Process uploaded image */
		jQuery( "#file_upload_banner" ).uploadifive({
			'auto'             : true,
			'multi'            : false,
			'uploadScript'     : wpj_vars.theme_path + '/lib/uploadifive/uploadbanner.php',
			'fileTypeExts'     : '*.jpg;*.jpeg;*.gif;*.png',
			'formData'         : { 'author': wpj_vars.uid, 'width': 1170, 'height': 215 },
			'fileType'         : 'image/*',
			'fileSizeLimit'    : wpj_vars.max_cover_filesize * 1024,

			onProgress         : function() {
				jQuery( "#dvloader" ).show();
				jQuery( ".banner_input" ).addClass( "avatar_input_inactive" );
			},

			onError : function( data ) {
				if ( data == "FILE_SIZE_LIMIT_EXCEEDED" ) {
					alert( wpj_vars.cover_filesize_msg );

				} else if (data == "FORBIDDEN_FILE_TYPE") {
					alert( wpj_vars.cover_filetype_msg );

				} else {
					alert( data );

				}

				jQuery( "#load_waiting" ).removeClass( 'uploading' ).removeClass( 'avatar_input_inactive' );
			},

			onUploadComplete : function( file, data, response ) {
				jQuery( "#dvloader" ).hide();
				var bar = data.split( "|" );

				var content = "\
					<a class='change-cover'><i class='close icon'></i></a>\
					<span style='display:none;' id='dvloader' class='dvloader-new'>\
						<img src='" + wpj_vars.theme_path + "/assets/images/notifications-loading.gif' />\
					</span>\
				";

				if ( bar[0] == "ok" ) {
					jQuery( '#banner' ).addClass( 'ub-cover-photo' );
					jQuery( '#banner' ).css( 'background', '' );
					jQuery( '#banner' ).css({'background-image': 'url(' + bar[1] + ')'});
					jQuery( '#banner' ).attr( 'data-attach_id', bar[2] );
					jQuery( '#contentbanner' ).html( content );

				} else if ( bar[0] == "size" ) {
					alert( wpj_vars.min_filesize_250 );
					jQuery( ".banner_input" ).removeClass( "avatar_input_inactive" );

				} else if ( bar[0] == "extension" ) {
					alert( wpj_vars.cover_filetype_msg );
					jQuery( ".banner_input" ).removeClass( "avatar_input_inactive" );

				} else {
					alert( wpj_vars.err );
					jQuery( ".banner_input" ).removeClass( "avatar_input_inactive" );

				}

				jQuery( "#load_waiting" ).removeClass( 'uploading' );
				jQuery( ".avatar_input" ).removeClass( 'uploading' ).removeClass( 'avatar_input_inactive' );
			}
		});

		/* Remove cover user image */
		jQuery( document ).on( 'click', '#contentbanner', ( function() {

			attach_id = jQuery( "#banner" ).attr( 'data-attach_id' );

			var content = "\
				<a class='change-cover'><i class='camera icon'></i></a>\
				<span style='display:none;' id='dvloader' class='dvloader-new'>\
					<img src='" + wpj_vars.theme_path + "/assets/images/notifications-loading.gif' />\
				</span>\
				";

			jQuery.ajax({
				type: "POST",
				url : wpj_vars.theme_path + '/lib/uploadifive/deletebanner.php',
				data: { 'user': wpj_vars.uid, 'attach_id':attach_id },
				onProgress : function() {
					jQuery( "#dvloader" ).show();
				},
				success: function ( result ) {
					jQuery( "#dvloader" ).hide();

					if ( 'resultok' == result ) {
						jQuery( '#banner' ).css( 'background', 'transparent' );
						jQuery( '#banner' ).removeClass( 'ub-cover-photo' );
						jQuery( '#contentbanner' ).html( "<div class='banner_input'><div id='contentbanner'>" + content + "</div></div>" );
					}

				}
			});

		}));

	}



});

/* USER AVATAR - UPLOADIFIVE */
function wpj_init_avatar_upload_form( width, height, page ) {

	var img_width  = typeof width  !== 'undefined' ? width : '50';
	var img_height = typeof height !== 'undefined' ? height : '50';

	var i = 0;
	var n = 1;

	jQuery( document ).on( 'click', '.avatar_input', ( function() {

		if ( ! jQuery( this ).hasClass( "avatar_input_inactive" ) ) {
			jQuery( "#uploadifive-file_upload input:last" ).click();

			i = i + 1;
			jQuery( this ).addClass( "clicked_" + i );
		}

	}));

	jQuery( "#file_upload" ).uploadifive({
		'auto'             : true,
		'multi'            : false,
		'uploadScript'     : wpj_vars.theme_path + '/lib/uploadifive/uploadavatar.php',
		'fileTypeExts'     : '*.jpg;*.jpeg;*.gif;*.png',
		'formData'         : { 'author': wpj_vars.uid, 'width': img_width, 'height': img_height },
		'fileType'         : 'image/*',
		'fileSizeLimit'    : wpj_vars.max_cover_filesize * 1024,

		onProgress : function() {
			jQuery( ".clicked_" + i ).addClass( "uploading" );
			jQuery( ".avatar_input" ).addClass( "avatar_input_inactive" );
		},

		onError : function( data ) {
			if ( data == "FILE_SIZE_LIMIT_EXCEEDED" ) {
				alert( wpj_vars.cover_filesize_msg );

			} else if (data == "FORBIDDEN_FILE_TYPE") {
				alert( wpj_vars.cover_filetype_msg );

			} else {
				alert( data );

			}

			jQuery( ".avatar_input" ).removeClass( 'uploading' ).removeClass( 'avatar_input_inactive' );
		},

		onUploadComplete : function( file, data, response ) {
			var bar = data.split( "|" );

			if ( bar[0] == "ok" ) {
				jQuery( '.avatar_input' ).find( 'img' ).attr( 'src', bar[1] );

			} else if ( bar[0] == "size" ) {
				alert( wpj_vars.min_filesize_250 );

			} else if ( bar[0] == "extension" ) {
				alert( wpj_vars.cover_filetype_msg );

			} else {
				alert( wpj_vars.err );

			}

			jQuery( ".clicked_" + i ).removeClass( 'uploading' );
			jQuery( ".avatar_input" ).removeClass( 'uploading' ).removeClass( 'avatar_input_inactive' );
		}
	});

}

/* WYSIWYG */
function wpj_init_wysiwyg_textarea( action, max_chr_limit, post_status, rejected_description, indx, id ) {
	if ( action == 'job_edit' ) {
		wpj_js_description_args_allowed( max_chr_limit, post_status , rejected_description );
	} else if ( action == 'packages' ) {
		wpj_js_description_args_allowed( max_chr_limit, '', '', indx );
	} else {
		wpj_js_description_args_allowed( max_chr_limit, '', '', '', id );
	}
}

jQuery( document ).ready( function( $ ) {

	// slider main menu
	$( '.menu-direction-right' ).click( function( e ) {
		e.preventDefault();
		$( '.middle-menu-slider' ).find( '.categories-here' ).animate( {scrollLeft: '+=200'}, 500 );
	});

	$( '.menu-direction-left' ).click( function( e ) {
		e.preventDefault();
		$( '.middle-menu-slider' ).find( '.categories-here' ).animate( {scrollLeft: '-=200'}, 500 );
	});

	$( window ).on( 'load resize', function() {
		if ( wpj_vars.long_menu_arrows == '1' ) {

			if ( $( 'ul.categories-here' ).prop( 'scrollWidth' ) > $( 'ul.categories-here' ).prop( 'clientWidth' ) ) {
				$( '.main-menu-wrapper' ).find( '.arrows-wrapper' ).addClass( 'visible' );
				$( 'ul.categories-here' ).css( 'overflow', 'hidden' );

			} else {
				$( '.main-menu-wrapper' ).find( '.arrows-wrapper' ).removeClass( 'visible' );
				$( '.middle-menu-slider' ).find( 'ul' ).css( 'overflow', 'visible' );

			}

		}

	});

	// submenu left for first element of a new row
	var last_element = false;
	$( 'ul.categories-here' ).children( 'li' ).each( function() {
		if ( last_element && last_element.offset().top != $( this ).offset().top ) {
			if ( $( this ).find( 'ul' ).hasClass( 'right0' ) ) {
				$( this ).find( 'ul' ).removeClass( 'right0' ).removeClass( 'little-right-space' ).addClass( 'left0' );
			}
		}
		last_element = $( this );
	});

	// secondary menu
	var is_rtl = typeof wpj_vars !== 'undefined' && wpj_vars.is_rtl == 'true' ? true : false;
	$( window ).on( 'load resize', function() {
		if ( $( '.secondary-menu' )[0] ) {

			if ( is_rtl ) {
				var nh_right_part_left_space = ( $( this ).width() - ( $( '.nh-right' ).offset().left + $( '.nh-right' ).outerWidth() ) );
			} else {
				var nh_right_part_left_space = $( '.nh-right' ).offset().left;
			}

			if ( is_rtl ) {
				var nh_logo_left_space = ( $( this ).width() - ( $( '.wrapper-menu-top-fixable' ).find( '.logo' ).offset().left + $( '.wrapper-menu-top-fixable' ).find( '.logo' ).outerWidth() ) );
			} else {
				var nh_logo_left_space = $( '.wrapper-menu-top-fixable' ).find( '.logo' ).offset().left;
			}

			var nh_logo_width = $( '.wrapper-menu-top-fixable' ).find( '.logo' ).width();

			var secondary_menu_width = Math.abs( Math.round( nh_right_part_left_space - nh_logo_left_space ) ) - nh_logo_width; // distance between logo and right part

			$( '.nh-secondary-menu' ).css( 'width', secondary_menu_width );

			var logo_column_width   = Math.abs( Math.round( $( '.logo_holder' ).width() ) ) + 28;
			var logo_width          = Math.abs( Math.round( $( '.wrapper-menu-top-fixable' ).find( '.logo' ).width() ) );
			var secondary_menu_left = -logo_column_width + logo_width + 15;
			var css_position        = is_rtl ? 'right' : 'left';

			$( '.nh-secondary-menu' ).css( css_position, secondary_menu_left );

		}
	});

	// show user dropdown menu
	$( ".nh-accordion-handler" ).click( function( event ) {
		event.preventDefault();

		$( ".nh-accordion" ).slideUp( 150 );
		$( ".nh-accordion-handler" ).removeClass( "nh-accordion-selected" );

		if ( $( this ).parent().children(" .nh-accordion" ).css( "display" ) == "block" ) {
			$( this ).parent().children( ".nh-accordion" ).slideUp( 150 );
			$( this ).removeClass( "nh-accordion-selected" );

			event.stopPropagation();
		} else {
			$( this ).parent().children( ".nh-accordion" ).slideDown( 150 );
			$( this ).addClass( "nh-accordion-selected" );

			event.stopPropagation();
		}
	});

	// responsive menus
	$( '.js-mobile-menu-toggle' ).click( function() {
		if ( $( this ).attr( 'class' ).indexOf( 'menu-left' ) != -1 ) {
			if ( ! $( '.left.menu' ).hasClass( 'visible' ) ) {
				$( '.ui.sidebar.left' ).sidebar({
					onChange: function() { $( 'html[dir=rtl]' ).css( 'overflow-x', 'hidden' ); },
					onHidden: function() { $( 'html[dir=rtl]' ).css( 'overflow-x', '' ); },
				})
				.sidebar( 'toggle' );

			}
		}

		if ( $( this ).attr( 'class' ).indexOf( 'menu-right' ) != -1 ) {
			if ( ! $( '.right.menu' ).hasClass( 'visible' ) ) {
				$( '.ui.sidebar.right' ).sidebar({
					onChange: function() { $( 'html[dir=rtl]' ).css( 'overflow-x', 'hidden' ); },
					onHidden: function() { $( 'html[dir=rtl]' ).css( 'overflow-x', '' ); },
				})
				.sidebar( 'toggle' );
			}
		}
	});

	// menu subcategories
	$( '#menu-header-main-menu li' ).each( function() {
		// this doesn't work for more than one level
		// it also prevents the top level menu link from working as usual
		if ( $( this ).find( 'ul' ).first().size() > 0 ) {
			$( this ).find( 'ul' ).parent().children( "a" ).addClass( 'nh-accordion-handler' );
			$( this ).find( 'ul' ).children("li").addClass( 'nh-accordion-container' );
			$( this ).find( 'ul' ).wrap( '<div class="nh-accordion" style="display: none;"></div>' );
		}
	});

	// hide category sidebar if is empty
	if ( $( "ul.subcat-list" ).has( 'li' ).length == 0 ) {
		$( ".ui.other-page.segment" ).remove();
	}

	// header menu
	var enable_disable = wpj_vars.header_fixed;
	$( window ).bind( 'scroll', function () {
		if ( enable_disable == 1 ) {
			var wpj_hwrapper = $( ".wrapper-menu-top-fixable" );
			var wpj_hwrapper_r = $( ".top-menu-wrapper-responsive" );
			$( window ).scroll( function() {
				var windowpos = $( window ).scrollTop();
				if ( windowpos > 0 ) {
					wpj_hwrapper.addClass( "fixed" );
					wpj_hwrapper_r.addClass( "fixed" );
				} else {
					wpj_hwrapper.removeClass( "fixed" );
					wpj_hwrapper_r.removeClass( "fixed" );
				}
			});

		}
	});

});

jQuery( document ).ready( function( $ ) {

	// Mark notifications as read
	$( document ).on( 'click', '.wpj-mark-notification-as-read', function() {
		$( this ).removeClass( 'x' ).removeClass( 'icon' ).addClass( 'ui active inline loader notification-loader' );

		$.ajax({
			type: "POST",
			url : wpj_vars.ajaxurl,
			data: {
				action         : 'mark_notification_as_read',
				notification_id: $( this ).attr( 'data-value' )
			},
			success: function( data ) {
				location.reload();
			}
		});
	});


	// Check notification status
	function check_notifications( id, cname ) {
		if ( jQuery( '.' + cname + ':checked' ).length == jQuery( '.' + cname ).length ) {
			jQuery( '#' + id ).prop( 'checked', true );
		} else {
			jQuery( '#' + id ).prop( 'checked', false );
		}
	}

	// Check email from email settings
	check_notifications( 'all-email-notify', 'email_notifications' );

	$( '#all-email-notify' ).change( function() {
		var checkboxes = $( this ).closest( '.mail_notification' ).find( ':checkbox' );
		if ( $( this ).is( ':checked' ) ) {
			checkboxes.prop( 'checked', true );
			jQuery( '#all-mail' ).find( 'label' ).text( wpj_vars.uncheck_all_email );
		} else {
			checkboxes.prop( 'checked', false );
			jQuery( '#all-mail' ).find( 'label' ).text( wpj_vars.check_all_email );
		}
	});

	$( '.mail_notification' ).change( function() {
		check_notifications( 'all-email-notify', 'email_notifications' );
	});

	// Check sms from sms settings
	check_notifications( 'all-sms-notify', 'sms_notifications' );

	$( '#all-sms-notify' ).change( function() {
		var checkboxes = $( this ).closest( '.sms_notification' ).find( ':checkbox' );
		if($( this ).is( ':checked' ) ) {
			checkboxes.prop( 'checked', true );
			jQuery( '#all-sms' ).find( 'label' ).text( wpj_vars.uncheck_all_sms );
		} else {
			checkboxes.prop( 'checked', false );
			jQuery( '#all-sms' ).find( 'label' ).text( wpj_vars.check_all_sms );
		}
	});

	$( '.sms_notification' ).change( function() {
		check_notifications( 'all-sms-notify', 'sms_notifications' );
	});
	
});
//------------------------------------------
// Job Price Functions
//------------------------------------------
function updatePurchasePrice( purchase_type ) {
	var $ = jQuery.noConflict();

	if ( typeof purchase_type == 'undefined' ) {
		purchase_type = 'job_purchase';
	}

	$( ".total" ).each( function() {

		var $total = $( this );
		var total = 0;

		if ( purchase_type == 'job_purchase' ) {
			var total = Number( $total.data( "price" ) );
		} else if ( purchase_type == 'feature' ) {
			var master_total = 0;
			var s_total = 0;
			$( ".featured_chk[type=checkbox]" ).each( function() {
				var ob = $( "#"+this.id );
				if ( $( this ).parents( '.ui.checkbox' )[0] && $( this ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
					s_total = Number( ob.data( "price" ) );
					master_total = master_total + s_total;
					ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );
				} else {
					ob.parents( '.ui.checkbox' ).checkbox( 'set unchecked' );
				}
			});
			var total = master_total;
		} else if ( purchase_type == 'badge' ) {
			var master_total = 0;
			var s_total = 0;
			$( ".badge_chk[type=checkbox]" ).each( function() {
				var ob = $( "#"+this.id );
				if ( $( this ).parents( '.ui.checkbox' )[0] && $( this ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
					s_total = Number( ob.data( "price" ) );
					master_total = master_total + s_total;
					ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );
				} else {
					ob.parents( '.ui.checkbox' ).checkbox( 'set unchecked' );
				}
			});
			var total = master_total;
		}

		var shipping              = $total.data( "shipping" ) || 0;
		var cur                   = $total.data( "cur" );
		var symbol                = $total.data( "symbol" ) || cur;
		var position              = $total.data( "position" ) || '';
		var space                 = $total.data( "space" ) || 'yes';
		var decimal               = $total.data( "decimal" ) || '.';
		var thousands             = $total.data( "thousands" ) || ',';
		var decimaldisplay        = $total.data( "decimaldisplay" ) || 'default';
		var processingfeesenable  = $total.data( "processingfeesenable" ) || 'disabled';
		var processingfeesfixed   = Number( $total.data( "processingfeesfixed" ) ) || 0;
		var processingfeespercent = $total.data( "processingfeespercent" ) || 0;
		var processingfeetax      = $total.data( "processingfeetax" ) || '';
		var tax                   = $total.data( "tax" ) || 0;
		var zerowithfree          = $total.data( "zerowithfree" ) || '';
		var freestr               = $total.data( "freestr" ) || 'Free';
		var amount;

		// Job Price
		var space_str = "";
		if ( space == "yes" ) { space_str = " "; }
		if ( purchase_type == 'job_purchase' ) {
			if ( Number( $("[name=myFormPurchase2] .main_value_inp" ).val() ) ) {
				total = total * Number( $("[name=myFormPurchase2] .main_value_inp" ).val() );
			}

			$( "[name=myFormPurchase2] [type=checkbox]" ).each( function() {
				if ( $( this ).parents( '.ui.checkbox' )[0] && $( this ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
					amount = Number( $(this ).parents( '.ui.checkbox' ).children( ".uzextracheck" ).val() );
					if ( isNaN( amount ) ) { amount = Number( $total.data( "price" ) ); }

					total = total + amount * Number( $( this ).data( "price" ) );
				}
			});
		}

		// Set data job price including extras
		$total.attr( 'data-price-with-extras', total );

		total = Hooks.apply_filters( 'wpj_order_price_total_filter', total, $total );

		if ( total < 0 ) { total = 0; }

		// Shipping
		shipping = Number( shipping );
		var chargable_total = total + shipping;

		// Processing Fee
		var processingfee_total = 0;
		if ( processingfeesenable != 'disabled' ) {
			if ( processingfeesenable == 'percent' ) {
				if ( processingfeespercent > 0 ) {
					processingfee_total = ( total + shipping ) * processingfeespercent / 100;
				} else {
					processingfee_total = 0;
				}
			}
			if ( processingfeesenable == 'fixed' ) {
				processingfee_total = processingfeesfixed;
			}
			// display processing fees
			var formatted_processingfee = String( processingfee_total.formatMoney( 2, decimal, thousands ) );

			if ( decimaldisplay == "ifneeded" ) {
				if ( isInt( processingfee_total ) ) {
					formatted_processingfee = String( processingfee_total.formatMoney( 0, decimal, thousands ) );
				} else {
					formatted_processingfee = String( processingfee_total.formatMoney( 2, decimal, thousands ) );
				}
			} else if ( decimaldisplay == "never" ) {
				formatted_processingfee = String( processingfee_total.formatMoney( 0, decimal, thousands ) );
			}
			if ( position == "front" ) {
				$( ".processingfee-amount" ).html( symbol + space_str + formatted_processingfee );
			} else {
				$( ".processingfee-amount" ).html( formatted_processingfee + space_str + symbol );
			}
		}

		// processing fees only apply when price > 0
		if ( chargable_total > 0 ) {
			chargable_total = chargable_total + Number( processingfee_total );
		}

		// Tax
		var tax_amount = 0;
		if ( tax != '0' ) {
			var tax_chargable_total = 0;
			if ( processingfeetax == 'yes' ) {
				tax_chargable_total = total + processingfee_total + shipping;
			} else {
				tax_chargable_total = total + shipping;
			}
			tax_amount = tax_chargable_total * tax / 100;

			// display tax
			var formatted_tax = String( tax_amount.formatMoney( 2, decimal, thousands ) );

			if ( decimaldisplay == "ifneeded" ) {
				if ( isInt( tax_amount ) ) {
					formatted_tax = String( tax_amount.formatMoney( 0, decimal, thousands ) );
				} else {
					formatted_tax = String( tax_amount.formatMoney( 2, decimal, thousands ) );
				}
			} else if ( decimaldisplay == "never" ) {
				formatted_tax = String( tax_amount.formatMoney( 0, decimal, thousands ) );
			} else {
				formatted_tax = String( tax_amount.formatMoney( 2, decimal, thousands ) );
			}

			if ( position == "front" ) {
				$( ".tax-amount" ).html( symbol + space_str + formatted_tax );
			} else {
				$( ".tax-amount" ).html( formatted_tax + space_str + symbol );
			}
		} else {
			tax_amount = 0;
		}

		// tax only applies when price > 0
		if ( chargable_total > 0 ) {
			chargable_total = chargable_total + tax_amount;
		}

		// total price
		$total.attr( 'data-total', chargable_total );

		var formatted_money = '';
		if ( decimaldisplay == "ifneeded" ) {
			if ( isInt( chargable_total ) ) {
				formatted_money = String( chargable_total.formatMoney( 0, decimal, thousands ) );
			} else {
				formatted_money = String( chargable_total.formatMoney( 2, decimal, thousands ) );
			}
		} else if ( decimaldisplay == "never" ) {
			formatted_money = String( chargable_total.formatMoney( 0, decimal, thousands ) );
		} else {
			formatted_money = String( chargable_total.formatMoney( 2, decimal, thousands ) );
		}
		if ( position == "front" ) {
			if ( total > 0 ) {
				$total.html( symbol + space_str + formatted_money );
			} else {
				if ( zerowithfree === 'yes' ) {
					$total.html( freestr );
				} else {
					$total.html( symbol + space_str + formatted_money );
				}
			}
		} else {
			if ( chargable_total > 0 ) {
				$total.html( formatted_money + space_str + symbol );
			} else {
				if ( zerowithfree === 'yes' ) {
					$total.html( freestr );
				} else {
					$total.html( formatted_money + space_str + symbol );
				}
			}
		}

		if ( chargable_total <= 0 || isNaN( chargable_total ) ) {
			$( '#credits' ).text( wpj_vars.get_for_free );
			$( '.payment-gateways a' ).hide();
		} else {
			$( '#credits' ).text( wpj_vars.account_balance );
			$( '.payment-gateways a' ).show();
		}
	});
};

//------------------------------------------
// Job Price & Extras
//------------------------------------------
jQuery( document ).ready( function() {
	jQuery( ".uzextracheck[type=checkbox]" ).change();
});

jQuery( window ).ready( function( $ ) {
	// Extra - check/uncheck
	$( ".uzextracheck[type=checkbox]" ).change( function() {
		var ob = $( "[name=" + $( this ).attr( "name" ) + "]" );
		if ( $( this ).parents( '.ui.checkbox' )[0] && $( this ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
			ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );
		} else {
			ob.parents( '.ui.checkbox' ).checkbox( 'set unchecked' );
		}

		updatePurchasePrice( "job_purchase" );
	});

	// Featured - check/uncheck
	if ( typeof $( ".featured_chk[type=checkbox]" ) != 'undefined' ) {
		$( ".featured_chk[type=checkbox]" ).change( function() {
			if ( ! $( '.ui.message' ).hasClass( 'hidden' ) ) {
				$( '.ui.message' ).addClass( 'hidden' );
			}

			updatePurchasePrice( "feature" );

			// Disable button if not enough credits
			if ( parseFloat( $( '#showtotal' ).attr( 'data-total' ) ) > parseFloat( wpj_vars.user_credits ) ) {
				jQuery( '#credits' ).attr( 'onclick', '' );
				jQuery( '#credits' ).addClass( 'disabled' );
				jQuery( '#credits' ).parent().attr( 'data-tooltip', wpj_vars.not_enough_credits );
				jQuery( '#credits' ).parent().attr( 'data-position', 'top left' );
				jQuery( '#credits' ).parent().attr( 'data-inverted', '' );
			} else {
				jQuery( '#credits' ).attr( 'onclick', 'take_to_gateway( "credits", "", "featured" );' );
				jQuery( '#credits' ).removeClass( 'disabled' );
				jQuery( '#credits' ).parent().removeAttr( 'data-tooltip' );
				jQuery( '#credits' ).parent().removeAttr( 'data-position' );
				jQuery( '#credits' ).parent().removeAttr( 'data-inverted' );
			}

			return false;
		});
	}

	// Badge - check/uncheck
	if ( typeof $( ".badge_chk[type=checkbox]" ) != 'undefined' ) {
		$( ".badge_chk[type=checkbox]" ).change( function() {

			if ( ! $( '.ui.message' ).hasClass( 'hidden' ) ) {
				$( '.ui.message' ).addClass( 'hidden' );
			}

			updatePurchasePrice( "badge" );

			// Disable button if not enough credits
			if ( parseFloat( $( '#showtotal' ).attr( 'data-total' ) ) > parseFloat( wpj_vars.user_credits ) ) {
				jQuery( '#credits' ).attr( 'onclick', '' );
				jQuery( '#credits' ).addClass( 'disabled' );
				jQuery( '#credits' ).parent().attr( 'data-tooltip', wpj_vars.not_enough_credits );
				jQuery( '#credits' ).parent().attr( 'data-position', 'top left' );
				jQuery( '#credits' ).parent().attr( 'data-inverted', '' );
			} else {
				jQuery( '#credits' ).attr( 'onclick', 'take_to_gateway( "credits", "", "badge" );' );
				jQuery( '#credits' ).removeClass( 'disabled' );
				jQuery( '#credits' ).parent().removeAttr( 'data-tooltip' );
				jQuery( '#credits' ).parent().removeAttr( 'data-position' );
				jQuery( '#credits' ).parent().removeAttr( 'data-inverted' );
			}

			return false;
		});
	}

	// Multiple Add
	$( '.amount_add' ).on( 'click', function( e ) {
		e.preventDefault();
		var amountnb      = $( this ).parents( '.amount_section' ).attr( 'data-amountnb' );
		var c_amount_chk  = $( ".extra_nb_" + amountnb + " label .uzextracheck" );
		var c_amount_cont = $( ".extra_nb_" + amountnb + " .amount_section .current_amount" );
		var max           = parseInt( c_amount_cont.data( "max" ) );

		if ( $( this ).parent().parent().hasClass( "main_amount_box" ) ) {
			var max = parseInt( $( ".main_amount_box .current_amount" ).data( "max" ) );
			var c_amount = parseInt( $( this ).siblings( ".main_value_inp" ).val() );
			if ( c_amount < max ) {
				$( ".main_value_inp" ).val( c_amount + 1 );
				if ( $( '.chk_extrafast' ).parents( '.ui.checkbox' )[0] && $( '.chk_extrafast' ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
					if ( c_amount < parseInt( $( '.hid_extrafast' ).data( "max" ) ) ) {
						$( ".chk_extrafast" ).val( c_amount + 1 );
						$( ".hid_extrafast" ).val( c_amount + 1 );
					}
				}
			}
			c_amount_cont = $( ".main_amount_box .current_amount" );


		} else {
			var ob = $( "[name=" + $( this ).parents( 'li' ).find( "[type=checkbox]" ).attr( "name" ) + "]" );
			ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );

			var c_amount = parseInt( c_amount_chk.val() );
			if ( c_amount < max ) {
				c_amount_chk.val( c_amount + 1 );
				$( '.hid_extra' + amountnb ).val( c_amount + 1 );
			}
		}

		if ( $( "#getforfree" ).length != 0 ) {
			$( "#getforfree" ).attr( 'href', $( "#getforfree" ).attr( 'href' ).replace( /amount=[^&]+/, 'amount=' + ( c_amount + 1 ) ) );
		}

		if ( c_amount < max ) {
			c_amount_cont.html( c_amount + 1 );
		}

		updatePurchasePrice();
	});

	// Multiple Remove
	$( '.amount_rmv' ).on( 'click', function( e ) {
		e.preventDefault();
		var amountnb      = $( this ).parents( '.amount_section' ).attr( 'data-amountnb' );
		var c_amount_chk  = $( ".extra_nb_" + amountnb + " label .uzextracheck" );
		var c_amount_cont = $( ".extra_nb_" + amountnb + " .amount_section .current_amount" );
		if ( $( this ).parent().parent().hasClass( "main_amount_box" ) ) {
			var c_amount = parseInt( $( this ).siblings( ".main_value_inp" ).val() );
			if ( c_amount > 1 ) {
				$( ".main_value_inp" ).val( c_amount - 1 );
				if ( $( '.chk_extrafast' ).parents( '.ui.checkbox' )[0] && $( '.chk_extrafast' ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
					if ( c_amount <= ( parseInt( $( '.hid_extrafast' ).data( "max" ) ) + 1 ) ) {
						$( ".chk_extrafast" ).val( c_amount - 1 );
						$( ".hid_extrafast" ).val( c_amount - 1 );
					}
				}
			}
			c_amount_cont = $( ".main_amount_box .current_amount" );
		} else {
			var ob = $( "[name=" + $( this ).parents( 'li' ).find( "[type=checkbox]" ).attr( "name" ) + "]" );
			ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );

			var c_amount = parseInt( c_amount_chk.val() );
			if ( c_amount > 1 )
				c_amount_chk.val( c_amount - 1 );
		}

		if ( $( "#getforfree" ).length != 0 ) {
			$( "#getforfree" ).attr( 'href', $( "#getforfree" ).attr( 'href' ).replace( /amount=[^&]+/, 'amount=' + ( c_amount - 1 ) ) );
		}

		if ( c_amount > 1 ) {
			c_amount_cont.html( c_amount - 1 );
			$( '.hid_extra' + amountnb ).val( c_amount - 1 );
		}

		updatePurchasePrice();
	});

	// Job amount - change
	$( ".main_value_inp" ).on( "change", function() {
		if ( $( "#getforfree" ).length != 0 ) {
			$( "#getforfree" ).attr( 'href', $( "#getforfree" ).attr( 'href' ).replace( /amount=[^&]+/, 'amount=' + $( this ).val() ) );
		}
	});

	// Extra fast delivery - change
	$( ".chk_extrafast" ).change( function() {
		var c_amount = parseInt( $( ".main_amount_box .main_value_inp" ).val() );
		c_amount = isNaN( c_amount ) ? 1 : c_amount;

		if ( $( '.chk_extrafast' ).parents( '.ui.checkbox' )[0] && $( '.chk_extrafast' ).parents( '.ui.checkbox' ).checkbox( 'is checked' ) ) {
			if ( c_amount < parseInt( $( '.hid_extrafast' ).data( "max" ) ) ) {
				$( ".chk_extrafast" ).val( c_amount );
				$( ".hid_extrafast" ).val( c_amount );
			} else {
				$( ".chk_extrafast" ).val( parseInt( $( '.hid_extrafast' ).data( "max" ) ) );
				$( ".hid_extrafast" ).val( parseInt( $( '.hid_extrafast' ).data( "max" ) ) );
			}
		}

	});

	// Prevents the customer from inserting a wrong value and change inp border color to red
	$( '.current_amount' ).on( 'click keyup keypress blur change', function( e ) {
		var ob = $( "[name=" + $(this).parents( 'li' ).find( "[type=checkbox]" ).attr( "name" ) + "]" );
		ob.parents( '.ui.checkbox' ).checkbox( 'set checked' );

		var amountnb = $( this ).parents( '.amount_section' ).attr( 'data-amountnb' );
		$( '.hid_extra' + amountnb ).val( $( this ).val() );
	});

	// Box value
	$( ".current_amount" ).each( function() {
		$( this ).on( "change", function(){
			var amountnb      = $( this ).parents( '.amount_section' ).attr( 'data-amountnb' );
			var c_amount_cont = $( ".extra_nb_" + amountnb + " .amount_section .current_amount" );
			var c_amount_chk  = $( ".extra_nb_" + amountnb + " label .uzextracheck" );

			if ( $( this ).parent().parent().hasClass( "main_amount_box" ) ) {
				c_amount_cont = $( ".main_amount_box .current_amount" );
			}

			var max = parseInt( c_amount_cont.data( "max" ) );
			if ( parseInt( $( this ).val() ) > max ) {
				$( this ).css( { border: '0 solid #ff0000' } ).fadeIn( 'slow' );
				$( this ).val( max );
				$( this ).animate( { borderWidth: 1, borderColor: '#dddddd' }, 2000 );
			}

			c_amount_chk.val( $( this ).val() );

			updatePurchasePrice();
		});
	});

	// Prevent action and propagation
	$( ".amount_section" ).click( function( e ) {
		e.preventDefault();
		e.stopPropagation();
	});

	// Extra - fill box value
	$( ".extrali" ).each( function( ind ) {
		var newamnt = $( ".hid_extra" + parseInt( ind + 1 ) ).val();
		if ( typeof newamnt == 'undefined' ){ newamnt = 1; }
		$( ".chk_extra" + parseInt( ind + 1 ) ).val( newamnt );
		$( this ).find( '.current_amount' ).html( newamnt );
	});
	$( ".extralibot" ).each( function( ind ) {
		var newamnt = $( ".hid_extra" + parseInt( ind + 1 ) ).val();
		if ( typeof newamnt == 'undefined' ) { newamnt = 1; }
		$( ".chk_extra" + parseInt( ind + 1 ) ).val( newamnt );
		$( this ).find( '.current_amount' ).html( newamnt );
	});

	var newamnt_fast = $( ".hid_extrafast" ).val();
	if ( typeof newamnt_fast == 'undefined' ) { newamnt_fast = 1; }
	$( ".chk_extrafast" ).val( newamnt_fast );
	$( ".extra_nb_fast" ).find( '.current_amount' ).html( newamnt_fast );

	var newamnt_rev = $( ".hid_extrarevision" ).val();
	if ( typeof newamnt_rev == 'undefined' ) { newamnt_rev = 1; }
	$( ".chk_extrarevision" ).val( newamnt_rev );
	$( ".extra_nb_revision" ).find( '.current_amount' ).html( newamnt_rev );

	$( ".main_amount_box .main_amount" ).html( $( "[name=myFormPurchase2] .main_amount_box .main_value_inp" ).val() );
	updatePurchasePrice();
});
//------------------------------------------
// Job Packages Functions
//------------------------------------------
function change_color( $this ) {
	var $ = jQuery.noConflict();

	$( '.pc-packages .active' ).removeClass( 'active' );

	var this_index = $this.index();
	var col = $this.parents( 'tbody' ).siblings( 'thead' ).children( 'tr' ).children( 'th:nth(' + this_index + ')' ).index();
	$( 'td' ).filter( ':nth-child(' + ( col + 1 ) + ')' ).addClass( 'active' );
}

function package_selection( $this, $packages_selector, $package_selector, $type ) {
	var $ = jQuery.noConflict();

	$( $packages_selector ).each( function() {
		$( this ).removeClass( 'selected' );
		$( this ).find( $package_selector ).removeClass( 'right' ).removeClass( 'labeled' );
		$( this ).find( $package_selector ).children( 'i.checkmark.icon' ).hide();

		if ( $type == 'sidebar' ) {
			$( this ).find( '.title.active' ).removeClass( 'active' );
			$( this ).find( '.content.active' ).removeClass( 'active' );
		} else if ( $type == 'mobile' ) {
			$( this ).siblings( '.pacakges-tabs' ).children( '.item.active' ).removeClass( 'active' );
			$( this ).removeClass( 'active' );
		}
	});

	$this.parents( $packages_selector ).addClass( 'selected' );
	$this.addClass( 'right' ).addClass( 'labeled' );
	$this.children( 'i.checkmark.icon' ).show();

	if ( $type == 'sidebar' ) {
		$this.parents( '.content' ).addClass( 'active' );
		$this.parents( '.content' ).siblings( '.title' ).addClass( 'active' );
	} else if ( $type == 'mobile' ) {
		$this.parents( '.packages-mobile' ).addClass( 'active' );
		curr_tab = $this.parents( '.packages-mobile' ).attr( 'data-tab' );
		$this.parents( '.packages-mobile' ).siblings( '.pacakges-tabs' ).find( "[data-tab='" + curr_tab + "']" ).addClass( 'active' );
	}
}

//------------------------------------------
// Job Packages
//------------------------------------------
jQuery( document ).ready( function( $ ) {

	// Set package price to total value
	if ( $( '.pck_price_val' ).val() ) {
		$( '.total' ).data( 'price', $( '.pck_price_val' ).val() ).attr( 'data-price', $( '.pck_price_val' ).val() );
	}

	// Delete a Row
	$( document ).on( 'click', '.pck-icon-rem', function( e ) {
		if ( $( '.pck-icon-rem' ).length > 1 ) {
			$( this ).parents( '.pck-repeater' ).remove();
		} else {
			$( '.pck-repeater .ui.checkbox' ).each( function(){
				$( this ).checkbox( 'uncheck' );
			});
			$( '.pck-inp-custom-name' ).val( '' );
		}
	});

	// Add a Row
	$( '#add_custom_field_to_package' ).click( function() {
		var clone = $( '.pck-repeater:first' ).clone();
		clone.find( 'input:text' ).val( '' );
		clone.find( 'input:checkbox' ).removeAttr('checked');
		clone.find( '.pck-icon-rem' ).show();
		clone.appendTo( '.packages tbody' );

		$( '.ui.checkbox' ).checkbox();
	});

	// Select package
	$( '.pck-sidebar-select-package, .pck-mobile-select-package' ).on( 'click', function( e ) {
		var $this = $( this );
		var regex = /[+-]?\d+(\.\d+)?/g;
		var indx = parseFloat( $( this ).attr( 'class' ).match( regex ) );

		$( '.pck-order' ).eq( indx ).trigger( 'click' );

		if( $this.attr('class').match( 'pck-mobile-select-package' ) ) {
			package_selection( $( '.pck-sidebar-select-package.' + indx ), '.packages-sidebar', '.pck-sidebar-select-package', 'sidebar' );
			package_selection( $this, '.packages-mobile', '.pck-mobile-select-package', 'mobile' );
		} else {
			package_selection( $this, '.packages-sidebar', '.pck-sidebar-select-package', 'sidebar' );
			package_selection( $( '.pck-mobile-select-package.' + indx ), '.packages-mobile', '.pck-mobile-select-package', 'mobile' );
		}
	});

	// Send package values
	$( '.pck-order' ).on( 'click', function( e ) {
		var $this         = $( this );
		var current_nth   = $this.index();
		var nth           = current_nth + 1;
		var pck_to_select = current_nth - 1;

		package_selection( $( '.'+pck_to_select ), '.packages-sidebar', '.pck-sidebar-select-package', 'sidebar' );

		// Check the column
		$this.children( 'div' ).children( 'input' ).prop( 'checked', true );

		// Change column color
		change_color( $this );

		// Get float value
		var regex = /[+-]?\d+(\.\d+)?/g;

		// Get and update delivery time
		var deliv_time_unformatted = $this.parent().prev( 'tr' ).prev( 'tr' ).prev( 'tr' ).children( 'td:nth-child( ' + nth + ' )' ).html();
		var deliv_time = parseFloat( deliv_time_unformatted.match( regex ) );
		$( '.single-job-delivery-time' ).html( deliv_time_unformatted );
		$( '.pck_deliv_val' ).val( deliv_time );

		// Get and update the price
		var price_formatted = $this.parent().prev( 'tr' ).children( 'td:nth-child( ' + nth + ' )' ).html();
		$( '.main_amount_box span.extra-price-inside' ).html( price_formatted );

		var price_unformatted = $this.parent().prev( 'tr' ).children( 'td:nth-child( ' + nth + ' )' ).attr( 'data-price' );
		$( '.total' ).data( 'price', price_unformatted ).attr( 'data-price', price_unformatted );
		$( '.pck_price_val' ).val( price_unformatted );
	});

});

jQuery( window ).ready( function( $ ) {
	// On load - trigger standard package click
	$( '.pck-order' ).eq( 1 ).trigger( 'click' );

	// Package - change
	$( '.pck-order, .pck-sidebar-select-package' ).on( 'click', function( e ) {
		updatePurchasePrice();
	});
});

//------------------------------------------
// Post/Edit Job Price
//------------------------------------------
jQuery( document ).ready( function( $ ) {
	var price_placeholder    = $( 'input[name="job_cost"]' ).attr( 'placeholder' );
	var custom_placeholder   = $( 'input[name="job_cost"]' ).attr( 'data-customplaceholder' );
	var packages_placeholder = $( 'input[name="job_cost"]' ).attr( 'data-packages' );

	if ( $( 'select[name="price_type"]' ).val() == 'custom' || $( 'select[name="price_type"]' ).val() == 'package' ) {
		$( 'input[name="job_cost"]' ).prop( 'disabled', true );
		if ( $( 'select[name="price_type"]' ).val() == 'custom' ) {
			$( 'input[name="job_cost"]' ).attr( 'placeholder', custom_placeholder );
		} else if ( $( 'select[name="price_type"]' ).val() == 'package' ) {
			$( 'input[name="job_cost"]' ).attr( 'placeholder', packages_placeholder );
		}
	}

	if ( $( 'select[name="price_type"]' ).val() == 'package' ) {
		$( '.packages' ).show();
		$( '#job_delivery_time_field' ).hide();
		$( '#job_instant_delivery_field' ).hide();
	} else {
		$( '.packages' ).parents( '.fields' ).hide();
	}

	$( 'select[name="price_type"]' ).change( function() {

		if ( $( this ).val() == 'package' ) {

			$( '.packages' ).show();
			$( '.packages' ).parents( '.fields' ).show();
			$( '#job_delivery_time_field' ).hide();
			$( '#job_instant_delivery_field' ).hide();

			$( 'input[name="job_cost"]' ).prop( 'disabled', true );
			$( 'input[name="job_cost"]' ).attr( 'placeholder', packages_placeholder );

		} else {

			$( '.packages' ).hide();
			$( '.packages' ).parents( '.fields' ).hide();
			$( '#job_delivery_time_field' ).show();
			$( '#job_instant_delivery_field' ).show();

			if ( $( this ).val() == 'custom' ) {
				$( 'input[name="job_cost"]' ).prop( 'disabled', true );
				$( 'input[name="job_cost"]' ).attr( 'placeholder', custom_placeholder );
			} else {
				$( 'input[name="job_cost"]' ).prop( 'disabled', false );
				$( 'input[name="job_cost"]' ).attr( 'placeholder', price_placeholder );
			}

		}

		var this_val = $( this ).val();
		Hooks.do_action( 'wpj_after_job_price_type_changed', this_val );

	});
});
jQuery( window ).ready( function( $ ) {

	// Open notification preview box
	var notifications_ajax_load_callback = function( show_icon ) {

		$.ajax({
			type: 'post',
			url : wpj_vars.ajaxurl,
			data: {
				action: 'show_notifications_panel_preview'
			},

			beforeSend: function() {
				$( '.nh-notifications-dropdown' ).each( function() {
					$( this ).html( '' );
					$( this ).addClass( 'loading' );
				});
			},

			success: function( data ) {
				$( '.nh-notifications-dropdown' ).each( function() {
					$( this ).html( data );

					$( this ).removeClass( 'loading' );

					$( ".antiscroll-inner" ).mCustomScrollbar({
						theme:"minimal-dark"
					});
				});
			}
		});
	};

	// Expand user notifications
	$( '.nh-notifications .nh-link' ).click( function( event ) {
		event.preventDefault();

		if ( $( ".nh-notifications-dropdown" ).css( "display" ) == "block" ) {

			$( '.nh-messages' ).attr( 'data-position', 'bottom center' );
			$( '.nh-notifications' ).attr( 'data-position', 'bottom center' );

			$( ".nh-notifications-dropdown" ).css( "display", "none" );

			event.stopPropagation();

		} else {

			$( '.nh-messages' ).attr( 'data-position', 'left center' );
			$( '.nh-notifications' ).attr( 'data-position', 'right center' );

			$( ".nh-notifications-dropdown" ).css( "display", "block" );

			event.stopPropagation();

		}
	});

	$( document ).mouseup( function ( e ) {
		var notifications_container = $( ".nh-notifications-dropdown" );
		var notifications_handler   = $( ".nh-notifications" );

		if ( ! notifications_container.is( e.target ) // if the target of the click isn't the container...
			&& notifications_container.has( e.target ).length === 0 // ... nor a descendant of the container
			&& ! notifications_handler.is( e.target )
			&& notifications_handler.has( e.target ).length === 0 )
		{
			$( '.nh-messages' ).attr( 'data-position', 'bottom center' );
			$( '.nh-notifications' ).attr( 'data-position', 'bottom center' );

			notifications_container.css( "display", "none" );
		}
	});

	// Open messages preview box
	var messages_ajax_load_callback = function( show_icon ) {

		$.ajax({
			type: 'post',
			url : wpj_vars.ajaxurl,
			data: {
				action: 'show_messages_panel_preview'
			},

			beforeSend: function() {
				$( '.nh-messages-dropdown' ).each( function() {
					$( this ).html( '' );
					$( this ).addClass( 'loading' );
				});
			},

			success: function( data ) {
				$( '.nh-messages-dropdown' ).each( function() {
					$( this ).html( data );

					$( this ).removeClass( 'loading' );

					$( ".antiscroll-inner" ).mCustomScrollbar({
						theme:"minimal-dark"
					});
				});
			}
		});
	};

	// Expand user messages
	$( '.nh-messages .nh-link' ).click( function( event ) {
		event.preventDefault();

		if ( $( ".nh-messages-dropdown" ).css( "display" ) == "block" ) {

			$( '.nh-messages' ).attr( 'data-position', 'bottom center' );
			$( '.nh-notifications' ).attr( 'data-position', 'bottom center' );

			$( ".nh-messages-dropdown" ).css( "display", "none" );

			event.stopPropagation();

		} else {

			$( '.nh-messages' ).attr( 'data-position', 'left center' );
			$( '.nh-notifications' ).attr( 'data-position', 'right center' );

			$( ".nh-messages-dropdown" ).css( "display", "block" );

			event.stopPropagation();

		}
	});

	$( document ).mouseup( function ( e ) {
		var messages_container = $( ".nh-messages-dropdown" );
		var messages_handler   = $( ".nh-messages-dropdown" );

		if ( ! messages_container.is( e.target ) // if the target of the click isn't the container...
			&& messages_container.has( e.target ).length === 0 // ... nor a descendant of the container
			&& ! messages_handler.is( e.target )
			&& messages_handler.has( e.target ).length === 0 )
		{
			$( '.nh-messages' ).attr( 'data-position', 'bottom center' );
			$( '.nh-notifications' ).attr( 'data-position', 'bottom center' );

			messages_container.css( "display", "none" );
		}
	});

	$( ".nh-notifications .nh-link" ).each( function() {
		$( this ).click( notifications_ajax_load_callback );
	});

	$( ".nh-messages .nh-link" ).each( function() {
		$( this ).click( messages_ajax_load_callback );
	});
});

jQuery( document ).ready( function( $ ) {

	// delete private message
	$( document ).on( "click", ".js-pm-delete", function( event ) {
		event.preventDefault();

		var url = $( this ).attr( 'data-href' );
		var current_pm = $( this ).parents( ".js-pm-holder" );

		$.ajax({
			url       : url,
			type      : "POST",
			data      : { delete_pm: "1" },
			beforeSend: function(){ },
			success   : function( data ) {
				$( current_pm ).fadeOut( 400, function() { $( this ).remove(); });

				if ( $( ".private-message-from-user div" ).length == 12 ) {
					$( ".private-message-from-user" ).html( "<div class='ui segment error-no-messages'>" + wpj_vars.no_messages + "</div>" );
				}
			}
		});
	});

	// delete private messages from single
	$( document ).on( "click", ".js-pm-action-delete", function( event ) {
		event.preventDefault();

		$.ajax({
			url       : $( this ).attr( 'data-href' ),
			type      : "POST",
			data      : { action_button: "1" },
			beforeSend: function(){ },
			success   : function( data ) {
				$( ".js-pm-holder" ).hide( 400 );
				$( ".pm-ajax-trigger-container" ).hide( 400 );
				window.location.href = $( ".pm-nav-inbox" ).attr( 'href' );
			}
		});
	});

	// archive, unarchive private messages from single
	$( document ).on( "click", ".js-pm-action-archive", function( event ) {
		event.preventDefault();

		$.ajax({
			url: $( this ).attr( 'data-href' ),
			type: "POST",
			data: { action_button: "1" },
			beforeSend: function() {},
			success: function( data ) {
				$( ".js-pm-action-archive" ).toggleClass( "disabled" );

				var newUrl = new URL(window.location.href);

				if ( newUrl.searchParams.get( 'type' ) === 'archived' ) {
					newUrl.searchParams.delete( 'type' );
					window.location.href = newUrl.href;

				} else {
					newUrl.searchParams.set( 'type', 'archived' );
					window.location.href = newUrl.href;
				}
			}
		});
	});

	// delete, archive, unarchive conversations from list
	$( document ).on( "click", ".js-tpm-action-listener", function( event ) {
		event.preventDefault();

		var url = $( this ).attr( 'data-href' );
		var current_pm = $( this ).parents( ".js-tpm-holder" );

		$.ajax({
			url       : url,
			type      : "POST",
			data      : { action_button: "1" },
			beforeSend: function() {},
			success   : function( data ) {
				$( current_pm ).hide( 400 );

				var actionUrl = new URL(url);
				var newUrl = new URL(window.location.href);

				if ( actionUrl.searchParams.get( 'username' ) === newUrl.searchParams.get( 'username' ) ) {

					if ( actionUrl.searchParams.get( 'unarchive_conversation' ) === '1' ) {
						newUrl.searchParams.delete( 'type' );
						window.location.href = newUrl.href;
					}

					if ( actionUrl.searchParams.get( 'archive_conversation' ) === '1' ) {
						newUrl.searchParams.set( 'type', 'archived' );
						window.location.href = newUrl.href;
					}

					if ( actionUrl.searchParams.get( 'delete_conversation' ) === '1' ) {
						newUrl.searchParams.delete( 'username' );
						window.location.href = newUrl.href;
					}
				}
			}
		});
	});

	// scroll to last message
	if ( $( ".pm-holder" ).length && wpj_vars.is_page_pm_single == 1 ) {
		$( 'html, body' ).animate({
			scrollTop: $( ".pm-holder" ).last().offset().top - 94
		}, 1000);
	}

	// private message ajax no page reload
	jQuery( document ).on( 'click', '.cmi-listen.message-field', function( e ) {
		$( '.wrapper-pm-errors' ).fadeOut( 600 );
	});

	// send message with ENTER key
	wpj_send_message_with_enter( '.submit-private-message' );

	$( '.submit-private-message' ).click( function( e ) {
		e.preventDefault();

		var otheruid = $( this ).attr( 'data-otheruid' );

		if ( wpj_vars.pm_emoji_enabled != 'no' ) {
			var message = wpj_validate_input_content( $( '.cmi-listen.message-field' ).data( 'emojioneArea' ).getText() );
		} else {
			var message = wpj_validate_input_content( $( '.cmi-listen.message-field' ).val() );
		}

		var upload     = $( 'input[name="hidden_files_pm_attachments"]' ).val();
		var request_id = $( '#pm_request_id' ).val();
		var job_id     = $( '#pm_job_id' ).val();

		if ( wpj_vars.pm_emoji_enabled != 'no' ) {
			var message_length = get_input_length_emoji( $( '.cmi-listen.message-field' ).data( 'emojioneArea' ).getText() );
		} else {
			var message_length = get_input_length( $( '.cmi-listen.message-field' ) );
		}

		if ( message == "" ) {

			wpj_focus_pm_input();

		} else if ( message_length < parseInt( wpj_vars.characters_pm_min ) ) {

			$( '.wrapper-pm-errors' ).hide().html( '<div class="ui small error message"> ' + wpj_vars.pm_min_content + ' </div>' ).fadeIn( 600 );
			wpj_focus_pm_input();

		} else if ( message_length > parseInt( wpj_vars.characters_pm_max ) ) {

			$( '.wrapper-pm-errors' ).hide().html( '<div class="ui small error message"> ' + wpj_vars.pm_max_content + ' </div>' ).fadeIn( 600 );
			wpj_focus_pm_input();

		} else {

			jQuery.ajax({
				type: 'post',
				url : wpj_vars.ajaxurl,
				data: {
					action    : 'wpj_ajax_send_message_users',
					otheruid  : otheruid,
					message   : message,
					upload    : upload,
					request_id: request_id,
					job_id    : job_id,
				},
				beforeSend: function() {
					$( '.send-my-pm' ).addClass( 'loading' );
					$( '.submit-private-message' ).addClass( 'disabled' );
				},
				success: function( data ) {
					$( '.private-message-from-user' ).append( data );
					$( '#user_messages' ).find( 'a[data-user-id="' + otheruid + '"] .js-tpm-text' ).html( message );
				},
				error: function( response ) {
					console.log( 'oops' );
				},
				complete: function() {
					$( '.send-my-pm' ).removeClass( 'loading' );
					$( '.submit-private-message' ).removeClass( 'disabled' );

					$( '.ui.dropdown' ).dropdown();

					$( '.error-no-messages' ).remove();
				}
			});

			// clear the inout
			$( '#message-pm-user' ).val( '' );
			$( '#message-pm-user' ).css( 'height', 'auto' );

			if ( wpj_vars.pm_emoji_enabled != 'no' ) {
				$( '.emojionearea-editor' ).text( '' );
			}

			// focus the input
			wpj_focus_pm_input();

			// clear the attachments queue
			$( '#uploadifive-file_upload_pm_attachments-queue' ).empty();

			// clear the errors
			$( '.wrapper-pm-errors' ).hide()

		}

	});

	// init pm counter
	jQuery( ".charlimit-message" ).counted({ count: wpj_vars.characters_pm_max });

	// auto-resize textarea based on input
	if ( wpj_vars.is_page_pm_single == 1 ) {

		// TODO: doesn't work on window resize
		$('.cmi-listen.message-field').each(function () {
			// note: this breaks the emojionearea input on Firefox
			// this.setAttribute('style', 'height:' + (this.scrollHeight) + 'px;overflow-y:hidden;');
		}).on('input propertychange change blur', function () {
			this.style.height = 'auto';
			this.style.height = (this.scrollHeight) + 'px';
		});

		MutationObserver = window.MutationObserver || window.WebKitMutationObserver;
		var observer = new MutationObserver(function(mutations, observer) {
			// fired when a mutation occurs
			// note: this triggers 70 times on first input focus for some reason

			// auto-resize content container based on input
			jQuery('.thread-wrapper').css('margin-bottom', jQuery('.thread-input').height());
		});

		// define what element should be observed by the observer
		// and what types of mutations trigger the callback
		observer.observe(document, {
			subtree: true,
			attributes: true,
			childList: true
			//...
		});
	}

	// focus pm input
	wpj_focus_pm_input();

	// settings popup position for mobile
	jQuery( window ).on( 'load resize', _.debounce( function() {
		if ( jQuery( '.js-switch-position-mobile' ).length ) {
			if ( $( this ).width() <= ( 767 ) ) {
				jQuery( '.js-switch-position-mobile' ).removeClass( 'right' );
				jQuery( '.js-switch-position-mobile' ).addClass( 'left' );
			} else {
				jQuery( '.js-switch-position-mobile' ).removeClass( 'left' );
				jQuery( '.js-switch-position-mobile' ).addClass( 'right' );
			}
		}
	}, 200 ) );

	// fire lazy load on messages scroll
	jQuery( '.thread-viewport' ).on( 'scroll', _.debounce( function(){
		if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
			jQuery.fn.echoLazyLoadRender();
		}
	}, 200 ) );

	jQuery( '.thread-list-viewport' ).on( 'scroll', _.debounce( function(){
		if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
			jQuery.fn.echoLazyLoadRender();
		}
	}, 200 ) );

});

function wpj_focus_pm_input() {
	if ( wpj_vars.is_page_pm_single == 1 ) {
		if ( wpj_vars.pm_emoji_enabled != 'no' ) {
			setTimeout(function(){
				jQuery( '.emojionearea-editor' ).focus();
			}, 300) // wait for emojionearea to be ready, there is no ready event
		} else {
			jQuery( '#message-pm-user' ).focus();
		}
	}
}

function wpj_unarchive_pm_conversation( user_nicename ) {
	jQuery.ajax({
		url    : wpj_vars.privurl_m + 'username=' + user_nicename + '&unarchive_conversation=1',
		type   : "POST",
		data   : { action_button: "1" },
		success: function( data ) {}
	});
}

function wpj_send_message_with_enter( button_class ) {

	jQuery( '.ui.checkbox.send-message-enter-key' ).checkbox({
		onChange: function() {
			jQuery.ajax({
				type: 'post',
				url : wpj_vars.ajaxurl,
				data: {
					action: 'pm_enter_key',
					value : jQuery( '#pm-enter-key' ).is( ':checked' ) ? true : false,
				},
				success: function( data ) {}
			});
		}
	});


	jQuery( document ).on( 'keypress', '.cmi-listen.message-field', function( e ) {

		if ( jQuery( '#pm-enter-key' ).is( ':checked' )
			&& jQuery( window ).width() > 767 ) {

			if ( e.keyCode == 13 && ! e.shiftKey ) {
				e.preventDefault();
				jQuery( button_class ).trigger( 'click' );
			}

		}

	});

}
jQuery( document ).ready( function( $ ) {

	// New quick response
	$( document ).on( 'click', '#new-quick-response', function( e ) {

		var uid = $( this ).attr( 'data-uid' );

		$( '#new-quick-response-modal-' + uid ).find( '.header' ).first().html( wpj_vars.add_quick_response );

		$( '#new-quick-response-modal-' + uid )
			.modal({
				onVisible: function() {
					// clear the inputs
					$( '#new-quick-response-modal-' + uid ).find( '.quick-response-name-input' ).val( '' );
					$( '#new-quick-response-modal-' + uid ).find( '.quick-response-content-textarea' ).val( '' );
					$( '#new-quick-response-modal-' + uid ).find( '.edit-action' ).val( '' );
				}
			})
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' )
			.modal( 'refresh' );

	});

	// Edit quick response
	$( document ).on( 'click', '#edit-quick-response', function( e ) {

		e.preventDefault();

		// Remove autocomplete text
		var this_editor = wpj_get_editor_element( $( this ) );

		this_editor.html( '' );

		var id  = $( this ).attr( 'data-id' );
		var uid = $( this ).attr( 'data-uid' );

		$( '#new-quick-response-modal-' + uid ).find( '.header' ).first().html( wpj_vars.edit_quick_response );

		var last_quick_response = JSON.parse( localStorage.getItem( 'last_quick_response' ) );

		if ( wpj_vars.quick_responses.hasOwnProperty( id ) ) {
			var name    = wpj_vars.quick_responses[id].name;
			var content = wpj_vars.quick_responses[id].content;

		} else {
			var name    = last_quick_response[1];
			var content = last_quick_response[2];

		}

		$( '#new-quick-response-modal-' + uid )
			.modal({
				onVisible: function() {
					$( this ).find( '.quick-response-name-input' ).val( name );
					$( this ).find( '.quick-response-content-textarea' ).val( content );
					$( this ).find( '.edit-action' ).val( id );
				}
			})
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' )
			.modal( 'refresh' );

	});

	// Save quick response
	$( document ).on( 'click', '#save-quick-response', function( e ) {

		var uid               = $( this ).attr( 'data-uid' );
		var this_modal_elem   = $( this ).parents( '#new-quick-response-modal-' + uid );
		var this_select_elemt = $( '.quick-response-dropdown' );

		// get name and content
		var name    = this_modal_elem.find( '.quick-response-name-input' ).val();
		var content = this_modal_elem.find( '.quick-response-content-textarea' ).val();

		if ( name && content ) {

			// hide errors
			$( '#quick-response-error' ).html( '' ).addClass( 'hidden' ).removeClass( 'visible' );

			// hide modal
			this_modal_elem.modal( 'hide' );

			// generate array of existing numbers for data_id
			var restricted = [0];
			if ( this_select_elemt.find( '.menu' ).find( '.item' )[0] ) {
				this_select_elemt.find( '.menu' ).find( '.item' ).each( function() {
					restricted.push( $( this ).attr( 'data-id' ) );
				});
			}

			// get last quick response id
			if ( this_modal_elem.find( '.edit-action' ).val() ) {
				var data_id = this_modal_elem.find( '.edit-action' ).val();
			} else {
				var data_id = wpj_generate_number( restricted );
			}

			// save content to localstorage
			localStorage.setItem( 'last_quick_response', JSON.stringify( [data_id, name, content] ) );

			// insert/edit quick response to dropdown
			if ( this_modal_elem.find( '.edit-action' ).val() ) {

				this_select_elemt.find( '.menu' ).find( '.item[data-id="' + this_modal_elem.find( '.edit-action' ).val() + '"]' ).find( 'span' ).text( name );

			} else {

				// display delete all link
				$( '.quick-response-dropdown' ).find( '#delete-all-quick-responses-wrapper' ).show();

				// remove no quik responses item
				$( '.quick-response-dropdown' ).find( '#no-quick-responses' ).remove();

				var new_item = '\
					<div class="item" data-id="' + data_id + '">\
						\
						<span>' + name.substring( 0, 25 ) + '</span>\
						\
						<div class="action-buttons float-right">\
								<i data-uid="' + uid + '" data-id="' + data_id + '" id="edit-quick-response" class="edit icon"></i>\
								<i data-uid="' + uid + '" data-id="' + data_id + '" id="remove-quick-response" class="close red icon"></i>\
						</div>\
						\
					</div>\
				';
				$( new_item ).insertAfter( this_select_elemt.find( '.menu' ).find( '.header:nth-child(3)' ) );

			}

			// clear the inputs
			$( '.quick-response-name-input' ).val( '' );
			$( '.quick-response-content-textarea' ).val( '' );

			// save quick response
			$.ajax({
				type : 'post',
				url  : wpj_vars.ajaxurl,
				data : {
					action : 'save_quick_response',
					uid    : uid,
					id     : data_id,
					name   : name,
					content: content,
					is_ajax: true
				},
				success : function( data ) {

				}
			});

		} else {
			$( '#quick-response-error' ).html( wpj_vars.empty_quick_response ).removeClass( 'hidden' ).addClass( 'visible' );

		}

	});

	// Remove quick response
	$( document ).on( 'click', '#remove-quick-response', function( e ) {

		e.preventDefault();

		var id  = $( this ).attr( 'data-id' );
		var uid = $( this ).attr( 'data-uid' );

		// Remove autocomplete text
		var this_editor = wpj_get_editor_element( $( this ) );

		this_editor.html( '' );

		var this_select_elemt = $( '.quick-response-dropdown' );

		$( '.item[data-id="' + id + '"]' ).remove();

		// if no quick responses
		if ( ! this_select_elemt.find( '.menu' ).find( '.item' )[0] ) {

			// add no quik responses item
			var no_responses_item = '<div class="item" id="no-quick-responses">' + wpj_vars.no_quick_responses + '</div>';
			$( no_responses_item ).insertAfter( this_select_elemt.find( '.menu' ).find( '.header:nth-child(3)' ) );

			// hide delete all link
			$( '.quick-response-dropdown' ).find( '#delete-all-quick-responses-wrapper' ).hide();

		}

		// delete quick response
		$.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action : 'delete_quick_response',
				id     : id,
				uid    : uid,
				is_ajax: true
			},
			success : function( data ) {

			}
		});

	});

	// INIT 'Remove all quick responses' MODAL
	$( document ).on( 'click', '#delete-all-quick-responses', function( e ) {

		var uid = $( this ).attr( 'data-uid' );

		$( '#delete-all-quick-responses-modal-' + uid )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' )
			.modal( 'refresh' );

	});

	// Remove all quick responses action
	$( document ).on( 'click', '#delete-all-quick-responses-action', function( e ) {

		var uid               = $( this ).attr( 'data-uid' );
		var this_select_elemt = $( '.quick-response-dropdown' );

		// Remove autocomplete text
		var this_editor = wpj_get_editor_element( $( this ) );

		this_editor.html( '' );

		// hide delete all link
		$( '.quick-response-dropdown' ).find( '#delete-all-quick-responses-wrapper' ).hide();

		// hide modal
		var this_modal_elem = $( this ).parents( '#delete-all-quick-responses-modal-' + uid );
		this_modal_elem.modal( 'hide' );

		// delete items
		this_select_elemt.find( '.menu' ).find( '.item' ).each( function() {
			$( this ).remove();
		});

		// add no quik responses item
		var no_responses_item = '<div class="item" id="no-quick-responses">' + wpj_vars.no_quick_responses + '</div>';
		$( no_responses_item ).insertAfter( this_select_elemt.find( '.menu' ).find( '.header:nth-child(3)' ) );

		// delete all quick responses
		$.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action : 'delete_quick_responses',
				uid    : uid,
				is_ajax: true
			},
			success : function( data ) {

			}
		});

	});

	// Select quick response
	window.onload = function() {
		if ( $( '.quick-response-dropdown' ).length ) {
			$( '.quick-response-dropdown' ).dropdown( 'setting', 'onChange', function( value, text, selected_item ) {

				var $this = $( this );
				wpj_insert_quick_response_to_textarea( selected_item, $this );

			});
		}
	}

});

function wpj_insert_quick_response_to_textarea( selected_item, wrapper ) {

	if ( selected_item ) {

		var sel_item            = jQuery( selected_item ).data( 'id' );
		var last_quick_response = JSON.parse( localStorage.getItem( 'last_quick_response' ) );

		if ( sel_item ) {

			if ( wpj_vars.quick_responses.hasOwnProperty( sel_item ) ) {

				if ( last_quick_response && last_quick_response[0] == sel_item ) {

					if ( wpj_vars.quick_responses[sel_item].content == last_quick_response[2] ) {
						var message = wpj_vars.quick_responses[sel_item].content;

					} else {
						var message = last_quick_response[2];

					}

				} else {
					var message = wpj_vars.quick_responses[sel_item].content;

				}

			} else {
				var message = last_quick_response[2];

			}

			message = message.replace( '{username}', wrapper.attr( 'data-username' ) );

			var this_editor = wpj_get_editor_element( wrapper );

			this_editor.html( message );

			this_editor.focus();

			// move curost to the end of the text
			document.execCommand( 'selectAll', false, null );
			document.getSelection().collapseToEnd();

		}

	}

}

function wpj_get_editor_element( wrapper ) {
	if ( wrapper.parents( '.emoji-enabled' )[0] ) {
		return wrapper.parents( '.emoji-enabled' ).find( '.emojionearea-editor' );

	} else {
		if ( wrapper.parents( '.message-box-wrapper' )[0] ) {
			return wrapper.parents( '.message-box-wrapper' ).find( '.message-field' );

		} else if ( wrapper.parents( '.thread-input' )[0] ) {
			return wrapper.parents( '.thread-input' ).find( '.message-field' );

		} else {
			return wrapper.parents( '.quick-response-wrapper' ).siblings( '.message-field' );

		}

	}
}
jQuery( document ).ready( function( $ ) {

	// Fill request subcategory by selected categories
	$( '#request_category_field' ).find( '.delete.icon' ).click( function() {
		$( '#request_category' ).trigger( 'change' );
	});

	$( '#request_category' ).on( 'change rightnow', function( e ) {
		if ( $( this ).val().length !== 0 ) {
			var vals = $( this ).val() instanceof Array ? $( this ).val().join( ',' ) : $( this ).val();

			$.post( wpj_vars.blog_url + "/?get_subcats_for_me=1", { queryString: vals, multiple: wpj_vars.request_multiple, term_val_type: 'slug' }, function( data ) {

				if ( data && data.match( /option/g ).length > 2 ) {
					$( '#request_subcategory_field' ).show();

					if ( e.type == 'change' ) {
						$( '#request_subcategories' ).html( data );
					}

					$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
				} else {
					$( '#request_subcategory_field' ).hide();
				}

			});
		} else {
			$( '#request_subcategory_field' ).hide();
		}
	}).triggerHandler( 'rightnow' );

	// Initialize counted fields
	jQuery( ".charlimit-request-title" ).counted( {count:wpj_vars.characters_title_max} );
	jQuery( ".charlimit-request-description" ).counted( {count:wpj_vars.characters_description_max} );

	// Show/hide fields on let's meet
	$( '#request_lets_meet' ).change( function() {
		if ( this.checked ) {
			$( '.js-location-item' ).removeClass( 'hidden' );
			$( '.js-location-item' ).parent().removeClass( 'hidden' );
		} else {
			$( '.js-location-item' ).addClass( 'hidden' );
			$( '.js-location-item' ).parent().addClass( 'hidden' );
		}
	});

	// Hide div when field is disabled from admin
	jQuery( '.fields' ).each( function() {
		var this_id             = $( this );
		var hidden_fields_count = 0;
		var fields_count        = 0;

		this_id.children( '.field' ).each( function () {
			fields_count++;
			if ( $( this ).hasClass( 'hidden' ) ) {
				hidden_fields_count++;
			}
		});

		if ( fields_count == hidden_fields_count ) {
			this_id.addClass( 'hidden' );
		}
	});

	// Save autodraft post values
	// when "suggest" button is clicked
	$( '#add-edit-request-form' ).click( function() {
		if ( $( this ).attr( 'data-operation' ) == 'new' ) {
			jQuery.ajax({
				type: 'post',
				url : wpj_vars.ajaxurl,
				data: $( this ).serialize(),
				success: function( data ) {}
			});
		}
	});

});

// Validation
jQuery( document ).ready( function( $ ) {
	$.fn.form.settings.rules.request_budget = function ( inputValue ) {
		if ( $( '#request_budget_to' ).val() ) {
			return parseFloat( inputValue ) < parseFloat( $( '#request_budget_to' ).val() );
		} else {
			return true;
		}
	}

	$.fn.form.settings.rules.request_date = function ( inputValue ) {
		if ( $( '#request_end_date' ).val() ) {
			return parseInt( $( 'input[name="request_start_date"]' ).val() ) < parseInt( $( 'input[name="request_end_date"]' ).val() );
		} else {
			return true;
		}
	}

	var fields_arr = {
		title: {
			identifier : 'request_title',
			rules: [
				{
					type   : 'empty',
					prompt : wpj_vars.lbl_request_title_empty
				},
				{
					type   : 'minLength[' + wpj_vars.characters_title_min + ']',
					prompt : wpj_vars.lbl_request_title_min,
				},
				{
					type   : 'maxLength[' + wpj_vars.characters_title_max + ']',
					prompt : wpj_vars.lbl_request_title_max,
				}
			]
		},
		description: {
			identifier : 'request_description',
			rules: [
				{
					type   : 'empty',
					prompt : wpj_vars.lbl_request_description_empty
				},
				{
					type   : 'minLength[' + wpj_vars.characters_description_min + ']',
					prompt : wpj_vars.lbl_request_description_min,
				},
				{
					type   : 'maxLength[' + wpj_vars.characters_description_max + ']',
					prompt : wpj_vars.characters_request_description_max,
				}
			]
		},
		category: {
			identifier : 'request_category',
			rules: [{
				type   : 'empty',
				prompt : wpj_vars.lbl_request_category
			}]
		},
		budget: {
			identifier : 'request_budget_from',
			rules: [{
				type   : 'request_budget',
				prompt : wpj_vars.lbl_request_budget
			}]
		},
		date: {
			identifier : 'request_start_date-old',
			rules: [{
				type   : 'request_date',
				prompt : wpj_vars.lbl_request_date
			}]
		},
	};

	fields_arr = Hooks.apply_filters( 'wpj_fields_validation_filter', fields_arr, 'request' );

	jQuery( '#add-edit-request-form' ).form({
		on: 'blur',
		keyboardShortcuts: false,
		fields: fields_arr,
		onSuccess : function( e ) {
			if ( wpj_vars.is_user_logged_in != true ) {
				openRegisterModal( e );
			}
		}
	});
});

// Activate / Deactivate / Delete Modals
jQuery( function( $ ) {

	function wpj_change_request_section( my_id, status ) {

		// Increment and decrement requests count tab
		var current_tab = '';
		if ( status == 'inactive' ) { current_tab = 'active';
			jQuery( '.ticket-count-active' ).text( parseInt( jQuery( '.ticket-count-active' ).text() ) - 1 );
			jQuery( '.ticket-count-inactive' ).text( parseInt( jQuery( '.ticket-count-inactive' ).text() ) + 1 );
		} else if ( status == 'active' ) { current_tab = 'inactive';
			jQuery( '.ticket-count-active' ).text( parseInt( jQuery( '.ticket-count-active' ).text() ) + 1 );
			jQuery( '.ticket-count-inactive' ).text( parseInt( jQuery( '.ticket-count-inactive' ).text() ) - 1 );
		}

		// Show table header if initially no requests
		if ( $( '.no-requests-message' )[0] ) {
			$( '.no-requests-message' ).remove();
			jQuery( 'div.ui.tab[data-tab="' + status + '"]' ).find( '.wpj-grid-table' ).show();
		}

		// Move request to correct tab
		jQuery( '.background-request-' + my_id ).detach().prependTo( jQuery( 'div.ui.tab[data-tab="' + status + '"]' ).find( '#job_listings' ) );

		// Change active tab
		jQuery( '.item.force-white-btn[data-tab="' + status + '"]' ).trigger( 'click' );

		// Add no requests text if no more requests
		if ( ! jQuery.trim( jQuery( 'div.ui.tab[data-tab="' + current_tab + '"]' ).find( '#job_listings' ).text() ) ) {
			jQuery( 'div.ui.tab[data-tab="' + current_tab + '"]' ).find( '.wpj-grid-table' ).hide();
			jQuery( 'div.ui.tab[data-tab="' + current_tab + '"]' ).find( '#job_listings' ).parents( '.ui.tab' ).append( '<span class="no-requests-message">' + wpj_vars.no_requests + '</span>' );
		}
	}

	$( document ).on( 'click', '.open-deactivate-request', function() {
		$( '.ajax_deactivate_request' ).attr( 'data-id', $( this ).attr( 'data-id' ) );

		$( '.request-title-modal' ).html( wpj_validate_input_content( $( this ).attr( 'data-title' ) ) );

		$( '.ui.modal.deactivate-request' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_deactivate_request', function( event ) {

		event.preventDefault();

		var my_id = $( this ).attr( 'data-id' );

		jQuery.ajax({
			type: 'post',
			url : wpj_vars.ajaxurl,
			data: {
				action      : 'wpj_ajax_deactivate_request',
				var_post_id : my_id
			},
			beforeSend: function() {
				$( '.ajax_deactivate_request' ).addClass( 'loading' );
			},
			success: function( response ) {
				if ( response == 'success' ) {
					$( '.background-request-' + my_id + ' .open-deactivate-request' ).html( wpj_vars.activate );
					$( '.background-request-' + my_id + ' .open-deactivate-request' ).addClass( 'open-activate-request' ).removeClass( 'open-deactivate-request' );
					$( '.background-request-' + my_id + ' .request-status .oe-green' ).addClass( 'oe-yellow' ).removeClass( 'oe-green' );
					$( '.background-request-' + my_id + ' .request-status .oe-yellow' ).html( wpj_vars.paused );

					$( '.ui.modal.deactivate-request' ).modal( 'hide' );

					wpj_change_request_section( my_id, 'inactive' );

				} else if ( response == 'not_your_post' ) {
					$( '.content.deactivate-request' ).text( 'This is not your post.' );
				} else if ( response == 'not_logged_in' ) {
					$( '.content.deactivate-request' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_deactivate_request' ).removeClass( 'loading' );
			}
		});

		return false;
	});

	$( document ).on( 'click', '.open-activate-request', function() {
		$( '.ajax_activate_request' ).attr( 'data-id', $( this ).attr( 'data-id' ) );

		$( '.request-title-modal' ).html( wpj_validate_input_content( $( this ).attr( 'data-title' ) ) );

		$( '.ui.modal.activate-request' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_activate_request', function( event ) {
		var my_id = $( this ).attr( 'data-id' );

		event.preventDefault();

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action      : 'wpj_ajax_activate_request',
				var_post_id : my_id
			},
			beforeSend: function() {
				$( '.ajax_activate_request' ).addClass( 'loading' );
			},
			success: function( response ) {

				if ( response == 'success' ) {
					$( '.background-request-' + my_id + ' .open-activate-request' ).html( wpj_vars.deactivate );
					$( '.background-request-' + my_id + ' .open-activate-request' ).addClass( 'open-deactivate-request' ).removeClass( 'open-activate-request' );
					$( '.background-request-' + my_id + ' .request-status .oe-yellow' ).addClass( 'oe-green' ).removeClass( 'oe-yellow' );
					$( '.background-request-' + my_id + ' .request-status .oe-green' ).html( wpj_vars.published );

					$( '.ui.modal.activate-request' ).modal( 'hide' );

					wpj_change_request_section( my_id, 'active' );

				} else if ( response == 'not_your_post' ) {
					$( '.content.activate-request' ).text( 'This is not your post.' );
				} else if ( response == 'no_credits' ) {
					$( '.content.activate-request' ).text( wpj_vars.no_credits );
				} else if ( response == 'not_logged_in' ) {
					$( '.content.activate-request' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_activate_request' ).removeClass( 'loading' );
			}
		});

		return false;
	});

	$( document ).on( 'click', '.request-open-modal', function() {
		$( '.ajax_delete_request' ).attr( 'data-request-id', $( this ).attr( 'data-request-id' ) );

		$( '.request-title-modal' ).html( $( this ).attr( 'data-title-request' ) );

		$( '.ui.modal.delete-request' )
			.modal( 'setting', 'transition', 'fly down' )
			.modal( 'show' );
	});

	$( document ).on( 'click', '.ajax_delete_request', function( event ) {

		event.preventDefault();

		var my_id = $( this ).attr( 'data-request-id' );

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action      : 'wpj_ajax_request_delete',
				var_post_id : my_id
			},
			beforeSend: function() {
				$( '.ajax_delete_request' ).addClass( 'loading' );
			},
			success: function( response ) {
				if ( response = 'success' ) {

					// Remove current request
					$( '.background-request-' + my_id ).css( 'background-color', '#df3f3f' );
					$( '.background-request-' + my_id ).slideUp( 800, function() {

						$( this ).remove();

						// Close modal
						$( '.ui.modal.delete-request' ).modal( 'hide' );

						// Name of active tab
						var active_tab  = jQuery( '.item.force-white-btn.active' ).attr( 'data-tab' );

						// Decrement requests count tab
						var active_elem = jQuery( 'div.item.force-white-btn[data-tab="' + active_tab + '"]' );
						active_elem.find( 'span' ).text( parseInt( active_elem.find( 'span' ).text() ) - 1 );

						// Add no requests text if no more requests
						if ( ! jQuery.trim( jQuery( 'div.ui.tab[data-tab="' + active_tab + '"]' ).find( '#job_listings' ).text() ) ) {
							jQuery( 'div.ui.tab[data-tab="' + active_tab + '"]' ).find( '.wpj-grid-table' ).remove();
							jQuery( 'div.ui.tab[data-tab="' + active_tab + '"]' ).append( '<span class="no-request-message">' + wpj_vars.no_requests + '</span>' );
						}

					});

				} else if ( response = 'not_your_post' ) {
					$( '.content.delete-request' ).text( 'This is not your post.' );
				} else if ( response = 'not_logged_in' ) {
					$( '.content.delete-request' ).text( 'You need to login.' );
				}
			},
			error: function( response ) {
				console.log( 'Error: ' + response );
			},
			complete: function() {
				$( '.ajax_delete_request' ).removeClass( 'loading' );
			}
		});

		return false;
	});
});

// View more button & Errors
jQuery( window ).ready( function( $ ) {
	$.fn.requestFunctions = function() {
		$( 'html' ).on( 'click', function() {
			$( ".request-error-container" ).slideUp( 400 );
		});

		$( 'html' ).on( 'click', '.request-error', function( event ) {
			if ( $( this ).siblings( ".request-error-container" ).css( "display" ) == "inline-block" ) {
				$( this ).siblings( ".request-error-container" ).slideUp( 400 );
				event.stopPropagation();
			} else {
				$( this ).siblings( ".request-error-container" ).slideDown( 400 );
				event.stopPropagation();
			}
		});

		$( 'html' ).on( 'click', '.request-view-more-link', function( event ) {
			var attr = $( this ).attr( 'href' );
			if ( typeof attr === typeof undefined || attr === false ) {
				if ( $( this ).parents( '.request-job-wrapper' ).find( '.request-content-view-more' ).is( ':visible' ) ) {
					$( this ).text( wpj_vars.view_more );
				} else {
					$( this ).text( wpj_vars.show_less );
				}
			}

			var requestid = $( this ).data( 'requestid' );
			$( '#request-' + requestid + ' .request-right-view-more' ).slideToggle( 400 );
			$( '#request-' + requestid + ' .request-content-view-more' ).slideToggle( 400 );
			$( '#request-' + requestid + ' .request-content-title' ).slideToggle( 400 );

			if ( $( '#request-' + requestid + ' .request-content-view-more' ).css( "display" ) != "none" ) {
				$( '#request-' + requestid + ' .request-map' ).each( function() {
					var embed ="<iframe class='request-google-map' frameborder='0' scrolling='no' marginheight='0' marginwidth='0' src='https://maps.google.com/maps?&amp;q=" + encodeURIComponent( $( this ).data( 'address' ) ) + "&amp;output=embed'></iframe>";
					$( this ).html( embed );
				});
			}
		});
	}

	$.fn.requestFunctions();
});

jQuery( document ).ready( function( $ ) {

	var search_jobs_url     = wpj_vars.search_jobs_url + '?term=';
	var search_requests_url = wpj_vars.search_requests_url + '?term=';
	var search_users_url    = wpj_vars.search_users_url + '?user=';
	var user_profile_url    = wpj_vars.user_profile_url;
	var jobs_label          = wpj_vars.jobs_label;
	var requests_label      = wpj_vars.requests_label;
	var users_label         = wpj_vars.users_label;
	var search_users_label  = '<span class="no-highlight">' + wpj_vars.search_users_label + '</span> ';

	$('.nh-search-container').each( function() {
		search_autocomplete_init( $(this) );
	});
	$('.autocomplete-search').each( function() {
		search_autocomplete_init( $(this) );
	});
	$('.wpj-search-autocomplete').each( function() {
		search_autocomplete_init( $(this) );
	});

	// search init
	function search_autocomplete_init( $container ) {
		var search_timeout;

		var $input = $container.find('input[type="text"]');
		$input.on('keyup keydown keypress', function() {
			$container.addClass('loading');
			clearTimeout(search_timeout);
			search_timeout = setTimeout(function() {
				search_when_done_typing($container, $input);
			}, 250);
		});

		$container.append('<div class="autocomplete-list-container"></div>');
		//$container.append('<i class="autocomplete-icon notched circle loading icon" style="display: none"></i>');

		var $list = $container.find('.autocomplete-list-container');

		$('html').click(function() {
			$list.slideUp(150);
		});

		$container.click(function(event) {
			$list.slideDown(150);
			event.stopPropagation();
		});
	}



	// search ajax
	function search_when_done_typing( $container, $input ) {

		function autocomplete_item_html( item_html, item_input, item_class ) {

			if ( item_class == '' ) {
				item_class = 'autocomplete';
			}

			var cnt_open  = '';
			var cnt_close = '';

			if ( item_input != '' ) {
				cnt_open  = '<div class="autocomplete-text">';
				cnt_close = '</div>';
			}

			var a_href_open  = '';
			var a_href_close = '';
			var item_icon    = '';

			if ( item_class == 'autocomplete-search-jobs' ) {
				a_href_open  = '<a href="' + search_jobs_url + item_input + '" class="js-internal">';
				a_href_close = '</a>';
				item_icon    = '<i class="search icon"></i>';
			}
			if ( item_class == 'autocomplete-search-requests' ) {
				a_href_open  = '<a href="' + search_requests_url + item_input + '" class="js-internal">';
				a_href_close = '</a>';
				item_icon    = '<i class="search icon"></i>';
			}
			if ( item_class == 'autocomplete-search-users' ) {
				a_href_open  = '<a href="' + search_users_url + item_input + '" class="js-internal">';
				a_href_close = '</a>';
				item_icon    = '<i class="search icon"></i>';
			}
			if ( item_class == 'autocomplete-user' ) {
				a_href_open  = '<a href="' + user_profile_url + item_input + '" class="js-internal">';
				a_href_close = '</a>';
				item_icon    = '<i class="user icon"></i>';
			}

			var item_return =
				'<div class="autocomplete-item">'
					+ a_href_open
						+ '<div class="' + item_class + '" data-input="' + item_input + '">'
							+ cnt_open
								+ item_icon + item_html
							+ cnt_close
						+ '</div>'
					+ a_href_close
				+ '</div>';

			return item_return;
		}

		var action = 'search_autocomplete_ajax';
		var input  = wpj_validate_input_content( $input.val() );

		var data = {
			'action': action,
			'input': input
		};

		$.post( wpj_vars.ajaxurl, data, function( response ) {

			var arr = JSON.parse( response );

			var items_html = '';
			if ( input != '' && input != ' ' ) {
				items_html += '<div class="autocomplete-list">';

				if(wpj_vars.allow_job == 'yes'){
					items_html += autocomplete_item_html( jobs_label, '', 'autocomplete-title' );
					if ( arr['jobs'].length ) {
						for ( var i = 0; i < arr['jobs'].length; i++ ) {
							items_html += autocomplete_item_html( arr['jobs'][i], arr['jobs'][i], 'autocomplete-search-jobs' );
						}
					} else {
						items_html += autocomplete_item_html( input, input, 'autocomplete-search-jobs' );
					}
				}

				if(wpj_vars.allow_request == 'yes'){
					items_html += autocomplete_item_html( requests_label, '', 'autocomplete-title' );
					if ( arr['requests'].length ) {
						for ( var i = 0; i < arr['requests'].length; i++ ) {
							items_html += autocomplete_item_html( arr['requests'][i], arr['requests'][i], 'autocomplete-search-requests' );
						}
					} else {
						items_html += autocomplete_item_html( input, input, 'autocomplete-search-requests' );
					}
				}

				if(wpj_vars.allow_users == 'yes'){
					items_html += autocomplete_item_html( users_label, '', 'autocomplete-title');
					items_html += autocomplete_item_html( search_users_label + input, input, 'autocomplete-search-users');
					if ( arr['users'].length ) {
						for ( var i = 0; i < arr['users'].length; i++ ) {
							if ( arr['companies'].length ) {
								items_html += autocomplete_item_html( arr['users'][i] + arr['companies'][i], arr['users'][i], 'autocomplete-user');
							} else {
								items_html += autocomplete_item_html( arr['users'][i], arr['users'][i], 'autocomplete-user');
							}
						}
					}
				}

				items_html += '</div>';
			}

			$container.find('.autocomplete-list-container').html( items_html );

			$container.find('.autocomplete-list-container .autocomplete-item').each( function() {
				$(this).find( '.autocomplete-text' ).highlight( input );
			});

			$container.removeClass('loading');

			jQuery( 'a.js-internal' ).off( 'click.js-internal' ).on( 'click.js-internal', function() {
				var obj = {
					isExternal    : false,
					isTargetBlank : jQuery( this ).attr( 'target' ) ? jQuery( this ).attr( 'target' ) === '_blank' : false,
					currentUrl    : window.location.href,
					nextUrl   : jQuery( this ).attr( 'href' )
				};
				window.parent.postMessage( {data: obj}, "*" );
			});
		});
	}

	// highlight jquery
	jQuery.extend({
		highlight: function (node, re, nodeName, className) {
			if (node.nodeType === 3) {
				var match = node.data.match(re);
				if (match) {
					var highlight = document.createElement(nodeName || 'span');
					highlight.className = className || 'highlight';
					var wordNode = node.splitText(match.index);
					wordNode.splitText(match[0].length);
					var wordClone = wordNode.cloneNode(true);
					highlight.appendChild(wordClone);
					wordNode.parentNode.replaceChild(highlight, wordNode);
					return 1; //skip added node in parent
				}
			} else if ((node.nodeType === 1 && node.childNodes) && // only element nodes that have children
					!/(script|style)/i.test(node.tagName) && // ignore script and style nodes
					!(node.tagName === nodeName.toUpperCase() && node.className === className)) { // skip if already highlighted
				for (var i = 0; i < node.childNodes.length; i++) {
					i += jQuery.highlight(node.childNodes[i], re, nodeName, className);
				}
			}
			return 0;
		}
	});

	jQuery.fn.unhighlight = function (options) {
		var settings = { className: 'highlight', element: 'span' };
		jQuery.extend(settings, options);

		return this.find(settings.element + "." + settings.className).each(function () {
			var parent = this.parentNode;
			parent.replaceChild(this.firstChild, this);
			parent.normalize();
		}).end();
	};

	jQuery.fn.highlight = function (words, options) {
		var settings = { className: 'highlight', element: 'span', caseSensitive: false, wordsOnly: false };
		jQuery.extend(settings, options);

		if (words.constructor === String) {
			words = [words];
		}
		words = jQuery.grep(words, function(word, i){
		return word != '';
		});
		words = jQuery.map(words, function(word, i) {
		return word.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
		});
		if (words.length == 0) { return this; };

		var flag = settings.caseSensitive ? "" : "i";
		var pattern = "(" + words.join("|") + ")";
		if (settings.wordsOnly) {
			pattern = "\\b" + pattern + "\\b";
		}
		var re = new RegExp(pattern, flag);

		return this.each(function () {
			jQuery.highlight(this, re, settings.element, settings.className);
		});
	};

	jQuery( '#big-search-submit' ).click( function( e ) {
		e.preventDefault();
		jQuery( this ).parents( 'form' ).trigger( 'submit' );
	});
});

function wpj_big_search_top() {

	function suggest( inputString ) {
		if ( inputString.length == 0 ) {
			jQuery( '#suggestions' ).fadeOut();
		} else {
			jQuery( '#big-search' ).addClass( 'load' );
			jQuery.post( "<?php echo get_admin_url(null, '/admin-ajax.php?action=autosuggest_it'); ?>", {queryString: ""+inputString+""}, function( data ) {
				if( data.length > 0 ) {
					var stringa = data.charAt( data.length - 1 );
					if ( stringa == '0' ) data = data.slice( 0, -1 );
					else data = data.slice( 0, -2 );
					jQuery( '#suggestions' ).fadeIn();
					jQuery( '#suggestionsList' ).html(data);
					jQuery( '#big-search' ).removeClass( 'load' );
				}
			});
		}
	}

	function fill( thisValue ) {
		jQuery( '#big-search' ).val( thisValue );
		setTimeout( "jQuery('#suggestions').fadeOut();", 600 );
	}

	jQuery( document ).ready( function() {
		jQuery( ".expnd_col" ).click( function() {
			var rels = jQuery( this ).attr( 'rel' );
			jQuery( "#term_submenu" + rels ).toggle();

			return false;
		});


		//Auto load script
		jQuery.fn.isOnScreen = function() {
			var win = jQuery( window );

			var viewport = {
				top : win.scrollTop(),
				left : win.scrollLeft()
			};

			viewport.right = viewport.left + win.width();
			viewport.bottom = viewport.top + win.height();

			var bounds = this.offset();
			bounds.right = bounds.left + this.outerWidth();
			bounds.bottom = bounds.top + this.outerHeight();

			return ( ! ( viewport.right < bounds.left || viewport.left > bounds.right || viewport.bottom < bounds.top || viewport.top > bounds.bottom ) );
		};

		if ( jQuery( '.auto-load' ).length ) {
			jQuery( window ).on( 'scroll', function() {
				if ( jQuery( '.auto-load' ).isOnScreen() === true ) {
					if ( ( jQuery( '.auto-load' ).css( 'display' ) != 'none' ) && ( ! jQuery( '.auto-load' ).hasClass( 'loading' ) ) ) {
						jQuery( "div.auto-load" ).trigger( "click" );
					}
				}
			});
		}
	});
}

jQuery( document ).ready( function( $ ) {

	// initialize top search
	if ( typeof wpj_big_search_top == 'function' ) { wpj_big_search_top(); }

	// modernizr library
	if ( typeof Modernizr !== 'undefined' ) {
		if ( Modernizr.touch ){
			$( 'body' ).addClass( 'touch' );
		} else {
			$( 'body' ).addClass( 'no-touch' );
		}
	}

	// disable mousewheel on a input number field when not in focus
	// (to prevent Cromium browsers change the value when scrolling)
	$( 'form' ).on( 'blur', 'input[type=number]', function ( e ) {
		$( this ).off( 'mousewheel.disableScroll' );
	});

	// iOS devices
	var ver = getIOSversion();
	if ( ver[0] >= 11 ) {
		$( "body" ).addClass( "ios11" );
	}

	// mobile iframe
	if ( inIframe() ) {
		jQuery( 'body' ).addClass( 'wpj-is-iframe' );
		jQuery( 'body' ).removeClass( 'wpj-maybe-iframe' );
		$.cookie( 'wpj_is_iframe', 'true', { expires: 7, path: '/' });
	} else {
		jQuery( 'body' ).removeClass( 'wpj-is-iframe' );
		jQuery( 'body' ).removeClass( 'wpj-maybe-iframe' );
		$.cookie( 'wpj_is_iframe', 'false', { expires: 7, path: '/' });
	}

	// get the real viewport height on mobile when the address bar or other bars are on
	// https://css-tricks.com/the-trick-to-viewport-units-on-mobile/
	let vh = window.innerHeight * 0.01;
	document.documentElement.style.setProperty('--vh', `${vh}px`);
	jQuery( window ).on( 'load resize', _.debounce( function() {
		let vh = window.innerHeight * 0.01;
		document.documentElement.style.setProperty('--vh', `${vh}px`);
	}, 200 ) );

	// brizy: stop login/register popup when editing
	if ( wpj_vars.is_user_logged_in && ( getUrlParameter( 'brizy-edit' ) || getUrlParameter( 'brizy-edit-iframe' ) ) ) {
		$( document ).off( 'click', '.login-link' );
		$( document ).off( 'click', '.register-link' );
	}

	// apply lazy loading to all site images
	if ( wpj_vars.lazy_loading_enabled == 1 && typeof wpj_enable_lazy_loading == 'function' ) {

		$( 'img' ).each( function() {

			if (
				! $( this ).hasClass( "brz-img" )
				&& ! $( this ).hasClass( "portfolio-image" )
				&& ! $( this ).hasClass( "rs-pzimg" )
				&& ! $( this ).hasClass( "rev-slidebg" )
				&& ! $( this ).parents( '.message-box-logo-container' )[0]
			) { // exclude brizy, featherlight (portofolio), revslider images

				$( this ).attr( 'data-echo', $( this ).attr( 'src' ) );
				$( this ).addClass( 'echo-lazy-load' );
				$( this ).attr( 'src', wpj_vars.theme_path + "/assets/images/blank.gif" );

			}

		});

		wpj_enable_lazy_loading();

	}

	// clear localstorage on logout
	$( document ).on( 'click', '.log-out', function() {
		localStorage.clear();
	});

	// accepts only numbers in numeric inputs
	$( 'input[type="number"]' ).on( 'keypress', function( e ) {

		var allowed_key_codes_arr = [/*backspace*/8,/*tab*/9,/*arrows*/37,39,/*numbers*/48,49,50,51,52,53,54,55,56,57,/*dot*/46,110,190]; // allowed keys

		// if event key is not in array and its not Ctrl+V (paste) return false
		if ( $.inArray( e.keyCode, allowed_key_codes_arr ) === -1 && ( e.keyCode != 17 && e.keyCode != 86 ) ) {
			e.preventDefault();

		// if float decimal exists and key is not backspace return false
		} else if ( $.trim( $( this ).val() ).indexOf( '.' ) > -1 && $.inArray( e.keyCode, [110, 190] ) != -1 ) {
			e.preventDefault();

		// return true
		} else {
			return true;

		}

	}).on( 'paste', function( e ) {

		// get event text and filter out letter characters
		var pasted_text = e.originalEvent.clipboardData.getData( 'Text' ).replace( /[^0-9.]/g, '' );

		if ( $.isNumeric( pasted_text ) ) {
			e.originalEvent.target.value = pasted_text;
			e.preventDefault();

		} else {
			e.preventDefault();

		};

	});

});
jQuery( document ).ready( function( $ ) {

	// Subscription front price update
	$( document ).on( 'change', 'input[name="sub_id"]', function( event ) {
		var sd_arr  = $( this ).val().split( '-' );
		var sub_typ = sd_arr[0];
		var sub_lvl = sd_arr[1];

		// Get price
		var sub_amt = $( this ).siblings( 'label[for=' + sub_typ + '-' + sub_lvl + ']' ).children( '.level-amount' ).html();
		if ( sub_amt ) { sub_amt = sub_amt.trim(); }

		// Remove class active from all levels
		$( '.level0, .level1, .level2, .level3' ).removeClass( 'active' );

		// Add active class to selected level
		$( '.' + sub_lvl ).addClass( 'active' ).html( sub_amt );

		// Add price to selected level
		$( '.subsc-total' ).html( sub_amt );
	});
});

jQuery( document ).ready( function( $ ) {

	function wpj_add_hash( hash ) {
		if ( history.pushState ) {
			history.pushState( null, null, hash );
		} else {
			location.hash = hash;
		}
	}

	// run only on post new job & request
	$.fn.pageLoadToolTip = function() {
		if ( jQuery( ".post-new-job-wrapper" )[0] ) {
			var data_handler_id = jQuery( '.post-new-job-wrapper' ).find( '.tab.active' ).find( '.js-tooltip-handler' ).attr( 'data-handler-id' );
			if ( data_handler_id && data_handler_id != 'cfield_' && data_handler_id != 'request_cfield_' ) {
				jQuery( '[data-handler-id="' + data_handler_id + '"]' ).mouseenter().mouseleave();
			}
		}
	}
	$.fn.pageLoadToolTip();

	// select correct tab from hash
	var tab_id = window.location.hash.replace("#step", "#tab");
	if ( tab_id ) {
		$('.js-tabs-wrapper .step.active').removeClass('active');
		$(tab_id).addClass('active');
		$('.js-tabs-wrapper .js-tab-wrapper .tab.active').removeClass('active');
		var this_tab = $($(".js-tabs-wrapper .js-tab-wrapper .tab").get( $(tab_id).index() ) );
		this_tab.addClass("active");
		$.fn.pageLoadToolTip();
	}

	// change tab when ckicking on tab header
	jQuery('.js-tabs-wrapper .step').on('click', function() {
		$('.js-tabs-wrapper .step.active').removeClass('active');
		$(this).addClass('active');
		$('.js-tabs-wrapper .js-tab-wrapper .tab.active').removeClass('active');
		var this_tab = $($('.js-tabs-wrapper .js-tab-wrapper .tab').get($(this).index()));
		this_tab.addClass('active');
		var hash = $(this).attr("id").replace("tab", "#step");
		wpj_add_hash( hash );
	});

	// change tab when clicking next
	jQuery('.post-new-job-wrapper .tab-controls a.right').click(function(e){
		e.preventDefault();
		$('.js-tabs-wrapper .js-tab-wrapper .tab.active').removeClass('active');
		var curent_tab = $( this ).parents( '.tab' ).index();
		$($('.js-tabs-wrapper .js-tab-wrapper .tab').get(curent_tab + 1)).addClass('active');
		$('.js-tabs-wrapper .step.active').removeClass('active');
		var this_tab = $($('.js-tabs-wrapper .step').get(curent_tab + 1));
		this_tab.addClass('active');
		var hash = this_tab.attr("id").replace("tab", "#step");
		wpj_add_hash( hash );
		$('html, body').animate({ scrollTop: $(".post-new-job-wrapper").offset().top - 108 }, 1000);
	});

	// change tab when clicking previous
	jQuery('.post-new-job-wrapper .tab-controls a.left').click(function(e){
		e.preventDefault();
		$('.js-tabs-wrapper .js-tab-wrapper .tab.active').removeClass('active');
		var curent_tab = $( this ).parents( '.tab' ).index();
		$($('.js-tabs-wrapper .js-tab-wrapper .tab').get(curent_tab - 1)).addClass('active');
		$('.js-tabs-wrapper .step.active').removeClass('active');
		var this_tab = $($('.js-tabs-wrapper .step').get(curent_tab - 1));
		this_tab.addClass('active');
		var hash = this_tab.attr("id").replace("tab", "#step");
		wpj_add_hash( hash );
		$('html, body').animate({ scrollTop: $(".post-new-job-wrapper").offset().top - 108 }, 1000);
	});

	// button tabs
	if ( typeof current_active === 'undefined' && $( '.item.force-white-btn.active' )[0] ) {
		var is_first = true;
		var current_active = $( '.item.force-white-btn.active' ).attr( 'data-tab' );
	}

	$( document ).on( 'click', '.item.force-white-btn', function() {

		var url_initial = window.location.pathname;

		if ( wpj_vars.homepage_slug ) {
			url_initial = wpj_vars.homepage_slug + '/';
		}

		if ( is_first && ! url_initial.includes( current_active ) ) {
			window.history.pushState( {}, document.title, url_initial + current_active );
		}

		var url_final = window.location.pathname;
		window.history.pushState( {}, document.title, url_final.replace( current_active, $( this ).attr( 'data-tab' ) ) );

		current_active = $( this ).attr( 'data-tab' );

		is_first = false;

		$( this ).parents( ".js-tab-to-dropdown" ).find( '.ui.dropdown' ).dropdown( 'set selected', $( '.item.force-white-btn.active' ).attr( 'data-tab' ) );

		if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
			jQuery.fn.echoLazyLoadRender();
		}
	});

	// browser navigation button pressed
	$( window ).on( 'popstate', function( event ) {
		var active_tab = window.location.pathname.match( /([^\/]*)\/*$/ )[1];

		$( '.ui.secondary.menu' ).find( '.item' ).tab( 'change tab', active_tab ); // pc tab
		$( '.js-tab-to-dropdown' ).find( '.ui.dropdown' ).dropdown( 'set selected', active_tab ); // mobile dropdown

		if ( typeof jQuery.fn.echoLazyLoadRender == 'function' ) {
			jQuery.fn.echoLazyLoadRender();
		}
	});

});

jQuery( document ).ready( function( $ ) {
	$( ".simple-radio[type=radio]" ).change( function() {
		$( '.error-wrapper' ).addClass( 'hidden' );
	});
});
function wpj_get_val( identificator ) {
	return wpj_validate_input_content( jQuery( identificator ).val() );
}

function wpj_item_has_value( item_name ) {
	var value = false;
	if ( item_name == "languages" ) {
		if ( wpj_get_val( ".up_language" ) && wpj_get_val( ".up_proficiency" ) ) { value = true; }
	} else if ( item_name == "skills" ) {
		if ( wpj_get_val( ".up_skills" ) ) { value = true; }
	}

	return value;
}

function wpj_get_html_for_inputs( $this, item_name, item_value ) {
	var content = "";

	if ( item_name == "languages" ) {
		content = '\
			<div class="new_item">\
				<div class="ui mini input new-item-content">\
					<input placeholder="' + wpj_vars.language_lbl + '" class="di up_language" type="text" name="language" />\
					&nbsp;\
					<input placeholder="' + wpj_vars.proficiency_lbl + '" class="di up_proficiency" type="text" name="proficiency" />\
				</div>\
			</div>\
		';
	} else if ( item_name == "skills" ) {
		content = '\
			<div class="new_item">\
				<input placeholder="' + wpj_vars.skill_lbl + '" class="up_skills" type="text" name="skill" />\
			</div>\
		';
	} else if ( item_name == "tagline" ) {
		content = "\
			<div class='tagline-temp'>\
				<div class='ui input'><input type='text' id='tmp_tagline' class='tmp_tagline' value='" + item_value + "' /></div>\
				<a data-type='tagline' class='save-info'>" + wpj_vars.save_lbl + "</a>\
			</div>\
		";
	} else if ( item_name == "description" ) {
		if ( item_value == null || item_value === false ) { item_value = ''; }
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			content = '<textarea class="tmp_description" id="tmp_description">' + item_value + '</textarea>\
				\
				<div id="tmp_description_toolbar" class="tmp_description-wysiwyg-toolbar">\
					<a data-wysihtml5-command="bold"><i class="bordered bold icon"></i></a>\
					<a data-wysihtml5-command="italic"><i class="bordered italic icon"></i></a>\
					<a data-wysihtml5-command="underline"><i class="bordered underline icon"></i></a>\
					<a data-wysihtml5-command="insertUnorderedList"><i class="bordered unordered list icon"></i></a>\
					<a data-wysihtml5-command="insertOrderedList"><i class="bordered ordered list icon"></i></a>\
				</div>\
			';
		} else {
			content = "<textarea id='tmp_description'>" + item_value + "</textarea>";
		}
	}

	jQuery( $this ).parents( '.user-' + item_name + '-wrapper' ).find( '.' + item_name + '-content' ).append( content );

};

function wpj_get_html_to_show( $this, item_name ) {

	var $ = jQuery.noConflict();

	var content = "";

	if ( item_name == "languages" ) {
		content = '\
			<span class="' + wpj_get_val( ".up_language" ) + '">\
				<input readonly type="text" class="inp_language not_editable di" value="' + wpj_get_val( ".up_language" ) + '" />\
				<input readonly type="text" class="inp_proficiency not_editable di" value="' + wpj_get_val( ".up_proficiency" ) + '" />\
				\
				<div class="right di">\
					<div class="di" data-inverted="" data-tooltip="' + wpj_vars.edit_lbl + '" data-position="top center">\
						<i data-type="' + item_name + '" class="user-edit-language edit icon" class="di"></i>\
					</div>\
					\
					<div class="di" data-inverted="" data-tooltip="' + wpj_vars.delete_lbl + '" data-position="top center">\
						<i data-type="' + item_name + '" class="user-remove-item red remove icon" class="di"></i>\
					</div>\
				</div>\
			</span>\
		';
	} else if ( item_name == "skills" ) {
		content = '\
			<span class="' + wpj_sanitize_title( wpj_get_val( ".up_skills" ) ) + '">' + $.trim( wpj_get_val( ".up_skills" ) ) + '\
				<div class="actions di">\
					<i data-type="' + item_name + '" class="user-remove-item red remove icon" class="di"></i>\
				</div>\
			</span>\
		';
	}

	jQuery( '.' + item_name + '-content' ).append( content );
}

function wpj_initialize_and_remove_textarea( action ) {

	var $ = jQuery.noConflict();

	if ( action == "initialize" ) {
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			wpj_js_description_args_allowed( parseInt( wpj_vars.user_chr_limit ), '', '', '', 'tmp_description' );
		} else {
			$( "#tmp_description" ).height( $( "#tmp_description" )[0].scrollHeight );
			$( "#tmp_description" ).focus();
		}
	} else if ( action == "remove" ) {
		if ( wpj_vars.wysiwyg_enabled == 'yes' ) {
			$( '#tmp_description' ).remove();
			$( '.wysihtml5-sandbox' ).remove();
			$( '#tmp_description_toolbar' ).remove();
		} else {
			$( '#tmp_description' ).remove();
		}
	} else {
		return false;
	}
}

function wpj_get_ajax_action( item_name ) {
	if ( item_name == "languages_new" ) {
		return "save_user_language_content";
	} else if ( item_name == "languages_remove" ) {
		return "remove_user_language_content";
	} else if ( item_name == "skills_new" ) {
		return "save_user_skill_content";
	} else if ( item_name == "skills_remove" ) {
		return "remove_user_skill_content";
	} else if ( item_name == "description_edit" ) {
		return "save_user_description_content";
	} else if ( item_name == "tagline_edit" ) {
		return "save_user_tagline_content";
	} else if ( item_name == "education_remove" ) {
		return "remove_user_education_content";
	} else if ( item_name == "certification_remove" ) {
		return "remove_user_certification_content";
	} else {
		return false;
	}
}

function wpj_get_ajax_data( item_name, item_value ) {
	var data = {};
	if ( item_name == "languages_new" ) {
		data = {
			action      : wpj_get_ajax_action( item_name ),
			language    : wpj_get_val( ".up_language" ),
			proficiency : wpj_get_val( ".up_proficiency" ),
			uid         : jQuery( '#user_id' ).text()
		};
	} else {
		data = {
			action : wpj_get_ajax_action( item_name ),
			item   : item_value,
			uid    : jQuery( '#user_id' ).text()
		};
	}

	return data;
}

function wpj_send_via_ajax( data ) {
	jQuery.ajax({
		type: "POST",
		url: wpj_vars.ajaxurl,
		data: data,
		success: function( data ) {}
	});
}

function wpj_up_open_modal( item_name, action_type, $this ) {

	var $ = jQuery.noConflict();

	if ( ! action_type ) { action_type = 'new'; }

	var $indx = $this.parents( '#' + item_name + '-item' ).attr( 'class' );

	$( '.up-' + item_name + '-modal-wrapper' )
		.modal({
			onApprove: function() { return false; },
			onDeny: function() { return false; }
		})
		.modal('setting', 'transition', 'fly down')
		.modal('show')
		.modal('refresh');

	jQuery.ajax({
		type: 'POST',
		url: wpj_vars.ajaxurl,
		data: {
			action: 'show_user_' + item_name + '_content',
			uid: $( '#user_id' ).text(),
			action_type: action_type,
			indx: $indx,
		},
		success: function( data ) {
			var item_action = action_type == 'new' ? wpj_vars.add_lbl : wpj_vars.edit_lbl;
			$( '.add-or-edit-title' ).html( item_action );

			$( '.up-' + item_name + '-modal-main-content' ).html( data );

			$( '.up-' + item_name + '-modal-wrapper' ).modal( 'refresh' );

			if ( action_type == 'new' ) {
				$( '.save-item' ).addClass( 'disabled' );
			}

			if ( $( ".user_from_year" ).val() ) {
				$( ".user_to_year" ).find( 'option' ).each( function() {
					if ( parseInt( $( ".user_from_year" ).val() ) && parseInt( $( this ).val() ) >= parseInt( $( ".user_from_year" ).val() ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});
			}

			if ( $( ".user_to_year" ).val() ) {
				$( ".user_from_year" ).find( 'option' ).each( function() {
					if ( parseInt( $( ".user_to_year" ).val() ) && parseInt( $( this ).val() ) <= parseInt( $( ".user_to_year" ).val() ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});
			}
		}
	});

	return false;
}

function strip_tags( val ) {
	if ( val ) {
		return val.replace( /<(.|\n)*?>/g, '' );
	} else {
		return val;
	}
}

jQuery( document ).ready( function( $ ) {

	// Switch between mobile and pc view
	$( window ).on( 'load resize', function() {
		var win = $( this );
		if ( win.width() > 767 ) {

			// User account table info
			$( '.ui.divided.list.user-account-list' ).addClass( 'relaxed' ).addClass( 'horizontal' );

		} else {

			// User account table info
			$( '.ui.divided.list.user-account-list' ).removeClass( 'relaxed' ).removeClass( 'horizontal' );

		}
	});

	// count info popup
	$( '.content-wrapper' ).popup({ on: 'hover' });

//--> START New Item
	var toggle_new_item = false;
	$( document ).on( "click", ".user-new-item", function( e ) {
		e.preventDefault();

		var $this = $( this );
		var item_name = $( this ).data( 'type' );

		if ( item_name == 'education' || item_name == 'certification' ) {
			wpj_up_open_modal( item_name, 'new', $this );
		} else {

			/* EDIT */ if ( ! toggle_new_item ) { toggle_new_item = true;

				// Change the label to "Save";
				$( this ).text( wpj_vars.save_lbl );

				// Append inputs to complete the content
				wpj_get_html_for_inputs( $this, item_name );

			/* SAVE */ } else { toggle_new_item = false;

				// Get values
				var val = wpj_item_has_value( item_name );

				if ( val && ! $( 'span' ).hasClass( wpj_sanitize_title( wpj_get_val( ".up_" + item_name ) ) ) ) {

					// Show the new content in fron-end
					wpj_get_html_to_show( $this, item_name );

					// Save the data to user_meta
					wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_new", wpj_get_val( ".up_" + item_name ) ) );

					// Remove "no item" paragraph
					$( '.' + item_name + '-content' ).children( '.no_item' ).remove();

				}

				// Change the label to "Add New";
				$( this ).text( wpj_vars.add_new_lbl );

				// Remove editable content
				$( ".new_item" ).remove();
			}

		}
	});
//--> END New Item

//--> START Edit Item
	var toggle_edit_item = false;
	var click_count = 0;
	$( document ).on( "click", ".user-edit-item", function( event, item_name ) { click_count++;
		event.preventDefault();

		var $this = $( this );

		if ( event.originalEvent !== undefined ) { // is clicked
			item_name = $( this ).data( 'type' );
		} else { // is triggered
			toggle_edit_item = true;
		}

		if ( item_name == 'education' || item_name == 'certification' ) {
			wpj_up_open_modal( item_name, 'edit', $this );
		} else {

			/* EDIT */ if ( ! toggle_edit_item ) { if ( item_name != "tagline" ) { toggle_edit_item = true; }
				// Change the label to "Save Description";
				if ( item_name == "description" ) { $( this ).text( wpj_vars.save_lbl ); }

				// Hide paragraph description until edit is done
				if ( item_name == "tagline" ) {
					$( this ).hide();
				} else {
					$( this ).siblings( '.' + item_name + '-content' ).find( '.' + item_name ).hide();
				}

				// Append inputs to complete the content
				if ( item_name == "description" ) {
					var value = wpj_vars.desc_content;
					if ( click_count > 1 ) {
						var value = wpj_vars.wysiwyg_enabled == 'yes' ? $( '.description-content' ).html() : $( '.description-content' ).text();
						if ( value.includes( "no_item" ) ) {
							value = '';
						}
					}
				} else if ( item_name == "tagline" ) {
					var value = $( this ).attr( 'class' ).includes( "no_item" ) ? '' : $( this ).text();
				}

				// Show editable content
				wpj_get_html_for_inputs( $this, item_name, value );

				// Set Focus
				$( '#tmp_' + item_name ).focus();

				// Initialize Textarea
				if ( item_name == "description" ) { wpj_initialize_and_remove_textarea( "initialize" ); }

			/* SAVE */ } else { toggle_edit_item = false;

				// Change the label to "Edit Description";
				if ( item_name == "description" ) { $( this ).text( wpj_vars.edit_desc_lbl ); }

				// Show paragraph
				if ( item_name == "description" ) {
					if ( strip_tags( $( '.tmp_' + item_name ).val() ) == '' ) {
						$( '.user-description-wrapper' ).find( '.description-content' ).find( '.' + item_name ).html( '<p class="no_item">' + wpj_vars.no_description + '</p>' ).show();
					} else {
						$( '.user-description-wrapper' ).find( '.description-content' ).find( '.' + item_name ).html( $( '.tmp_' + item_name ).val() ).show();
					}
				} else {
					$( '.' + item_name ).html( wpj_validate_input_content( $( '.tmp_' + item_name ).val() ) ).show();
				}

				// Lost Focus
				$( '#tmp_' + item_name ).blur();

				// Save the data to user_meta
				wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_edit", $( '#tmp_' + item_name ).val() ) );

				// Remove editable content
				if ( item_name == "description" ) {
					wpj_initialize_and_remove_textarea( "remove" );
				}
			}
		}
	});
//--> END Edit Item

//--> START Remove Item
	$( document ).on( "click", ".user-remove-item", function( e ) {
			e.preventDefault();

			var item_name = $( this ).data( 'type' );

			// Remove in front-end
			$( this ).parents( 'span' ).remove();

			// Insert no item text if items list is empty
			if ( $( '.' + item_name + '-content > span' ).length == 0 ) {
				var message = '';
				if ( item_name == "languages" ) {
					message = wpj_vars.no_languages;
				} else if ( item_name == "skills" ) {
					message = wpj_vars.no_skills;
				} else if ( item_name == "education" ) {
					message = wpj_vars.no_educations;
				} else if ( item_name == "certification" ) {
					message = wpj_vars.no_certifications;
				}
				$( '.' + item_name + '-content' ).append( '<p class="no_item">' + message + '</p>' );
			}

			// Save the data to user_meta
			var item_to_be_removed = item_name == "skills" ? $( this ).parents( "span" ).text() : $( this ).parents( "span" ).attr( "class" );
			wpj_send_via_ajax( wpj_get_ajax_data( item_name + "_remove", wpj_validate_input_content( item_to_be_removed ) ) );

		});
//--> END Remove Item

//--> START Edit User Languages
	var toggle_edit_language = false;
	$( document ).on( "click", ".user-edit-language", function( e ) {
		e.preventDefault();

		var item_name = $( this ).data( 'type' );

		/* EDIT */ if ( !toggle_edit_language ) { toggle_edit_language = true;

			// Current SPAN
			var this_span = $( this ).parents( "span" );

			// Reset divs to store the value before edit
			$( '.old_language, .old_proficiency' ).remove();

			// Make the content editable
			this_span.find( ".inp_language, .inp_proficiency" ).removeClass( "not_editable" );
			this_span.find( ".inp_language, .inp_proficiency" ).attr( "readonly", false );

			// Remove "edit" class and add "save" class
			this_span.find( ".user-edit-language" ).removeClass( "edit" ).addClass( "save" );
			this_span.find( ".user-edit-language" ).parent().attr( "data-tooltip", wpj_vars.save_lbl );

			// Store the value before edit
			var old_content = '\
				<div class="old_language" style="display:none">' + this_span.find( ".inp_language" ).val() + '</div>\
				<div class="old_proficiency" style="display:none">' + this_span.find( ".inp_proficiency" ).val() + '</div>\
			';
			$( old_content ).insertAfter( this_span.find( ".inp_proficiency" ) );

		/* SAVE */ } else { toggle_edit_language = false;

			// Current SPAN
			var this_span = $( this ).parents( "span" );

			// Transform the content to paragraph
			this_span.find( ".inp_language, .inp_proficiency" ).addClass( "not_editable" );
			this_span.find( ".inp_language, .inp_proficiency" ).attr( "readonly", true );

			// Remove "save" class and add "edit" class
			this_span.find( ".user-edit-language" ).removeClass( 'save' ).addClass( 'edit' );
			this_span.find( ".user-edit-language" ).parent().attr( "data-tooltip", wpj_vars.edit_lbl );

			// Save the content
			var data = {
				action          : 'change_user_language_content',
				old_language    : this_span.find( ".old_language" ).html(),
				language        : wpj_validate_input_content( this_span.find( ".inp_language" ).val() ),
				old_proficiency : this_span.find( ".old_proficiency" ).html(),
				proficiency     : wpj_validate_input_content( this_span.find( ".inp_proficiency" ).val() ),
				uid             : $( '#user_id' ).text(),
			};
			wpj_send_via_ajax( data );

		}
	});
//--> END Edit User Languages

//--> START User Tagline
	$( document ).on( "click", ".save-info", function( e ) {
		e.preventDefault();

		var tagline_value = wpj_validate_input_content( $( ".tmp_tagline" ).val() );
		if ( ! tagline_value ) {
			tagline_value = wpj_vars.no_tagline;
			$( this ).parents( '.user-tagline-wrapper' ).find( '.tagline' ).addClass( 'no_item' );
		} else {
			$( this ).parents( '.user-tagline-wrapper' ).find( '.tagline' ).removeClass( 'no_item' );
		}

		$( ".tagline" ).html( tagline_value ).show();

		wpj_send_via_ajax( wpj_get_ajax_data( "tagline_edit", wpj_validate_input_content( $( "#tmp_tagline" ).val() ) ) );

		$( ".tagline-temp" ).remove();
	});
//--> END User Tagline

//--> START User Education & Certification
	var classes = [ "user_from_year", "user_to_year" ];

	classes.forEach( function( class_name ) {
		$( document ).on( 'change', '.' + class_name, function() {
			var this_val = wpj_validate_input_content( $( this ).val() );

			if ( class_name.includes( "to" ) ) {

				$( ".user_from_year" ).find( 'option' ).each( function() {
					if ( parseInt( this_val ) && parseInt( $( this ).val() ) <= parseInt( this_val ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});

			} else {

				$( ".user_to_year" ).find( 'option' ).each( function() {
					if ( parseInt( this_val ) && parseInt( $( this ).val() ) >= parseInt( this_val ) ) {
						$( this ).attr( "disabled", false );
					} else {
						$( this ).attr( "disabled", true );
					}
				});

			}
		});
	});

	$( document ).on( 'submit', '.modal_form', function( event ) {
		event.preventDefault();

		var item_name = $( this ).data( 'type' );

		$( '.modal_form .actions .button' ).addClass( 'loading' );

		jQuery.ajax({
			type : "POST",
			url  : wpj_vars.ajaxurl,
			data : "action=save_user_" + item_name + "_content&" + $( this ).serialize(),
			success: function( msg ) {
				$( '.ui.modal.up-' + item_name + '-modal-wrapper' ).modal( 'hide' );
				location.reload();
			}
		});

	});

	$( document ).on( 'change', 'input[name="user_school"], input[name="user_certification_name"]', function( event ) {
		if ( $( this ).val().length !== 0 ) {
			$( '.save-item' ).removeClass( 'disabled' );
		} else {
			$( '.save-item' ).addClass( 'disabled' );
		}
	});

	$( document ).on( 'change', '.certification-not-expire, .user_to_year, .user_to_month', function( event ) {
		if ( $( this ).attr( 'class' ) == 'certification-not-expire' ) {
			$( '.user_to_year' ).val( '' );
			$( '.user_to_month' ).val( '' );
		} else {
			$( '.certification-not-expire' ).prop( 'checked', false );
		}
	});

//--> END User Education & Certification

//--> START User Portfolio
	$( document ).on( "click", ".js-toggle-portfolio-handler", function( e ) {
		e.preventDefault();

		$(this).parent().children(".js-profile-portfolio-carousel").hide();
		$(this).hide();

		$(this).parent().children(".js-profile-portfolio-uploader").show();
		$(this).parent().children(".js-refresh-portfolio-handler").show();
	});

	$( document ).on( "click", ".js-refresh-portfolio-handler", function( e ) {
		e.preventDefault();
		location.reload();
	});
//--> END User Portfolio

//--> START User Search
	$( '#searchInp, #locationInp, #radiusInp' ).on( 'keyup keydown keypress blur change', function() {
		var strName        = '';
		var strLocation    = '';
		var strLocationRad = '';
		var strLong        = '';
		var strLat         = '';
		var params         = '';

		if ( $( '#searchInp' ).length !== 0 ) {
			strName = wpj_validate_input_content( $( '#searchInp' ).val() );
			strName = strName.replace( /\s+/g, '-' ).toLowerCase();
			params  = params + '&user=' + strName;
		}

		if ( $( '#locationInp' ).length !== 0 ) {
			strLocation = wpj_validate_input_content( $( '#locationInp' ).val() );
			strLocation = strLocation.replace( /\s+/g, '-' ).toLowerCase();
			params      = params + '&location=' + strLocation;

			strLong     = wpj_validate_input_content( $( '#user_long' ).val() );
			params      = params + '&long=' + strLong;

			strLat      = wpj_validate_input_content( $( '#user_lat' ).val() );
			params      = params + '&lat=' + strLat;
		}

		if ( $( '#radiusInp' ).length !==0 ) {
			strLocationRad = wpj_validate_input_content( $( '#radiusInp' ).val() );
			strLocationRad = strLocationRad.replace( /\s+/g, '-' ).toLowerCase();
			params         = params + '&location_rad=' + strLocationRad;
		}

		if ( params != '' ) {
			params = '?' + params.substring( 1 );
		}

		$( '.searchUsername' ).addClass( 'loading' );

		history.pushState( null, "page 2", wpj_vars.page_url + params );
	});

	if ( $( '#searchInp' ).length > 0 ) {

		var user            = wpj_validate_input_content( $( "#searchInp" ).val() );
		var limitInp        = wpj_vars.posts_per_page;
		var initialLimitInp = wpj_vars.posts_per_page;

		doneTyping();

		var typingTimer;
		var doneTypingInterval = 500;
		var $input = $( '#searchInp, #locationInp, #radiusInp' );

		$input.on( 'keyup keydown keypress blur change', function () {
			clearTimeout( typingTimer );
			typingTimer = setTimeout( doneTyping, doneTypingInterval );
		});

		$input.on( 'keydown', function () {
			clearTimeout( typingTimer );
			$( '.wpj-search-user-load-more' ).show();
			$( '.wpj-search-user-load-more' ).parent().parent().addClass( 'mb150' );
			$( '.wpj-search-user-load-more' ).parent().addClass( 'pr' );

			limitInp = wpj_vars.posts_per_page;
		});

		$( ".wpj-search-user-load-more" ).click( function() {
			$( this ).addClass( 'loading' );
			initialLimitInp = Number( initialLimitInp ) + Number( wpj_vars.posts_per_page );
			limitInp = initialLimitInp;
			doneTyping();
		});
	}

	function doneTyping () {
		var searchInp   = wpj_validate_input_content( $( '#searchInp' ).val() );
		var locationInp = wpj_validate_input_content( $( '#locationInp' ).val() );
		var radiusInp   = wpj_validate_input_content( $( '#radiusInp' ).val() );
		var longInp     = wpj_validate_input_content( $( '#user_long' ).val() );
		var latInp      = wpj_validate_input_content( $( '#user_lat' ).val() );

		$.post( wpj_vars.ajaxurl, {
			action     : 'search_users_ajax',
			searchInp  : searchInp,
			limitInp   : limitInp,
			locationInp: locationInp,
			radiusInp  : radiusInp,
			longInp    : longInp,
			latInp     : latInp,
		},
		function( data ) {
			obj = JSON.parse( data );

			$( ".wpj-search-user-load-more" ).removeClass( 'loading' );

			if ( typeof( obj['usersInfo'][0] ) != "undefined" && obj['usersInfo'][0] !== null ) {
				if ( obj['usersInfo'][0].queryresults < obj['usersInfo'][0].limit ) {
					$( '.wpj-search-user-load-more' ).hide();
					$( '.wpj-search-user-load-more' ).parent().parent().removeClass( 'mb150' );
					$( '.wpj-search-user-load-more' ).parent().removeClass( 'pr' );
				} else {
					$( '.wpj-search-user-load-more' ).show();
					$( '.wpj-search-user-load-more' ).parent().parent().addClass( 'mb150' );
					$( '.wpj-search-user-load-more' ).parent().addClass( 'pr' );
				}
			} else {
				$( '.wpj-search-user-load-more' ).hide();
				$( '.wpj-search-user-load-more' ).parent().parent().removeClass( 'mb150' );
				$( '.wpj-search-user-load-more' ).parent().removeClass( 'pr' );
			}

			$( '.searchUsername' ).removeClass( 'loading' );

			$( '#userInformations' ).empty();

			if ( obj['usersInfo'].length ) {
				$.each( obj['usersInfo'] , function( index, obj ) {
					if( obj.description ) {
						var desc = '<div class="userDescription">' + obj.description + '</div>';
					} else {
						var desc = '';
					}

					if ( obj.current_user ) {
						var login_class = '';
					} else {
						var login_class = 'login-link';
					}

					if ( obj.contact_url ) {
						var contact_button = '<a onclick="return wpj_chat_open_box( ' + obj.id + ' );" class="ui fluid button ' + login_class + '" href="' + obj.contact_url + '">' + wpj_vars.contact + '</a>';
					} else {
						var contact_button = '<span class="ui fluid button disabled" href="#">' + wpj_vars.contact + '</span>';
					}

					if ( obj.company ) {
						var company = ' <span class="user-company">(' + obj.company + ')</span>';
					} else {
						var company = '';
					}

					$( '#userInformations' ).append(
						'<div class="ui segment">\
							<div class="ui three column middle aligned stackable grid">\
								<div class="two wide column">\
									<div class="userImage">\
										<img width="100" height="100" border="0" class="user_img round-avatar" src="' + obj.avatar + '" />' + obj.level_icon + '\
									</div>\
								</div>\
								<div class="eleven wide column">\
									<div class="userDetails">\
										<h2 class="userName di"><a href="' + obj.addr + '">' + obj.username + company + '</a></h2>\
										' + obj.user_icons + desc + '\
										<div class="userExtraDetails">\
											<span class="userRating"><span class="labelDesc">' + wpj_vars.rating + '</span> ' + obj.rating + '</span>\
											<span class="userCompletedOrders"><span class="labelDesc">' + wpj_vars.completed_jobs + '</span> ' + obj.com_jb + '</span>\
											<span class="userCompany"><span class="labelDesc">' + wpj_vars.registered + '</span>  ' + obj.joined + '</span>\
										</div>\
									</div>\
								</div>\
								<div class="three wide column">\
									<div class="userContact">' + Hooks.apply_filters( 'wpj_user_search_action_buttons_filter', contact_button, { uid : obj.id, username : obj.username } ) + '</div>\
								</div>\
							</div>\
						</div>'
					);
				});
			} else {
				$( '#userInformations' ).append( '<div class="no-results">' + wpj_vars.nothing_found + '</div>' );
			}

		});
	}
//--> END User Search

//--> START User Settings Validation
	var fields_arr = {
		current_password: {
			identifier  : 'current_password',
			rules: [{
				type   : 'empty',
				prompt: wpj_vars.old_wrong_password,
			}]
		},
		new_password: {
			identifier  : 'password',
			rules: [{
				type   : 'empty',
				prompt : wpj_vars.blank_password,
			}]
		},
		repeat_password: {
			identifier  : 'repeat_password',
			rules: [{
				type   : 'empty',
				prompt: wpj_vars.repeat_password,
			}]
		},
		new_password_match: {
			identifier  : 'repeat_password',
			rules: [{
				type   : 'match[password]',
				prompt: wpj_vars.password_not_match,
			}]
		},
	};

	fields_arr = Hooks.apply_filters( 'wpj_fields_validation_filter', fields_arr, 'user-profile' );

	jQuery( '.ui.form.edit-profile' ).form({
		on: 'blur',
		keyboardShortcuts: false,
		fields: fields_arr
	});
//--> END User Settings Validation

	var lmt = new Date();
	last_move_time = lmt.getTime();

	jQuery( document ).mousemove( function(){
		var cmt = new Date();
		current_move_time = cmt.getTime();

		if ( ( current_move_time - last_move_time ) > 60000 ) {
			$.ajax({
				method : "POST",
				url    : wpj_vars.light_ajax_url,
				data   : { 'action': 'update_user_meta_for_user_online_status_action' },
				success: function ( data ) {}
			});
			last_move_time = cmt.getTime();
		}
	});

}); //<!-- END jQuery document ready

//---------------------------------------
// Vacation Mode
//---------------------------------------
jQuery( function( $ ) {

	$( document ).on( 'click', '#vacation_mode_toggle_ui', function() {
		$( '#vacation_mode_modal_ui' ).modal({
			onVisible: function(){
				$.fn.wpjCalendarInit();
			},
			onHide : function(){
				$( '#vacation_mode_toggle_ui' ).checkbox( 'toggle' );
			},
			autofocus: false,
			transition: 'fly down',
			observeChanges: true
		})
		.modal( 'show' )
		.modal( 'refresh' )
		;
	});

	// HELPERS
	$( document ).on( 'click', '.message .close', function( event ) {
		$( this )
			.closest( '.message' )
			.transition( 'fade' )
		;
	});

	function dismissableMessage( type, title, content ) {
		return '<div class="ui ' + type + ' message"><i class="close icon"></i><div class="header">' + title + '</div><p>' + content + '</p></div>';
	}

	function vacationModalRefresh() {
		jQuery.ajax({
			type : 'post',
			url : wpj_vars.ajaxurl,
			data : {
				action: 'wpj_vacation_mode_content',
				_ajax_nonce: wpj_vars._ajax_nonce
			},
			beforeSend: function() {
				$( '#vacation_modal_refresh' ).addClass( 'loading' );
			},
			success: function( response ) {
				$( '#vacation_mode_modal_ui' ).html( response );
				$( '.ui.dropdown' ).dropdown( { message: { noResults: wpj_vars.nothing_found } } );
			},
			error: function( response ) {
				$( '#vacation_mode_modal_ui .content' ).html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_something_wrong ) );
				$( '#vacation_mode_modal_ui .actions' ).html( '<div class="ui green labeled icon button" id="vacation_modal_refresh">' + wpj_vars.err_try_again + '<i class="refresh icon"></i></div>' );
			},
			complete: function() {
				$( '#vacation_modal_refresh' ).removeClass( 'loading' );
			}
		});
	}

	// AJAX REFRESH
	$( document ).on( 'click', '#vacation_modal_refresh', function( event ) {
		vacationModalRefresh();
		return false;
	});

	// AJAX YES
	$( document ).on( 'click', '#vacation_mode_yes', function( event ) {
		event.preventDefault();
		var $button       = $( this );
		var $modal_cnt    = $( '#vacation_mode_modal_ui' );
		var $messages_cnt = $( '#vacation_mode_modal_ui .content .messages' );

		var away_reason          = wpj_validate_input_content( $( "#wpjobster_vacation_away_reason" ).val() );
		var start_date           = $( "#wpjobster_vacation_duration_start" ).val();
		var start_date_timestamp = $( "#wpjobster_vacation_duration_start" ).attr( 'data-timestamp' );
		var end_date             = $( "#wpjobster_vacation_duration_end" ).val();
		var end_date_timestamp   = $( "#wpjobster_vacation_duration_end" ).attr( 'data-timestamp' );

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action              : 'wpj_vacation_mode_activate',
				_ajax_nonce         : wpj_vars._ajax_nonce,
				away_reason         : away_reason,
				start_date          : start_date,
				start_date_timestamp: start_date_timestamp,
				end_date            : end_date,
				end_date_timestamp  : end_date_timestamp
			},
			beforeSend: function() {
				$button.addClass( 'loading' );
			},
			success: function( response ) {

				if ( response == 'success' ) {
					$messages_cnt.html( dismissableMessage( 'success', wpj_vars.success, wpj_vars.success_saved ) );

					$modal_cnt
					.modal({
						transition: 'fly down',
					})
					.delay( 1000 )
					.queue( function() {
						$( this ).modal( 'hide' ).dequeue();
						vacationModalRefresh();
					});

				} else if ( response == 'err_already_in_vacation' ) {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_already_in_vacation ) );

				} else if ( response == 'err_empty_start_date' ) {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_empty_start_date ) );

				} else if ( response == 'err_small_start_date' ) {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_small_start_date ) );

				} else if ( response == 'err_empty_end_date' ) {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_empty_end_date ) );

				} else if ( response == 'err_small_end_date' ) {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err, wpj_vars.err_small_end_date ) );

				} else {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err_unknown, wpj_vars.err_try_again_later ) );
				}
			},
			error: function( response ) {
				$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err_unknown, wpj_vars.err_try_again_later ) );
			},
			complete: function() {
				$button.removeClass( 'loading' );
			}
		});

		return false;
	});

	// AJAX NO
	$( document ).on( 'click', '#vacation_mode_no', function( event ) {
		event.preventDefault();
		var $button       = $( this );
		var $modal_cnt    = $( '#vacation_mode_modal_ui' );
		var $messages_cnt = $( '#vacation_mode_modal_ui .content .messages' );

		jQuery.ajax({
			type : 'post',
			url  : wpj_vars.ajaxurl,
			data : {
				action      : 'wpj_vacation_mode_deactivate',
				_ajax_nonce : wpj_vars._ajax_nonce
			},
			beforeSend: function() {
				$button.addClass( 'loading' );
			},
			success: function( response ) {

				if ( response == 'success' ) {
					$messages_cnt.html( dismissableMessage( 'success', wpj_vars.success, wpj_vars.success_saved ) );

					$modal_cnt
					.modal({
						transition: 'fly down',
					})
					.delay( 1000 )
					.queue( function() {
						$( this ).modal( 'hide' ).dequeue();
						vacationModalRefresh();
					});
				} else {
					$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err_unknown, wpj_vars.err_try_again_later ) );
				}
			},
			error: function( response ) {
				$messages_cnt.html( dismissableMessage( 'error', wpj_vars.err_unknown, wpj_vars.err_try_again_later ) );
			},
			complete: function() {
				$button.removeClass( 'loading' );
			}
		});

		return false;
	});
});

jQuery( function( $ ) {

	// Open modal
	$( document ).on( 'click', '.report-link', function( e ) { e.preventDefault();
		var id = $( this ).attr( 'data-id' );
		$( '.ui.modal.report-modal.' + id ).modal( 'setting', 'transition', 'fly down' ).modal( 'show' ).modal( 'refresh' );
		$( ".report-error-wrapper" ).html( '' );
	});

	// Send report
	$( document ).on( 'click', '.report-submit', function( e ) { e.preventDefault();
		var $this = $( this );

		$.ajax({
			data: $( this ).parents( 'form' ).serialize(),
			type: "POST",
			dataType : 'json',
			url : wpj_vars.ajaxurl,
			success: function( msg ) {

				if ( msg.err == '1' ) {

					$( ".report-error-wrapper" ).html( '<div class="ui negative visible message"><p>' + msg.msg + '</p></div><div class="ui hidden divider"></div>' );

				} else {

					$( ".report-error-wrapper" ).html( '<div class="ui positive visible message"><p>' + msg.msg + '</p></div><div class="ui hidden divider"></div>' );
					setTimeout( function() {
						$this.parents( '.ui.modal' ).modal( 'hide' );
					}, 1000 );

				}

			}
		});
	});

	// Close modal
	$( document ).on( 'click', '.report-close', function( e ) { e.preventDefault();
		$( this ).parents( '.ui.modal' ).modal( 'hide' );
	});

});
jQuery( document ).ready(function( $ ) {

	/* Accept order */
	jQuery( document ).on( 'click', 'a.accept_order', function() {

		var $this =  $( this );

		$this.addClass( 'loading' ).addClass( 'disabled' );

		jQuery.ajax({
			type: "POST",
			url : wpj_vars.ajaxurl,
			data: {
				action: 'accept_order',
				oid: oid
			},
			success: function( msg ) {
				$this.removeClass( 'loading' ).removeClass( 'disabled' );

				if ( wpj_vars.live_notify == 'yes' ) {
					initLiveNotifications();
				} else {
					location.reload();
				}
			}
		});
	});

	/* Deny order */
	jQuery( document ).on( 'click', 'a.deny_order', function() {

		var $this =  $( this );

		$this.addClass( 'loading' ).addClass( 'disabled' );

		jQuery.ajax({
			type: "POST",
			url : wpj_vars.ajaxurl,
			data: {
				action: 'deny_order',
				oid: oid
			},
			success: function( msg ) {
				$this.removeClass( 'loading' ).removeClass( 'disabled' );

				if ( wpj_vars.live_notify == 'yes' ) {
					initLiveNotifications();
				} else {
					location.reload();
				}
			}
		});
	});

});